      program MAIN
** This program computes partial atomic charges of a molecule according to the
** method of J. Gasteiger and M. Marsili, Tetrahedron 36 (1980), 3219-3288
** Version 12.02.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      parameter(NT=32)
      real CHI(NUMATM), CHIP(NUMATM)
      real AIV(0:NT), BIV(0:NT), CIV(0:NT)
      real PAR(NUCLUS+1+NUSUB/6,6),ROTC(NUCLUS,3),STEP(12)
      integer I,J, ITYPE(NUMATM), ISP, ISTP(12), NP
      integer ILOOP,ILOOP1,ILOOP2
      character FNAME*40, POTFIL*40, ATTYPE(NUMATM)*8, TYPE(NT)*8
      character SEQ*3
      logical CONT, FOUND, EX
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      INTEGER IBO(0:6,NUMATM),ATNO,FN
      COMMON /BOND/ IBO
      CHARACTER PERIOD(100)*2
      COMMON /PERIOD/ PERIOD
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL
** subroutines:
** RDATM
** RDTAB
** BONDMA
** FRACRT
************************************************************************
      FN=1
      CONT=.false.
      IDUM=1
      ILOOP=100
      write(*,*) 'PROGRAM GASTEIGER, Version February 12, 1997'
      write(*,*)
      FNAME=' '
      open(unit=7,file='gast.inp',err=970,status='old')
      read(7,'(a)') FNAME
      close(unit=7)
    5 continue
      IFN=index(FNAME,' ')
      if(IFN.eq.0) IFN=41
      open(unit=1,file=FNAME(:IFN-1)//'.inp',err=975,status='old')
      open(unit=2,file=FNAME(:IFN-1)//'.in2',err=980,status='unknown')
      rewind(unit=2)
      print*,'reading input file ...'
      call RDATM(FN,METHOD,PAR,NP,POTFIL,ROTC,
     $   CONT,IEND,STEP,ISTP,IDUM,ILOOP1,ILOOP2,INLOOP,IANALY,ISP)
      if(ILOOP.gt.ILOOP2) ILOOP=ILOOP+1
      print*,'finding bonds ...'
      call BONDMA
      do 110 I=1,NATM1
	Q(I)=0.0
	CHI(I)=0.0
	CHIP(I)=0.0
	IB=IBO(0,I)
	if(ATNO(ATNAME(I)).eq.6.and.IB.eq.2) ATTYPE(I)='C1'
	if(ATNO(ATNAME(I)).eq.6.and.IB.eq.3) ATTYPE(I)='C2'
	if(ATNO(ATNAME(I)).eq.6.and.IB.eq.4) ATTYPE(I)='C3'
	if(ATNO(ATNAME(I)).eq.7.and.IB.eq.1) ATTYPE(I)='N1'
	if(ATNO(ATNAME(I)).eq.7.and.IB.eq.2) ATTYPE(I)='N2'
	if(ATNO(ATNAME(I)).eq.7.and.IB.eq.3) ATTYPE(I)='N3'
	if(ATNO(ATNAME(I)).eq.8.and.IB.eq.1) ATTYPE(I)='O2'
	if(ATNO(ATNAME(I)).eq.8.and.IB.eq.2) ATTYPE(I)='O3'
	if(ATNO(ATNAME(I)).ne.6.and.ATNO(ATNAME(I)).ne.7
     $                         .and.ATNO(ATNAME(I)).ne.8) then
	  ATTYPE(I)=PERIOD(ATNO(ATNAME(I)))
	end if
  110 continue
      print*,'reading table'
      call RDTAB(AIV,BIV,CIV,TYPE,NTYP)
      do 130 I=1,NATM1
	FOUND=.false.
	do 120 J=1,NTYP
	  if(ATTYPE(I).eq.TYPE(J)) then
	    ITYPE(I)=J
	    FOUND=.true.
	  end if
  120   continue
	if(.not.FOUND) then
	  print*,'WARNING - atom type of ',ATNAME(I),' not found'
	  ITYPE(I)=0
	end if
  130 continue
      do 200 IALP=1,5
	do 170 I=1,NATM1
	  do 160 J=1,NTYP
	    CHI(I)=AIV(ITYPE(I))+BIV(ITYPE(I))*Q(I)+
     $             CIV(ITYPE(I))*Q(I)**2
	    CHIP(I)=AIV(ITYPE(I))+BIV(ITYPE(I))+CIV(ITYPE(I))
  160     continue
  170   continue
	do 190 I=1,NATM1
	  DQ=0.0
	  do 180 J=1,IBO(0,I)
	    JN=IBO(J,I)
	    if(CHI(JN).gt.CHI(I)) then
	      DQ=DQ+(CHI(JN)-CHI(I))/CHIP(I)
	    else
	      DQ=DQ+(CHI(JN)-CHI(I))/CHIP(JN)
	    end if
  180     continue
	  DQ=DQ*(0.5**IALP)
	  Q(I)=Q(I)+DQ
	  write(*,'(1x,a8,f8.2)') ATNAME(I),Q(I)
  190   continue
  200 continue
      close(FN)
  205 continue
      call OUTPT2(2,METHOD,STEP,ISTP,ILOOP,F,ROTC,IDUM)
      write(*,'(1x,2a)') 'Output written to ',FNAME(:IFN-1)//'.in2'
      close(2)
      goto 9999
  970 continue
      inquire(file='gast.inp',exist=EX,sequential=SEQ,err=9999)
      if(.not.EX) print*,'ERROR - File gast.inp does not exist.'
      if(SEQ.eq.'NO') print*,'ERROR - File gast.inp may not ',
     $                       'be opened for sequential input.'
      if(EX.and.SEQ.eq.'YES') print*,
     $                       'ERROR - Error opening gast.inp.'
      print*,'Program stopped'
      stop
  975 continue
      inquire(file=FNAME(:IFN-1)//'.inp',exist=EX,sequential=SEQ,
     $                                                  err=9999)
      if(.not.EX) print*,'ERROR - File ',FNAME(:IFN-1)//'.inp',
     $                   ' does not exist.'
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.inp',
     $                   ' may not be opened for sequential input.'
      if(EX.and.SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.inp.'
      print*,'Program stopped'
      stop
  980 continue
      inquire(file=FNAME(:IFN-1)//'.in2',sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.in2',
     $                   ' may not be opened for sequential output.'
      if(SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.in2'
      print*,'Program stopped'
      stop
 9999 continue
      end
**      
      subroutine RDTAB(A,B,C,TYPE,NTYP)
** This subroutine read a table with the parameters A, B, C of the
** equation Chi = A + B*Q + C*Q**2
** Chi: electronegativity
** Q:   atomic charge
************************************************************************
      parameter(NT=32)
      character LINE*132,FELD*12,TYPE(NT)*8,LOHI*8
      real A(0:NT), B(0:NT), C(0:NT)
      open(unit=9,file='gasteige.dat',status='old',err=9999)
      NTYP=0
      A(NTYP)=1.0
      B(NTYP)=1.0
      C(NTYP)=1.0
   10 continue
      read(9,'(a)',err=9999,end=9999) LINE
      LINE(1:8)=LOHI(LINE(1:8))
** ATOM TYPES, A, B, C
      IF(LINE(1:5).EQ.'TYPE ') THEN
	NTYP=NTYP+1
	CALL LINCUT(LINE,FELD)
	TYPE(NTYP)=LOHI(FELD(1:8))
	CALL LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=10) A(NTYP)
	CALL LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=10) B(NTYP)
	CALL LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=10) C(NTYP)
      END IF
      goto 10
 9999 continue
      close(9)
      end
**
      FUNCTION DIS(I,J) 
** CALCULATES DISTANCE BETWEEN ATOM I AND ATOM J
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      INTEGER I,J
      real DIS
      DIS=sqrt(
     $         (XYZC(I,1)-XYZC(J,1))**2+
     $         (XYZC(I,2)-XYZC(J,2))**2+
     $         (XYZC(I,3)-XYZC(J,3))**2)
      END
**
      subroutine LINCUT(LINE,FELD)
** Searches for the first and second position in the character variable LINE
** where a space or a comma is followed by a character which is neither a
** space or a comma. The region between both positions is transferred to
** the character variable FELD and afterwards cut from the variable LINE.
*** VERSION 6.3.92
      implicit real (a-h,o-z)
      CHARACTER LINE*132, FELD*12
      INTEGER CUT
************************************************************************
      FELD=' '
      CUT=0
      DO 10 I=1,131
	IF((LINE(I:I).EQ.' '.OR.LINE(I:I).EQ.',').AND.
     $     (LINE(I+1:I+1).NE.' '.AND.LINE(I+1:I+1).NE.',')) THEN
	  LINE = LINE(I+1:)
	  CUT=1
	  GOTO 20
	END IF
   10 CONTINUE
   20 CONTINUE
      IF(CUT.NE.1) LINE = ' '
      FELD = LINE
      DO 30 I=1,131
	IF((LINE(I:I).EQ.' '.OR.LINE(I:I).EQ.',').AND.
     $     (LINE(I+1:I+1).NE.' '.AND.LINE(I+1:I+1).NE.',')) THEN
	  FELD = LINE(:I)
	  RETURN
	END IF
   30 CONTINUE
      END
      
      function LOHI(STRING)
** converts small letters to capital letters
      character*8 STRING,LOHI
      integer IC
      IC = ichar('a')-ichar('A')
      do 10 I=1,8
	if(STRING(I:I).ge.'a'.and.STRING(I:I).le.'z') then
	  LOHI(I:I) = char(ichar(STRING(I:I))-IC)
	else
	  LOHI(I:I) = STRING(I:I)
	end if
   10 continue
      end
      
      function ATNO(NAME)
** Bestimmt die zu einem Atomnamen gehoerende Ordnungszahl.
** Version 22.02.96
      CHARACTER NAME*8,LOHI*8
      CHARACTER PERIOD(100)*2, TEST*2
      INTEGER ATNO
      COMMON /PERIOD/ PERIOD
      TEST = LOHI(NAME)
      ATNO = 0
      if(ichar(TEST(2:2)).lt.ichar('A').or.
     $   ichar(TEST(2:2)).gt.ichar('Z')) TEST(2:2)=' '
      do 10 J=1,92
	if(TEST.eq.PERIOD(J)) ATNO=J
   10 continue
      end
**      
      subroutine BONDMA
** CALCULATES BOND MATRIX
** Version 22.02.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      real DIS
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      INTEGER IBO(0:6,NUMATM),ATNO, I1,J1
      COMMON /BOND/ IBO  
      REAL BDRD(100),R1,R2
C * COVALENT BOND RADII 
C * (VCH Verlagsgesellschaft mbH, Periodensystem der Elemente)
      DATA (BDRD(L),L=1,100) /
     $ 0.40, 0.00, 1.23, 0.89, 0.81, 0.77, 0.70, 0.66, 0.64, 0.00,
     $ 1.57, 1.36, 1.25, 1.17, 1.10, 1.04, 0.99, 0.00, 2.03, 1.74,
     $ 1.44, 1.32, 1.22, 1.18, 1.18, 1.16, 1.16, 1.15, 1.17, 1.25,
     $ 1.25, 1.22, 1.21, 1.17, 1.14, 0.00, 2.16, 1.91, 1.62, 1.45,
     $ 1.34, 1.30, 1.27, 1.25, 1.25, 1.28, 1.34, 1.41, 1.50, 1.40,
     $ 1.41, 1.37, 1.33, 0.00, 2.53, 1.98, 1.69, 1.65, 1.65, 1.64,
     $ 1.63, 1.62, 1.85, 1.61, 1.59, 1.59, 1.58, 1.57, 1.56, 1.74,
     $ 1.56, 1.44, 1.34, 1.30, 1.28, 1.26, 1.27, 1.30, 1.34, 1.44,
     $ 1.55, 1.54, 1.46, 1.46, 1.45, 0.00, 0.00, 0.00, 0.00, 1.65,
     $ 0.00, 1.42, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00/
C             
C  *******************
      DO 210 I=1,NATM1
	IBO(0,I)=0
	DO 200 J=1,NATM1
	  IF(I.EQ.J.OR.ICLUS(I).NE.ICLUS(J)) GO TO 200 
C     IF BONDING CONDITION FOUND: 
C     STORE J IN IBO ARRAY 
	  I1=ATNO(ATNAME(I))
	  J1=ATNO(ATNAME(J))
	  if(I1.ne.0) R1=BDRD(I1)
	  if(J1.ne.0) R2=BDRD(J1)
	  if(I1.eq.0) R1=0.0
	  if(J1.eq.0) R2=0.0
	  if(DIS(I,J).lt.1.1*(R1+R2)) then
	    IF(IBO(0,I).GT.6) THEN
	      PRINT *,'MORE THAN 6 BONDS FOR ATOM ',ATNAME(I)
	      GO TO 210
	    END IF
	    IBO(0,I)=IBO(0,I)+1
	    IBO(IBO(0,I),I)=J
	  end if
  200   continue 
  210 continue
      end     
**      
      subroutine SYMTRN(XYZ,R,T,I)
**** Dieses Unterprogramm interpretiert Symmetrieoperationen in 
**** algebraischer Schreibweise
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16)
      character XYZ(3)*8
      real R(NUSYM,3,3), T(NUSYM,3)
************************************************************************
      print *,XYZ
      do 10 J=1,3
	if(index(XYZ(J),'1').ne.0) T(I,J)=1
	if(index(XYZ(J),'2/').ne.0) T(I,J)=2
	if(index(XYZ(J),'3/').ne.0) T(I,J)=3
	if(index(XYZ(J),'4/').ne.0) T(I,J)=4
	if(index(XYZ(J),'5/').ne.0) T(I,J)=5
	if(index(XYZ(J),'6/').ne.0) T(I,J)=6
	if(index(XYZ(J),'7/').ne.0) T(I,J)=7
	if(index(XYZ(J),'8/').ne.0) T(I,J)=8
	if(index(XYZ(J),'9/').ne.0) T(I,J)=9
   10 continue

      do 20 J=1,3
	if(index(XYZ(J),'/2').ne.0) T(I,J)=T(I,J)/2
	if(index(XYZ(J),'/3').ne.0) T(I,J)=T(I,J)/3
	if(index(XYZ(J),'/4').ne.0) T(I,J)=T(I,J)/4
	if(index(XYZ(J),'/6').ne.0) T(I,J)=T(I,J)/6
   20 continue

      do 30 J=1,3
	if(index(XYZ(J),'-1').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-2').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-3').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-4').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-5').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-6').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-7').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-8').ne.0) T(I,J)=-T(I,J)
	if(index(XYZ(J),'-9').ne.0) T(I,J)=-T(I,J)
   30 continue

      do 50 J=1,3
	if(index(XYZ(J),'-X').ne.0) then
	  R(I,J,1)=-1
	else if(index(XYZ(J),'X').ne.0) then
	  R(I,J,1)=+1
	end if
	if(index(XYZ(J),'-Y').ne.0) then
	  R(I,J,2)=-1
	else if(index(XYZ(J),'Y').ne.0) then
	  R(I,J,2)=+1
	end if
	if(index(XYZ(J),'-Z').ne.0) then
	  R(I,J,3)=-1
	else if(index(XYZ(J),'Z').ne.0) then
	  R(I,J,3)=+1
	end if
   50 continue

      end
**      
      subroutine SROT
** Look for atoms taking part in a subrotation and calculate direction
** of rotation axis
** Version 23.2.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      parameter (PI=3.141592653589793d0)
      logical FRAGM(NUMATM)
      double precision V(3),X(3),ALPHA1,ALPHA2
      integer IBO(0:6,NUMATM)
      common /BOND/ IBO
      do 40 N=1,NSUB
	do 10 I=1,NATM1
	  FRAGM(I) = .false.
   10   continue
	K1 = ISUB(1,N)
	K2 = ISUB(2,N)
	LSUB(K1)=-N
	LSUB(K2)=-N
	FRAGM(K1) = .true.
	FRAGM(K2) = .true.
	L = 2
	do 15 M=1,NATM1-1
	do 20 I=1,NATM1
	  do 30 J=1,6
	    if(IBO(J,I).ne.K1.and.IBO(J,I).ne.0) then
	      if(.not.FRAGM(I).and.FRAGM(IBO(J,I)))then
		L = L + 1
		ISUB(L,N) = I
		LSUB(I)=N
		FRAGM(I) = .true.
	      end if
	    end if
   30     continue
   20   continue
   15   continue
** a) directional vector defining rotation axis (first bond atom in origin)
	V(1) = XYZC(ISUB(2,N),1) - XYZC(ISUB(1,N),1)
	V(2) = XYZC(ISUB(2,N),2) - XYZC(ISUB(1,N),2)
	V(3) = XYZC(ISUB(2,N),3) - XYZC(ISUB(1,N),3)
** b) rotation of rotation axis onto x-axis
** 1. rotation around y-axis onto x-y-plane by angle ALPHA1
	if(abs(V(3)).lt.1e-10) then
	  ALPHA1 = 0.0
	else if(abs(V(1)).lt.1e-10) then
	  ALPHA1 = PI/2.
	else
	  ALPHA1 = atan(V(3)/V(1))
	end if
	SUBDIR(N,1)=sin(ALPHA1)
	SUBDIR(N,3)=cos(ALPHA1)
	X(1) = V(1)*SUBDIR(N,3) + V(3)*SUBDIR(N,1)
	V(1) = X(1)
** 2. rotation around z-axis onto x-axis by angle ALPHA2
	if(abs(V(2)).lt.1e-10) then
	  ALPHA2 = 0.0
	else if(abs(V(1)).lt.1e-10) then
	  ALPHA2 = PI/2.
	else
	  ALPHA2=-atan(V(2)/V(1))
	end if
	SUBDIR(N,2)=sin(ALPHA2)
	SUBDIR(N,4)=cos(ALPHA2)
	X(1) = V(1)*SUBDIR(N,4) - V(2)*SUBDIR(N,2)
	V(1) = X(1)
	if(V(1).lt.0.0) then
	  SUBDIR(N,2) = -SUBDIR(N,2)
	  SUBDIR(N,4) = -SUBDIR(N,4)
	end if
   40 continue
      end
**      
      subroutine BONDL(LABEL1,LABEL2,BL)
** Change bond distance between the atoms LABEL1 and LABEL2
** Version 02.03.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      character LABEL1*8,LABEL2*8
      I1=0
      I2=0
      do 10 I=1,NATM1
	if(LABEL1.eq.ATNAME(I)) I1=I
	if(LABEL2.eq.ATNAME(I)) I2=I
   10 continue
      if(I1.eq.I2) then
**        write(2,'(/1x,2a/)') 'WARNING - CANNOT CHANGE BOND LENGTH OF',
**     $                       ' 2 IDENTICAL ATOMS.'
	write(*,'(/1x,2a/)') 'WARNING - CANNOT CHANGE BOND LENGTH OF',
     $                       ' 2 IDENTICAL ATOMS.'
	goto 999
      end if
      if(I1.eq.0.or.I2.eq.0) then
**        write(2,'(/1x,2a,1x,2a/)') 'WARNING - BOND ',
**     $                        LABEL1,LABEL2,' NOT FOUND.'
	write(*,'(/1x,2a,1x,2a/)') 'WARNING - BOND ',
     $                        LABEL1,LABEL2,' NOT FOUND.'
	goto 999
      end if
      D=DIS(I1,I2)
      if(D.gt.1.5*(VWR(I1)+VWR(I2))) then
**        write(2,'(/1x,2a,1x,a,f10.5/)')
**     $                'WARNING - EXTREMELY LONG BOND: ',LABEL1,LABEL2,D
	write(*,'(/1x,2a,1x,a,f10.5/)')
     $                'WARNING - EXTREMELY LONG BOND: ',LABEL1,LABEL2,D
	goto 999
      end if
      do 20 J=1,3
	XYZC(I2,J)=XYZC(I1,J)+BL/D*(XYZC(I2,J)-XYZC(I1,J))
   20 continue
  999 continue
      end

      block data P
      parameter(NUCLUS=16,NUSUB=12)
      CHARACTER PERIOD(100)*2
      character PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      COMMON /PERIOD/ PERIOD
      COMMON /PARNAM/ PNAME,RNAME
      DATA (PERIOD(I),I=1,92)/'H ','HE','LI','BE','B ','C ','N ','O ',
     $                        'F ','NE','NA','MG','AL','SI','P ','S ',
     $                        'CL','AR','K ','CA','SC','TI','V ','CR',
     $                        'MN','FE','CO','NI','CU','ZN','GA','GE',
     $                        'AS','SE','BR','KR',
     $                        'RB','SR','Y ','ZR','NB','MO','TC','RU',
     $                        'RH','PD','AG','CD','IN','SN','SB','TE',
     $                        'I ','XE','CS','BA','LA','CE','PR','ND',
     $                        'PM','SM','EU','GD','TB','DY','HO','ER',
     $                        'TM','YB','LU','HF','TA','W ','RE','OS',
     $                        'IR','PT','AU','HG',
     $                        'TL','PB','BI','PO','AT','RN','FR','RA',
     $                        'AC','TH','PA','U '/
      DATA (PNAME(K),K=1,NUCLUS*6+6) /
     $'A','B','C','ALPHA','BETA','GAMMA',
     $'TA1','TB1','TC1','THETA1','CHI1','PHI1',
     $'TA2','TB2','TC2','THETA2','CHI2','PHI2',
     $'TA3','TB3','TC3','THETA3','CHI3','PHI3',
     $'TA4','TB4','TC4','THETA4','CHI4','PHI4',
     $'TA5','TB5','TC5','THETA5','CHI5','PHI5',
     $'TA6','TB6','TC6','THETA6','CHI6','PHI6',
     $'TA7','TB7','TC7','THETA7','CHI7','PHI7',
     $'TA8','TB8','TC8','THETA8','CHI8','PHI8',
     $'TA9','TB9','TC9','THETA9','CHI9','PHI9',
     $'TA10','TB10','TC10','THETA10','CHI10','PHI10',
     $'TA11','TB11','TC11','THETA11','CHI11','PHI11',
     $'TA12','TB12','TC12','THETA12','CHI12','PHI12',
     $'TA13','TB13','TC13','THETA13','CHI13','PHI13',
     $'TA14','TB14','TC14','THETA14','CHI14','PHI14',
     $'TA15','TB15','TC15','THETA15','CHI15','PHI15',
     $'TA16','TB16','TC16','THETA16','CHI16','PHI16'/
      DATA (RNAME(K),K=1,NUSUB) /
     $'PSI1','PSI2','PSI3','PSI4','PSI5','PSI6',
     $'PSI7','PSI8','PSI9','PSI10','PSI11','PSI12'/
      end

      subroutine DUMP
** THIS SUBROUTINE WRITES THE VALUES OF ALL VARIABLES OF THE COMMON BLOCK
** AND THE COMMON /PARA/ BLOCK TO THE FILE DUMP.OUT
** Version 11.03.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      open(unit=11,file='dump.out',err=9999,status='unknown')
      print*,'writing to dump.out...'
      write(11,'(6(1x,a,i10))',err=9999) 'NUMATM=',NUMATM,
     $ 'NUSYM=',NUSYM,'NUCLUS=',NUCLUS,'NPOTL=',NPOTL,'NV=',NV,'NUSUB=',
     $ NUSUB
      write(11,'(1x,a,l1)') 'SPEC=',SPEC
      write(11,'(4(1x,a,i10))',err=9999) 'NCH=',NCH,
     $                            'NATM1=',NATM1,'NCLUS=',NCLUS,'NS=',NS
      write(11,'(a/15(i4))',err=9999) 'ICLUS=',ICLUS
      write(11,'(a/15(i4))',err=9999) 'LSUB=',LSUB
      write(11,'(a/15(i4))',err=9999) 'ISPC=',ISPC
      write(11,'(2(1x,a,i4))',err=9999) 'NSUB=',NSUB,'NPOT=',NPOT
      write(11,'(a/6(i4))',err=9999) 'ISUB=',
     $                                    ((ISUB(I,J),J=1,6),I=1,NUMATM)
      write(11,'(a/18(i4))',err=9999) 'IVAR=',IVAR
      write(11,'(a/18(i4))',err=9999) 'IPAR=',IPAR
      write(11,'(a/15(i4))',err=9999) 'PTYP=',PTYP
      write(11,'(a/5(1pe14.6))',err=9999) 'VWR=',VWR
      write(11,'(a/5(1pe14.6))',err=9999) 'MXR=',MXR
      write(11,'(a/5(1pe14.6))',err=9999) 'MINR=',MINR
      write(11,'(a/5(1pe14.6))',err=9999) 'Q=',Q
      write(11,'(a/5(1pe14.6))',err=9999) 'POT(I,J,1)=',
     $                           ((POT(I,J,1),J=1,NPOTL),I=1,NPOTL)
      write(11,'(a/5(1pe14.6))',err=9999) 'POT(I,J,2)=',
     $                           ((POT(I,J,2),J=1,NPOTL),I=1,NPOTL)
      write(11,'(a/5(1pe14.6))',err=9999) 'POT(I,J,3)=',
     $                           ((POT(I,J,3),J=1,NPOTL),I=1,NPOTL)
      write(11,'(a/5(1pe14.6))',err=9999) 'POT(I,J,4)=',
     $                           ((POT(I,J,4),J=1,NPOTL),I=1,NPOTL)
      write(11,'(a/2(1pe14.6))',err=9999) 'SPOT=',SPOT
      write(11,'(a,1pe14.6)',err=9999) 'PRESS=',PRESS
      write(11,'(a,3(1pe14.6)/3(1pe14.6))',err=9999) 'CELL=',CELL
      write(11,'(a/3(1pe14.6))',err=9999) 'T=',
     $                                   ((T(I,J),J=1,3),I=1,NUSYM)
      do 30 I=1,NUSYM
	write(11,'(a,i2,a/9i4)',err=9999) 
     $                             'R(',I,')=',((R(I,J,K),J=1,3),K=1,3)
   30 continue
      write(11,'(a/18i4)') 'ISYM=',ISYM
      do 40 L=1,NUCLUS
	write(11,'(a,i2,a/12(a6))') 'SPC(M,',L,')=',(SPC(M,L),M=1,NUSYM)
   40 continue
      write(11,'(a/3(1pe14.6))',err=9999) 'XYZC=',
     $                                 ((XYZC(I,J),J=1,3),I=1,NUMATM)
      write(11,'(a/3(1pe14.6))',err=9999) 'XYZS=',
     $                                 ((XYZS(L,J),J=1,3),L=1,NUCLUS)
      write(11,'(a/3(1pe14.6))',err=9999) 'ROT=',
     $                                 ((ROT(L,J),J=1,3),L=1,NUCLUS)
      write(11,'(a/5(1pe14.6))',err=9999) 'SUBROT=',SUBROT
      do 60 M=1,NUSYM
	write(11,'(a,i2,a/3(1pe14.6))',err=9999) 'XYZSC(',M,')=',
     $                                ((XYZSC(J,L,M),J=1,3),L=1,NUCLUS)
   60 continue
      write(11,'(a/8(a,1x))') 'ATNAME=',ATNAME
      write(11,'(2a)') 'PTNAME= ',PTNAME
      write(11,'(a/18(a,1x))') 'PNAM=',PNAM
      write(11,'(4a)') 'SPG= ',SPG,' UNAX= ',UNAX
      write(11,'(a)') 'SYMMLS= ',SYMMLS
      write(11,'(2a)') 'TITLE= ',TITLE
      write(11,'(a,1pe14.6,1x,a,3i4)') 'SUMR= ',SUMR,'ISUM= ',ISUM
 9999 continue
      close(unit=11)
      end

      subroutine FRACRT(XYZF,XYZ2,CELL,VOL,IDIR,UNAX,OLD,IERR)
** TRANSFORMS FRACTIONAL COORDINATES XYZF TO CARTESIAN COORDINATES
** XYZ2 AND VICE VERSA.
** Version 05.03.1996
** CELL: d cell constants, angles in radian measure
** XYZ:  d fractional coordinates
** XYZ2: d cartesian coordinates
** A:    d transformation matrix fractional -> cartesian
** AI:   d transformation matrix cartesian  -> fractional
** VOL:  d cell volume
** IDIR: i 1: fractional -> cartesian
**        -1: cartesian  -> fractional
** UNAX: c unique axis (a/A, b/B, c/C, r/R)
** OLD:  l .true.: use old transformation matrix
**         .false.: calculate new transformation matrix
** IERR: i 0: no error    
**         1: one angle is less than or equal to 1 deg. or one angle
**            is greater then 180 deg.
**         2: one cell edge is less than 1
**         3: IDIR is neither -1 nor 1
**         4: sum of angles is greater or equal 360 deg.
**         5: ((cos(beta)-cos(gamma)*cos(alpha))/sin(alpha))**2 +
**            cos(gamma)**2 
**            or corresponding expressions are greater than 1.0
************************************************************************
** definition of cartesian axes (unique axis=a):
** x-axis parallel to a-axis
** y-axis in a-b-plane, on the same side as b-axis
** z-axis perpendicular to x- and y-axis (right-hand system)
** (unique axis=b):
** x-axis perpendicular to y- and z-axis (right-hand system)
** y-axis parallel to b-axis
** z-axis in b-c-plane, on the same side as c-axis
** (unique axis=c):
** x-axis in c-a-plane, on the same side as a-axis
** y-axis perpendicular to z- and x-axis (right-hand system)
** z-axis parallel to c-axis
************************************************************************
      implicit real (a-h,o-z)
      parameter(PI=3.141592653589793d0,PI20=PI/20d0)
      real CELL(6), XYZF(3), XYZ2(3), VOL
      real D, C1,C2,C3,S1,S2,S3
      integer IDIR, IERR
      character UNAX*1
      logical OLD
      real A(3,3), AI(3,3)
      common /TEST/ A,AI
************************************************************************
      IERR = 0
      if(OLD) goto 100
** calculate transformation matrix (fractional to cartesian)
      if(CELL(4).lt.PI20.or.CELL(5).lt.PI20.or.CELL(6).lt.PI20) then
	IERR = 1
	return
      end if
      if(CELL(4).ge.PI.or.CELL(5).ge.PI.or.CELL(6).ge.PI) then
	IERR = 1
	return
      end if
      C1 = COS(CELL(4))
      C2 = COS(CELL(5))
      C3 = COS(CELL(6))
      if(CELL(1).lt.1.0.or.CELL(2).lt.1.0.or.CELL(3).lt.1.0) then
	IERR = 2
	return
      end if
      if(CELL(4)+CELL(5)+CELL(6).ge.2*PI) then
	IERR = 4
	return
      end if
      if(UNAX.eq.' '.or.UNAX.eq.'a'.or.UNAX.eq.'A') then
	S3 = SIN(CELL(6))
	A(1,1) = CELL(1)
	A(1,2) = CELL(2)*C3
	A(2,1) = 0.0
	A(2,2) = CELL(2)*S3
	A(1,3) = CELL(3)*C2
	A(2,3) = CELL(3)*(C1-C2*C3)/S3
	A2 = (A(2,3)/CELL(3))**2+C2**2
	if(A2.gt.1.0) then
	  IERR = 5
	  return
	end if
	A(3,1) = 0.0
	A(3,2) = 0.0
	A(3,3) = CELL(3)*SQRT(1. - A2)
      else if(UNAX.eq.'b'.or.UNAX.eq.'B') then
	S1 = SIN(CELL(4))
	A(2,2) = CELL(2)
	A(2,3) = CELL(3)*C1
	A(3,3) = CELL(3)*S1
	A(2,1) = CELL(1)*C3
	A(3,1) = CELL(1)*(C2-C3*C1)/S1
	A(3,2) = 0.0
	A2 = (A(3,1)/CELL(1))**2+C3**2
	if(A2.gt.1.0) then
	  IERR = 5
	  return
	end if
	A(1,1) = CELL(1)*SQRT(1. - A2)
	A(1,2) = 0.0
	A(1,3) = 0.0
      else if(UNAX.eq.'c'.or.UNAX.eq.'C') then
	S2 = SIN(CELL(5))
	A(3,3) = CELL(3)
	A(3,1) = CELL(1)*C2
	A(1,1) = CELL(1)*S2
	A(3,2) = CELL(2)*C1
	A(1,2) = CELL(2)*(C3-C1*C2)/S2
	A(1,3) = 0.0
	A2 = (A(1,2)/CELL(2))**2+C1**2
	if(A2.gt.1.0) then
	  IERR = 5
	  return
	end if
	A(2,1) = 0.0
	A(2,2) = CELL(2)*SQRT(1. - A2)
	A(2,3) = 0.0
      else if(UNAX.eq.'r'.or.UNAX.eq.'R') then
	A(1,1) = 0.0
	A(1,2) = sqrt(0.5)*CELL(1)*SQRT(1.0-C1)
	A(1,3) = -A(1,2)
	A(2,1) = -2.0*A(1,2)/sqrt(3.0)
	A(2,2) = -A(2,1)/2.0
	A(2,3) = A(2,2)
	A(3,1) = SQRT(CELL(1)**2-A(2,1)**2)
	A(3,2) = A(3,1)
	A(3,3) = A(3,1)
      end if
      if(IDIR.ne.1.and.IDIR.ne.-1) then
	IERR = 3
	return
      end if
  100 continue
      if(UNAX.ne.'r'.and.UNAX.ne.'R') VOL = A(1,1)*A(2,2)*A(3,3)
      if(UNAX.eq.'r'.or.UNAX.eq.'R') then
	VOL = A(1,2)*A(2,3)*A(3,1) + A(1,3)*A(2,1)*A(3,2) -
     $        A(3,1)*A(2,2)*A(1,3) - A(2,1)*A(1,2)*A(3,3)
      end if
      if(IDIR.eq.1) then
	XYZ2(1) = A(1,1)*XYZF(1) + A(1,2)*XYZF(2) + A(1,3)*XYZF(3)
	XYZ2(2) = A(2,1)*XYZF(1) + A(2,2)*XYZF(2) + A(2,3)*XYZF(3)
	XYZ2(3) = A(3,1)*XYZF(1) + A(3,2)*XYZF(2) + A(3,3)*XYZF(3)
	return
      end if
      if(IDIR.eq.-1) then
	if(OLD) goto 200
** calculate inverse transformation matrix (cartesian to fractional)
	D = VOL
	AI(1,1) = (A(2,2)*A(3,3)-A(3,2)*A(2,3))/D
	AI(2,1) =-(A(2,1)*A(3,3)-A(3,1)*A(2,3))/D
	AI(3,1) = (A(2,1)*A(3,2)-A(3,1)*A(2,2))/D
	AI(1,2) =-(A(1,2)*A(3,3)-A(3,2)*A(1,3))/D
	AI(2,2) = (A(1,1)*A(3,3)-A(3,1)*A(1,3))/D
	AI(3,2) =-(A(1,1)*A(3,2)-A(3,1)*A(1,2))/D
	AI(1,3) = (A(1,2)*A(2,3)-A(2,2)*A(1,3))/D
	AI(2,3) =-(A(1,1)*A(2,3)-A(2,1)*A(1,3))/D
	AI(3,3) = (A(1,1)*A(2,2)-A(2,1)*A(1,2))/D
  200   continue
	XYZF(1) = AI(1,1)*XYZ2(1) + AI(1,2)*XYZ2(2) + AI(1,3)*XYZ2(3)
	XYZF(2) = AI(2,1)*XYZ2(1) + AI(2,2)*XYZ2(2) + AI(2,3)*XYZ2(3)
	XYZF(3) = AI(3,1)*XYZ2(1) + AI(3,2)*XYZ2(2) + AI(3,3)*XYZ2(3)
	return
      end if
      end
      
      subroutine RDATM(FN,METHOD,PAR,NP,POTFIL,ROTC,
     $   CONT,IEND,STEP,ISTP,IDUM,ILOOP1,ILOOP2,INLOOP,IANALY,ISP)
** THIS SUBROUTINE READS AN INPUT FILE
** Input Variables:  FN,CONT
** Output Variables: ATNAME, CELL, IDUM, 
**                   SUMR, IEND, ILOOP1, ILOOP2, IPA, ISTP, ISUM, 
**                   METHOD, MTBL, NATM1, NCH, 
**                   NCLUS, NP, NS, NSUB, PAR, POTFIL, Q, RPA, STEP, RM, 
**                   SPG, T, TITLE, UNAX, VWR, XYZC
** Version 06.02.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
** additional Variables:
** BLTP:           c Bravais lattice type
** CONT:           l .true.: continue reading parameter file
**                   .false.: start reading parameter file
** FN:             i channel number of parameter file
** ICENT:          i centricity code (ICENT=1: centrosymmetric structure)
** INCELL(J)       r cell constants to be used for transformation of input
**                   fractional coordinates to cartesian coordinates (angles
**                   in degrees)
** NP:             i number of PARM lines
** PAR(L,J):       r value of parameter no. J of molecule/ion no. L
**                   subrotation parameters are in PAR(NCLUS+1,J)
** POTFIL:         c name of potential parameters file
** ROTC(L,J):      r center of rotation of molecule/ion no. L
** RATN(1,N):      c names of Nth subrotation defining atoms (no. 1)
** RATN(2,N):      c names of Nth subrotation defining atoms (no. 2)
** TSTART (RPA(2): r temperature to start simulated annealing with
** TEND   (RPA(4): r temperature to end simulated annealing with
************************************************************************
      real VDWR(100), AMASS(100)
      integer FN, FN1, I,J, ICENT, ATNO, ISTP(12)
      integer R1,R2,R3, IDUM, ILOOP1,ILOOP2, IEND,IANALY, ISP
      real PAR(NUCLUS+1+NUSUB/6,6),STEP(12), ROTC(NUCLUS,3)
      real XYZF(3),XC(3),BL, INCELL(6)
      character LINE*132, POTFIL*40, FELD*12, LID*8, LABEL1*8,LABEL2*8
      character BLTP*1,SYMM(3)*8, LOHI*8, P(NUMATM)*4, A1*4, A2*4
      character RATN(2,NUSUB)*8
      character PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      logical CONT,FOUND,INLOOP,IDFND,AUTO
      parameter (PI=3.141592653589793d0)
      common /PARNAM/ PNAME,RNAME
      
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL
      SAVE P,NR,RATN

** VAN DER WAALS RADII - A.BONDI, J.PHYS.CHEM.(1964),68,441-451.
** SOME ENTRIES WERE ESTIMATED AS COVALENT RADIUS + 0.8 ANG.
** THE ENTRIES FOR H, C, N, O ARE FROM KITAIGORODSKI, "MOLEKUELKRISTALLE".
      DATA (VDWR(L),L=1,100) /
     $ 1.17, 1.40, 2.05, 1.15, 1.63, 1.80, 1.58, 1.52, 1.47, 1.50,
     $ 1.77, 1.90, 2.15, 2.10, 1.80, 1.80, 1.75, 1.80, 2.13, 1.79,
     $ 2.24, 2.27, 2.13, 2.15, 2.15, 2.14, 2.03, 2.30, 2.32, 2.25,
     $ 2.02, 1.97, 1.85, 1.90, 1.85, 1.90, 2.27, 1.92, 2.58, 2.36,
     $ 2.28, 2.27, 2.15, 2.20, 2.25, 2.30, 2.39, 2.49, 2.43, 2.26,
     $ 2.26, 2.06, 1.98, 2.16, 2.47, 2.14, 2.67, 2.63, 2.62, 2.61,
     $ 2.43, 2.42, 2.65, 2.41, 2.39, 2.39, 2.38, 2.37, 2.36, 2.54,
     $ 2.36, 2.24, 2.14, 2.10, 2.08, 2.06, 2.07, 2.10, 2.14, 2.24,
     $ 2.35, 2.34, 2.26, 2.26, 2.25, 0.00, 0.00, 0.00, 0.00, 2.45,
     $ 0.00, 2.22, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00/
C * ATOMIC MASSES
C * (VCH Verlagsgesellschaft mbH, Periodensystem der Elemente)
      DATA (AMASS(L),L=1,100) /
     $ 1.00794, 4.00260, 6.941  , 9.01218,10.811  ,
     $12.011  ,14.00674,15.9994 ,18.99840,20.1797 ,
     $22.98977,24.3050 ,26.98154,28.0855 ,30.97376,
     $32.066  ,35.4527 ,39.948  ,39.0983 ,40.078  ,
     $44.95591,47.88   ,50.9415 ,51.9961 ,54.93805,
     $55.847  ,58.93320,58.6934 ,63.546  ,65.39   ,
     $69.723  ,72.61   ,74.92159,78.96   ,79.904  ,
     $83.80   ,85.4678 ,87.62   ,88.90585,91.224  ,
     $92.90585,95.94   ,98.9063 ,101.07  ,102.9055,
     $106.42  ,107.8682,112.411 ,114.818 ,118.710 ,
     $121.757 ,127.60  ,126.9045,131.29  ,132.9054,
     $137.327 ,138.9055,140.115, 140.9076,144.24  ,
     $146.9151,150.36  ,151.965 ,157.25  ,158.9253,
     $162.50  ,164.9303,167.26  ,168.9342,173.04  ,
     $174.967 ,178.49  ,180.9479,183.84  ,186.207 ,
     $190.23  ,192.22  ,195.08  ,196.9665,200.59  ,
     $204.3833,207.2   ,208.9804,208.9824,209.9871,
     $222.0176,223.0197,226.0254,227.0278,232.0381,
     $231.0359,238.0289,237.0482,244.0642,243.0614,
     $247.0703,247.0703,251.0796,252.0829,257.0951/
************************************************************************
** Routines used by this subroutine:
** ANASYM   analyze symmetry operations, find crystal system
** ATNO     read atom name, return atomic number
** BONDL    changes bond distance between two atoms
** DUMP     writes the values of the common variables onto file
** LINCUT   cut a part from the variable LINE and put it to the variable
**          FELD
** LOHI     converts small letters to capital letters
** SPGR     look for space group name/number and read R and T.
** SYMTRN   read equivalent positions as algebraic expression
** SYMMCL   include translations and center of symmetry
************************************************************************
** initialization (global)
      FN1=0
      RPA(1) = 0.0
      RPA(2) = 0.0
      RPA(4) = 0.0
      IPA(1) = 0
      IPA(2) = 0
      if(CONT) goto 20

** initialization only for first optimization
      AUTO = .false.
      CELL(1) = 0
      INCELL(1) = 0
      ICENT = 0
      IPA(3) = 1
      IEND = 0
      MINR = 3.5
      NATM1 = 0
      NCH = 0
      NCLUS = 1
      NP = 0
      NS = 0
      NSUB = 0
      NPOT = 0
      NVAR = 0
      POTFIL = ' '
      PRESS = 0.0
      PTNAME = ' '
      SPEC = .false.
      SPG = ' '
      UNAX = ' '
      DO 110 L=1,NUCLUS
	SUBROT(L) = 0.0
	DO 110 J=1,3
	  ROT(L,J) = 0.0
	  ROTC(L,J) = -999.
  110 CONTINUE
      DO 130 L=1,NUCLUS+1
	if(L.le.NUCLUS) ISPC(L)=0
	DO 120 J=1,6
	  IVAR(L*6+J-6)=0
	  PAR(L,J)=-999.
  120   CONTINUE
  130 CONTINUE
      DO 140 J=1,NV
	IPAR(J)=0
  140 CONTINUE
      DO 160 I=1,NUMATM
	LSUB(I)=0
	Q(I)=0.0
	DO 150 J=1,NUSUB
	  RATN(1,J)=' '
	  RATN(2,J)=' '
	  ISUB(I,J)=0
  150   CONTINUE
	DO 160 J=1,3
	  XYZC(I,J)=-999.
  160 CONTINUE
      DO 170 J=1,3
	T(1,J)=0.0
	DO 170 K=1,3
	  IF(J.EQ.K) R(1,J,K)=1
	  IF(J.NE.K) R(1,J,K)=0
  170 CONTINUE
      DO 180 J=1,12
	STEP(J)=0.0
	ISTP(J)=0
  180 CONTINUE
      DO 190 M1=1,NPOTL
	PNAM(M1)='*'
	DO 190 M2=1,NPOTL
	  DO 190 J=1,4
	    POT(M1,M2,J)=0.0
  190 CONTINUE
      SUMR=9.0
      ISUM(1)=0
      ISUM(2)=0
      ISUM(3)=0
      I=0
****************** MAIN LOOP START
   20 CONTINUE
      METHOD=0
      IDFND=.false.
      READ(FN,'(A)',ERR=20,END=490) LINE
***
      LID = LOHI(LINE(1:8))

** TITLE
      IF(LID(1:6).EQ.'TITLE ') THEN
	IDFND=.true.
	TITLE = LINE(7:80)
      ELSE IF(LID(1:5).EQ.'TITL ') THEN
	IDFND=.true.
	TITLE = LINE(6:80)
      END IF

** CUT OFF EVERYTHING BEHIND THE EXCLAMATION MARK
      IF(INDEX(LINE,'!').NE.0) LINE = LINE(1:INDEX(LINE,'!')-1)
      
** SPACE GROUP
      IF(LID(1:5).EQ.'SPGR '.or.LID(1:3).eq.'SP ') THEN
	IDFND=.true.
	CALL LINCUT(LINE,FELD)
	SPG = LOHI(FELD(1:8))
	CALL LINCUT(LINE,FELD)
	UNAX = LOHI(FELD(1:8))
	CALL SPGR(SPG,UNAX,R,T,NR,NS,ICENT,BLTP)
      END IF
***
** SYMM/DUPL
      IF(LID(1:5).EQ.'SYMM '.or.LID(1:3).eq.'SY '.or.
     $   LID(1:5).EQ.'DUPL '.or.LID(1:3).eq.'DU ') THEN
	IDFND=.true.
	NS = NS + 1
	if(NS.gt.NUSYM) then
	  write(2,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
	  write(*,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
	  NS = NUSYM
	  GOTO 20
	end if
	CALL LINCUT(LINE,FELD)
	SYMM(1)=LOHI(FELD(1:8))
	IS=index(SYMM(1),',')
	if(IS.ne.0) SYMM(1)(IS:IS)=' '
	SYMMLS(NS)(1:10)=SYMM(1)
	SYMMLS(NS)(11:11)=','
	CALL LINCUT(LINE,FELD)
	SYMM(2)=LOHI(FELD(1:8))
	IS=index(SYMM(2),',')
	if(IS.ne.0) SYMM(2)(IS:IS)=' '
	SYMMLS(NS)(12:21)=SYMM(2)
	SYMMLS(NS)(22:22)=','
	CALL LINCUT(LINE,FELD)
	SYMM(3)=LOHI(FELD(1:8))
	IS=index(SYMM(3),',')
	if(IS.ne.0) SYMM(3)(IS:IS)=' '
	SYMMLS(NS)(23:33)=SYMM(3)
	CALL SYMTRN(SYMM,R,T,NS)
	IF((LID(1:5).EQ.'DUPL '.or.LID(1:3).eq.'DU ').and.NS.ne.1) THEN
	  NS = (NS-1)*2
	  if(NS.gt.NUSYM) then
	    write(2,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
	    write(*,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
	    NS = NS/2 + 1
	    GOTO 20
	  end if
	  M2 = NS/2
	  DO 210 M=1,M2
	    DO 200 J=1,3
	      R(M+M2,J,1) = R(M2+1,J,1)*R(M,1,1)+R(M2+1,J,2)*R(M,2,1)+
     $                      R(M2+1,J,3)*R(M,3,1)
	      R(M+M2,J,2) = R(M2+1,J,1)*R(M,1,2)+R(M2+1,J,2)*R(M,2,2)+
     $                      R(M2+1,J,3)*R(M,3,2)
	      R(M+M2,J,3) = R(M2+1,J,1)*R(M,1,3)+R(M2+1,J,2)*R(M,2,3)+
     $                      R(M2+1,J,3)*R(M,3,3)
	      T(M+M2,J) = R(M2+1,J,1)*T(M,1)+R(M2+1,J,2)*T(M,2)+
     $                    R(M2+1,J,3)*T(M,3) + T(M2+1,J)
  200     CONTINUE
  210   CONTINUE
	END IF
	call SYMMCL('P',0)
      END IF
***
** OUTPUT (NO, FEW, ALL)
      IF(LID(1:5).EQ.'OUTP '.or.LID(1:5).EQ.'MORE ') THEN
	IDFND = .true.
	CALL LINCUT(LINE,FELD)
	if(FELD.EQ.'3'.OR.LOHI(FELD(1:8)).EQ.'NO') then
	  IPA(3) = 3
	else if(FELD.EQ.'1'.OR.LOHI(FELD(1:8)).EQ.'FEW') then
	  IPA(3) = 1
	else if(FELD.EQ.'2'.OR.LOHI(FELD(1:8)).EQ.'MUCH') then
	  IPA(3) = 2
	else if(FELD.EQ.'4'.OR.LOHI(FELD(1:8)).EQ.'FULL'.OR.
     $                         LOHI(FELD(1:8)).EQ.'ALL') then
	  IPA(3) = 4
	else
	  write(2,'(/1x,3a/)') 'WARNING - CANNOT UNDERSTAND OUTP ',
     $                        FELD(1:8),'. OUTP FEW ASSUMED.'
	  write(*,'(/1x,3a/)') 'WARNING - CANNOT UNDERSTAND OUTP ',
     $                        FELD(1:8),'. OUTP FEW ASSUMED.'
	end if
      END IF
***
** ATOM NAMES, POTENTIAL TYPES, COORDINATES, CHARGES, VDW RADII, CV RADII
      IF(LID(1:5).EQ.'ATOM '.OR.LID(1:3).EQ.'AT ') THEN
	IDFND = .true.
	if(NATM1.eq.0) call ANASYM(ISP)
	NATM1 = NATM1+1
	ICLUS(NATM1) = NCLUS
	CALL LINCUT(LINE,FELD)
	ATNAME(NATM1) = LOHI(FELD(1:8))
	IF(ATNO(ATNAME(NATM1)).EQ.0) THEN
	  VWR(NATM1) = 0.0
	  RM(NATM1) = 0.0
	ELSE
	  VWR(NATM1) = VDWR(ATNO(ATNAME(NATM1)))
	  RM(NATM1) = AMASS(ATNO(ATNAME(NATM1)))
	END IF
	CALL LINCUT(LINE,FELD)
	P(NATM1) = LOHI(FELD(1:8))
	if(ichar(P(NATM1)(1:1)).lt.ichar('A').or.
     $     ichar(P(NATM1)(1:1)).gt.ichar('Z')) then
	  write(2,'(/1x,4a/)') 
     $           'WARNING - ILLEGAL ATOM TYPE NAME FOR ',ATNAME(NATM1),
     $           ':',P(NATM1)
	  write(*,'(/1x,4a/)') 
     $           'WARNING - ILLEGAL ATOM TYPE NAME FOR ',ATNAME(NATM1),
     $           ':',P(NATM1)
	  LINE = FELD//LINE
	end if
	FOUND = .false.
	do 220 J=1,NPOT
	  if(P(NATM1).eq.PNAM(J)) then
	    FOUND = .true.
	    PTYP(NATM1) = J
	  end if
  220   continue
	if(.not.FOUND) then
	  NPOT = NPOT + 1
	  PNAM(NPOT) = P(NATM1)
	  PTYP(NATM1) = NPOT
	  IF(NPOT.gt.NPOTL) THEN
	    write(2,'(/1x,3a/)') 
     $      'WARNING - TOO MANY ATOM TYPES. THE ATOM TYPE ',
     $      A1,' WILL BE IGNORED.'
	    write(*,'(/1x,3a/)') 
     $      'WARNING - TOO MANY ATOM TYPES. THE ATOM TYPE ',
     $      A1,' WILL BE IGNORED.'
	    NPOT = NPOT - 1
	    GOTO 20
	  END IF
	end if
	DO 240 J=1,3
	  CALL LINCUT(LINE,FELD)
	  READ(FELD,'(BN,F12.0)',ERR=20) XYZF(J)
  240   CONTINUE
	CALL FRACRT(XYZF,XC,INCELL,VOL,1,UNAX,.false.,IERR)
	DO 250 J=1,3
	  XYZC(NATM1,J) = XC(J)
  250   CONTINUE
	CALL LINCUT(LINE,FELD)
	IF(FELD.NE.'$') READ(FELD,'(BN,F12.0)',ERR=20) Q(NATM1)
	IF(ABS(Q(NATM1)).NE.0.0) THEN
	  NCH = NCH + 1
	END IF
	CALL LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') THEN
	  READ(FELD,'(BN,F12.0)',ERR=20) VWR(NATM1)
	END IF
      END IF

*** CELL CONSTANTS
      IF(LID(1:5).EQ.'CELL ') THEN
	IDFND=.true.
	DO 260 J=1,6
	  CALL LINCUT(LINE,FELD)
	  READ(FELD,'(BN,F12.0)',ERR=20) CELL(J)
	  IF(J.GT.3) CELL(J)=CELL(J)/180.0*PI
	  IF((J.LE.3.AND.CELL(J).LT.2.0).OR.
     $       (J.GT.3.AND.(CELL(J).LT.PI/20.OR.CELL(J).GT.0.95*PI))) THEN
	    write(2,'(/1x,a,6f8.2/)') 
     $           'WARNING - UNREASONABLE CELL PARAMETERS: CELL ',CELL
	    write(*,'(/1x,a,6f8.2/)') 
     $           'WARNING - UNREASONABLE CELL PARAMETERS: CELL ',CELL
	  END IF
  260   CONTINUE
	IF(INCELL(1).EQ.0.0) THEN
	  DO 270 J=1,6
	    INCELL(J)=CELL(J)
  270     CONTINUE
	END IF
      END IF

*** INCELL CELL CONSTANTS
      IF(LID(1:7).EQ.'INCELL ') THEN
	IDFND=.true.
	DO 280 J=1,6
	  CALL LINCUT(LINE,FELD)
	  READ(FELD,'(BN,F12.0)',ERR=20) INCELL(J)
	  IF(J.GT.3) INCELL(J)=INCELL(J)/180.0*PI
  280   CONTINUE
	IF(CELL(1).EQ.0.0) THEN
	  DO 290 J=1,6
	    CELL(J)=INCELL(J)
  290     CONTINUE
	END IF
      END IF

*** ROTATION CENTER
      IF(LID(1:5).EQ.'ROTC ') THEN
	IDFND=.true.
	CALL LINCUT(LINE,FELD)
	READ(FELD,'(BN,I12)',ERR=20) L
	DO 295 J=1,3
	  CALL LINCUT(LINE,FELD)
	  READ(FELD,'(BN,F12.0)',ERR=20) XYZF(J)
  295   CONTINUE
	CALL FRACRT(XYZF,XC,INCELL,VOL,1,UNAX,.false.,IERR)
	DO 298 J=1,3
	  ROTC(L,J) = XC(J)
  298   CONTINUE
      END IF

*** MOLE
      IF(LID(1:5).EQ.'MOLE ') THEN
	IDFND=.true.
	IF(NATM1.GE.1) NCLUS=NCLUS+1
      END IF

*** COPY
      IF(LID(1:5).EQ.'COPY ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,I12)',ERR=20) IC
	IF(abs(IC).LE.NCLUS.and.IC.ne.0) THEN
	  NCLUS=NCLUS+1
	  N=NATM1
	  DO 300 I=1,N
	    IF(ICLUS(I).EQ.abs(IC)) THEN
	      NATM1=NATM1+1
	      if(NATM1.gt.NUMATM) then
		write(2,'(/1x,a,i4,a/)') 'ERROR - TOO MANY ATOMS (',
     $            NATM1,') PRODUCED BY COPY. PROGRAM ABORTED.'
		write(*,'(/1x,a,i4,a/)') 'ERROR - TOO MANY ATOMS (',
     $            NATM1,') PRODUCED BY COPY. PROGRAM ABORTED.'
		call DUMP
		stop
	      end if
	      ICLUS(NATM1)=NCLUS
	      ATNAME(NATM1)=ATNAME(I)
	      VWR(NATM1)=VWR(I)
	      RM(NATM1)=RM(I)
	      P(NATM1)=P(I)
	      PTYP(NATM1)=PTYP(I)
	      XYZC(NATM1,1)=XYZC(I,1)
	      XYZC(NATM1,2)=XYZC(I,2)
	      XYZC(NATM1,3)=XYZC(I,3)
	      if(IC.lt.0) then
		XYZC(NATM1,1)=-XYZC(NATM1,1)
		XYZC(NATM1,2)=-XYZC(NATM1,2)
		XYZC(NATM1,3)=-XYZC(NATM1,3)
	      end if
	      Q(NATM1)=Q(I)
	      IF(ABS(Q(NATM1)).NE.0.0) THEN
		NCH=NCH+1
	      END IF
	    END IF
  300     CONTINUE
	END IF
      END IF

*** VARIABLES (FIX/UNFIX)
      IF(LID(1:5).EQ.'VARY '.OR.LID(1:4).EQ.'FIX ') THEN
	IDFND=.true.
	IF(LID(1:5).EQ.'VARY ') THEN
	  IFIX=0
	ELSE
	  IFIX=1
	END IF
  310   CONTINUE
	call LINCUT(LINE,FELD)
	FELD(1:8) = LOHI(FELD(1:8))
	FOUND=.false.
	IF(FELD(1:5).eq.'AUTO '.and.LID(1:5).eq.'VARY ') THEN
	  DO 320 K=1,NUCLUS*6+6+NSUB
	    IF(K.LE.NCLUS*6+6.OR.K.GT.NUCLUS*6+6) IVAR(K)=1
  320     CONTINUE
	  FOUND=.true.
	  AUTO =.true.

** monoclinic
	  IF(ISP.EQ.2) THEN
	    IF(UNAX.EQ.'A') THEN
	      IVAR(5)=0
	      IVAR(6)=0
	      CELL(5)=PI/2
	      CELL(6)=PI/2
	    ELSE IF(UNAX.EQ.'B') THEN
	      IVAR(4)=0
	      IVAR(6)=0
	      CELL(4)=PI/2
	      CELL(6)=PI/2
	    ELSE IF(UNAX.EQ.'C') THEN
	      IVAR(4)=0
	      IVAR(5)=0
	      CELL(4)=PI/2
	      CELL(5)=PI/2
	    END IF
** orthorhombic
	  ELSE IF(ISP.EQ.3) THEN
	    IVAR(4)=0
	    IVAR(5)=0
	    IVAR(6)=0
	    CELL(4)=PI/2
	    CELL(5)=PI/2
	    CELL(6)=PI/2
** tetragonal/hexagonal/trigonal (hex. setting)
	  ELSE IF(ISP.EQ.4.OR.ISP.EQ.6.OR.
     $           (ISP.EQ.5.AND.UNAX.NE.'R')) THEN
	    IVAR(4)=0
	    IVAR(5)=0
	    IVAR(6)=0
	    CELL(4)=PI/2
	    CELL(5)=PI/2
	    CELL(6)=PI/2
	    IF(UNAX.EQ.'A') THEN
	      IVAR(3)=0
	      IF(ISP.GE.5) CELL(4)=2.0/3.0*PI
	    ELSE IF(UNAX.EQ.'B') THEN
	      IVAR(3)=0
	      IF(ISP.GE.5) CELL(5)=2.0/3.0*PI
	    ELSE IF(UNAX.EQ.'C') THEN
	      IVAR(2)=0
	      IF(ISP.GE.5) CELL(6)=2.0/3.0*PI
	    END IF
** trigonal (rhomb. setting)/cubic
	  ELSE IF((ISP.EQ.5.AND.UNAX.EQ.'R').OR.ISP.EQ.7) THEN
	    IVAR(2)=0
	    IVAR(3)=0
	    IVAR(5)=0
	    IVAR(6)=0
	  END IF
** look for single atoms
	  DO 340 L=1,NCLUS
	    K=0
	    DO 330 I=1,NATM1
	      IF(ICLUS(I).EQ.L) K=K+1
  330       CONTINUE
	    IF(K.EQ.1) THEN
	      IVAR(L*6+4)=0
	      IVAR(L*6+5)=0
	      IVAR(L*6+6)=0
	    END IF
  340     CONTINUE
** can I fix some of the translations of the first molecule/ion?
	  IVAR(7)=0
	  IVAR(8)=0
	  IVAR(9)=0
	  DO 350 M=1,NS
	    R1=R(M,1,1)
	    R2=R(M,2,2)
	    R3=R(M,3,3)
	    IF(R1.NE.1.OR.R(M,1,2).NE.0.OR.R(M,1,3).NE.0) IVAR(7)=1
	    IF(R(M,2,1).NE.0.OR.R2.NE.1.OR.R(M,2,3).NE.0) IVAR(8)=1
	    IF(R(M,3,1).NE.0.OR.R(M,3,2).NE.0.OR.R3.NE.1) IVAR(9)=1
  350     CONTINUE
	  IF(ISUM(1).EQ.0.OR.ISUM(2).EQ.0.OR.ISUM(3).EQ.0) THEN
	    CALL FIXCEL(ISUM,T,NS,IVAR,IPAR,NVAR)
	  END IF
	END IF
	DO 360 K=1,NUCLUS*6+6+NSUB
	  IF(FELD.EQ.PNAME(K)) THEN
	    IF(IFIX.EQ.0) IVAR(K)=1
	    IF(IFIX.EQ.1) IVAR(K)=0
	    FOUND=.true.
	  END IF
  360   CONTINUE
** put subrotation to the end of array IVAR
	DO 370 K=1,NUSUB
	  IF(FELD.EQ.RNAME(K)) THEN
	    IF(IFIX.EQ.0) IVAR((NUCLUS+1)*6+K)=1
	    IF(IFIX.EQ.1) IVAR((NUCLUS+1)*6+K)=0
	    FOUND=.true.
	  END IF
  370   CONTINUE
	IF(.not.FOUND.and.FELD.ne.' ') THEN
	  write(2,'(/1x,3a/)') 'WARNING - DON''T KNOW PARAMETER NAME ',
     $                        FELD(1:8),'.'
	  write(*,'(/1x,3a/)') 'WARNING - DON''T KNOW PARAMETER NAME ',
     $                        FELD(1:8),'.'
	END IF
	IF(FELD.NE.' ') GOTO 310
** count and sort variables
	NVAR=0
** cell constants, translations, rotations:
	DO 380 K=1,NUCLUS*6+6
	  IF(IVAR(K).gt.0) THEN
	    NVAR=NVAR+1
	    if(NVAR.gt.NV) then
	      write(2,'(/1x,a,i4,2a/)')'WARNING - TOO MANY VARIABLES (',
     $                           NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
	      write(*,'(/1x,a,i4,2a/)')'WARNING - TOO MANY VARIABLES (',
     $                           NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
	    else
	      IVAR(K)=NVAR
	      IPAR(NVAR)=K
	    end if
	  END IF
  380   CONTINUE
** subrotations:
	DO 390 K=1,NUSUB
	  IF(IVAR((NUCLUS+1)*6+K).gt.0) THEN
	    NVAR=NVAR+1
	    if(NVAR.gt.NV) then
	      write(2,'(/1x,a,i4,a/)') 'WARNING - TOO MANY VARIABLES (',
     $                           NVAR,'). ',RNAME(K),' WILL BE IGNORED.'
	      write(*,'(/1x,a,i4,a/)') 'WARNING - TOO MANY VARIABLES (',
     $                           NVAR,'). ',RNAME(K),' WILL BE IGNORED.'
	      NVAR=NVAR-1
	    else
	      IVAR((NUCLUS+1)*6+K)=NVAR
	      IPAR(NVAR)=(NUCLUS+1)*6+K
	    end if
	  END IF
  390   CONTINUE
** auto constraints
	IF(AUTO) THEN
** tetragonal/hexagonal/trigonal (hex. setting)
	  IF(ISP.EQ.4.OR.ISP.EQ.6.OR.(ISP.EQ.5.AND.UNAX.NE.'R')) THEN
	    IF(UNAX.EQ.'A') THEN
	      IVAR(3)=IVAR(2)
	    ELSE IF(UNAX.EQ.'B') THEN
	      IVAR(3)=IVAR(1)
	    ELSE IF(UNAX.EQ.'C') THEN
	      IVAR(2)=IVAR(1)
	    END IF
** trigonal (rhomb. setting)/cubic
	  ELSE IF((ISP.EQ.5.AND.UNAX.EQ.'R').OR.ISP.EQ.7) THEN
	    IVAR(2)=IVAR(1)
	    IVAR(3)=IVAR(1)
	    IF(ISP.EQ.5) IVAR(5)=IVAR(4)
	    IF(ISP.EQ.5) IVAR(6)=IVAR(4)
	  END IF
	END IF
	DO 400 I=NVAR+1,NV
	  IPAR(I)=0
  400   CONTINUE
      END IF

*** DEFINE SUBROTATIONS
      IF(LID(1:6).EQ.'INROT ') THEN
	IDFND=.true.
	NSUB=NSUB+1
	IF(NSUB.GT.NUSUB) THEN
	  write(2,'(/1x,a/1x,a/)') 
     $      'WARNING - TOO MANY SUBROTATIONS.',
     $       'SUBROTATION WILL BE IGNORED.'
	  write(*,'(/1x,a/1x,a/)') 
     $      'WARNING - TOO MANY SUBROTATIONS.',
     $       'SUBROTATION WILL BE IGNORED.'
	  NSUB=NSUB-1
	  GOTO 20
	END IF
	call LINCUT(LINE,FELD)
	RATN(1,NSUB)=LOHI(FELD(1:8))
	call LINCUT(LINE,FELD)
	RATN(2,NSUB)=LOHI(FELD(1:8))
	IF(RATN(1,NSUB).EQ.' '.OR.RATN(2,NSUB).EQ.' ') THEN
	  write(2,'(/1x,a/1x,a,1x,2a/)') 
     $      'WARNING - NOT ENOUGH SUBROTATION DEFINING ATOMS:',
     $        RATN(1,NSUB),RATN(2,NSUB),
     $       '. THIS SUBROTATION WILL BE IGNORED.'
	  write(*,'(/1x,a/1x,a,1x,2a/)') 
     $      'WARNING - NOT ENOUGH SUBROTATION DEFINING ATOMS:',
     $        RATN(1,NSUB),RATN(2,NSUB),
     $       '. THIS SUBROTATION WILL BE IGNORED.'
	  NSUB=NSUB-1
	END IF
      END IF

*** CONSTRAINTS
      IF(LID(1:5).EQ.'CNST ') THEN
	IDFND=.true.
	BM=1
	call LINCUT(LINE,FELD)
	L1=0
	DO 410 K=1,NUCLUS*6+6
	  IF(LOHI(FELD(1:8)).EQ.PNAME(K)) L1=K
  410   CONTINUE
	DO 420 K=1,NUSUB
	  IF(LOHI(FELD(1:8)).EQ.RNAME(K)) L1=K+NUCLUS*6+6
  420   CONTINUE
	IF(L1.EQ.0) THEN
	  write(2,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  write(*,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  GOTO 20
	END IF
	CS=0
	call LINCUT(LINE,FELD)
	IF(FELD.EQ.'=') CS=1
	IF(FELD.EQ.'<>') CS=-1
	IF(CS.eq.0) THEN
	  write(2,'(/1x,4a)') 
     $     'WARNING - ILLEGAL CHARACTER ',FELD(1:8),'. ',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  write(*,'(/1x,4a)') 
     $     'WARNING - ILLEGAL CHARACTER ',FELD(1:8),'. ',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  GOTO 20
	END IF
	call LINCUT(LINE,FELD)
	if(FELD.eq.'-') THEN
	  BM=-1
	  call LINCUT(LINE,FELD)
	end if
	L2=0
	DO 430 K=1,NUCLUS*6+6
	  IF(LOHI(FELD(1:8)).EQ.PNAME(K)) L2=K
  430   CONTINUE
	DO 440 K=1,NUSUB
	  IF(LOHI(FELD(1:8)).EQ.RNAME(K)) L2=K+NUCLUS*6+6
  440   CONTINUE
	IF(L2.EQ.0) THEN
	  write(2,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  write(*,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
	  GOTO 20
	END IF
	IF((L1.LE.3.AND.L2.GT.3).OR.(L1.GT.3.AND.L2.LE.3).OR.
     $     (L1.LE.6.AND.L2.GT.6).OR.(L1.GT.6.AND.L2.LE.6)) THEN
	  write(2,'(/1x,5a)') 
     $     'ILLEGAL CONSTRAINT ',PNAME(L1),' ',PNAME(L2),
     $     '. THIS CONSTRAINT WILL BE IGNORED.'
	  write(*,'(/1x,5a)') 
     $     'ILLEGAL CONSTRAINT ',PNAME(L1),' ',PNAME(L2),
     $     '. THIS CONSTRAINT WILL BE IGNORED.'
	  GOTO 20
	END IF
	IF(CS.EQ.1) IVAR(L1) = BM*IVAR(L2)
	IF(CS.EQ.-1) IVAR(L1) = 0
	GOTO 20
      END IF

*** BOND LENGTH
      IF(LID(1:5).EQ.'BOND ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	LABEL1 = FELD
	call LINCUT(LINE,FELD)
	LABEL2 = FELD
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=20) BL
	call BONDL(LABEL1,LABEL2,BL)
      END IF

*** SPECIAL POSITIONS
      IF(LID(1:5).EQ.'SPEC ') THEN
	IDFND=.true.
	SPEC=.true.
      END IF

*** PARAMETERS
      IF(LID(1:5).EQ.'PARM ') THEN
	IDFND=.true.
	NP=NP+1
	if(NP.gt.NUCLUS+1+(NUSUB-1)/6) 
     $               write(2,'(1x,a)') 'WARNING! too many PARM lines'
	if(NP.gt.NUCLUS+1+(NUSUB-1)/6) 
     $               write(*,'(1x,a)') 'WARNING! too many PARM lines'
	do 450 J=1,6
	  call LINCUT(LINE,FELD)
	  IF(FELD.NE.'$') READ(FELD,'(BN,F12.0)',ERR=20) PAR(NP,J)
  450   continue
      END IF

*** SUMMATION RADIUS
      IF(LID(1:5).EQ.'SUMR ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=20) SUMR
	call LINCUT(LINE,FELD)
	if(FELD.ne.' ') THEN
	  ISUM(1)=int(SUMR)
	  SUMR=0.0
	  READ(FELD,'(BN,I12)',ERR=20) ISUM(2)
	  call LINCUT(LINE,FELD)
	  READ(FELD,'(BN,I12)',ERR=20) ISUM(3)
	ELSE
	  ISUM(1)=0
	  ISUM(2)=0
	  ISUM(3)=0
	END IF
      END IF

** Minimum height of cell
      IF(LID(1:5).EQ.'MINR ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=20) MINR
      END IF
*** PRESSURE
      IF(LID(1:5).EQ.'PRES ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,F12.0)',ERR=20) PRESS
      END IF

*** INITIALIZE RANDOM NUMBER GENERATOR (RANDOM SEED)
      IF(LID(1:5).EQ.'RNSD ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,I12)',ERR=20) IDUM
      END IF

** LOOP
      IF(LID(1:5).EQ.'LOOP ') THEN
	IDFND=.true.
	if(INLOOP) goto 20
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,I12)',ERR=20) ILOOP1
	if(ILOOP1.lt.1.or.ILOOP1.gt.99) write(2,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP1:',ILOOP1
	if(ILOOP1.lt.1.or.ILOOP1.gt.99) write(*,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP1:',ILOOP1
	call LINCUT(LINE,FELD)
	READ(FELD,'(BN,I12)',ERR=20) ILOOP2
	if(ILOOP2.eq.0) ILOOP2=ILOOP1
	if(ILOOP2.lt.1.or.ILOOP2.gt.99.or.ILOOP2.lt.ILOOP1) 
     $      write(2,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP2:',ILOOP2
	if(ILOOP2.lt.1.or.ILOOP2.gt.99.or.ILOOP2.lt.ILOOP1) 
     $      write(*,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP2:',ILOOP2
	INLOOP=.true.
      END IF

*** ROSENBROCK OR POWELL METHOD
      if(LID(1:5).eq.'ROBR '.or.LID(1:5).eq.'POWL ') THEN
	IDFND=.true.
	if(LID(1:5).eq.'ROBR ') METHOD=1
	if(LID(1:5).eq.'POWL ') METHOD=2
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(4)
	if(IPA(2).eq.0) IPA(2)=500
	IPA(1)=20
	RPA(1)=1e-4
	RPA(2)=1e-8
	RPA(3)=-.05
	if(RPA(4).eq.0.0) RPA(4)=1e-6
	GOTO 500
      end if
*** THRESHOLD ACCEPTING, GREAT DELUGE OR SIMULATED ANNEALING METHOD      
      if(LID(1:5).eq.'THAC '.or.LID(1:5).eq.'GRDL '.or.
     $   LID(1:5).eq.'SMAN ') THEN
	IDFND=.true.
	if(LID(1:5).eq.'GRDL ') METHOD=3
	if(LID(1:5).eq.'THAC ') METHOD=4
	if(LID(1:5).eq.'SMAN ') METHOD=5
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(1)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(1)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(2)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(4)
	if(RPA(1).eq.0.0) RPA(1)=1e-2
	RPA(3)=0.5
	GOTO 500
      end if

*** MELTING     
      if(LID(1:5).eq.'MELT ') THEN
	IDFND=.true.
	METHOD=6
	call LINCUT(LINE,FELD)
	IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
	RPA(3)=0.5
	GOTO 500
      end if

*** GRID SEARCH METHOD OR 2-DIM. MAP
      if(LID(1:5).eq.'GRID '.or.LID(1:4).eq.'MAP ') THEN
	IDFND=.true.
	if(LID(1:5).eq.'GRID ') METHOD=7
	if(LID(1:4).eq.'MAP ') METHOD=10
	do 460 J=1,12
	  call LINCUT(LINE,FELD)
	  IF(FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) STEP(J)
	  call LINCUT(LINE,FELD)
	  IF(FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) ISTP(J)
	  IF(ISTP(J).LT.0.OR.(ISTP(J).GT.64.AND.METHOD.eq.10)) THEN
	    WRITE(2,'(/1x,2a,i5,a/)') 
     $                'ERROR - ILLEGAL NO. OF STEPS FOR MAP OR GRID',
     $                ' SEARCH:',ISTP(J),'. PROGRAM ABORTED.'
	    WRITE(*,'(/1x,2a,i5/)') 
     $                'ERROR - ILLEGAL NO. OF STEPS FOR MAP OR GRID',
     $                ' SEARCH:',ISTP(J),'. PROGRAM ABORTED.'
	    CALL DUMP
	    STOP
	  END IF
  460   continue
	GOTO 500
      end if

*** STEEPEST DESCENT OR DAMPED NEWTON METHOD
      if(LID(1:5).eq.'STDS '.or.LID(1:5).eq.'NEWT ') THEN
	IDFND=.true.
	if(LID(1:5).eq.'STDS ') METHOD=8
	if(LID(1:5).eq.'NEWT ') METHOD=9
	RPA(4)=0.1
	RPA(1)=1e-5
	RPA(2)=1e-6
	IPA(1)=100
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(1)
	call LINCUT(LINE,FELD)
**     in this case epsmi is epsgrd
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(4)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(2)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(1)
	IPA(2)=IPA(1)*(2*NVAR+10)
	GOTO 500
      end if

*** ENERGY AND GRADIENT
      if(LID(1:5).eq.'STAT ') THEN
	IDFND=.true.
	METHOD=11
	IANALY=0
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IANALY
	GOTO 500
      end if

*** SIMPLEX
      if(LID(1:5).eq.'SIMP ') THEN
	IDFND=.true.
	METHOD=12
	RPA(2)=1e-8
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(2)
	call LINCUT(LINE,FELD)
	IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(2)
	GOTO 500
      end if

*** NAME OF POTENTIAL
      if(LID(1:5).eq.'PTYP ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	PTNAME = LOHI(FELD(1:8))
      END IF

*** POTENTIAL FILE      
      IF(LID(1:5).EQ.'FPOT '.AND.FN1.EQ.0) THEN
	IDFND=.true.
	POTFIL=LINE(6:)
	open(unit=8,file=POTFIL,status='old',err=1010)
	FN1=FN
	FN=8
      ELSE IF(LID(1:5).EQ.'FPOT '.AND.FN1.NE.0) THEN
	IDFND=.true.
	WRITE(2,*) 'POTENTIAL FILE ALREADY OPEN. CANNOT OPEN A ',
     $             'SECOND ONE.'
	WRITE(*,*) 'POTENTIAL FILE ALREADY OPEN. CANNOT OPEN A ',
     $             'SECOND ONE.'
      END IF

*** POTENTIAL PARAMETERS
      IF(LID(1:4).eq.'POT ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	A1=LOHI(FELD(1:8))
	FOUND=.false.
	M1=0
	do 470 I=1,NPOT
	  if(A1.eq.PNAM(I)) then
	    FOUND=.true.
	    M1=I
	  end if
  470   continue
	if(.not.FOUND) goto 20
	call LINCUT(LINE,FELD)
	A2=LOHI(FELD(1:8))
	FOUND=.false.
	M2=0
	do 480 I=1,NPOT
	  if(A2.eq.PNAM(I)) then
	    FOUND=.true.
	    M2=I
	  end if
  480   continue
	if(.not.FOUND) goto 20
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,1)
	POT(M2,M1,1)=POT(M1,M2,1)
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,2)
	POT(M2,M1,2)=POT(M1,M2,2)
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,3)
	POT(M2,M1,3)=POT(M1,M2,3)
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,4)
	POT(M2,M1,4)=POT(M1,M2,4)
      END IF
*** SURFACE POTENTIAL PARAMETERS
      IF(LID(1:5).eq.'SURF ') THEN
	IDFND=.true.
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) SPOT(1,1)
	call LINCUT(LINE,FELD)
	read(FELD,'(bn,f12.0)',err=20) SPOT(1,2)
      END IF        

** End of File
      if(LID(1:4).eq.'END '.and.FN1.eq.0) goto 490
      if(LID(1:4).eq.'END '.and.FN1.ne.0) then
	CLOSE(UNIT=FN)
	FN=FN1
	FN1=0
	goto 20
      end if
      if(LID(1:4).eq.'REM ') IDFND=.true.
      if(LID(1:5).eq.'DUMP ') then
	IDFND=.true.
	call DUMP
      end if
      if(LID.eq.' ') IDFND=.true.         
      if(.not.IDFND) then
	WRITE(2,'(/1x,3a/)') 'WARNING - LINE ID ',LID,' NOT FOUND.'
	WRITE(*,'(/1x,3a/)') 'WARNING - LINE ID ',LID,' NOT FOUND.'
      end if

****************** MAIN LOOP END
      GOTO 20

  490 CONTINUE
      IF(FN1.NE.0) THEN
	CLOSE(UNIT=FN)
	FN=FN1
	FN1=0
	goto 20
      END IF
      IEND=-1
  500 CONTINUE
** CALCULATE MISSING POTENTIAL PARAMETERS BY GEOMETRICAL MEANS
      DO 510 M1=1,NPOT
	DO 510 M2=1,NPOT
	  IF(POT(M1,M2,1).EQ.0.0) THEN
	    POT(M1,M2,1)=sqrt(POT(M1,M1,1)*POT(M2,M2,1))
	    POT(M2,M1,1)=POT(M1,M2,1)
	  END IF
	  IF(POT(M1,M2,2).EQ.0.0) THEN
	    POT(M1,M2,2)=(POT(M1,M1,2)+POT(M2,M2,2))/2.0
	    POT(M2,M1,2)=POT(M1,M2,2)
	  END IF
	  IF(POT(M1,M2,3).EQ.0.0) THEN
	    POT(M1,M2,3)=sqrt(POT(M1,M1,3)*POT(M2,M2,3))
	    POT(M2,M1,3)=POT(M1,M2,3)
	  END IF
	  IF(POT(M1,M2,4).EQ.0.0) THEN
	    POT(M1,M2,4)=(POT(M1,M1,4)+POT(M2,M2,4))/2.0
	    POT(M2,M1,4)=POT(M1,M2,4)
	  END IF
  510 CONTINUE
** ARE THERE SOME ATOMS WITHOUT POTENTIAL PARAMETERS?
      DO 520 M1=1,NPOT
	IF(POT(M1,M1,1).eq.0.0.and.POT(M1,M1,2).eq.0.0.and.
     $     POT(M1,M1,3).eq.0.0.and.POT(M1,M1,4).eq.0.0.and.
     $     PTNAME.ne.'SQUARE'.and.PTNAME.ne.'SOFT') THEN
	  WRITE(2,'(/1x,a,a/)') 
     $           'WARNING - NO PARAMETERS FOUND FOR ATOM TYPE ',PNAM(M1)
	  WRITE(*,'(/1x,a,a/)') 
     $           'WARNING - NO PARAMETERS FOUND FOR ATOM TYPE ',PNAM(M1)
	END IF
  520 CONTINUE
      DO 550 M1=2,NPOT+1
	IF(SPOT(M1,1).EQ.0.0) THEN
	  SPOT(M1,1)=sqrt(SPOT(1,1)*POT(M1-1,M1-1,1))
	  SPOT(M1,2)=sqrt(SPOT(1,2)*POT(M1-1,M1-1,3))
	END IF
  550 CONTINUE

************************************************************************
** LOOK FOR THE SUBROTATION-DEFINING ATOMS
      do 720 N=1,NSUB
	FOUND=.false.
	do 700 I=1,NATM1
	  if(ATNAME(I).eq.RATN(1,N)) then
	    ISUB(1,N) = I
	    FOUND=.true.
	    goto 710
	  end if
  700   continue
  710   continue
	if(.NOT.FOUND) THEN
	  write(2,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(1,N),'. THIS SUBROTATION WILL BE IGNORED.'
	  write(*,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(1,N),'. THIS SUBROTATION WILL BE IGNORED.'
	  ISUB(1,N) = -1
	  ISUB(2,N) = -1
	END IF
  720 continue
      do 740 N=1,NSUB
	FOUND=.false.
	do 730 I=1,NATM1
	  if(ATNAME(I).eq.RATN(2,N)) then
	    ISUB(2,N) = I
	    FOUND=.true.
	    goto 735
	  end if
  730   continue
  735   continue
	if(.NOT.FOUND) THEN
	  write(2,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(2,N),'. THIS SUBROTATION WILL BE IGNORED.'
	  write(*,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(2,N),'. THIS SUBROTATION WILL BE IGNORED.'
	  ISUB(1,N) = -1
	  ISUB(2,N) = -1
	END IF
  740 continue
** Default symmetries
      if(NS.eq.0) then
	NS=1
	SPG='P1'
      end if
** Reduce symmetry translation vector
      do 760 M=1,NS
	do 750 J=1,3
	  if(T(M,J).gt.0.5) T(M,J) = T(M,J) - 1.0
	  if(T(M,J).lt.-.5) T(M,J) = T(M,J) + 1.0
  750   continue
  760 continue
** do I have to vary cell constants and can I fix the orientation of the
** first molecule?
      IF(AUTO.AND.(ISUM(1).EQ.0.OR.ISUM(2).EQ.0.OR.ISUM(3).EQ.0)) THEN
	CALL FIXCEL(ISUM,T,NS,IVAR,IPAR,NVAR)
      END IF
      return
 1010 continue
      write(2,'(/1x,2a/)') 
     $       'ERROR - CANNOT FIND THE POTENTIAL FILE ',POTFIL
      write(*,'(/1x,2a/)') 
     $       'ERROR - CANNOT FIND THE POTENTIAL FILE ',POTFIL
      return
      END
      
      subroutine SPGR(FELD,S,R,T,NR,NS,ICENT,BLTP)
** looks for space group name/number and reads R and T.
** Version 16.11.95
** variables:
** BLTP:      c  Bravais lattice type
** FOUND:     l  .false.: given space group not found in space group table
** ICENT:     i  centricity code (ICENT=1: centrosymmetric structure)
** FELD:      c  space group name or space group number to look for
** NAME:      c  space group name found in space group table
** NR:        i  space group number found in space group table
** NS:        i  number of symmetry operations
** R(I,J,K):  i  rotational part of symmetry operation no. I to give
**               Jth component of position
** S          c  unique axis to look for
** UNAX:      c  unique axis (a, b, c) found in space group table
** T(I,J):    r  translational part of symmetry operation no. I to give
**               Jth component of position
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUSYM=24)
      character FELD*8,NAME*8,UNAX*1,S*1,BLTP*1,LOHI*8
      real T(NUSYM,3)
      integer NR, NS, ICENT, I1(3),I2(3), R(NUSYM,3,3)
      logical FOUND
************************************************************************
      FOUND = .false.
      open(unit=3,file='space.dat',status='old',err=999)
** name or number?
      if(FELD(1:1).ge.'0'.and.FELD(1:1).le.'9') then
	read(FELD,'(bn,i12)',err=100) LOOKNR
	goto 150
      end if
** look for space group name
   10 continue
      read(3,'(i4,2x,i2,3x,i1,3x,a8,a1)',end=100) NR,NS,ICENT,NAME,UNAX
      if(LOHI(NAME).eq.LOHI(FELD).and.
     $  (LOHI(UNAX//'       ').eq.LOHI(S//'       ').or.' '.eq.S.or.
     $                                              UNAX.eq.' ')) then
	if(UNAX.ne.' ') print*,'space group ',NAME,', ',UNAX
	if(UNAX.eq.' ') print*,'space group ',NAME
	FOUND=.true.
	FELD = LOHI(NAME)
	BLTP = NAME(1:1)
	if(NS.gt.NUSYM) then
	  write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (',NS,
     $         ') FOR THIS SPACE GROUP. PROGRAM ABORTED.'
	  write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (',NS,
     $         ') FOR THIS SPACE GROUP. PROGRAM ABORTED.'
	  call DUMP
	  stop
	end if
	do 20 J=1,NS
	  read(3,'(3(2i3,3i3))') (I1(K),I2(K),(R(J,K,L),L=1,3),K=1,3)
	  do 30 K=1,3
	    if(I2(K).ne.0) then
	      T(J,K) = real(I1(K))/I2(K)
	    else
	      T(J,K) = 0.0
	    end if
   30     continue
   20   continue
	S = LOHI(UNAX)
	call SYMMCL(BLTP,ICENT)
      else
	do 140 J=1,NS
	  read(3,*,end=100)
  140   continue
	goto 10
      end if
      goto 100
** look for space group number
  150 continue
      read(3,'(i4,2x,i2,3x,i1,3x,a8,a1)',end=100) NR,NS,ICENT,NAME,UNAX
      if(NR.eq.LOOKNR.and.
     $  (LOHI(UNAX//'       ').eq.LOHI(S//'       ').or.' '.eq.S
     $                                           .or.UNAX.eq.' ')) then
	if(UNAX.ne.' ') print*,'space group ',NAME,', ',UNAX
	if(UNAX.eq.' ') print*,'space group ',NAME
	FELD = LOHI(NAME)
	BLTP = NAME(1:1)
	FOUND=.true.
	do 160 J=1,NS
	  read(3,'(3(2i3,3i3))') (I1(K),I2(K),(R(J,K,L),L=1,3),K=1,3)
	  do 170 K=1,3
	    if(I2(K).ne.0) then
	      T(J,K) = real(I1(K))/I2(K)
	    else
	      T(J,K) = 0.0
	    end if
  170     continue
  160   continue
	call SYMMCL(BLTP,ICENT)
      else
	do 180 J=1,NS
	  read(3,*,end=100)
  180   continue
	goto 150
      end if
  100 continue
      if(.not.FOUND) then
	write(2,'(/1x,4a/)') 'WARNING - SPACE GROUP ',FELD,S,
     $                       ' NOT FOUND. SPGR P1 ASSUMED.'
	write(*,'(/1x,4a/)') 'WARNING - SPACE GROUP ',FELD,S,
     $                       ' NOT FOUND. SPGR P1 ASSUMED.'
	FELD='P1'
      end if
  999 continue
      close(3)
      end
      
      subroutine SYMMCL(BLTP,ICENT)
** INCLUDES TRANSLATIONS AND CENTER OF SYMMETRY
** WRITES SYMMLS
** CREATES LIST OF DIFFERENT ROTATIONS
** Version 02.05.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
      integer ICENT
      character BLTP*1,SC(-1:1,3)*2
      logical EQUAL1,EQUAL2
      data ((SC(I,J),I=-1,1),J=1,3) /'-X',' ','+X','-Y',' ','+Y',
     $                               '-Z',' ','+Z'/

** face-centered of body-centered
      if(BLTP.eq.'A'.or.BLTP.eq.'B'.or.BLTP.eq.'C'.or.BLTP.eq.'I')then
	do 510 J=1,NS
	  do 510 K=1,3
	    T(J+NS,K) = T(J,K)
	    if(BLTP.eq.'I') T(J+NS,K)=T(J,K)+0.5
	    if(K.eq.1.and.(BLTP.eq.'B'.or.BLTP.eq.'C'))
     $                                       T(J+NS,K)=T(J,K)+0.5
	    if(K.eq.2.and.(BLTP.eq.'A'.or.BLTP.eq.'C'))
     $                                       T(J+NS,K)=T(J,K)+0.5
	    if(K.eq.3.and.(BLTP.eq.'A'.or.BLTP.eq.'B'))
     $                                       T(J+NS,K)=T(J,K)+0.5
	    do 510 L=1,3
	      R(J+NS,K,L) = R(J,K,L)
  510   continue
	NS = NS*2
      end if
      if(BLTP.eq.'F') then
	do 520 J=1,NS
	  do 520 K=1,3
	    do 520 M=1,3
	    T(J+M*NS,K) = T(J,K)+0.5
	    if(K.eq.M) T(J+M*NS,K)=T(J,K)
	    do 520 L=1,3
	      R(J+M*NS,K,L) = R(J,K,L)
  520   continue
	NS = NS*4
      end if
** rhombohedral
      if(BLTP.eq.'R'.and.UNAX.ne.'R') then
	do 530 J=1,NS
	  do 530 K=1,3
	    do 530 M=1,2
	      if(K.eq.1) then
		if(M.eq.1) T(J+M*NS,K) = T(J,K)+1.0/3
		if(M.ne.1) T(J+M*NS,K) = T(J,K)+2.0/3
	      else
		if(M.eq.1) T(J+M*NS,K) = T(J,K)+2.0/3
		if(M.ne.1) T(J+M*NS,K) = T(J,K)+1.0/3
	      end if
	      do 530 L=1,3
		R(J+M*NS,K,L) = R(J,K,L)
  530   continue
	NS = NS*3
      end if
** centrosymmetric
      if(ICENT.eq.1) then
	do 540 J=1,NS
	  do 540 K=1,3
	    T(J+NS,K) = 1.0-T(J,K)
	      do 540 L=1,3
		R(J+NS,K,L) = -R(J,K,L)
  540   continue
	NS = NS*2
      end if
      do 700 I=1,NS
	SYMMLS(I)=' '
	SYMMLS(I)(11:11)=','
	SYMMLS(I)(22:22)=','
	do 590 J=1,3
	  if(abs(1./6-abs(T(I,J)) ).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/6'
	  if(abs(1./4-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/4'
	  if(abs(1./3-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/3'
	  if(abs(1./2-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/2'
	  if(abs(2./3-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='2/3'
	  if(abs(3./4-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='3/4'
	  if(abs(5./6-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='5/6'
	  if(abs(7./6-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='7/6'
	  if(T(I,J).lt.0.0) SYMMLS(I)(J*11-10:J*11-10)='-'
	  do 580 K=1,3
	    SYMMLS(I)(J*11+K*2-8:J*11+K*2-7)=SC(R(I,J,K),K)
  580     continue
  590   continue
** Delete spaces
	do 610 K=1,9
	  do 600 J=1,32
	    if(SYMMLS(I)(J:J).eq.' ') then
	      SYMMLS(I)=SYMMLS(I)(1:J-1)//SYMMLS(I)(J+1:33)//' '
	    end if
  600     continue
  610   continue
** Delete leading '+' characters
	if(SYMMLS(I)(1:1).eq.'+') SYMMLS(I)=SYMMLS(I)(2:33)//' '
	do 620 K=1,2
	  KI=index(SYMMLS(I),',+')
	  if(KI.ne.0) SYMMLS(I)=SYMMLS(I)(1:KI)//SYMMLS(I)(KI+2:33)//' '
  620   continue
  700 continue
** create list of different orientations
      NSYM=0
      EQUAL1=.false.
      EQUAL2=.false.
      do 750 M=1,NS
	do 740 N=1,M-1
	  EQUAL1=.true.
	  EQUAL2=.true.
	  do 730 J=1,3
	    do 720 K=1,3
	      if(R(M,J,K).ne.R(N,J,K)) then
		EQUAL1=.false.
	      end if
	      if(R(M,J,K).ne.-R(N,J,K)) then
		EQUAL2=.false.
	      end if
  720       continue
  730     continue
	  if(EQUAL1) then
	    ISYM(M)=ISYM(N)
	    goto 750
	  else if(EQUAL2) then
	    ISYM(M)=-ISYM(N)
	    goto 750
	  end if
  740   continue
	if(.not.EQUAL1.and..not.EQUAL2) then
	  NSYM=NSYM+1
	  ISYM(M)=NSYM
	end if
	if(NSYM.gt.NUSYM/4) then
	  write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY DIFFERENT ORIENTATIONS (',NSYM,
     $         ') FOR THIS SPACE GROUP. PROGRAM ABORTED.'
	  write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY DIFFERENT ORIENTATIONS (',NSYM,
     $         ') FOR THIS SPACE GROUP. PROGRAM ABORTED.'
	  call DUMP
	  stop
	end if
  750 continue
      end
      
      subroutine ANASYM(ISP)
** Version 26.11.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************
** additional Variables:
************************************************************************
** SGMAT(M)  i describes the type of rotation or inversion of matrix
**             R(M,I,J)   
** IDIR(N)   i indicates if there is a symmetry element in the direction N 
**             0: no, 1: yes
**             N=1, 2, 3: a, b, c-direction
**             N=4, 5, 6, 7: space diagonal, abc, -abc, a-bc, ab-c-direction
** ISP       i crystal system
**             1: triclinic, 2: monoclinic, 3: orthorhombic, 4: tetragonal
**             5: trigonal, 6: hexagonal, 7: cubic
** ITRAC     i trace of matrix
**
      integer SGMAT(NUSYM),IDIR(10),IDET(NUSYM)
      do 5 I=1,10
	IDIR(I)=0
    5 continue
      do 10 M=1,NS
	IDET(M)=R(M,1,1)*R(M,2,2)*R(M,3,3)+R(M,1,2)*R(M,2,3)*R(M,3,1)+
     $          R(M,1,3)*R(M,2,1)*R(M,3,2)-R(M,1,1)*R(M,2,3)*R(M,3,2)-
     $          R(M,1,2)*R(M,2,1)*R(M,3,3)-R(M,1,3)*R(M,2,2)*R(M,3,1)
	ITRAC=R(M,1,1)+R(M,2,2)+R(M,3,3)
	if(ITRAC.eq.3) SGMAT(M)=1
	if(ITRAC.eq.-3) SGMAT(M)=-1
	if(ITRAC.eq.-1.and.IDET(M).eq.1) SGMAT(M)=2
	if(ITRAC.eq.1.and.IDET(M).eq.1) SGMAT(M)=4
	if(ITRAC.eq.-1.and.IDET(M).eq.-1) SGMAT(M)=-4
	if(ITRAC.eq.1.and.IDET(M).eq.-1) SGMAT(M)=-2
	if(ITRAC.eq.0) SGMAT(M)=IDET(M)*3
	if(ITRAC.eq.2) SGMAT(M)=IDET(M)*6
   10 continue
      NR2=0
      NR3=0
      NR4=0
      NR6=0
      I4=0
      do 20 M=1,NS
	ITRAC=R(M,1,1)+R(M,2,2)+R(M,3,3)
** Twofold rotation or screw axis along or mirror or glide plane 
** perpendicular to a cell edge
	if(abs(SGMAT(M)).eq.2) then
	  NR2=NR2+1
	  if(ITRAC*R(M,1,1).eq.-1.and.
     $               R(M,1,2)+R(M,1,3)+R(M,2,1)+R(M,3,1).eq.0) IDIR(1)=1
	  if(ITRAC*R(M,2,2).eq.-1.and.
     $               R(M,1,2)+R(M,3,2)+R(M,2,1)+R(M,2,3).eq.0) IDIR(2)=1
	  if(ITRAC*R(M,3,3).eq.-1.and.
     $               R(M,1,3)+R(M,2,3)+R(M,3,1)+R(M,3,2).eq.0) IDIR(3)=1
	end if                                                  
** Threefold rotation or screw axis parallel to a cell edge
	if(abs(SGMAT(M)).eq.3) then
	  NR3=NR3+1
	  if(R(M,1,1)*IDET(M).eq.1) IDIR(1)=1
	  if(R(M,2,2)*IDET(M).eq.1) IDIR(2)=1
	  if(R(M,3,3)*IDET(M).eq.1) IDIR(3)=1
	end if
** Threefold rotation or screw axis parallel to a space diagonal
	if(abs(SGMAT(M)).eq.3) then
	  if(R(M,1,1).eq.0.and.R(M,2,2).eq.0.and.R(M,3,3).eq.0) then
	    if(R(M,1,3).ne.0) then
	      I1=R(M,2,1)*IDET(M)
	      I2=R(M,3,2)*IDET(M)
	    else
	      I1=R(M,1,2)*IDET(M)
	      I2=R(M,2,3)*IDET(M)
	    end if
	    if(I1.eq.1.and.I2.eq.1) IDIR(4)=1
	    if(I1.eq.-1.and.I2.eq.1) IDIR(5)=1
	    if(I1.eq.-1.and.I2.eq.-1) IDIR(6)=1
	    if(I1.eq.1.and.I2.eq.-1) IDIR(7)=1
	  end if
	end if
** Fourfold rotation or screw axis
	if(abs(SGMAT(M)).eq.4) then
	  NR4=NR4+1
	  if(R(M,1,1)*IDET(M).eq.1) then
	    IDIR(1)=1
	    I4=1
	  else if(R(M,2,2)*IDET(M).eq.1) then
	    IDIR(2)=1
	    I4=2
	  else if(R(M,3,3)*IDET(M).eq.1) then
	    IDIR(3)=1
	    I4=3
	  end if
	end if
** Sixfold rotation or screw axis parallel to a cell edge
	if(abs(SGMAT(M)).eq.6) then
	  NR6=NR6+1
	  ISP=6
	  if(R(M,1,1)*IDET(M).eq.1.and.R(M,1,2)+R(M,1,3).eq.0) IDIR(1)=1
	  if(R(M,2,2)*IDET(M).eq.1.and.R(M,2,1)+R(M,2,3).eq.0) IDIR(2)=1
	  if(R(M,3,3)*IDET(M).eq.1.and.R(M,3,1)+R(M,3,2).eq.0) IDIR(3)=1
	end if
	ID=IDIR(1)+IDIR(2)+IDIR(3)
** triclinic
	if(ID.eq.0) then
	  ISP=1
	  UNAX='A'
** monoclinic
	else if(NR3.eq.0.and.NR4.eq.0.and.NR6.eq.0.and.ID.eq.1) then
	  ISP=2
	  if(IDIR(1).eq.1) UNAX='A'
	  if(IDIR(2).eq.1) UNAX='B'
	  if(IDIR(3).eq.1) UNAX='C'
** orthorhombic
	else if(NR3.eq.0.and.NR4.eq.0.and.NR6.eq.0.and.ID.eq.3) then
	  ISP=3
	  UNAX='A'
** tetragonal
	else if(NR4.gt.0.and.NR3.eq.0) then
	  ISP=4
	  if(I4.eq.1) UNAX='A'
	  if(I4.eq.2) UNAX='B'
	  if(I4.eq.3) UNAX='C'
** trigonal (hexagonal setting)
	else if(NR2.eq.0.and.NR3.gt.0.and.NR4.eq.0.and.NR6.eq.0.and.
     $                                               IDIR(4).eq.0) then
	  ISP=5
	  if(IDIR(1).eq.1) UNAX='A'
	  if(IDIR(2).eq.1) UNAX='B'
	  if(IDIR(3).eq.1) UNAX='C'
** trigonal (rhombohedrig setting)
	else if(NR2.eq.0.and.NR3.gt.0.and.NR4.eq.0.and.NR6.eq.0.and.
     $                                               IDIR(4).eq.1) then
	  ISP=5
	  UNAX='R'
** hexagonal
	else if(NR6.gt.0) then
	  ISP=6
	  if(IDIR(1).eq.1) UNAX='A'
	  if(IDIR(2).eq.1) UNAX='B'
	  if(IDIR(3).eq.1) UNAX='C'
** cubic
	else if(NR3.gt.0.and.NR2.gt.0.and.
     $                                IDIR(5)+IDIR(6)+IDIR(7).ne.0) then
	  ISP=7
	  UNAX='A'
	end if
   20 continue
      END
	
      SUBROUTINE FIXCEL(ISUM,T,NS,IVAR,IPAR,NVAR)
      parameter(NUSYM=24,NUCLUS=16,NV=36,NUSUB=12)
      integer ISUM(3),NS,NVAR
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV)
      real T(NUSYM,3)
** fix cell edges?  
	DO 780 J=1,3
	  DO 765 M=1,NS
	    IF(T(M,J).NE.0.0) GOTO 780
  765     CONTINUE
	  IF(ISUM(J).EQ.0.AND.IVAR(J).NE.0) THEN
	    DO 770 K=IVAR(J),NVAR-1
	      IPAR(K)=IPAR(K+1)
	      IVAR(IPAR(K))=K
  770       CONTINUE
	    IVAR(J)=0
	    IPAR(NVAR)=0
	    NVAR=NVAR-1
	  END IF
  780   CONTINUE
** fix cell angles?
	DO 800 J=1,3
	  J1=J+1
	  IF(J1.GT.3) J1=J1-3
	  J2=J+2
	  IF(J2.GT.3) J2=J2-3
	  DO 785 M=1,NS
	    IF(T(M,J1).NE.0.0) THEN
	      DO 784 N=1,NS
		IF(T(N,J2).NE.0.0) GOTO 800
  784         CONTINUE
	    END IF
  785     CONTINUE
	  IF(ISUM(J1).EQ.0.AND.ISUM(J2).EQ.0.AND.IVAR(J+3).NE.0) THEN
	    DO 790 K=IVAR(J+3),NVAR-1
	      IPAR(K)=IPAR(K+1)
	      IVAR(IPAR(K))=K
  790       CONTINUE
	    IVAR(J+3)=0
	    IPAR(NVAR)=0
	    NVAR=NVAR-1
	  END IF
  800   CONTINUE
** fix orientation of the first molecule?
	DO 815 M=1,NS
	  IF(T(M,1).NE.0.0.OR.T(M,2).NE.0.0.OR.T(M,3).NE.0.0) RETURN
  815   CONTINUE
	DO 810 J=1,3
	  IF(ISUM(J).EQ.0.AND.IVAR(J+9).NE.0) THEN
	    DO 805 K=IVAR(J+9),NVAR-1
	      IPAR(K)=IPAR(K+1)
	      IVAR(IPAR(K))=K
  805       CONTINUE
	    IVAR(J+9)=0
	    IPAR(NVAR)=0
	    NVAR=NVAR-1
	  END IF
  810   CONTINUE
      END
      
      subroutine OUTPT2(FN,METHOD,STEP,ISTP,ILOOP,F,ROTC,IDUM)
****** THIS SUBROUTINE WRITES AN ARCHIVES FILE
** Version 07.02.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
** ISPC(L)      i number of symmetry operations which can reproduce 
**                positon of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                parameters from I=1 to I=6 are cell constants
**                parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                0: atom no. I does not take part in any subrotation
**                negativ: atom no. I is one of the two subrotation defining
**                         atoms
** MINR         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=250,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=12)
      integer ISYM(NUSYM), NCH, NPOT
      integer NATM1,NCLUS,NS, ICLUS(NUMATM),LSUB(NUMATM)
      integer NSUB,ISUB(NUMATM,NUSUB),R(NUSYM,3,3), ISPC(NUCLUS)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real VWR(NUMATM),RM(NUMATM),MXR(NUCLUS),MINR
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,2), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character TITLE*72, SPC(NUSYM,NUCLUS)*5
      logical SPEC
      common NATM1,NCLUS,
     $       XYZC, MINR, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** SHIFT         l allows the subroutine FOPT to shift all molecules into
**                 the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
      real CELL(6), XYZS(NUCLUS,3), ROT(NUCLUS,3), SUBROT(NUSUB)
      real SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, SUBROT, SUBDIR, SUMR, ISUM, SHIFT
************************************************************************

      parameter(PI=3.14159265)
      integer FN,METHOD,ILOOP,IDUM,ISTP(12)
      real STEP(12),ROTC(NUCLUS,3)
      CHARACTER LINE*80, PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      COMMON /PARNAM/ PNAME,RNAME
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL

      
      DO 10 I=72,1,-1
	IF(TITLE(I:I).NE.' ') THEN
	  IS=MIN(I+1,72)
	  GOTO 15
	END IF
   10 CONTINUE
   15 CONTINUE
      WRITE(FN,'(2A)') 'TITLE ', TITLE(1:IS)
      WRITE(FN,'(A,1pe12.4,A)') 'REM E=', F,' kJ/mol'
      WRITE(FN,'(A,2I3)') 'LOOP ',ILOOP,ILOOP
      WRITE(FN,'(A,6F8.2)') 'INCELL ',1.,1.,1.,90.,90.,90.
      WRITE(FN,'(A,6F10.5)') 'CELL ',(CELL(J),J=1,3),
     $                               (CELL(J)*180/PI,J=4,6)
      IF(NSUB.ne.0) then
	do 70 N=1,NSUB
	  write(FN,'(3(A,1X))') 'INROT',
     $                      ATNAME(ISUB(1,N)),ATNAME(ISUB(2,N))
   70   continue
      end if
      IF(SPG.NE.' ') WRITE(FN,'(A,A,1X,A)') 'SPGR ',SPG, UNAX
      IF(SPG.NE.' ') WRITE(FN,'(A,A)') ('REM SYMM ',SYMMLS(J),J=1,NS) 
      IF(SPG.EQ.' ') WRITE(FN,'(A,A)') ('SYMM ',SYMMLS(J),J=1,NS) 
      DO 80 I=1,NATM1
	IF(I.gt.1.and.ICLUS(I).ne.ICLUS(I-1)) WRITE(FN,'(A)') 'MOLE'
	WRITE(FN,'(a4,1x,a8,1x,a4,1x,3(f10.5,1x),2f6.3)') 'ATOM',
     $              ATNAME(I),PNAM(PTYP(I)),
     $              (XYZC(I,J),J=1,3),Q(I),VWR(I)
   80 CONTINUE
** Parameters
      DO 90 L=1,NCLUS
	WRITE(FN,'(A,I3,A)') 'REM ',L,':'
	IF(ROTC(L,1).GT.-999..AND.
     $     ROTC(L,2).GT.-999..AND.ROTC(L,3).GT.-999.) THEN
	  WRITE(FN,'(A5,i3,3(1pe12.4))') 'ROTC ',L,0.,0.,0.
	END IF
	IF(SHIFT) THEN
	  WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',
     $               (mod(XYZS(L,J),1.0),J=1,3),
     $               (mod(ROT(L,J),6.2831853)*180./3.14159265,J=1,3)
	ELSE
	  if(abs(XYZS(L,1)).gt.0.5.or.abs(XYZS(L,2)).gt.0.5.or.
     $       abs(XYZS(L,3)).gt.0.5) WRITE(FN,'(A)')
     $           'REM WARNING - UNUSUALLY LARGE TRANSLATIONAL PARAMETER'
	  WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',(XYZS(L,J),J=1,3),
     $               (mod(ROT(L,J),6.2831853)*180./3.14159265,J=1,3)
	END IF
   90 CONTINUE
      if(NSUB.gt.0) WRITE(FN,'(A)') 'REM INROT:'
      if(NSUB.gt.0) WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',
     $               (mod(SUBROT(J),6.2831853)*180./3.14159265,J=1,NSUB)
      
      if(SUMR.gt.0.0) WRITE(FN,'(a,1x,f8.4)') 'SUMR',SUMR
      if(SUMR.eq.0.0) WRITE(FN,'(a,1x,3i3)') 'SUMR',ISUM
      
** Variables
      LINE=' '
      NVAR=0
      DO 110 I=1,NV
	IF(IPAR(I).GT.0) THEN
	  NVAR=NVAR+1
	  LINE(mod(NVAR-1,6)*10+1:mod(NVAR-1,6)*10+10)=PNAME(IPAR(I))
	  if(IPAR(I).gt.(NUCLUS+1)*6) then
	    LINE(mod(NVAR-1,6)*10+1:mod(NVAR-1,6)*10+10)=
     $                                       RNAME(IPAR(I)-(NUCLUS+1)*6)
	  end if
	  if(mod(NVAR-1,6).eq.5) then
	    WRITE(FN,'(2a)') 'VARY ',LINE(1:72)
	    LINE=' '
	  end if
	END IF
  110 CONTINUE
      if(mod(NVAR-1,6).ne.5) WRITE(FN,'(2a)') 'VARY ',LINE(1:72)

      do 120 J=1,NCLUS*6+6
	if(IVAR(J).ne.0) then
	  if(IVAR(J).gt.0) then
	    if(IPAR(IVAR(J)).eq.J) goto 120
	  end if
	  if(IVAR(J).gt.0) then
	    write(FN,'(4A)') 'CNST ',PNAME(J),' = ',PNAME(IPAR(IVAR(J)))
	  else 
	    write(FN,'(4a)') 'CNST ',PNAME(J),' = -',PNAME(IPAR(-IVAR(J)))
	  end if
	end if
  120 continue
      do 150 J=NUCLUS*6+6+1,NUCLUS*6+6+NSUB
	if(IVAR(J).ne.0) then
	  if(IVAR(J).gt.0) then
	    if(IPAR(IVAR(J)).eq.J) goto 150
	  end if
	  J1 = NUCLUS*6-6
	  if(IVAR(J).gt.0) then
	    WRITE(FN,'(4A)') 'CNST ',
     $                         RNAME(J-J1),' = ',RNAME(IPAR(IVAR(J))-J1)
	  else
	    WRITE(FN,'(4A)') 'CNST ',
     $                       RNAME(J-J1),' = -',RNAME(IPAR(-IVAR(J))-J1)
	  end if
	end if
  150 continue
      
      if(SPEC) WRITE(FN,'(a)') 'SPEC'
      
      if(IPA(3).eq.1) WRITE(FN,'(a)') 'OUTP FEW'
      if(IPA(3).eq.2) WRITE(FN,'(a)') 'OUTP MUCH'
      if(IPA(3).eq.3) WRITE(FN,'(a)') 'OUTP NO'
      if(IPA(3).eq.4) WRITE(FN,'(a)') 'OUTP ALL'

      WRITE(FN,'(2a)') 'PTYP ',PTNAME
      DO 200 I=1,NPOT
	DO 190 J=1,I
	  WRITE(FN,'(a,2(a,1x),4(1pe12.4))') 'POT ',PNAM(I),PNAM(J),
     $                                      (POT(I,J,K),K=1,4)
  190   CONTINUE
  200 CONTINUE
      WRITE(FN,'(a,2(1pe12.4))') 'SURF ',SPOT(1,1),SPOT(1,2)
      
      WRITE(FN,'(a,1pe12.4)') 'PRES ',PRESS
      WRITE(FN,'(a,1f11.3)') 'MINR ',MINR

      WRITE(FN,'(a,i9)') 'RNSD ',IDUM

      if(METHOD.eq.1) WRITE(FN,'(a,i8,1pe12.4)') 'ROBR',IPA(2),RPA(4)
      if(METHOD.eq.2) WRITE(FN,'(a,i8)') 'POWL',IPA(2)
      if(METHOD.eq.3) WRITE(FN,'(a,2i8,3f10.4)') 'GRDL',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.4) WRITE(FN,'(a,2i8,3f10.4)') 'THAC',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.5) WRITE(FN,'(a,2i8,3f10.4)') 'SMAN',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.6) WRITE(FN,'(a,i8)') 'MELT',IPA(2)
      if(METHOD.eq.7) WRITE(FN,'(a,12(f7.2,i3:))') 'GRID',
     $                                         (STEP(I),ISTP(I),I=1,12)
      if(METHOD.eq.8) WRITE(FN,'(a,i8,3(1pe12.4))') 'STDS',IPA(2),
     $                                         RPA(4),RPA(2),RPA(1)
      if(METHOD.eq.9) WRITE(FN,'(a,i8,3(1pe12.4))') 'NEWT',IPA(2),
     $                                         RPA(4),RPA(2),RPA(1)
      if(METHOD.eq.12) WRITE(FN,'(a,i8,f10.5)') 'SIMP',IPA(2),RPA(2)

      WRITE(FN,'(a)') 'END'

      CLOSE(UNIT=FN)
      END
