      program MAIN
** Version 01.05.98
** Rainer Rudert, Muellerstrasse 134, D-13349 Berlin (Germany)
** e-mail: nwfrieden@gn.apc.org  or  rudert@chemie.fu-berlin.de
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.141592653589793d0,PI2=PI*2)
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL
************************************************************************
      real XYZ(3),XC(3)
      real AMAT(3,3), AMATI(3,3)
      common /TEST/ AMAT,AMATI
      integer METHOD, ISTP(12), ILOOP,ILOOP1,ILOOP2
      real VMAX(NV),STEP(12),G(NV)
      real RXYZ(3,NUMATM,NUSYM),ROTC(NUCLUS,3)
      real PAR(NUCLUS+1+NUSUB/6,6)
      real SMASS(NUCLUS),SQ(NUCLUS),MROT(3,3)
      double precision RAN2, G1(NV), GRADMX, H
      character FNAME*40,POTFIL*40,CLOOP*2,METH(13)*6,SEQ*3,VARY*6
      character CSTOP*6,TIME*24
      logical CONT, INLOOP, EX
      common /RXYZ/ RXYZ
      real F,FC,FD,FR
      data METH/'ROBRO ','POWELL','GRTDLG','THRACC','SIMANN','MELT  ',
     $ 'GRDSRC','STPDSC','NEWTON','MAP   ','STAT  ','SIMPLX','GENALG'/
** NVAR          (int)   Number of variables
** IPA(1), ITMAX (int)   >0: max. number of iterations
**                       <0: fuer alle IPA und RPA werden Standardwerte
**                           benutzt.
** IPA(2), IFZMAX (int)   max. Zahl von Zielfunktionswerten
** IPA(3), IDR   (int)   1: Ausgabe von Eingabewert und Endergebnis
**                       2: wie 1, zusaetzl. Ergebnis jeder Iteration
**                       3: keine Ausgabe
**                       4: wie 2, zusaetzliche Groessen
** IPA(4), IOUT  (int)   output unit
** IPA(14), IRET (int)   Grund des Abbruchs, <=0: normaler Abbruch
**                       1,2: Abbruch von FOPT aus
**                       8:  Abbruch durch EPSMI
**                       11: Abbruch durch ITMAX
**                       12: Abbruch durch IFZMAX
** RPA(1), EPSX
** RPA(2), EPSF  (real) Test fuer maximale Funktionswertaenderung
** RPA(3), SWA   (real) Anfangsschrittweite
** RPA(4), EPSMI (real) Test fuer maximale Parameteraenderung
** F             (real) Zielfunktionswert
** X0(I)         (real) parameter values (start)
** X(I)          (real) parameter values (optimized)
** FNAME         (char) input filename
** CONT          (bool)  .true.: continue reading input file
**                       .false.: start reading input file
** IEND          (int)  -1: end of input file has been reached
**                       1: end of job has been reached
** IDUM          (int)  random seed parameter
**
** Subroutines called by this program unit:
** RDATM:  read input parameters
** BONDMA: compute bond matrix
** CALSYM: calculate cartesian symmetry operations
** CLSTR:  Look for Clusters
** GRAD:   calculate gradient
** OUTPT1: write table of input data
** OUTPT2: write an archive file
** OUTPT3: write table of short intermolecular contacts and list of
**         parameter values
** OUTPT4: write a SCHAKAL file
** OUTPT5: write a POWDER CELL file
** MELT:   "Melting" of the structure
** REDUCE:
** ROBRO:  das gradientenfreie Verfahren nach Rosenbrock
** POWELL: das gradientenfreie Verfahren nach Powell
** GRDSRC: Grid-Search-Verfahren
** GRTDLG: das Sintflut (Great Deluge)-Verfahren
** SIMANN: das Simulated Annealing-Verfahren
** SPCPOS: checks, if any molecule/ion is in a special position
** STPDSC: das Steepest Descent-Verfahren
** THRACC: das Threshold Accepting-Verfahren
** SIMPLX: das Polytop-Verfahren (Simplex)
** GENALG: Genetic Algorithm
**********************************************************************

      FNAME=' '
      TIME=' '
      IJOB=0
      open(unit=7,file='packmain.inp',err=970,status='old')
      read(7,'(a)',err=2) FNAME
      read(7,'(a)',err=2) TIME
    2 continue
      close(unit=7)
** calculate random seed number from time
      if(TIME.eq.' ') then
        IDUM=1
      else
        I=index(TIME,':')
        read(TIME(I-2:),'(i2,1x,i2,1x,i2)') I1,I2,I3
        IDUM=I1*10000+I2*100+I3
      end if
    3 continue
      CLOOP='00'
      CONT=.false.
      IEND=0
      ILOOP=360
      ILOOP1=1
      ILOOP2=1
      INLOOP=.false.
      METHOD=0
      write(*,'(1x,72a1)') ('*',J=1,72)
      write(*,'(1x,a,a46,a25,t73,a1)')
     $  '*',' PROGRAM HARDPACK, Version May 1, 1998,  ',FNAME,'*'
      write(*,'(1x,a1,1x,a6,i3,a8,i3,2(a9,i4),a5,i3,a8,i3,t73,a1)') '*',
     $ 'NUSYM:',NUSYM,', NUSUB:',NUSUB,', NUMATM:',NUMATM,
     $ ', NUCLUS:',NUCLUS,', NV:',NV,', NPOTL:',NPOTL,'*'
      if(TIME.ne.' ') write(*,'(1x,a1,24x,a,t73,a1)') '*',TIME,'*'
      write(*,'(1x,72a1)') ('*',J=1,72)
      IFN=index(FNAME,' ')
      if(IFN.eq.0) IFN=41
      open(unit=1,file=FNAME(:IFN-1)//'.inp',err=975,status='old')
      open(unit=2,file=FNAME(:IFN-1)//'.out',err=980,status='unknown')
      rewind(unit=2)
    5 continue
      write(*,'(1x,a)') 'Reading data and instructions...'
** READ DATA
      call RDATM(1,METHOD,PAR,NP,POTFIL,ROTC,CONT,IEND,IJOB,STEP,ISTP,
     $         IDUM,ILOOP1,ILOOP2,INLOOP,IANALY,ISP,ISAVE)
      write(*,'(1x,a)') TITLE
      if(ILOOP.gt.ILOOP2) ILOOP=ILOOP1
      if(ILOOP.lt.10) write(CLOOP(2:2),'(i1)') ILOOP
      if(ILOOP.ge.10.and.ILOOP.lt.100) write(CLOOP,'(i2)') ILOOP
      if(ILOOP.ge.100) write(CLOOP,'(a1,i1)') 
     $                  char(ichar('a')+(ILOOP-100)/10),mod(ILOOP,10)
      if(.not.CONT) write(*,'(1x,a,i4,2(a,i3))') 'no. of atoms:',NATM1,
     $                        ', no. of molecules/ions:',NCLUS,
     $                        ', no. of atom types:',NPOT
      if(.not.CONT) write(*,'(1x,4a)') 'Space group: ',SPG,',',UNAX
      if(NCLUS.gt.NUCLUS) then
        write(2,'(/1x,a,i4,a/)')
     $                     'ERROR - TOO MANY MOLECULES/IONS (MORE THAN',
     $                      NUCLUS,'). PROGRAM ABORTED.'
        write(*,'(/1x,a,i4,a/)')
     $                     'ERROR - TOO MANY MOLECULES/IONS (MORE THAN',
     $                      NUCLUS,'). PROGRAM ABORTED.'
        call DUMP
        stop
      end if
      if(NATM1.eq.0) then
        write(2,'(/1x,a/)') 'ERROR - NO ATOM FOUND. PROGRAM ABORTED.'
        write(*,'(/1x,a/)') 'ERROR - NO ATOM FOUND. PROGRAM ABORTED.'
        call DUMP
        stop
      end if
      if((SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0).and.
     $  (abs(CELL(4)-PI/2.).gt.1e-4.or.abs(CELL(5)-PI/2.).gt.1e-4)) then
        write(2,'(/1x,2a/)') 'ERROR - CELL ANGLES ALPHA AND BETA MUST ',
     $                       'BE 90 DEGREES.'
        write(*,'(/1x,2a/)') 'ERROR - CELL ANGLES ALPHA AND BETA MUST ',
     $                       'BE 90 DEGREES.'
        call DUMP
        stop
      end if
      if(NS.eq.0) then
        NS=1
        SYMMLS(NS)='X,Y,Z'
        ISYM(1)=1
        write(2,'(/1x,2a/)') 'WARNING - NO SYMMETRY GIVEN. P1 ASSUMED. '
        write(*,'(/1x,2a/)') 'WARNING - NO SYMMETRY GIVEN. P1 ASSUMED. '
      end if
** initialize random number function
      if(.not.CONT.and.ILOOP.eq.ILOOP1) then
        YY=RAN2(-IDUM)
      end if
** end of file or end of job has been reached
      if(IEND.ne.0) goto 960
      if(SPEC) write(*,'(1x,a)') 'There are atoms on special positions.'
      if(.not.CONT) then
** CALCULATE BOND MATRIX
        call BONDMA
      end if
** LOOK FOR SUBROTATION GROUPS
      do 130 I=1,NUMATM
        LSUB(I)=0
  130 continue
      call SROT
      write(*,*) 'last potential type found: ',PTNAME
      if(POTFIL.ne.' ') write(*,*) 'last potential file read: ',POTFIL
** CALCULATE CARTESIAN SYMMETRY OPERATIONS
      if(.not.CONT) call CALSYM
** LOOK FOR MOLECULES AND CALCULATE CENTERS OF MASS
      if(.not.CONT) call CLSTR(SMASS,SQ,VOL,ROTC)
** PUT PARAMETER VALUES TO XYZS, ROT AND SUBROT
      do 150 L=1,NCLUS
        do 140 J=1,3
          if(PAR(L,J).gt.-999.) then
            XYZS(L,J)=PAR(L,J)
            PAR(L,J)=-999.
          end if
  140   continue
        do 145 J=4,6
          if(PAR(L,J).gt.-999.) then
            ROT(L,J-3)=PAR(L,J)/180.*PI
            PAR(L,J)=-999.
          end if
  145   continue
  150 continue
      do 155 J=1,NSUB
        J1=mod(J,6)
        if(J1.eq.0) J1=6
        N1=1+int((J-1)/6)
        if(PAR(NCLUS+N1,J1).gt.-999) then
          SUBROT(J)=PAR(NCLUS+N1,J1)/180.*PI
          PAR(NCLUS+N1,J1)=-999.
        end if
  155 continue
** LOOK FOR SPECIAL POSITIONS
      if(SPEC) call SPCPOS
** WRITE TABLES OF INPUT DATA
      call OUTPT1(2,VOL,ATVOL,SMASS,SQ,IPA(3),CONT,ILOOP,ILOOP1,ILOOP2,
     $            ISP,TIME)
** set values of variables
      NVAR=0
      do 160 I=1,NV
        MR=mod(IPAR(I),6)
** cell constants
        if(IPAR(I).ne.0.and.IPAR(I).le.6) then
          NVAR=NVAR+1
          X0(NVAR)=CELL(IPAR(I))
        end if
** translation
        if(IPAR(I).gt.6.and.IPAR(I).le.(NUCLUS+1)*6.and.
     $                                  MR.le.3.and.MR.gt.0) then
          if((IPAR(I)-1)/6.gt.NCLUS) then
            write(2,'(/1x,2a,i3,a/1x,a,i3,a)') 
     $       'ERROR - CANNOT VARY PARAMETER ',
     $       'OF MOLECULE/ION NO.',(IPAR(I)-1)/6,'.',
     $       'THERE ARE ONLY ',NCLUS,' MOLECULES/IONS. PROGRAM ABORTED.'
            write(*,'(/1x,2a,i3,a/1x,a,i3,a)') 
     $       'ERROR - CANNOT VARY PARAMETER ',
     $       'OF MOLECULE/ION NO.',(IPAR(I)-1)/6,'.',
     $       'THERE ARE ONLY ',NCLUS,' MOLECULES/IONS. PROGRAM ABORTED.'
            call DUMP
            stop
          end if
          NVAR=NVAR+1
          X0(NVAR)=XYZS((IPAR(I)-1)/6,MR)
        end if
** rotation
        if(IPAR(I).gt.6.and.IPAR(I).le.(NUCLUS+1)*6.and.
     $                      (MR.eq.4.or.MR.eq.5.or.MR.eq.0)) then
          if(MR.gt.3) J=MR-3
          if(MR.eq.0) J=3
          if((IPAR(I)-1)/6.gt.NCLUS) then
            write(2,'(/1x,2a,i3,a/1x,a,i3,a)') 
     $       'ERROR - CANNOT VARY PARAMETER ',
     $       'OF MOLECULE/ION NO.',(IPAR(I)-1)/6,'.',
     $       'THERE ARE ONLY ',NCLUS,' MOLECULES/IONS. PROGRAM ABORTED.'
            write(*,'(/1x,2a,i3,a/1x,a,i3,a)') 
     $       'ERROR - CANNOT VARY PARAMETER ',
     $       'OF MOLECULE/ION NO.',(IPAR(I)-1)/6,'.',
     $       'THERE ARE ONLY ',NCLUS,' MOLECULES/IONS. PROGRAM ABORTED.'
            call DUMP
            stop
          end if
          NVAR=NVAR+1
          X0(NVAR)=ROT((IPAR(I)-1)/6,J)
        end if
** subrotation
        if(IPAR(I).gt.(NUCLUS+1)*6) then
          NVAR=NVAR+1
          X0(NVAR)=SUBROT(IPAR(I)-(NUCLUS+1)*6)
        end if
  160 continue
      if(SUMR.gt.0.0) then
        write(*,'(1x,a,i3,a,f6.2,a)') 'no. of variables:',NVAR,
     $     ', summation radius:',SUMR,' A'
      else
        write(*,'(1x,a,i3,a,i5)') 'no. of variables:',NVAR,
     $    ', no. of cells:',(ISUM(1)*2+1)*(ISUM(2)*2+1)*(ISUM(3)*2+1)
      end if
      if(PRESS.ne.0.0) write(*,'(1x,a,1pe12.4,a)') 'pressure: ',PRESS,
     $                                                            ' Pa'
      if((NVAR.eq.0.and.METHOD.ne.11).or.
     $   (NVAR.eq.0.and.METHOD.eq.11.and.IANALY.gt.1)) then
        write(2,'(/1x,a,a/)') 'ERROR - NO VARIABLES DEFINED. ',
     $                        'PROGRAM ABORTED.'
        write(*,'(/1x,a,a/)') 'ERROR - NO VARIABLES DEFINED. ',
     $                        'PROGRAM ABORTED.'
        call DUMP
        stop
      end if
** CALCULATE MAXIMUM NUMBER OF INTERMOLECULAR CONTACTS USED FOR ENERGY
** CALCULATION (This number can change during optimization)
      call CONTCT(NCONTC,VOL)
      write(*,'(1x,a,i8)') 'maximum no. of intermolecular contacts:',
     $                  NCONTC
      RPA(3)=0.4
** Parameters for Powell
      if(METHOD.eq.2) then
        IPA(6)=100
        IPA(7)=1
      end if
** Parameters for Great Deluge, Threshold Accepting, Simulated Annealing,
** Melt, and Genetic Algorithm
      if(METHOD.ge.3.and.METHOD.le.6.or.METHOD.eq.13) then
        if(IPA(2).eq.0.and.METHOD.ne.6) IPA(2)=50*2**(NVAR/2.0)
        if(IPA(2).eq.0.and.METHOD.eq.6) IPA(2)=50*2**(NVAR/2.0)/2
        if(IPA(1).eq.0) IPA(1)=IPA(2)/20
      else if(IPA(2).eq.0) then
        IPA(2)=200*NVAR
        if(IPA(1).eq.0) IPA(1)=100
      end if
      if(IPA(1).eq.0) IPA(1)=2**min(NVAR,15)
      IPA(4)=2
** Parameters for Threshold Accepting and Simulated Annealing
      if(METHOD.eq.4.or.METHOD.eq.5) then
        if(RPA(2).le.0.0) RPA(2)=1000.0
        if(RPA(4).le.0.0) RPA(4)=1.0
      end if
** Maximum variables for Rosenbrock, Great Deluge, Threshold Accepting,
** Simulated Annealing, Melt, Gridsearch, Map, Simplex, and Genetic Algorithm
      if((METHOD.ge.1.and.METHOD.le.7).or.
     $   METHOD.eq.10.or.METHOD.ge.12) then
        do 180 I=1,NVAR
          IP=IPAR(I)
          if(IP.ge.1.and.IP.le.3) VMAX(I)=CELL(IP)*1.9
          if(IP.ge.4.and.IP.le.6) VMAX(I)=PI/2.0
          if(IP.gt.6.and.mod(IP,6).ge.1.and.mod(IP,6).le.3) VMAX(I)=1.0
          if(IP.gt.6.and.mod(IP,6).eq.4) VMAX(I)=PI2
          if(IP.gt.6.and.mod(IP,6).eq.5) VMAX(I)=PI
          if(IP.gt.6.and.mod(IP,6).eq.0) VMAX(I)=PI2
          if(IP.gt.(NUCLUS+1)*6) VMAX(I)=PI2
  180   continue
      end if
** Parameters for Simplex
      if(METHOD.eq.12) then
        RPA(1)=1.0
        RPA(3)=0.5
        RPA(4)=2.0
      end if
      CSTOP=' '
  170 continue
      if(METHOD.eq.1) then
        write(*,*) 'calling ROSENBROCK...'
        SHIFT=.false.
        call ROBRO(F,FC,FD,FR,VMAX,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.2) then
        write(*,*) 'calling POWELL...'
        SHIFT=.false.
        call POWELL(0.10,F,FC,FD,FR,VMAX,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.3) then
        write(*,*) 'calling GREAT DELUGE...'
        SHIFT=.true.
        call SIMANN(F,FC,FD,FR,2,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.4) then
        write(*,*) 'calling THRESHOLD ACCEPTING...'
        SHIFT=.true.
        call SIMANN(F,FC,FD,FR,1,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.5) then
        write(*,*) 'calling SIMULATED ANNEALING...'
        SHIFT=.true.
        call SIMANN(F,FC,FD,FR,0,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.6) then
        write(*,*) 'calling MELTING...'
        SHIFT=.true.
        call MELT(F,FC,FD,FR,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.7) then
        do 190 I=1,NVAR
          if(ISTP(I).eq.0) ISTP(I)=7
          if(STEP(I).eq.0.0) STEP(I)=VMAX(I)/6.0
  190   continue
        write(*,*) 'calling GRID SEARCH...'
        SHIFT=.true.
        call GRDSRC(F,FC,FD,FR,IPAR,STEP,ISTP,ILOOP,ILOOP2)
      else if(METHOD.eq.8) then
        write(*,*) 'calling STEEPEST DESCENT...'
        SHIFT=.false.
        call STPDSC(F,FC,FD,FR,G,ILOOP,ILOOP2,CSTOP)
        do 195 I=1,NVAR
          G1(I)=G(I)
  195   continue
      else if(METHOD.eq.9) then
        write(*,*) 'calling NEWTON...'
        SHIFT=.false.
        call NEWTON(F,FC,FD,FR,G,ILOOP,ILOOP2,CSTOP)
        do 196 I=1,NVAR
          G1(I)=G(I)
  196   continue
      else if(METHOD.eq.10) then
        do 200 I=1,NVAR
          if(ISTP(I).eq.0) ISTP(I)=7
          if(STEP(I).eq.0.0) STEP(I)=VMAX(I)/6.0
  200   continue
        write(*,*) 'calling MAP...'
        SHIFT=.true.
        call MAP(IPAR,STEP,ISTP,FNAME)
      else if(METHOD.eq.11.and.IANALY.ge.1) then
        print*,'calculating energy...'
        SHIFT=.false.
        call FOPT(F,FC,FD,FR,X0,VOL,IRET)
        if(IRET.eq.1) then
          write(2,'(/1x,a/)') 'WARNING - IMPOSSIBLE CELL CONSTANTS.'
          write(*,'(/1x,a/)') 'WARNING - IMPOSSIBLE CELL CONSTANTS.'
        else if(IRET.eq.2.and.PTNAME.ne.'SOFT') then
          write(2,'(/1x,a/)') 'WARNING - COLLISION BETWEEN ATOMS.'
          write(*,'(/1x,a/)') 'WARNING - COLLISION BETWEEN ATOMS.'
        else if(IRET.eq.2.and.PTNAME.eq.'SOFT') then
          write(2,'(/1x,2a,f10.6/)') 'WARNING - COLLISION BETWEEN ATOMS'
     $         ,' OR REPULSION LARGER THAN ',real(NSUB*NATM1)**(2.0/3.0)           
          write(*,'(/1x,2a,f10.6/)') 'WARNING - COLLISION BETWEEN ATOMS'
     $         ,' OR REPULSION LARGER THAN ',real(NSUB*NATM1)**(2.0/3.0)           
        else if(IRET.eq.3) then
          write(2,'(/1x,2a/1x,a)') 'WARNING - CELL HEIGHT SMALLER ',
     $     'THAN HMIN OR ONE PROJECTION ',
     $     'OF A CELL EDGE ONTO ANOTHER CELL EDGE IS TOO LARGE.'
          write(*,'(/1x,2a/1x,a)') 'WARNING - CELL HEIGHT SMALLER ',
     $     'THAN HMIN OR ONE PROJECTION ',
     $     'OF A CELL EDGE ONTO ANOTHER CELL EDGE IS TOO LARGE.'
        end if
        if(NVAR.gt.0.and.IANALY.eq.99) then
          print*,'calculating gradient of energy...'
          H=1d-4
          call GRAD(NVAR,X0,G1,H,IRET)
          if(IRET.ne.0) then
            H=H/10.0
            call GRAD(NVAR,X0,G1,H,IRET)
          end if
          if(IRET.ne.0) then
            write(2,'(/1x,2a,i3)') 'WARNING - COULD NOT CALCULATE ',
     $     'GRADIENT NUMERICALLY. IRET=',IRET
            write(*,'(/1x,2a,i3)') 'WARNING - COULD NOT CALCULATE ',
     $     'GRADIENT NUMERICALLY. IRET=',IRET
            do 205 J=1,NV
              G1(J)=0.0
  205       continue
          end if
        end if
        if(NVAR.gt.0.and.IANALY.eq.2) then
          print*,'calculating gradient of energy...'
          call GOPT(G,X0,IRET)
          do 210 I=1,NVAR
            G1(I)=G(I)
  210     continue
        end if
      else if(METHOD.eq.12) then
        write(*,*) 'calling SIMPLX...'
        SHIFT=.true.
        call SIMPLX(F,FC,FD,FR,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      else if(METHOD.eq.13) then
        write(*,*) 'calling GENETIC ALGORITHM...'
        SHIFT=.true.
        call GENALG(F,FC,FD,FR,VMAX,IDUM,ILOOP,ILOOP2,CSTOP)
      end if
      if(CSTOP.ne.' ') then
        write(*,*) ' Optimization stopped by ',CSTOP
        write(2,*) ' Optimization stopped by ',CSTOP
      end if
      if(METHOD.ne.10.and.(METHOD.ne.11.or.IANALY.ne.0)) 
     $       write(*,'(1x,a12,1pg11.4,a)') 'Energy:',F,' kJ/mol',
     $      'Coulomb:',FC,' kJ/mol','Dispersion:',FD,' kJ/mol',
     $      'Repulsion:',FR,' kJ/mol'
      GRADMX=0.0
      do 690 J=1,NVAR
        if(abs(G1(J)).gt.GRADMX) GRADMX=abs(G1(J))
  690 continue
      if(METHOD.eq.11.and.NVAR.gt.0) then
        if(IRET.eq.0.and.IANALY.gt.1) then
         write(*,'(1x,a/(1x,8(1pe9.2,:)))') 'Gradient:',(G1(J),J=1,NVAR)
          write(*,'(1x,a,1pe10.3)') 'max. Gradient:',GRADMX
        else
          write(*,'(1x,a)') 'Gradient not calculated'
        end if
        do 695 J=1,NV
          X(J)=X0(J)
  695   continue
      end if
** put values of optimum variables to parameters
      do 700 J=1,6
        if(IVAR(J).gt.0) CELL(J)=X(IVAR(J))
  700 continue
      call FRACRT(XYZ,XC,CELL,VOL,-1,UNAX,.false.,IERR)
      if(METHOD.ne.10.and.PRESS.ne.0.0) write(*,'(1x,a12,1pg11.4,a)') 
     $      'Pressure:',1e-33*6.022045e23*PRESS*VOL/NS,' kJ/mol'
      do 750 L=1,NCLUS
        L6=L*6
** transform translations to the region -0.5..0.5
        do 730 J=1,3
          if(IVAR(L6+J).ne.0.and.IVAR(L6+J).ne.-9999) then
            if(IVAR(L6+J).gt.0) XYZS(L,J)=X(IVAR(L6+J))
            if(IVAR(L6+J).lt.0) XYZS(L,J)=-X(abs(IVAR(L6+J)))
          end if
  730   continue
** transform rotation angles theta, chi, phi to the region -pi..pi, 0..pi,
** -pi..pi
        do 740 J=4,6
          if(abs(IVAR(L6+J)).gt.0.and.IVAR(L6+J).ne.-9999) then
            if(IVAR(L6+J).gt.0) ROT(L,J-3)=mod(X(IVAR(L6+J)),PI2)
            if(IVAR(L6+J).lt.0) ROT(L,J-3)=mod(-X(abs(IVAR(L6+J))),PI2)
          end if
  740   continue
  750 continue
      N6=(NUCLUS+1)*6
      do 780 K=1,NUSUB
        if(abs(IVAR(N6+K)).gt.0.and.
     $         IVAR(N6+K).ne.-9999) then
          if(IVAR(N6+K).gt.0) SUBROT(K)=mod(X(IVAR(N6+K)),PI2)
          if(IVAR(N6+K).lt.0) SUBROT(K)=mod(-X(abs(IVAR(N6+K))),PI2)
        end if
  780 continue
      call REDUCE(ISP)
      if(ILOOP.lt.10) write(CLOOP(2:2),'(i1)') ILOOP
      if(ILOOP.ge.10.and.ILOOP.lt.100) write(CLOOP,'(i2)') ILOOP
      if(ILOOP.ge.100) write(CLOOP,'(a1,i1)') 
     $                  char(ichar('a')+(ILOOP-100)/10),mod(ILOOP,10)
      open(unit=9,file=FNAME(:IFN-1)//'.a'//CLOOP,err=985,
     $                                                 status='unknown')
** write ARCHIV file
      call OUTPT2(9,METHOD,STEP,ISTP,ILOOP,F,ROTC,IDUM)
      close(unit=9)
      open(unit=10,file=FNAME(:IFN-1)//'.his',err=965,status='unknown')
  785 continue
      read(10,'(a)',end=786,err=786)
      goto 785
  786 continue
      backspace(unit=10)
      if(ILOOP.eq.ILOOP1.and..not.CONT) then
        write(10,'(2a)') 'TI ',TITLE
        do 810 I=1,NATM1
          if(I.gt.1.and.ICLUS(I).ne.ICLUS(I-1)) write(10,'(a)') 'MOLE'
          write(10,'(3a,4(1x,f10.4),2i4)') 'AT ',ATNAME(I),
     $          PNAM(PTYP(I)),(XYZC(I,J),J=1,3),Q(I),
     $          LSUB(I)-128*nint(LSUB(I)/128.0),nint(LSUB(I)/128.0)
  810   continue
        do 815 M=1,NS
          write(10,'(a,1x,a)') 'SY',SYMMLS(M)
  815   continue
        write(10,'(2a,1x,a)') 'SPGR ',SPG,UNAX
      end if
      write(10,'(2a,1x,a)') 'METHOD ',METH(METHOD),CSTOP
      write(10,'(a,1x,i3)') 'LOOP',ILOOP
      write(10,'(a,1x,1pe11.4,1x,a,0pf6.2)')
     $                              'F:',F,'kJ/mol, PC:',ATVOL/VOL
      write(10,'(a,1x,i2,1x,a,1x,i2)') 'NCLUS ',NCLUS,'NSUB ',NSUB
      if(SUMR.gt.0.0) write(10,'(a,1x,f8.4)') 'SUMR',SUMR
      if(SUMR.eq.0.0) write(10,'(a,1x,3i3)') 'SUMR',ISUM
      VARY='000000'
      do 880 J=1,6
        if(IVAR(J).ne.0) VARY(J:J)='1'
  880 continue
      write(10,'(a,6(1pe11.4),1x,a6)') 'CELL',
     $                    (CELL(J),J=1,3),(CELL(J)*180./PI,J=4,6),VARY
      do 890 L=1,NCLUS
        VARY='000000'
        do 885 J=1,6
          if(IVAR(L*6+J).ne.0) VARY(J:J)='1'
  885   continue
        write(10,'(a,6(1x,1pe11.4:),1x,a6)') 'PARM',
     $                     (XYZS(L,J),J=1,3),(ROT(L,J),J=1,3),VARY
  890 continue
      do 895 K=1,NSUB,6
        VARY='000000'
        do 894 J=1,min(K+6,NSUB)
          if(IVAR(NUCLUS*6+J).ne.0) VARY(J:J)='1'
  894   continue
        if(NSUB.ne.0) write(10,'(a,6(1x,1pe11.4:),1x,a6)') 'PARM',
     $                     (SUBROT(J),J=K,min(K+5,NSUB))
  895 continue
      close(unit=10)
      do 788 I=1,NATM1
**        LS2 = nint(LSUB(I)/128.0)
**        LS1 = LSUB(I) - LS2*128
**        if(LS1.le.0.or.LS2.le.0) then
          do 787 J=1,3
            RXYZ(J,I,1)=XYZC(I,J)
  787     continue
**        end if
  788 continue
      do 790 K=1,NSUB
        call SBROT(K,SUBROT(K))
  790 continue
      do 800 L=1,NCLUS
        call ROTEUL(L,ROT,MROT,.true.)
  800 continue
** write list of short contacts, optimized parameters and energies
      call OUTPT3(2,F,FC,FD,FR,G1,SMASS,IPA(3),METHOD,IANALY,ILOOP)
** write SCHAKAL file
      if(ISAVE.eq.1) then
        open(unit=9,file=FNAME(:IFN-1)//'.d'//CLOOP,err=990,
     $                                                status='unknown')
        call OUTPT4(9,F)
        close(unit=9)
      end if
** write POWDER CELL file
      if(ISAVE.eq.2) then
        open(unit=9,file=FNAME(:IFN-1)//'.r'//CLOOP,err=995,
     $                                                status='unknown')
        call OUTPT5(9,F)
        close(unit=9)
      end if
      CONT=.true.
      goto 5
** end of input file or end of job has been reached
  960 continue
      ILOOP=ILOOP+1
      if(ILOOP.le.ILOOP2) then
        if(IEND.eq.-1) then
          print*,'end of input file has been reached'
        else if(IEND.ge.1) then
          print*,'end of job has been reached'
        end if
        rewind(unit=1)
        CONT=.false.
        IEND=0
        goto 5
      else
        if(IEND.eq.-1) then
          print*,'end of input file has been reached'
          close(unit=1)
          stop
        else if(IEND.ge.1) then
          print*,'end of job has been reached'
          rewind(unit=1)
          CONT=.false.
          IEND=0
          INLOOP=.false.
          IJOB=IJOB+1
          goto 3
        end if
      end if
  965 continue
      inquire(file=FNAME(:IFN-1)//'.his',sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.his',
     $                   ' may not be opened for sequential in/output.'
      if(SEQ.eq.'YES') print*,'ERROR - Error opening ',
     $                        FNAME(:IFN-1)//'.his'
      print*,'Program stopped'
      stop
  970 continue
      inquire(file='packmain.inp',exist=EX,sequential=SEQ,err=9999)
      if(.not.EX) print*,'ERROR - File packmain.inp does not exist.'
      if(SEQ.eq.'NO') print*,'ERROR - File packmain.inp may not ',
     $                       'be opened for sequential input.'
      if(EX.and.SEQ.eq.'YES') print*,
     $                       'ERROR - Error opening packmain.inp.'
      print*,'Program stopped'
      stop
  975 continue
      inquire(file=FNAME(:IFN-1)//'.inp',exist=EX,sequential=SEQ,
     $                                                  err=9999)
      if(.not.EX) print*,'ERROR - File ',FNAME(:IFN-1)//'.inp',
     $                   ' does not exist.'
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.inp',
     $                   ' may not be opened for sequential input.'
      if(EX.and.SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.inp.'
      print*,'Program stopped'
      stop
  980 continue
      inquire(file=FNAME(:IFN-1)//'.out',sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.out',
     $                   ' may not be opened for sequential output.'
      if(SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.out'
      print*,'Program stopped'
      stop
  985 continue
      inquire(file=FNAME(:IFN-1)//'.a'//CLOOP,sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.a'//CLOOP,
     $                   ' may not be opened for sequential output.'
      if(SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.a'//CLOOP
      print*,'Program stopped'
      stop
  990 continue
      inquire(file=FNAME(:IFN-1)//'.d'//CLOOP,sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.d'//CLOOP,
     $                   ' may not be opened for sequential output.'
      if(SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.d'//CLOOP
      print*,'Program stopped'
      stop
  995 continue
      inquire(file=FNAME(:IFN-1)//'.r'//CLOOP,sequential=SEQ,err=9999)
      if(SEQ.eq.'NO') print*,'ERROR - File ',FNAME(:IFN-1)//'.r'//CLOOP,
     $                   ' may not be opened for sequential output.'
      if(SEQ.ne.'NO') print*,'ERROR - Error opening ',
     $                   FNAME(:IFN-1)//'.r'//CLOOP
      print*,'Program stopped'
      stop
 9999 continue
      end
**      
      subroutine CLSTR(SMASS,SQ,VOL,ROTC)
** CALCULATES CENTER OF MASS, MASS, CHARGE AND RADIUS OF EACH MOLECULE/ION
** Version 18.02.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real SMASS(NUCLUS),SQ(NUCLUS),XC(3),XYZ(3),ROTC(NUCLUS,3)
** NC(L)   r number of atoms in molecule/ion no. L
      integer NC(NUCLUS)
** calculate mass and charge of each cluster
      do 150 L=1,NCLUS
        SMASS(L)=0.0
        SQ(L)=0.0
        MXR(L)=0.0
        NC(L)=0
        do 140 J=1,3
          XYZSC(J,L,1)=0.0
  140   continue
  150 continue
      do 170 I=1,NATM1
        L=ICLUS(I)
        NC(L)=NC(L)+1
        SMASS(L)=SMASS(L)+RM(I)
        SQ(L)=SQ(L)+Q(I)
        do 160 J=1,3
          XYZSC(J,L,1) = XYZSC(J,L,1) + XYZC(I,J)
  160   continue
  170 continue
** calculate centers of mass of each cluster, XYZSC and XYZS, using CELL.
** if ROTC is defined, ROTC will be used instead
      do 200 L=1,NCLUS
        if(ROTC(L,1).le.-999..and.ROTC(L,2).le.-999..and.
     $     ROTC(L,3).le.-999.) then
          do 180 J=1,3
            XYZSC(J,L,1)=XYZSC(J,L,1)/NC(L)
            XC(J)=XYZSC(J,L,1)
  180     continue
        else
          do 185 J=1,3
            XYZSC(J,L,1)=ROTC(L,J)
            XC(J)=XYZSC(J,L,1)
  185     continue
        end if
        call FRACRT(XYZ,XC,CELL,VOL,-1,UNAX,.false.,IERR)
        do 190 J=1,3
          XYZS(L,J)=XYZ(J)
  190   continue
  200 continue
** SHIFT MOLECULES/IONS INTO ORIGIN (ONLY ATOMIC COORDINATES)
      do 250 I=1,NATM1
        do 240 J=1,3
          XYZC(I,J) = XYZC(I,J) - XYZSC(J,ICLUS(I),1)
  240   continue
  250 continue
** calculate maximum distance from centers of mass + 1.1*van der Waals radius
      do 300 I=1,NATM1
        L=ICLUS(I)
        D = sqrt(XYZC(I,1)**2 + XYZC(I,2)**2 + XYZC(I,3)**2) +
     $      1.1*VWR(I)
        if(D.gt.MXR(L)) MXR(L)=D
  300 continue
      end
**
      function DIS(I,J) 
** CALCULATES DISTANCE BETWEEN ATOM I AND ATOM J
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      INTEGER I,J
      real DIS
      DIS=sqrt(
     $         (XYZC(I,1)-XYZC(J,1))**2+
     $         (XYZC(I,2)-XYZC(J,2))**2+
     $         (XYZC(I,3)-XYZC(J,3))**2)
      END
**
      function TOR(I,J,K,L)
** CALCULATES TORSIONAL ANGLE OF ATOMS I, J, K, L. I/J AND K/L ARE
** THE NEIGHBOURING BONDS. THE ANGLE IS IN DEGREES.
** Version 24.10.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.141592653589793d0)
      integer I,J,K,L
      real TOR
      double precision SKAL,ABS1,ABS2,E1(3),E2(3),E3(3),VE(3),V
** E1 und E2 sind die Normalvektoren auf den Ebenen IJK und JKL     
** VE ist der Verbindungsvektor JK
      E1(1)=(XYZC(K,2)-XYZC(J,2))*(XYZC(I,3)-XYZC(J,3))-
     $      (XYZC(K,3)-XYZC(J,3))*(XYZC(I,2)-XYZC(J,2))
      E1(2)=(XYZC(K,3)-XYZC(J,3))*(XYZC(I,1)-XYZC(J,1))-
     $      (XYZC(K,1)-XYZC(J,1))*(XYZC(I,3)-XYZC(J,3))
      E1(3)=(XYZC(K,1)-XYZC(J,1))*(XYZC(I,2)-XYZC(J,2))-
     $      (XYZC(K,2)-XYZC(J,2))*(XYZC(I,1)-XYZC(J,1))
      E2(1)=(XYZC(L,2)-XYZC(K,2))*(XYZC(J,3)-XYZC(K,3))-
     $      (XYZC(L,3)-XYZC(K,3))*(XYZC(J,2)-XYZC(K,2))
      E2(2)=(XYZC(L,3)-XYZC(K,3))*(XYZC(J,1)-XYZC(K,1))-
     $      (XYZC(L,1)-XYZC(K,1))*(XYZC(J,3)-XYZC(K,3))
      E2(3)=(XYZC(L,1)-XYZC(K,1))*(XYZC(J,2)-XYZC(K,2))-
     $      (XYZC(L,2)-XYZC(K,2))*(XYZC(J,1)-XYZC(K,1))
      SKAL = E1(1)*E2(1)+E1(2)*E2(2)+E1(3)*E2(3)
      ABS1 = SQRT(E1(1)**2+E1(2)**2+E1(3)**2)
      ABS2 = SQRT(E2(1)**2+E2(2)**2+E2(3)**2)
** Vektoren IJ und JK oder JK und KL sind parallel
      IF(ABS1.LT.0.01.OR.ABS2.LT.0.01) THEN
        TOR = 0.0
        RETURN
      END IF
      IF(SKAL/ABS1/ABS2.GE.1.0) THEN
        TOR = 0.0
        RETURN
      ELSE IF(SKAL/ABS1/ABS2.LE.-1.0) THEN
        TOR = 180.0
        RETURN
      ELSE
        TOR = ACOS(SKAL/ABS1/ABS2)*180.0/PI
      END IF
**  VORZEICHEN BESTIMMEN
      VE(1) = XYZC(K,1)-XYZC(J,1)
      VE(2) = XYZC(K,2)-XYZC(J,2)
      VE(3) = XYZC(K,3)-XYZC(J,3)
      V=SQRT(VE(1)**2+VE(2)**2+VE(3)**2)
      E3(1) = E1(2)*E2(3)-E1(3)*E2(2)
      E3(2) = E1(3)*E2(1)-E1(1)*E2(3)
      E3(3) = E1(1)*E2(2)-E1(2)*E2(1)
      E = SQRT(E3(1)**2+E3(2)**2+E3(3)**2)
      IF(ABS(VE(1)*E).GT.1d-18) THEN
        SG = E3(1)*V/(VE(1)*E)
      ELSE IF(ABS(VE(2)*E).GT.1d-18) THEN
        SG = E3(2)*V/(VE(2)*E)
      ELSE IF(ABS(VE(3)*E).GT.1d-18) THEN
        SG = E3(3)*V/(VE(3)*E)
      else
        SG=1
      end if
      TOR=TOR*SG
  999 return  
      end     
*
      subroutine FRACRT(XYZF,XYZ2,CELL,VOL,IDIR,UNAX,OLD,IERR)
** TRANSFORMS FRACTIONAL COORDINATES XYZF TO CARTESIAN COORDINATES
** XYZ2 AND VICE VERSA.
** Version 05.03.1996
** CELL: r cell constants, angles in radian measure
** XYZF: r fractional coordinates
** XYZ2: r cartesian coordinates
** A:    r transformation matrix fractional -> cartesian
** AI:   r transformation matrix cartesian  -> fractional
** VOL:  r cell volume
** IDIR: i 1: fractional -> cartesian
**        -1: cartesian  -> fractional
** UNAX: c unique axis (a/A, b/B, c/C, r/R)
** OLD:  l .true.: use old transformation matrix
**         .false.: calculate new transformation matrix
** IERR: i 0: no error    
**         1: one angle is less than or equal to 1 deg. or one angle
**            is greater then 180 deg.
**         2: one cell edge is less than 1
**         3: IDIR is neither -1 nor 1
**         4: sum of angles is greater or equal 360 deg.
**         5: ((cos(beta)-cos(gamma)*cos(alpha))/sin(alpha))**2 +
**            cos(gamma)**2 
**            or corresponding expressions are greater than 1.0
************************************************************************
** definition of cartesian axes 
** (unique axis=a):
** x-axis parallel to a-axis
** y-axis in a-b-plane, on the same side as b-axis
** z-axis perpendicular to x- and y-axis (right-hand system)
** (unique axis=b):
** x-axis perpendicular to y- and z-axis (right-hand system)
** y-axis parallel to b-axis
** z-axis in b-c-plane, on the same side as c-axis
** (unique axis=c):
** x-axis in c-a-plane, on the same side as a-axis
** y-axis perpendicular to z- and x-axis (right-hand system)
** z-axis parallel to c-axis
** (unique axis=r, space diagonal)
** z-axis parallel to the projection of the a-axis onto the x-y-plane
** y-axis perpendicular to z- and x-axis (right-hand system)
** z-axis parallel to the direction 111

************************************************************************
      implicit real (a-h,o-z)
      parameter(PI=3.141592653589793d0,PI20=PI/20d0,PI2=PI*2)
      real CELL(6), XYZF(3), XYZ2(3), VOL
      real D, C1,C2,C3,S1,S2,S3
      integer IDIR, IERR
      character UNAX*1
      logical OLD
      real A(3,3), AI(3,3), A2
      common /TEST/ A,AI
************************************************************************
      IERR = 0
      if(OLD) goto 100
** calculate transformation matrix (fractional to cartesian)
      if(CELL(4).lt.PI20.or.CELL(5).lt.PI20.or.CELL(6).lt.PI20) then
        IERR = 1
        return
      end if
      if(CELL(4).ge.PI.or.CELL(5).ge.PI.or.CELL(6).ge.PI) then
        IERR = 1
        return
      end if
      C1 = COS(CELL(4))
      C2 = COS(CELL(5))
      C3 = COS(CELL(6))
      if(CELL(1).lt.1.0.or.CELL(2).lt.1.0.or.CELL(3).lt.1.0) then
        IERR = 2
        return
      end if
      if(CELL(4)+CELL(5)+CELL(6).ge.PI2) then
        IERR = 4
        return
      end if
      if(UNAX.eq.' '.or.UNAX.eq.'a'.or.UNAX.eq.'A') then
        S3 = SIN(CELL(6))
        A(1,1) = CELL(1)
        A(1,2) = CELL(2)*C3
        A(2,1) = 0.0
        A(2,2) = CELL(2)*S3
        A(1,3) = CELL(3)*C2
        A(2,3) = CELL(3)*(C1-C2*C3)/S3
        A2 = (A(2,3)/CELL(3))**2+C2**2
        if(A2.gt.1.0) then
          IERR = 5
          return
        end if
        A(3,1) = 0.0
        A(3,2) = 0.0
        A(3,3) = CELL(3)*SQRT(1. - A2)
      else if(UNAX.eq.'b'.or.UNAX.eq.'B') then
        S1 = SIN(CELL(4))
        A(2,2) = CELL(2)
        A(2,3) = CELL(3)*C1
        A(3,3) = CELL(3)*S1
        A(2,1) = CELL(1)*C3
        A(3,1) = CELL(1)*(C2-C3*C1)/S1
        A(3,2) = 0.0
        A2 = (A(3,1)/CELL(1))**2+C3**2
        if(A2.gt.1.0) then
          IERR = 5
          return
        end if
        A(1,1) = CELL(1)*SQRT(1. - A2)
        A(1,2) = 0.0
        A(1,3) = 0.0
      else if(UNAX.eq.'c'.or.UNAX.eq.'C') then
        S2 = SIN(CELL(5))
        A(3,3) = CELL(3)
        A(3,1) = CELL(1)*C2
        A(1,1) = CELL(1)*S2
        A(3,2) = CELL(2)*C1
        A(1,2) = CELL(2)*(C3-C1*C2)/S2
        A(1,3) = 0.0
        A2 = (A(1,2)/CELL(2))**2+C1**2
        if(A2.gt.1.0) then
          IERR = 5
          return
        end if
        A(2,1) = 0.0
        A(2,2) = CELL(2)*SQRT(1. - A2)
        A(2,3) = 0.0
      else if(UNAX.eq.'r'.or.UNAX.eq.'R') then
        A(1,1) = 0.0
        A(1,2) = sqrt(0.5)*CELL(1)*SQRT(1.0-C1)
        A(1,3) = -A(1,2)
        A(2,1) = -2.0*A(1,2)/sqrt(3.0)
        A(2,2) = -A(2,1)/2.0
        A(2,3) = A(2,2)
        A(3,1) = SQRT(CELL(1)**2-A(2,1)**2)
        A(3,2) = A(3,1)
        A(3,3) = A(3,1)
      end if
      if(IDIR.ne.1.and.IDIR.ne.-1) then
        IERR = 3
        return
      end if
  100 continue
      if(UNAX.ne.'r'.and.UNAX.ne.'R') VOL = A(1,1)*A(2,2)*A(3,3)
      if(UNAX.eq.'r'.or.UNAX.eq.'R') then
        VOL = A(1,2)*A(2,3)*A(3,1) + A(1,3)*A(2,1)*A(3,2) -
     $        A(3,1)*A(2,2)*A(1,3) - A(2,1)*A(1,2)*A(3,3)
      end if
      if(IDIR.eq.1) then
        do 150 I=1,3
          XYZ2(I) = A(I,1)*XYZF(1) + A(I,2)*XYZF(2) + A(I,3)*XYZF(3)
  150   continue
        return
      end if
      if(IDIR.eq.-1) then
        if(OLD) goto 200
** calculate inverse transformation matrix (cartesian to fractional)
        D = VOL
        AI(1,1) = (A(2,2)*A(3,3)-A(3,2)*A(2,3))/D
        AI(2,1) =-(A(2,1)*A(3,3)-A(3,1)*A(2,3))/D
        AI(3,1) = (A(2,1)*A(3,2)-A(3,1)*A(2,2))/D
        AI(1,2) =-(A(1,2)*A(3,3)-A(3,2)*A(1,3))/D
        AI(2,2) = (A(1,1)*A(3,3)-A(3,1)*A(1,3))/D
        AI(3,2) =-(A(1,1)*A(3,2)-A(3,1)*A(1,2))/D
        AI(1,3) = (A(1,2)*A(2,3)-A(2,2)*A(1,3))/D
        AI(2,3) =-(A(1,1)*A(2,3)-A(2,1)*A(1,3))/D
        AI(3,3) = (A(1,1)*A(2,2)-A(2,1)*A(1,2))/D
  200   continue
        do 210 I=1,3
          XYZF(I) = AI(I,1)*XYZ2(1) + AI(I,2)*XYZ2(2) + AI(I,3)*XYZ2(3)
  210   continue
        return
      end if
      end
**
      function RAN2(IDUM)
** RETURNS A UNIFORM RANDOM DEVIATE BETWEEN 0.0 AND 1.0. Set IDUM to 
** any negative value to initialize or reinitialize the sequence
** Version 07.05.96
      implicit double precision (a-h,o-z)
      parameter (M=714025, IA=1366, IC=150889, RM=1./M)
      integer IDUM,IFF,IR(97),IY,J
      save
      data IFF /0/
**    As above
      if(IDUM.lt.0.or.IFF.eq.0) then
        IFF=1
        IDUM=mod(IC-IDUM,M)
**    initialize the shuffle table
        do 11 J=1,97
          IDUM=mod(IA*IDUM+IC,M)
          IR(J)=IDUM
   11   continue
        IDUM=mod(IA*IDUM+IC,M)
        IY=IDUM
      end if
**    Here is where we start except on initialization
      J=1+(97*IY)/M
      if(J.gt.97.or.J.lt.1) pause
      IY=IR(J)
      RAN2=IY*RM
      IDUM=mod(IA*IDUM+IC,M)
      IR(J)=IDUM
      return
      end

      subroutine NIGGLI(CELL,REDCEL,TRAN)
** COMPUTES THE REDUCED NIGGLI CELL
** See: I. Krivy, B. Gruber (1976). Acta Cryst. A32, 297
** Version 21.01.97
** TRAN: Matrix fuer die Transformation der Basisvektoren A,B,C der 
**       urspruenglichen Zelle in die Basisvektoren A',B',C' der 
**       Niggli-Zelle
** A' = TRAN(1,1)*A + TRAN(1,2)*B + TRAN(1,3)*C
** B' = TRAN(2,1)*A + TRAN(2,2)*B + TRAN(2,3)*C
** C' = TRAN(3,1)*A + TRAN(3,3)*B + TRAN(3,3)*C

      implicit real (a-h,o-z)
      real CELL(6),REDCEL(6)
      integer TRAN(3,3)
      double precision A,B,C,XI,ETA,ZETA,DUM
      do 5 I=1,3
        do 5 J=1,3
          if(I.eq.J) TRAN(I,J)=1.0
          if(I.ne.J) TRAN(I,J)=0.0
    5 continue
      NLOOP = 0
** 0.
      A=dble(CELL(1))**2
      B=dble(CELL(2))**2
      C=dble(CELL(3))**2
      XI = 2*dble(CELL(2))*dble(CELL(3))*cos(dble(CELL(4)))
      ETA= 2*dble(CELL(1))*dble(CELL(3))*cos(dble(CELL(5)))
      ZETA=2*dble(CELL(1))*dble(CELL(2))*cos(dble(CELL(6)))
   10 continue
      NLOOP = NLOOP + 1
      if(NLOOP.gt.12) goto 999
** 1. a' und b' vertauschen
      if(A-B.gt.1d-4.or.(abs(A-B).lt.1d-4.and.abs(XI).gt.abs(ETA))) then
        DUM=A
        A=B
        B=DUM
        DUM=XI
        XI=ETA
        ETA=DUM
        do 20 J=1,3
          DUM=TRAN(1,J)
          TRAN(1,J)=TRAN(2,J)
          TRAN(2,J)=DUM
   20   continue
      end if
** 2. b' und c' vertauschen
      if(B-C.gt.1d-4.or.(abs(B-C).lt.1d-4.and.abs(ETA).gt.abs(ZETA))) 
     $                                                              then
        DUM=B
        B=C
        C=DUM
        DUM=ETA
        ETA=ZETA
        ZETA=DUM
        do 30 J=1,3
          DUM=TRAN(2,J)
          TRAN(2,J)=TRAN(3,J)
          TRAN(3,J)=DUM
   30   continue
        goto 10
      end if
** 3. Richtung von 0 oder 2 Achsen umkehren
      if(XI*ETA*ZETA.gt.0.0) then
        if(XI.gt.0.0.and.ETA.lt.0.0) then
**      b' -> -b'; c' -> -c'
          do 40 J=1,3
            TRAN(2,J)=-TRAN(2,J)
            TRAN(3,J)=-TRAN(3,J)
   40     continue
        end if
**      a' -> -a'; c' -> -c'
        if(ETA.gt.0.0.and.ZETA.lt.0.0) then
          do 50 J=1,3
            TRAN(1,J)=-TRAN(1,J)
            TRAN(3,J)=-TRAN(3,J)
   50     continue
        end if
**      a' -> -a'; b' -> -b'
        if(ZETA.gt.0.0.and.XI.lt.0.0) then
          do 60 J=1,3
            TRAN(1,J)=-TRAN(1,J)
            TRAN(2,J)=-TRAN(2,J)
   60     continue
        end if
        XI=abs(XI)
        ETA=abs(ETA)
        ZETA=abs(ZETA)
      end if
** 4. Richtung von 1 oder 3 Achsen umkehren
      if(XI*ETA*ZETA.le.0.0) then
**      a' -> -a'
        if(XI.lt.0.0) then
          do 70 J=1,3
            TRAN(1,J)=-TRAN(1,J)
   70     continue
        end if
**      b' -> -b'
        if(ETA.lt.0.0) then
          do 80 J=1,3
            TRAN(2,J)=-TRAN(2,J)
   80     continue
        end if
**      c' -> -c'
        if(ZETA.lt.0.0) then
          do 90 J=1,3
            TRAN(3,J)=-TRAN(3,J)
   90     continue
        end if
        XI=-abs(XI)
        ETA=-abs(ETA)
        ZETA=-abs(ZETA)
      end if
** 5. c' -> c' - b' oder c' -> c' + b'
      if(abs(XI)-B.gt.1d-4.or.(abs(XI-B).lt.1d-4.and.2*ETA.lt.ZETA).or.
     $                   (abs(XI+B).lt.1d-4.and.ZETA.lt.0.0)) then
        if(XI.gt.0.0) then
**       c' -> c' - b'
          do 100 J=1,3
            TRAN(3,J)=TRAN(3,J)-TRAN(2,J)
  100     continue
          C=B+C-XI
          ETA=ETA-ZETA
          XI=XI-2*B
        else
**       c' -> c' + b'
          do 110 J=1,3
            TRAN(3,J)=TRAN(3,J)+TRAN(2,J)
  110     continue
          C=B+C+XI
          ETA=ETA+ZETA
          XI=XI+2*B
        end if
        goto 10
      end if
** 6. c' -> c' - a' oder c' -> c' + a'
      if(abs(ETA)-A.gt.1d-4.or.(abs(ETA-A).lt.1d-4.and.2*XI.lt.ZETA).or.
     $                    (abs(ETA+A).lt.1d-4.and.ZETA.lt.0.0)) then
        if(ETA.gt.0.0) then
**       c' -> c' - a'
          do 120 J=1,3
            TRAN(3,J)=TRAN(3,J)-TRAN(1,J)
  120     continue
          C=A+C-ETA
          XI=XI-ZETA
          ETA=ETA-2*A
        else
**       c' -> c' + a'
          do 130 J=1,3
            TRAN(3,J)=TRAN(3,J)+TRAN(1,J)
  130     continue
          C=A+C+ETA
          XI=XI+ZETA
          ETA=ETA+2*A
        end if
        goto 10
      end if
** 7. b' -> b' - a' oder b' -> b' + a'
      if(abs(ZETA)-A.gt.1d-4.or.(abs(ZETA-A).lt.1d-4.and.2*XI.lt.ETA)
     $                 .or.(abs(ZETA+A).lt.1d-4.and.ETA.lt.0.0)) then
        if(ZETA.gt.0.0) then
**       b' -> b' - a'
          do 140 J=1,3
            TRAN(2,J)=TRAN(2,J)-TRAN(1,J)
  140     continue
          B=A+B-ZETA
          XI=XI-ETA
          ZETA=ZETA-2*A
        else
**       b' -> b' + a'
          do 150 J=1,3
            TRAN(2,J)=TRAN(2,J)+TRAN(1,J)
  150     continue
          B=A+B+ZETA
          XI=XI+ETA
          ZETA=ZETA+2*A
        end if
        goto 10
      end if
** 8. c' -> a' + b' + c'
      if(XI+ETA+ZETA+A+B.lt.0.0.or.
     $  (abs(XI+ETA+ZETA+A+B).lt.1d-4.and.2*(A+ETA)+ZETA.gt.0.0)) then
        do 160 J=1,3
          TRAN(3,J)=TRAN(1,J)+TRAN(2,J)+TRAN(3,J)
  160   continue
        C=A+B+C+XI+ETA+ZETA
        XI=2*B+XI+ZETA
        ETA=2*A+ETA+ZETA
        goto 10
      end if
  999 continue
      REDCEL(1)=sqrt(A)
      REDCEL(2)=sqrt(B)
      REDCEL(3)=sqrt(C)
      REDCEL(4)=acos(XI/(2*REDCEL(2)*REDCEL(3)))
      REDCEL(5)=acos(ETA/(2*REDCEL(1)*REDCEL(3)))
      REDCEL(6)=acos(ZETA/(2*REDCEL(1)*REDCEL(2)))
      end
      
      subroutine CALSYM
** CALCULATES ROTATIONAL PART OF SYMMETRY OPERATIONS, RN (CARTESIAN 
** COORDINATE SYSTEM)
** Version 29.02.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real X(3),XC(3),Y(3,3)
      real AMAT(3,3), AMATI(3,3)
      common /TEST/ AMAT,AMATI
      do 10 I=1,3
        XC(I)=0.0
   10 continue
**  calculate AMAT and AMATI
      call FRACRT(X,XC,CELL,VOL,-1,UNAX,.false.,IERR)
      do 100 M=1,NS
        N=ISYM(M)
        do 30 K=1,3
          do 20 L=1,3
            Y(K,L) = R(M,K,1)*AMATI(1,L) +
     $               R(M,K,2)*AMATI(2,L) +
     $               R(M,K,3)*AMATI(3,L)
   20     continue
   30   continue
        do 50 K=1,3
          do 40 L=1,3
            if(N.gt.0) then
              RN(N,K,L) = AMAT(K,1)*Y(1,L) +
     $                    AMAT(K,2)*Y(2,L) +
     $                    AMAT(K,3)*Y(3,L)
            else
              RN(-N,K,L) = -AMAT(K,1)*Y(1,L) -
     $                      AMAT(K,2)*Y(2,L) -
     $                      AMAT(K,3)*Y(3,L)
            end if
   40     continue
   50   continue
  100 continue
      end

      subroutine SPCPOS
** CHECKS, IF ANY MOLECULE/ION IS IN A SPECIAL POSITION 
** RESULTS ARE WRITTEN TO SPC AND ISPC
** Version 12.03.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real XYZ1(3),XYZ2(3)
      character TEST*(NUSYM)
      do 100 L=1,NCLUS
        do 10 I=1,NUSYM
          TEST(I:I)='0'
   10   continue
        ISPC(L) = 0
        do 90 I1=-3,3
          do 80 I2=-3,3
            do 70 I3=-3,3
              do 60 M1=1,NS
                do 20 J=1,3
                  XYZ1(J) = R(M1,J,1)*XYZS(L,1) +
     $                      R(M1,J,2)*XYZS(L,2) +
     $                      R(M1,J,3)*XYZS(L,3) +
     $                      T(M1,J)
   20           continue
                do 50 M2=M1+1,NS
                  do 30 J=1,3
                    XYZ2(J) = R(M2,J,1)*XYZS(L,1) +
     $                        R(M2,J,2)*XYZS(L,2) +
     $                        R(M2,J,3)*XYZS(L,3) +
     $                        T(M2,J)
   30             continue
                  XYZ2(1)=XYZ2(1)+I1
                  XYZ2(2)=XYZ2(2)+I2
                  XYZ2(3)=XYZ2(3)+I3
                  D = sqrt((XYZ2(1)-XYZ1(1))**2 +
     $                     (XYZ2(2)-XYZ1(2))**2 +
     $                     (XYZ2(3)-XYZ1(3))**2)
                  if(D.lt.1e-4.and.TEST(M2:M2).eq.'0') then
                    TEST(M2:M2)='1'
                    ISPC(L) = ISPC(L) + 1
                    write(SPC(ISPC(L),L),'(i2,3i1)') M2,5+I1,5+I2,5+I3
                  end if
   50           continue
   60         continue
   70       continue
   80     continue
   90   continue
  100 continue
      end

      subroutine REDUCE(ISP)
** PUTS PARAMETERS INTO STANDARD REGION
** Version 18.11.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.141592653589793d0,PI2=PI*2)
      real XYZ(3),XYZAD(3)
      XYZAD(1)=0.0
      XYZAD(2)=0.0
      XYZAD(3)=0.0
      do 760 L=1,NCLUS
        L6=L*6
**        XYZMAX=-1e10
**        MMAX=1
** try to transform translations to the region -0.5..0.5 or -0.25..0.25
        do 700 J=1,3
          if(SHIFT.and.ICENT(J).eq.1.and.L.eq.1) then
            if(XYZS(L,J).lt.-0.25.and.XYZS(L,J).gt.-0.75) XYZAD(J)=0.5
            if(XYZS(L,J).gt.0.25.and.XYZS(L,J).lt.0.75) XYZAD(J)=-0.5
          end if
  700   continue
        do 730 J=1,3
          if(IVAR(L6+J).ne.0.and.IVAR(L6+J).ne.-9999) then
            if(abs(XYZS(L,J)).gt.0.5.and..not.SHIFT) then 
              write(2,'(/1x,a/)')
     $                'WARNING - UNUSUALLY LARGE TRANSLATION PARAMETER.'
              write(*,'(/1x,a/)')
     $                'WARNING - UNUSUALLY LARGE TRANSLATION PARAMETER.'
            end if
** carry out transformation of translations to region -0.5..0.5 or -0.25..0.25
            if(SHIFT) then
              XYZ(J)=mod(XYZS(L,J),1.0)+XYZAD(J)
              if(XYZ(J).lt.-0.5) XYZ(J)=XYZ(J)+1.0
              if(XYZ(J).gt.0.5) XYZ(J)=XYZ(J)-1.0
              XYZS(L,J)=XYZ(J)
            end if
          end if
  730   continue
        do 720 M=1,NS
** determinant of symmetry operation M
          IDET=R(M,1,1)*R(M,2,2)*R(M,3,3)+
     $         R(M,1,2)*R(M,2,3)*R(M,3,1)+
     $         R(M,1,3)*R(M,2,1)*R(M,3,2)-
     $         R(M,1,1)*R(M,2,3)*R(M,3,2)-
     $         R(M,1,2)*R(M,2,1)*R(M,3,3)-
     $         R(M,1,3)*R(M,2,2)*R(M,3,1)
          if(IDET.lt.0) goto 720
** if determinant is positive, carry out symmetry transformation M
          do 740 J=1,3
            XYZ(J)=R(M,1,J)*XYZS(L,1)+
     $             R(M,2,J)*XYZS(L,2)+
     $             R(M,3,J)*XYZS(L,3)+T(M,J)
  740     continue
          if(abs(XYZ(1)).lt.abs(XYZS(L,1)).or.

     $        (abs(abs(XYZ(1))-abs(XYZS(L,1))).lt.1e-4.and.
     $         XYZ(1).gt.XYZS(L,1)).or.

     $        (abs(XYZ(1)-XYZS(L,1)).lt.1e-4.and.
     $         abs(XYZ(2)).lt.abs(XYZS(L,2))).or.

     $        (abs(XYZ(1)-XYZS(L,1)).lt.1e-4.and.
     $         abs(abs(XYZ(2))-abs(XYZS(L,2))).lt.1e-4.and.
     $         XYZ(2).gt.XYZS(L,2)).or.

     $        (abs(XYZ(1)-XYZS(L,1)).lt.1e-4.and.
     $         abs(XYZ(2)-XYZS(L,2)).lt.1e-4.and.
     $         abs(XYZ(3)).lt.abs(XYZS(L,3))).or.

     $        (abs(XYZ(1)-XYZS(L,1)).lt.1e-4.and.
     $         abs(XYZ(2)-XYZS(L,2)).lt.1e-4.and.
     $         abs(abs(XYZ(3))-abs(XYZS(L,3))).lt.1e-4.and.
     $         XYZ(3).gt.XYZS(L,3))) then
**            XYZS(L,1)=XYZ(1)
**            XYZS(L,2)=XYZ(2)
**            XYZS(L,3)=XYZ(3)
**            C1=cos(ROT(L,1))
**            C2=cos(ROT(L,2))
**            C3=cos(ROT(L,3))
**            S1=sin(ROT(L,1))
**            S2=sin(ROT(L,2))
**            S3=sin(ROT(L,3))
**            X31=S1*S2*R(M,1,1)-C1*S2*R(M,2,1)+C2*R(M,3,1)
**            X32=S1*S2*R(M,1,2)-C1*S2*R(M,2,2)+C2*R(M,3,2)
**            X33=S1*S2*R(M,1,3)-C1*S2*R(M,2,3)+C2*R(M,3,3)
**            X13=(C1*C3-S1*C2*S3)*R(M,1,3)+(S1*C3+C1*C2*S3)*R(M,2,3)+
**     $          S2*S3*R(M,3,3)
**            X23=(-S1*C2*C3-C1*S3)*R(M,2,3)+(-S1*S3+C1*C2*C3)*R(M,2,3)+
**     $          S2*C3*R(M,3,3)
**            ROT(L,2)=acos(X33)
**            if(abs(abs(X33)-1.0).gt.1e-5) then
**              ROT(L,1)=asin(X31/sin(ROT(L,2)))
**              ROT(L,3)=asin(X13/sin(ROT(L,2)))
**              if(-acos(X32/sin(ROT(L,2))).ge.PI/2.and.ROT(L,1).lt.0.) then
**                ROT(L,1)=acos(X32/sin(ROT(L,2)))
**              else if(-acos(X32/sin(ROT(L,2))).ge.PI/2.and.ROT(L,1).gt.0.) then
**                ROT(L,1)=-acos(X32/sin(ROT(L,2)))
**              end if
**              if(-acos(X23/sin(ROT(L,2))).ge.PI/2.and.ROT(L,3).lt.0.) then
**                ROT(L,3)=acos(X23/sin(ROT(L,2)))
**              else if(-acos(X23/sin(ROT(L,2))).ge.PI/2.and.ROT(L,1).gt.0.) then
**                ROT(L,3)=-acos(X23/sin(ROT(L,2)))
**              end if
**            else
**              ROT(L,3)=0.0
**              ROT(L,1)=
**            end if
**          do 60 J=1,3
**            XYZ(J)=R(M,J,1)*YS(L,1)+R(M,J,2)*YS(L,2)+R(M,J,3)*YS(L,3)+
**     $             T(M,J)+XYZAD(J)
**   60     continue
          end if
  720   continue
** transform rotation angles theta, chi, phi to the region -pi..pi, 0..pi,
** -pi..pi, even, if these angles are fixed or constraint (exception:
** constraints between chi and theta or chi and phi)
        do 750 J=4,6
          ROT(L,J-3)=mod(ROT(L,J-3),PI2)
          if(ROT(L,J-3).le.-PI) ROT(L,J-3)=ROT(L,J-3)+PI2
          if(ROT(L,J-3).gt.PI)  ROT(L,J-3)=ROT(L,J-3)-PI2
  750   continue
        if(ROT(L,2).lt.0.0.and.
     $    (abs(IVAR(L6+4)).ne.0.or.abs(IVAR(L6+4)).ne.abs(IVAR(L6+5)))
     $                    .and.
     $    (abs(IVAR(L6+6)).ne.0.or.abs(IVAR(L6+6)).ne.abs(IVAR(L6+5))))
     $                                                              then
          ROT(L,2)=-ROT(L,2)
          ROT(L,1)=ROT(L,1)+PI
          ROT(L,3)=ROT(L,3)+PI
          if(ROT(L,1).gt.PI) ROT(L,1)=ROT(L,1)-PI2
          if(ROT(L,3).gt.PI) ROT(L,3)=ROT(L,3)-PI2
        end if
** if chi equals 0, theta and phi are equivalent
        if(IVAR(L6+4).eq.0.and.IVAR(L6+6).eq.0) then
          if(ROT(L,2).lt.1e-5) then
            ROT(L,1)=ROT(L,1)+ROT(L,3)
            ROT(L,3)=0.0
          end if
          if(abs(ROT(L,2)-PI).lt.1e-5) then
            ROT(L,1)=ROT(L,1)-ROT(L,3)
            ROT(L,3)=0.0
          end if
        end if
  760 continue
      N6=(NUCLUS+1)*6
      do 780 K=1,NUSUB
        if(abs(IVAR(N6+K)).gt.0.and.
     $         IVAR(N6+K).ne.-9999) then
          SUBROT(K)=mod(SUBROT(K),PI2)
          if(SUBROT(K).gt.PI) SUBROT(K)=SUBROT(K)-PI2
          if(SUBROT(K).le.-PI) SUBROT(K)=SUBROT(K)+PI2
        end if
  780 continue
      end

      block data P
      parameter(NUCLUS=16,NUSUB=8)
      character PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      COMMON /PARNAM/ PNAME,RNAME
      DATA (PNAME(K),K=1,NUCLUS*6+6) /
     $'A','B','C','ALPHA','BETA','GAMMA',
     $'TA1','TB1','TC1','THETA1','CHI1','PHI1',
     $'TA2','TB2','TC2','THETA2','CHI2','PHI2',
     $'TA3','TB3','TC3','THETA3','CHI3','PHI3',
     $'TA4','TB4','TC4','THETA4','CHI4','PHI4',
     $'TA5','TB5','TC5','THETA5','CHI5','PHI5',
     $'TA6','TB6','TC6','THETA6','CHI6','PHI6',
     $'TA7','TB7','TC7','THETA7','CHI7','PHI7',
     $'TA8','TB8','TC8','THETA8','CHI8','PHI8',
     $'TA9','TB9','TC9','THETA9','CHI9','PHI9',
     $'TA10','TB10','TC10','THETA10','CHI10','PHI10',
     $'TA11','TB11','TC11','THETA11','CHI11','PHI11',
     $'TA12','TB12','TC12','THETA12','CHI12','PHI12',
     $'TA13','TB13','TC13','THETA13','CHI13','PHI13',
     $'TA14','TB14','TC14','THETA14','CHI14','PHI14',
     $'TA15','TB15','TC15','THETA15','CHI15','PHI15',
     $'TA16','TB16','TC16','THETA16','CHI16','PHI16'/
      DATA (RNAME(K),K=1,NUSUB) /
     $'PSI1','PSI2','PSI3','PSI4','PSI5','PSI6','PSI7','PSI8'/
      end
      subroutine RDATM(FN,METHOD,PAR,NP,POTFIL,ROTC,CONT,
     $   IEND,IJOB,STEP,ISTP,IDUM,ILOOP1,ILOOP2,INLOOP,IANALY,ISP,ISAVE)
** THIS SUBROUTINE READS AN INPUT FILE
** Input Variables:  FN,CONT
** Output Variables: ATNAME, CELL, IDUM, 
**                   SUMR, IEND, ILOOP1, ILOOP2, IPA, ISTP, ISUM, 
**                   METHOD, MTBL, NATM1, NCH, 
**                   NCLUS, NP, NS, NSUB, PAR, POTFIL, Q, RPA, STEP, RM, 
**                   SPG, T, TITLE, UNAX, VWR, XYZC
** Version 20.5.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** additional Variables:
** BLTP:           c Bravais lattice type
** CONT:           l .true.: continue reading input file
**                   .false.: start reading input file
** FN:             i channel number of input file
** ICNT:           i 1: inversion center
** INCELL(J)       r cell constants to be used for transformation of input
**                   fractional coordinates to cartesian coordinates (angles
**                   in degrees)
** NP:             i number of PARM lines
** PAR(L,J):       r value of parameter no. J of molecule/ion no. L
**                   subrotation parameters are in PAR(NCLUS+1,J)
** POTFIL:         c name of potential parameters file
** ROTC(L,J):      r center of rotation of molecule/ion no. L
** RATN(1,N):      c names of Nth subrotation defining atoms (no. 1)
** RATN(2,N):      c names of Nth subrotation defining atoms (no. 2)
** TSTART (RPA(2): r temperature to start simulated annealing with
** TEND   (RPA(4): r temperature to end simulated annealing with
************************************************************************
      real VDWR(100), AMASS(100)
      integer FN, FN1, I,J, ATNO, ISTP(12)
      integer R1,R2,R3, IDUM, ILOOP1,ILOOP2, IEND,IANALY, ISP
      real PAR(NUCLUS+1+NUSUB/6,6),STEP(12), ROTC(NUCLUS,3)
      real XYZF(3),XC(3),BL, INCELL(6)
      character LINE*132, POTFIL*40, FELD*12, LID*8, LABEL1*8,LABEL2*8
      character BLTP*1,SYMM(3)*8, LOHI*8, P(NUMATM)*4, A1*4, A2*4
      character RATN(2,NUSUB)*8
      character PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      CHARACTER PERIOD(100)*2
      logical CONT,FOUND,INLOOP,IDFND,AUTO
      parameter (PI=3.141592653589793d0,PI2=PI*2.0)
      common /PARNAM/ PNAME,RNAME
      COMMON /PERIOD/ PERIOD
      
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL
      character*4 CHCK
      common /CHECK/ CHCK
      SAVE P,NR,RATN

      open(unit=3,file='atoms.par',status='old',err=1100)
      do 1 L=1,100
        read(3,*) VDWR(L),AMASS(L),PERIOD(L)
    1 continue
      close(unit=3)
************************************************************************
** Routines used by this subroutine:
** ANASYM   analyze symmetry operations, find crystal system
** ATNO     read atom name, return atomic number
** BONDL    changes bond distance between two atoms
** DUMP     writes the values of the common variables onto file
** LINCUT   cut a part from the variable LINE and put it to the variable
**          FELD
** LOHI     converts small letters to capital letters
** SPGR     look for space group name/number and read R and T.
** SYMTRN   read equivalent positions as algebraic expression
** SYMMCL   include translations and center of symmetry
************************************************************************
** initialization (global)
   10 continue
      FN1=0
      RPA(1) = 0.0
      RPA(2) = 0.0
      RPA(4) = 0.0
      IPA(1) = 0
      IPA(2) = 0
      if(CONT) goto 30

** initialization only for first optimization
      AUTO = .false.
      CELL(1) = 0
      CELLOK = .false.
      INCELL(1) = 0
      IPA(3) = 1
      ISAVE = 0
      ISP = 1
      HMIN = 3.5
      NATM1 = 0
      NCH = 0
      NCLUS = 1
      NP = 0
      NS = 0
      NSUB = 0
      NPOT = 0
      NVAR = 0
      POTFIL = ' '
      PRESS = 0.0
      PTNAME = ' '
      SPEC = .false.
      SPG = ' '
      SPOT(1,1) = 0.0
      SPOT(1,2) = 0.0
      SPOT(1,3) = 0.0
      UNAX = ' '
      DO 110 L=1,NUCLUS
        RMIN(L)=0.0
        DO 105 M=1,NUSYM
          SPC(M,L)=' '
          SYMMLS(M)=' '
  105   CONTINUE
        DO 110 J=1,3
          ROT(L,J) = 0.0
          ROTC(L,J) = -999.
  110 CONTINUE
      DO 125 I=1,(NUCLUS+1)*6+NUSUB
        IVAR(I)=0
  125 CONTINUE
      DO 130 L=1,NUCLUS+1+NUSUB/6
        if(L.le.NUCLUS) ISPC(L)=0
        DO 120 J=1,6
          PAR(L,J)=-999.
  120   CONTINUE
  130 CONTINUE
      DO 140 J=1,NV
        IPAR(J)=0
  140 CONTINUE
      DO 160 I=1,NUMATM
        LSUB(I)=0
        Q(I)=0.0
        ATNAME(I)=' '
        DO 150 J=1,NUSUB
          RATN(1,J)=' '
          RATN(2,J)=' '
          SUBROT(J) = 0.0
          ISUB(I,J)=0
  150   CONTINUE
        DO 160 J=1,3
          XYZC(I,J)=-999.
  160 CONTINUE
      DO 170 J=1,3
        T(1,J)=0.0
        DO 170 K=1,3
          IF(J.EQ.K) R(1,J,K)=1
          IF(J.NE.K) R(1,J,K)=0
  170 CONTINUE
      DO 180 J=1,12
        STEP(J)=0.0
        ISTP(J)=0
  180 CONTINUE
      DO 190 M1=1,NPOTL
        PNAM(M1)='*'
        DO 190 M2=1,NPOTL
          DO 190 J=1,4
            POT(M1,M2,J)=0.0
  190 CONTINUE
      SUMR=9.0
      ISUM(1)=0
      ISUM(2)=0
      ISUM(3)=0
      I=0
      IF(IJOB.GT.0) THEN
        IJ=0
        REWIND(FN)
   35   CONTINUE
          READ(FN,'(A)',ERR=35,END=490) LINE
          LID = LOHI(LINE(1:8))
          IF(LID(1:4).EQ.'RUN ') IJ=IJ+1
          IF(IJ.EQ.IJOB) GOTO 20
          GOTO 35
      END IF
   30 CONTINUE
      NVAR = 0
      DO 100 K=1,NV
        IF(IPAR(K).NE.0) NVAR = NVAR + 1
  100 CONTINUE

****************** MAIN LOOP START
   20 CONTINUE
      METHOD=0
      IDFND=.false.
      READ(FN,'(A)',ERR=20,END=490) LINE
***
      LID = LOHI(LINE(1:8))

** TITLE
      IF(LID(1:6).EQ.'TITLE ') THEN
        IDFND=.true.
        TITLE = LINE(7:80)
      ELSE IF(LID(1:5).EQ.'TITL ') THEN
        IDFND=.true.
        TITLE = LINE(6:80)
      END IF

** CUT OFF EVERYTHING BEHIND THE EXCLAMATION MARK
      IF(INDEX(LINE,'!').NE.0) LINE = LINE(1:INDEX(LINE,'!')-1)
      
** SPACE GROUP
      IF(LID(1:5).EQ.'SPGR '.or.LID(1:3).eq.'SP ') THEN
        IDFND=.true.
        CALL LINCUT(LINE,FELD)
        SPG = LOHI(FELD(1:8))
        CALL LINCUT(LINE,FELD)
        UNAX = LOHI(FELD(1:8))
        CALL SPGR(SPG,UNAX,R,T,NR,NS,ICNT,BLTP)
      END IF
***
** SYMM/DUPL
      IF(LID(1:5).EQ.'SYMM '.or.LID(1:3).eq.'SY '.or.
     $   LID(1:5).EQ.'DUPL '.or.LID(1:3).eq.'DU ') THEN
        IDFND=.true.
        NS = NS + 1
        if(NS.gt.NUSYM) then
          write(2,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
          write(*,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
          NS = NUSYM
          GOTO 20
        end if
        CALL LINCUT(LINE,FELD)
        SYMM(1)=LOHI(FELD(1:8))
        IS=index(SYMM(1),',')
        if(IS.ne.0) SYMM(1)(IS:IS)=' '
        SYMMLS(NS)(1:10)=SYMM(1)
        SYMMLS(NS)(11:11)=','
        CALL LINCUT(LINE,FELD)
        SYMM(2)=LOHI(FELD(1:8))
        IS=index(SYMM(2),',')
        if(IS.ne.0) SYMM(2)(IS:IS)=' '
        SYMMLS(NS)(12:21)=SYMM(2)
        SYMMLS(NS)(22:22)=','
        CALL LINCUT(LINE,FELD)
        SYMM(3)=LOHI(FELD(1:8))
        IS=index(SYMM(3),',')
        if(IS.ne.0) SYMM(3)(IS:IS)=' '
        SYMMLS(NS)(23:33)=SYMM(3)
        CALL SYMTRN(SYMM,R,T,NS)
        IF((LID(1:5).EQ.'DUPL '.or.LID(1:3).eq.'DU ').and.NS.ne.1) THEN
          NS = (NS-1)*2
          if(NS.gt.NUSYM) then
            write(2,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
            write(*,'(/1x,a/)') 'WARNING - TOO MANY SYMM/DUPL LINES.'
            NS = NS/2 + 1
            GOTO 20
          end if
          M2 = NS/2
          DO 210 M=1,M2
            DO 200 J=1,3
              R(M+M2,J,1) = R(M2+1,J,1)*R(M,1,1)+R(M2+1,J,2)*R(M,2,1)+
     $                      R(M2+1,J,3)*R(M,3,1)
              R(M+M2,J,2) = R(M2+1,J,1)*R(M,1,2)+R(M2+1,J,2)*R(M,2,2)+
     $                      R(M2+1,J,3)*R(M,3,2)
              R(M+M2,J,3) = R(M2+1,J,1)*R(M,1,3)+R(M2+1,J,2)*R(M,2,3)+
     $                      R(M2+1,J,3)*R(M,3,3)
              T(M+M2,J) = R(M2+1,J,1)*T(M,1)+R(M2+1,J,2)*T(M,2)+
     $                    R(M2+1,J,3)*T(M,3) + T(M2+1,J)
  200     CONTINUE
  210   CONTINUE
        END IF
        call SYMMCL('P',0)
      END IF
***
** OUTPUT (NO, FEW, ALL)
      IF(LID(1:5).EQ.'OUTP '.or.LID(1:5).EQ.'MORE ') THEN
        IDFND = .true.
        CALL LINCUT(LINE,FELD)
        if(FELD.EQ.'3'.OR.LOHI(FELD(1:8)).EQ.'NO') then
          IPA(3) = 3
        else if(FELD.EQ.'1'.OR.LOHI(FELD(1:8)).EQ.'FEW') then
          IPA(3) = 1
        else if(FELD.EQ.'2'.OR.LOHI(FELD(1:8)).EQ.'MUCH') then
          IPA(3) = 2
        else if(FELD.EQ.'4'.OR.LOHI(FELD(1:8)).EQ.'FULL'.OR.
     $                         LOHI(FELD(1:8)).EQ.'ALL') then
          IPA(3) = 4
        else
          write(2,'(/1x,3a/)') 'WARNING - CANNOT UNDERSTAND OUTP ',
     $                        FELD(1:8),'. OUTP FEW ASSUMED.'
          write(*,'(/1x,3a/)') 'WARNING - CANNOT UNDERSTAND OUTP ',
     $                        FELD(1:8),'. OUTP FEW ASSUMED.'
        end if
        CALL LINCUT(LINE,FELD)
        if(LOHI(FELD(1:8)).EQ.'SCHAKAL ') then
          ISAVE=1
        else if(LOHI(FELD(1:8)).EQ.'PC ') then
          ISAVE=2
        else if(LOHI(FELD(1:8)).EQ.'NOSAVE ') then
          ISAVE=0
        end if
      END IF
***
** ATOM NAMES, POTENTIAL TYPES, COORDINATES, CHARGES, VDW RADII, CV RADII
      IF(LID(1:5).EQ.'ATOM '.OR.LID(1:3).EQ.'AT ') THEN
        IDFND = .true.
        if(NATM1.eq.0) call ANASYM(ISP)
        NATM1 = NATM1+1
        if(NATM1.gt.NUMATM) then
          write(2,'(/1x,a,i4,a/)') 'ERROR - TOO MANY ATOMS (MORE THAN',
     $                              NUMATM,'). PROGRAM ABORTED.'
          write(*,'(/1x,a,i4,a/)') 'ERROR - TOO MANY ATOMS (MORE THAN',
     $                              NUMATM,'). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        ICLUS(NATM1) = NCLUS
        CALL LINCUT(LINE,FELD)
        ATNAME(NATM1) = LOHI(FELD(1:8))
        IF(ATNO(ATNAME(NATM1)).EQ.0) THEN
          VWR(NATM1) = 0.0
          RM(NATM1) = 0.0
        ELSE
          VWR(NATM1) = VDWR(ATNO(ATNAME(NATM1)))
          RM(NATM1) = AMASS(ATNO(ATNAME(NATM1)))
        END IF
        CALL LINCUT(LINE,FELD)
        P(NATM1) = LOHI(FELD(1:8))
        if(ichar(P(NATM1)(1:1)).lt.ichar('A').or.
     $     ichar(P(NATM1)(1:1)).gt.ichar('Z')) then
          write(2,'(/1x,4a/)') 
     $           'WARNING - ILLEGAL ATOM TYPE NAME FOR ',ATNAME(NATM1),
     $           ':',P(NATM1)
          write(*,'(/1x,4a/)') 
     $           'WARNING - ILLEGAL ATOM TYPE NAME FOR ',ATNAME(NATM1),
     $           ':',P(NATM1)
          LINE = FELD//LINE
        end if
        FOUND = .false.
        do 220 J=1,NPOT
          if(P(NATM1).eq.PNAM(J)) then
            FOUND = .true.
            PTYP(NATM1) = J
          end if
  220   continue
        if(.not.FOUND) then
          NPOT = NPOT + 1
          IF(NPOT.gt.NPOTL) THEN
            write(2,'(/1x,a,i3,4a/)') 
     $      'ERROR - MORE THAN',NPOTL,' ATOM TYPES.',
     $      'LAST ATOM TYPE READ: ',P(NATM1),'.'
            write(*,'(/1x,a,i3,4a/)') 
     $      'ERROR - MORE THAN',NPOTL,' ATOM TYPES.',
     $      'LAST ATOM TYPE READ: ',P(NATM1),'.'
            call DUMP
            stop
          END IF
          PNAM(NPOT) = P(NATM1)
          PTYP(NATM1) = NPOT
        end if
        DO 240 J=1,3
          CALL LINCUT(LINE,FELD)
          READ(FELD,'(BN,F12.0)',ERR=1020) XYZF(J)
  240   CONTINUE
        CALL FRACRT(XYZF,XC,INCELL,VOL,1,UNAX,.false.,IERR)
        DO 250 J=1,3
          XYZC(NATM1,J) = XC(J)
  250   CONTINUE
        CALL LINCUT(LINE,FELD)
        IF(FELD.NE.'$') READ(FELD,'(BN,F12.0)',ERR=1030) Q(NATM1)
        IF(ABS(Q(NATM1)).NE.0.0) THEN
          NCH = NCH + 1
        END IF
        CALL LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') THEN
          READ(FELD,'(BN,F12.0)',ERR=1040) VWR(NATM1)
        END IF
      END IF

*** CELL CONSTANTS
      IF(LID(1:5).EQ.'CELL ') THEN
        IDFND=.true.
        DO 260 J=1,6
          CALL LINCUT(LINE,FELD)
          READ(FELD,'(BN,F12.0)',ERR=1050) CELL(J)
          IF(J.GT.3) CELL(J)=CELL(J)/180.0*PI
          IF((J.LE.3.AND.CELL(J).LT.2.0).OR.
     $       (J.GT.3.AND.(CELL(J).LT.PI/20.OR.CELL(J).GT.0.95*PI))) THEN
            write(2,'(/1x,a,6f8.2/)') 
     $           'WARNING - UNREASONABLE CELL PARAMETERS: CELL ',CELL
            write(*,'(/1x,a,6f8.2/)') 
     $           'WARNING - UNREASONABLE CELL PARAMETERS: CELL ',CELL
          END IF
  260   CONTINUE
        IF(INCELL(1).EQ.0.0) THEN
          DO 270 J=1,6
            INCELL(J)=CELL(J)
  270     CONTINUE
        END IF
      END IF

*** INCELL CELL CONSTANTS
      IF(LID(1:7).EQ.'INCELL ') THEN
        IDFND=.true.
        DO 280 J=1,6
          CALL LINCUT(LINE,FELD)
          READ(FELD,'(BN,F12.0)',ERR=20) INCELL(J)
          IF(J.GT.3) INCELL(J)=INCELL(J)/180.0*PI
  280   CONTINUE
        IF(CELL(1).EQ.0.0) THEN
          DO 290 J=1,6
            CELL(J)=INCELL(J)
  290     CONTINUE
        END IF
      END IF

*** CELLOK (CHECK OR DO NOT CHECK CELL CONSTANTS)
      IF(LID(1:7).EQ.'CELLOK ') THEN
        IDFND=.true.
        CELLOK=.true.
      END IF

*** ROTATION CENTER
      IF(LID(1:5).EQ.'ROTC ') THEN
        IDFND=.true.
        CALL LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) L
        DO 295 J=1,3
          CALL LINCUT(LINE,FELD)
          READ(FELD,'(BN,F12.0)',ERR=20) XYZF(J)
  295   CONTINUE
        CALL FRACRT(XYZF,XC,INCELL,VOL,1,UNAX,.false.,IERR)
        DO 298 J=1,3
          ROTC(L,J) = XC(J)
  298   CONTINUE
      END IF

*** MOLE
      IF(LID(1:5).EQ.'MOLE ') THEN
        IDFND=.true.
        IF(NATM1.GE.1) NCLUS=NCLUS+1
      END IF

*** COPY
      IF(LID(1:5).EQ.'COPY ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) IC
        IF(abs(IC).LE.NCLUS.and.IC.ne.0) THEN
          NCLUS=NCLUS+1
          N=NATM1
          DO 300 I=1,N
            IF(ICLUS(I).EQ.abs(IC)) THEN
              NATM1=NATM1+1
              if(NATM1.gt.NUMATM) then
                write(2,'(/1x,a,i4,a/)')
     $             'ERROR - TOO MANY ATOMS (MORE THAN',
     $              NUMATM,') PRODUCED BY COPY. PROGRAM ABORTED.'
                write(*,'(/1x,a,i4,a/)')
     $             'ERROR - TOO MANY ATOMS (MORE THAN',
     $              NUMATM,') PRODUCED BY COPY. PROGRAM ABORTED.'
                call DUMP
                stop
              end if
              ICLUS(NATM1)=NCLUS
              ATNAME(NATM1)=ATNAME(I)
              VWR(NATM1)=VWR(I)
              RM(NATM1)=RM(I)
              P(NATM1)=P(I)
              PTYP(NATM1)=PTYP(I)
              XYZC(NATM1,1)=XYZC(I,1)
              XYZC(NATM1,2)=XYZC(I,2)
              XYZC(NATM1,3)=XYZC(I,3)
              if(IC.lt.0) then
                XYZC(NATM1,1)=-XYZC(NATM1,1)
                XYZC(NATM1,2)=-XYZC(NATM1,2)
                XYZC(NATM1,3)=-XYZC(NATM1,3)
              end if
              Q(NATM1)=Q(I)
              IF(ABS(Q(NATM1)).NE.0.0) THEN
                NCH=NCH+1
              END IF
            END IF
  300     CONTINUE
        END IF
      END IF

*** VARIABLES (FIX/UNFIX)
      IF(LID(1:5).EQ.'VARY '.OR.LID(1:4).EQ.'FIX ') THEN
        IDFND=.true.
        IF(LID(1:5).EQ.'VARY ') THEN
          IFIX=0
        ELSE
          IFIX=1
        END IF
  310   CONTINUE
        call LINCUT(LINE,FELD)
        FELD(1:8) = LOHI(FELD(1:8))
        FOUND=.false.
** automatically create variables and constraints
        IF(FELD(1:5).eq.'AUTO '.and.LID(1:5).eq.'VARY ') THEN
          DO 320 K=1,NUCLUS*6+6+NSUB
            IF(K.LE.NCLUS*6+6.OR.K.GT.NUCLUS*6+6) IVAR(K)=1
  320     CONTINUE
          DO 325 K=1,NV
            IPAR(K)=0
  325     CONTINUE
          FOUND=.true.
          AUTO =.true.

** monoclinic
          IF(ISP.EQ.2) THEN
            IF(UNAX.EQ.'A') THEN
              IVAR(5)=0
              IVAR(6)=0
              CELL(5)=PI/2
              CELL(6)=PI/2
            ELSE IF(UNAX.EQ.'B') THEN
              IVAR(4)=0
              IVAR(6)=0
              CELL(4)=PI/2
              CELL(6)=PI/2
            ELSE IF(UNAX.EQ.'C') THEN
              IVAR(4)=0
              IVAR(5)=0
              CELL(4)=PI/2
              CELL(5)=PI/2
            END IF
** orthorhombic
          ELSE IF(ISP.EQ.3) THEN
            IVAR(4)=0
            IVAR(5)=0
            IVAR(6)=0
            CELL(4)=PI/2
            CELL(5)=PI/2
            CELL(6)=PI/2
** tetragonal/hexagonal/trigonal (hex. setting)
          ELSE IF(ISP.EQ.4.OR.ISP.EQ.6.OR.
     $           (ISP.EQ.5.AND.UNAX.NE.'R')) THEN
            IVAR(4)=0
            IVAR(5)=0
            IVAR(6)=0
            CELL(4)=PI/2
            CELL(5)=PI/2
            CELL(6)=PI/2
            IF(UNAX.EQ.'A') THEN
              IVAR(3)=0
              IF(ISP.GE.5) CELL(4)=2.0/3.0*PI
            ELSE IF(UNAX.EQ.'B') THEN
              IVAR(3)=0
              IF(ISP.GE.5) CELL(5)=2.0/3.0*PI
            ELSE IF(UNAX.EQ.'C') THEN
              IVAR(2)=0
              IF(ISP.GE.5) CELL(6)=2.0/3.0*PI
            END IF
** trigonal (rhomb. setting)/cubic
          ELSE IF((ISP.EQ.5.AND.UNAX.EQ.'R').OR.ISP.EQ.7) THEN
            IVAR(2)=0
            IVAR(3)=0
            IVAR(5)=0
            IVAR(6)=0
          END IF
** look for single atoms
          DO 340 L=1,NCLUS
            K=0
            DO 330 I=1,NATM1
              IF(ICLUS(I).EQ.L) K=K+1
  330       CONTINUE
            IF(K.EQ.1) THEN
              IVAR(L*6+4)=0
              IVAR(L*6+5)=0
              IVAR(L*6+6)=0
            END IF
  340     CONTINUE
** can I fix some of the translations of the first molecule/ion?
          IVAR(7)=0
          IVAR(8)=0
          IVAR(9)=0
          DO 350 M=1,NS
            R1=R(M,1,1)
            R2=R(M,2,2)
            R3=R(M,3,3)
            IF(R1.NE.1.OR.R(M,1,2).NE.0.OR.R(M,1,3).NE.0) IVAR(7)=1
            IF(R(M,2,1).NE.0.OR.R2.NE.1.OR.R(M,2,3).NE.0) IVAR(8)=1
            IF(R(M,3,1).NE.0.OR.R(M,3,2).NE.0.OR.R3.NE.1) IVAR(9)=1
  350     CONTINUE
          IF(ISUM(1).EQ.0.OR.ISUM(2).EQ.0.OR.ISUM(3).EQ.0) THEN
            CALL FIXCEL(ISUM,SUMR,T,NS,IVAR,IPAR)
          END IF
        END IF
        DO 360 K=1,NUCLUS*6+6
          IF(FELD.EQ.PNAME(K)) THEN
            IF(IFIX.EQ.0.AND.IVAR(K).EQ.0) THEN
              NVAR = NVAR + 1
              IF(NVAR.gt.NV) THEN
               write(2,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
               write(*,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
              ELSE
                IVAR(K)=NVAR
                IPAR(NVAR)=K
              END IF
** fix variable corresponding to parameter K
            ELSE IF(IFIX.EQ.1.AND.IVAR(K).NE.0) THEN
              IVAR(K)=0
**              IF(IPAR(IVAR(K)).EQ.K) THEN
**                IV=IVAR(K)
**                DO 355 KK=1,NUCLUS*6+6
**                  IF(IVAR(KK).EQ.IV) then
**                    IVAR(KK)=0
**                    DO 354 KKK=KK+1,NUCLUS*6+6
**                      IF(IVAR(KKK).NE.0) THEN
**                        IVAR(KKK)=IVAR(KKK)-1
**                        IPAR(IVAR(KKK))=KKK
**                      END IF
**  354               CONTINUE
**                  END IF
**  355           CONTINUE
**                IPAR(NVAR)=0
**                NVAR = NVAR -1
**              END IF
**      print*,IPAR
            END IF
            FOUND=.true.
          END IF
  360   CONTINUE
** put subrotation to the end of array IVAR
        DO 370 K=1,NUSUB
          K1=(NUCLUS+1)*6+K
          IF(FELD.EQ.RNAME(K)) THEN
            IF(IFIX.EQ.0.AND.IVAR(K1).EQ.0) THEN
              NVAR = NVAR + 1
              if(NVAR.gt.NV) then
               write(2,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
               write(*,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
              ELSE
                IVAR(K1)=NVAR
                IPAR(NVAR)=K1
              END IF
            END IF
            IF(IFIX.EQ.1.AND.IVAR(K1).NE.0) THEN
              IF(IPAR(IVAR(K1)).EQ.K1) THEN
                IV=IVAR(K1)
                DO 365 KK=1,K1
                  IF(IVAR(KK).EQ.IV) IVAR(KK)=0
  365           CONTINUE
                IPAR(NVAR)=0
                NVAR = NVAR -1
              END IF
            END IF
            FOUND=.true.
          END IF
  370   CONTINUE
        IF(.not.FOUND.and.FELD.ne.' ') THEN
          write(2,'(/1x,3a/)') 'WARNING - DON''T KNOW PARAMETER NAME ',
     $                        FELD(1:8),'.'
          write(*,'(/1x,3a/)') 'WARNING - DON''T KNOW PARAMETER NAME ',
     $                        FELD(1:8),'.'
        END IF
        IF(FELD.NE.' ') GOTO 310
** count and sort variables (only for option AUTO)
        IF(AUTO) THEN
          NVAR=0
** cell constants, translations, rotations:
          DO 380 K=1,NUCLUS*6+6
            IF(IVAR(K).gt.0) THEN
              NVAR=NVAR+1
              if(NVAR.gt.NV) then
               write(2,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
               write(*,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',PNAME(K),' WILL BE IGNORED.'
              else
                IVAR(K)=NVAR
                IPAR(NVAR)=K
              end if
            END IF
  380     CONTINUE
** subrotations:
          DO 390 K=1,NUSUB
            IF(IVAR((NUCLUS+1)*6+K).gt.0) THEN
              NVAR=NVAR+1
              if(NVAR.gt.NV) then
               write(2,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',RNAME(K),' WILL BE IGNORED.'
               write(*,'(/1x,a,i4,3a/)')'WARNING - TOO MANY VARIABLES ('
     $                          ,NVAR,'). ',RNAME(K),' WILL BE IGNORED.'
                NVAR=NVAR-1
              else
                IVAR((NUCLUS+1)*6+K)=NVAR
                IPAR(NVAR)=(NUCLUS+1)*6+K
              end if
            END IF
  390     CONTINUE
        END IF
** auto constraints
        IF(AUTO) THEN
** tetragonal/hexagonal/trigonal (hex. setting)
          IF(ISP.EQ.4.OR.ISP.EQ.6.OR.(ISP.EQ.5.AND.UNAX.NE.'R')) THEN
            IF(UNAX.EQ.'A') THEN
              IVAR(3)=IVAR(2)
            ELSE IF(UNAX.EQ.'B') THEN
              IVAR(3)=IVAR(1)
            ELSE IF(UNAX.EQ.'C') THEN
              IVAR(2)=IVAR(1)
            END IF
** trigonal (rhomb. setting)/cubic
          ELSE IF((ISP.EQ.5.AND.UNAX.EQ.'R').OR.ISP.EQ.7) THEN
            IVAR(2)=IVAR(1)
            IVAR(3)=IVAR(1)
            IF(ISP.EQ.5) IVAR(5)=IVAR(4)
            IF(ISP.EQ.5) IVAR(6)=IVAR(4)
          END IF
        END IF
        DO 400 I=NVAR+1,NV
          IPAR(I)=0
  400   CONTINUE
      END IF

*** DEFINE SUBROTATIONS
      IF(LID(1:6).EQ.'INROT ') THEN
        IDFND=.true.
        NSUB=NSUB+1
        IF(NSUB.GT.NUSUB) THEN
          write(2,'(/1x,a,i2,a/1x,a/)') 
     $      'WARNING - TOO MANY SUBROTATIONS (MORE THAN',NUSUB,').',
     $       'SUBROTATION '//LINE(7:40)//'WILL BE IGNORED.'
          write(*,'(/1x,a,i2,a/1x,a/)') 
     $      'WARNING - TOO MANY SUBROTATIONS (MORE THAN',NUSUB,').',
     $       'SUBROTATION '//LINE(7:40)//'WILL BE IGNORED.'
          NSUB=NSUB-1
          GOTO 20
        END IF
        call LINCUT(LINE,FELD)
        RATN(1,NSUB)=LOHI(FELD(1:8))
        call LINCUT(LINE,FELD)
        RATN(2,NSUB)=LOHI(FELD(1:8))
        IF(RATN(1,NSUB).EQ.' '.OR.RATN(2,NSUB).EQ.' ') THEN
          write(2,'(/1x,a/1x,a,1x,2a/)') 
     $      'WARNING - NOT ENOUGH SUBROTATION DEFINING ATOMS:',
     $        RATN(1,NSUB),RATN(2,NSUB),
     $       '. THIS SUBROTATION WILL BE IGNORED.'
          write(*,'(/1x,a/1x,a,1x,2a/)') 
     $      'WARNING - NOT ENOUGH SUBROTATION DEFINING ATOMS:',
     $        RATN(1,NSUB),RATN(2,NSUB),
     $       '. THIS SUBROTATION WILL BE IGNORED.'
          NSUB=NSUB-1
        END IF
      END IF

*** CONSTRAINTS
      IF(LID(1:5).EQ.'CNST ') THEN
        IDFND=.true.
        BM=1
        call LINCUT(LINE,FELD)
        L1=0
        DO 410 K=1,NUCLUS*6+6
          IF(LOHI(FELD(1:8)).EQ.PNAME(K)) L1=K
  410   CONTINUE
        DO 420 K=1,NUSUB
          IF(LOHI(FELD(1:8)).EQ.RNAME(K)) L1=K+NUCLUS*6+6
  420   CONTINUE
        IF(L1.EQ.0) THEN
          write(2,'(/1x,3a/1x,a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          write(*,'(/1x,3a/1x,a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          GOTO 20
        END IF
        CS=0
        call LINCUT(LINE,FELD)
        IF(FELD.EQ.'=') CS=1
        IF(FELD.EQ.'<>') CS=-1
        IF(CS.eq.0) THEN
          write(2,'(/1x,4a)') 
     $     'WARNING - ILLEGAL CHARACTER ',FELD(1:8),'. ',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          write(*,'(/1x,4a)') 
     $     'WARNING - ILLEGAL CHARACTER ',FELD(1:8),'. ',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          GOTO 20
        END IF
        call LINCUT(LINE,FELD)
        if(FELD.eq.'-') THEN
          BM=-1
          call LINCUT(LINE,FELD)
        end if
        L2=0
        DO 430 K=1,NUCLUS*6+6
          IF(LOHI(FELD(1:8)).EQ.PNAME(K)) L2=K
  430   CONTINUE
        DO 440 K=1,NUSUB
          IF(LOHI(FELD(1:8)).EQ.RNAME(K)) L2=K+NUCLUS*6+6
  440   CONTINUE
        IF(L2.EQ.0) THEN
          write(2,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          write(*,'(/1x,3a/a)') 
     $     'WARNING - PARAMETER NAME ',LOHI(FELD(1:8)),' NOT FOUND.',
     $     'THIS CONSTRAINT WILL BE IGNORED.'
          GOTO 20
        END IF
        IF((L1.LE.3.AND.L2.GT.3).OR.(L1.GT.3.AND.L2.LE.3).OR.
     $     (L1.LE.6.AND.L2.GT.6).OR.(L1.GT.6.AND.L2.LE.6)) THEN
          write(2,'(/1x,5a)') 
     $     'ILLEGAL CONSTRAINT ',PNAME(L1),' ',PNAME(L2),
     $     '. THIS CONSTRAINT WILL BE IGNORED.'
          write(*,'(/1x,5a)') 
     $     'ILLEGAL CONSTRAINT ',PNAME(L1),' ',PNAME(L2),
     $     '. THIS CONSTRAINT WILL BE IGNORED.'
          GOTO 20
        END IF
        IF(CS.EQ.1) IVAR(L1) = BM*IVAR(L2)
        IF(CS.EQ.-1) IVAR(L1) = 0
        GOTO 20
      END IF

*** BOND LENGTH
      IF(LID(1:5).EQ.'BOND ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        LABEL1 = LOHI(FELD(1:8))
        call LINCUT(LINE,FELD)
        LABEL2 = LOHI(FELD(1:8))
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,F12.0)',ERR=20) BL
        call BONDL(LABEL1,LABEL2,BL)
      END IF

*** SPECIAL POSITIONS
      IF(LID(1:5).EQ.'SPEC ') THEN
        IDFND=.true.
        SPEC=.true.
      END IF

*** PARAMETERS
      IF(LID(1:5).EQ.'PARM ') THEN
        IDFND=.true.
        NP=NP+1
        if(NP.gt.NUCLUS+1+(NUSUB-1)/6) 
     $               write(2,'(1x,a)') 'WARNING! too many PARM lines'
        if(NP.gt.NUCLUS+1+(NUSUB-1)/6) 
     $               write(*,'(1x,a)') 'WARNING! too many PARM lines'
        do 450 J=1,6
          call LINCUT(LINE,FELD)
          IF(FELD.NE.'$') READ(FELD,'(BN,F12.0)',ERR=20) PAR(NP,J)
  450   continue
      END IF

*** SUMMATION RADIUS
      IF(LID(1:5).EQ.'SUMR ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,F12.0)',ERR=20) SUMR
        call LINCUT(LINE,FELD)
        if(FELD.ne.' ') THEN
          ISUM(1)=int(SUMR)
          SUMR=0.0
          READ(FELD,'(BN,I12)',ERR=20) ISUM(2)
          call LINCUT(LINE,FELD)
          READ(FELD,'(BN,I12)',ERR=20) ISUM(3)
        ELSE
          ISUM(1)=0
          ISUM(2)=0
          ISUM(3)=0
        END IF
      END IF

** Minimum height of cell
      IF(LID(1:5).EQ.'HMIN ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,F12.0)',ERR=20) HMIN
      END IF

** Minimum radius of molecule
      IF(LID(1:5).EQ.'RMIN ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) L
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,F12.0)',ERR=20) RMIN(L)
      END IF

*** PRESSURE
      IF(LID(1:5).EQ.'PRES ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,F12.0)',ERR=20) PRESS
      END IF

*** INITIALIZE RANDOM NUMBER GENERATOR (RANDOM SEED)
      IF(LID(1:5).EQ.'RNSD ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) IDUM
      END IF

** LOOP
      IF(LID(1:5).EQ.'LOOP ') THEN
        IDFND=.true.
        if(INLOOP) goto 20
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) ILOOP1
        if(ILOOP1.lt.1.or.ILOOP1.gt.359) write(2,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP1:',ILOOP1
        if(ILOOP1.lt.1.or.ILOOP1.gt.359) write(*,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP1:',ILOOP1
        call LINCUT(LINE,FELD)
        READ(FELD,'(BN,I12)',ERR=20) ILOOP2
        if(ILOOP2.eq.0) ILOOP2=ILOOP1
        if(ILOOP2.lt.1.or.ILOOP2.gt.359.or.ILOOP2.lt.ILOOP1) 
     $      write(2,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP2:',ILOOP2
        if(ILOOP2.lt.1.or.ILOOP2.gt.359.or.ILOOP2.lt.ILOOP1) 
     $      write(*,'(/1x,a,i12/)') 
     $      'WARNING - ILLEGAL VALUE FOR ILOOP2:',ILOOP2
        INLOOP=.true.
      END IF

*** ROSENBROCK OR POWELL METHOD
      if(LID(1:5).eq.'ROBR '.or.LID(1:5).eq.'POWL ') THEN
        IDFND=.true.
        if(LID(1:5).eq.'ROBR ') METHOD=1
        if(LID(1:5).eq.'POWL ') METHOD=2
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(4)
        if(IPA(2).eq.0) IPA(2)=500
        IPA(1)=20
        RPA(1)=1e-4
        RPA(2)=1e-8
        RPA(3)=-.05
        if(RPA(4).eq.0.0) RPA(4)=1e-6
        GOTO 500
      end if
*** THRESHOLD ACCEPTING, GREAT DELUGE OR SIMULATED ANNEALING METHOD      
      if(LID(1:5).eq.'THAC '.or.LID(1:5).eq.'GRDL '.or.
     $   LID(1:5).eq.'SMAN ') THEN
        IDFND=.true.
        IPA(5)=0
        if(LID(1:5).eq.'GRDL ') METHOD=3
        if(LID(1:5).eq.'THAC ') METHOD=4
        if(LID(1:5).eq.'SMAN ') METHOD=5
  455   continue
        call LINCUT(LINE,FELD)
        IF(FELD.EQ.'N'.OR.FELD.EQ.'n') THEN
          IPA(5)=1
          GOTO 455
        END IF
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(1)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(1)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(2)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) 
     $                                                            RPA(4)
        if(RPA(1).eq.0.0) RPA(1)=1e-2
        RPA(3)=0.5
        GOTO 500
      end if

*** MELTING     
      if(LID(1:5).eq.'MELT ') THEN
        IDFND=.true.
        METHOD=6
        call LINCUT(LINE,FELD)
        IF(FELD.NE.'$'.AND.FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) 
     $                                                            IPA(2)
        RPA(3)=0.5
        GOTO 500
      end if

*** GRID SEARCH METHOD OR 2-DIM. MAP
      if(LID(1:5).eq.'GRID '.or.LID(1:4).eq.'MAP ') THEN
        IDFND=.true.
        if(LID(1:5).eq.'GRID ') METHOD=7
        if(LID(1:4).eq.'MAP ') METHOD=10
        do 460 J=1,12
          call LINCUT(LINE,FELD)
          IF(FELD.NE.' ') READ(FELD,'(BN,F12.0)',ERR=20) STEP(J)
          call LINCUT(LINE,FELD)
          IF(FELD.NE.' ') READ(FELD,'(BN,I12)',ERR=20) ISTP(J)
          IF(ISTP(J).LT.0.OR.(ISTP(J).GT.64.AND.METHOD.eq.10)) THEN
            WRITE(2,'(/1x,2a,i5,a/)') 
     $                'ERROR - ILLEGAL NO. OF STEPS FOR MAP OR GRID',
     $                ' SEARCH:',ISTP(J),'. PROGRAM ABORTED.'
            WRITE(*,'(/1x,2a,i5/)') 
     $                'ERROR - ILLEGAL NO. OF STEPS FOR MAP OR GRID',
     $                ' SEARCH:',ISTP(J),'. PROGRAM ABORTED.'
            CALL DUMP
            STOP
          END IF
  460   continue
        GOTO 500
      end if

*** STEEPEST DESCENT OR DAMPED NEWTON METHOD
      if(LID(1:5).eq.'STDS '.or.LID(1:5).eq.'NEWT ') THEN
        IDFND=.true.
        if(LID(1:5).eq.'STDS ') METHOD=8
        if(LID(1:5).eq.'NEWT ') METHOD=9
        RPA(4)=0.1
        RPA(1)=1e-5
        RPA(2)=1e-6
        IPA(1)=100
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(1)
        call LINCUT(LINE,FELD)
**     in this case epsmi is epsgrd
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(4)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(2)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(1)
        IPA(2)=IPA(1)*(2*NVAR+10)
        GOTO 500
      end if

*** ENERGY AND GRADIENT
      if(LID(1:5).eq.'STAT ') THEN
        IDFND=.true.
        METHOD=11
        IANALY=0
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IANALY
        GOTO 500
      end if

*** SIMPLEX, GENETIC ALGORITHM
      if(LID(1:5).eq.'SIMP '.or.LID(1:5).eq.'GENE ') THEN
        IDFND=.true.
        if(LID(1:5).eq.'SIMP ') METHOD=12
        if(LID(1:5).eq.'GENE ') METHOD=13
        RPA(1)=0.01
        RPA(2)=1e-8
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$') 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(2)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$'.AND.METHOD.EQ.12) 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(2)
        IF(FELD.NE.' '.AND.FELD.NE.'$'.AND.METHOD.EQ.13) 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(1)
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$'.AND.METHOD.EQ.13) 
     $                       READ(FELD,'(BN,I12)',ERR=20) IPA(6)
        IF((IPA(6).GT.100.OR.IPA(6).LT.1).AND.METHOD.eq.13) THEN
            WRITE(2,'(/1x,a,i5,a/)') 
     $                'ERROR - ILLEGAL SIZE OF POPULATION',IPA(6),
     $                '. PROGRAM ABORTED.'
            WRITE(*,'(/1x,a,i5,a/)') 
     $                'ERROR - ILLEGAL SIZE OF POPULATION',IPA(6),
     $                '. PROGRAM ABORTED.'
            CALL DUMP
            STOP
        END IF
        call LINCUT(LINE,FELD)
        IF(FELD.NE.' '.AND.FELD.NE.'$'.AND.METHOD.EQ.13) 
     $                       READ(FELD,'(BN,F12.0)',ERR=20) RPA(1)
        GOTO 500
      end if

*** NAME OF POTENTIAL
      if(LID(1:5).eq.'PTYP ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        PTNAME = LOHI(FELD(1:8))
      END IF

*** POTENTIAL FILE      
      IF(LID(1:5).EQ.'FPOT '.AND.FN1.EQ.0) THEN
        IDFND=.true.
        POTFIL=LINE(6:)
        open(unit=8,file=POTFIL,status='old',err=1010)
        FN1=FN
        FN=8
      ELSE IF(LID(1:5).EQ.'FPOT '.AND.FN1.NE.0) THEN
        IDFND=.true.
        WRITE(2,*) 'POTENTIAL FILE ALREADY OPEN. CANNOT OPEN A ',
     $             'SECOND ONE.'
        WRITE(*,*) 'POTENTIAL FILE ALREADY OPEN. CANNOT OPEN A ',
     $             'SECOND ONE.'
      END IF

*** POTENTIAL PARAMETERS
      IF(LID(1:4).eq.'POT ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        A1=LOHI(FELD(1:8))
        FOUND=.false.
        M1=0
        do 470 I=1,NPOT
          if(A1.eq.PNAM(I)) then
            FOUND=.true.
            M1=I
          end if
  470   continue
        if(.not.FOUND) goto 20
        call LINCUT(LINE,FELD)
        A2=LOHI(FELD(1:8))
        FOUND=.false.
        M2=0
        do 480 I=1,NPOT
          if(A2.eq.PNAM(I)) then
            FOUND=.true.
            M2=I
          end if
  480   continue
        if(.not.FOUND) goto 20
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,1)
        POT(M2,M1,1)=POT(M1,M2,1)
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,2)
        POT(M2,M1,2)=POT(M1,M2,2)
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,3)
        POT(M2,M1,3)=POT(M1,M2,3)
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) POT(M1,M2,4)
        POT(M2,M1,4)=POT(M1,M2,4)
      END IF
*** SURFACE POTENTIAL PARAMETERS
      IF(LID(1:5).eq.'SURF ') THEN
        IDFND=.true.
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) SPOT(1,1)
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) SPOT(1,2)
        call LINCUT(LINE,FELD)
        read(FELD,'(bn,f12.0)',err=20) SPOT(1,3)
      END IF        

** End of File
      if(LID(1:4).eq.'END '.and.FN1.eq.0) goto 490
      if(LID(1:4).eq.'END '.and.FN1.ne.0) then
        CLOSE(UNIT=FN)
        FN=FN1
        FN1=0
        goto 20
      end if
      if(LID(1:4).eq.'RUN '.and.FN1.eq.0) then
        CONT=.false.
        IEND = 1
        goto 500
      end if
      if(LID(1:4).eq.'REM ') IDFND=.true.
      if(LID(1:5).eq.'DUMP ') then
        IDFND=.true.
        call DUMP
      end if
      if(LID.eq.' ') IDFND=.true.         
      if(.not.IDFND) then
        WRITE(2,'(/1x,3a/)') 'WARNING - LINE ID ',LID,' NOT FOUND.'
        WRITE(*,'(/1x,3a/)') 'WARNING - LINE ID ',LID,' NOT FOUND.'
      end if

****************** MAIN LOOP END
      GOTO 20

  490 CONTINUE
      IF(FN1.NE.0) THEN
        CLOSE(UNIT=FN)
        FN=FN1
        FN1=0
        goto 20
      END IF
      IEND=-1
  500 CONTINUE
** CALCULATE MISSING POTENTIAL PARAMETERS BY GEOMETRICAL MEANS
      DO 510 M1=1,NPOT
        DO 510 M2=1,NPOT
          IF(POT(M1,M2,1).EQ.0.0) THEN
            POT(M1,M2,1)=sqrt(POT(M1,M1,1)*POT(M2,M2,1))
            POT(M2,M1,1)=POT(M1,M2,1)
          END IF
          IF(POT(M1,M2,2).EQ.0.0) THEN
            POT(M1,M2,2)=(POT(M1,M1,2)+POT(M2,M2,2))/2.0
            POT(M2,M1,2)=POT(M1,M2,2)
          END IF
          IF(POT(M1,M2,3).EQ.0.0) THEN
            POT(M1,M2,3)=sqrt(POT(M1,M1,3)*POT(M2,M2,3))
            POT(M2,M1,3)=POT(M1,M2,3)
          END IF
          IF(POT(M1,M2,4).EQ.0.0) THEN
            POT(M1,M2,4)=(POT(M1,M1,4)+POT(M2,M2,4))/2.0
            POT(M2,M1,4)=POT(M1,M2,4)
          END IF
  510 CONTINUE
** ARE THERE SOME ATOMS WITHOUT POTENTIAL PARAMETERS?
      DO 520 M1=1,NPOT
        IF(POT(M1,M1,1).eq.0.0.and.POT(M1,M1,2).eq.0.0.and.
     $     POT(M1,M1,3).eq.0.0.and.POT(M1,M1,4).eq.0.0.and.
     $     PTNAME.ne.'SQUARE'.and.PTNAME.ne.'SOFT') THEN
          WRITE(2,'(/1x,a,a/)') 
     $           'WARNING - NO PARAMETERS FOUND FOR ATOM TYPE ',PNAM(M1)
          WRITE(*,'(/1x,a,a/)') 
     $           'WARNING - NO PARAMETERS FOUND FOR ATOM TYPE ',PNAM(M1)
        END IF
  520 CONTINUE
** ARE THERE ANY POTENTIAL PARAMETERS WHICH ARE ZERO FOR ALL ATOM TYPES?
      CHCK='0000'
      DO 530 I=1,NATM1
        IF(Q(I).ne.0) CHCK(1:1)='1'
  530 CONTINUE
      DO 540 M1=1,NPOT
        DO 540 M2=1,NPOT
          IF(POT(M1,M2,2).ne.0.0) CHCK(2:2)='1'
          IF(POT(M1,M2,3).ne.0.0) CHCK(3:3)='1'
          IF(POT(M1,M2,4).ne.0.0) CHCK(4:4)='1'
  540 CONTINUE
      DO 550 M1=2,NPOT+1
        IF(SPOT(M1,1).EQ.0.0.OR.SPOT(M1,2).EQ.0.0) THEN
          if(SPOT(1,3).eq.0.0) then
            SPOT(M1,1)=PI2/90*sqrt(SPOT(1,1)*POT(M1-1,M1-1,1)/PI2*90)
            SPOT(M1,2)=PI2/12*sqrt(SPOT(1,2)*POT(M1-1,M1-1,3)/PI2*12)
          ELSE
            SPOT(M1,1)=PI2*sqrt(SPOT(1,1)*POT(M1-1,M1-1,1)/PI2)
            SPOT(M1,2)=(SPOT(1,2)+POT(M1-1,M1-1,2))/2.0
            SPOT(M1,3)=PI2/12*sqrt(SPOT(1,3)*POT(M1-1,M1-1,3)/PI2*12)
          END IF
        END IF
  550 CONTINUE

************************************************************************
** LOOK FOR THE SUBROTATION-DEFINING ATOMS
      do 720 N=1,NSUB
        FOUND=.false.
        do 700 I=1,NATM1
          if(ATNAME(I).eq.RATN(1,N)) then
            ISUB(1,N) = I
            FOUND=.true.
            goto 710
          end if
  700   continue
  710   continue
        if(.NOT.FOUND) THEN
          write(2,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(1,N),'. THIS SUBROTATION WILL BE IGNORED.'
          write(*,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(1,N),'. THIS SUBROTATION WILL BE IGNORED.'
          ISUB(1,N) = -1
          ISUB(2,N) = -1
        END IF
  720 continue
      do 740 N=1,NSUB
        FOUND=.false.
        do 730 I=1,NATM1
          if(ATNAME(I).eq.RATN(2,N)) then
            ISUB(2,N) = I
            FOUND=.true.
            goto 735
          end if
  730   continue
  735   continue
        if(.NOT.FOUND) THEN
          write(2,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(2,N),'. THIS SUBROTATION WILL BE IGNORED.'
          write(*,'(/1x,a/1x,a,1x,a/)') 
     $    'WARNING - CANNOT FIND THIS SUBROTATION DEFINING ATOM:',
     $          RATN(2,N),'. THIS SUBROTATION WILL BE IGNORED.'
          ISUB(1,N) = -1
          ISUB(2,N) = -1
        END IF
  740 continue
** Default symmetries
      if(NS.eq.0) then
        NS=1
        ISYM(NS)=1
        SYMMLS(NS)='X,Y,Z'
        SPG='P1'
      end if
** Reduce symmetry translation vector
      do 760 M=1,NS
        do 750 J=1,3
          if(T(M,J).gt.0.5) T(M,J) = T(M,J) - 1.0
          if(T(M,J).lt.-.5) T(M,J) = T(M,J) + 1.0
  750   continue
  760 continue
** do I have to vary cell constants and can I fix the orientation of the
** first molecule?
      IF(AUTO.AND.(ISUM(1).EQ.0.OR.ISUM(2).EQ.0.OR.ISUM(3).EQ.0)) THEN
        CALL FIXCEL(ISUM,SUMR,T,NS,IVAR,IPAR)
      END IF
      return
 1010 continue
      write(2,'(/1x,2a/)') 
     $       'ERROR - CANNOT FIND THE POTENTIAL FILE ',POTFIL
      write(*,'(/1x,2a/)') 
     $       'ERROR - CANNOT FIND THE POTENTIAL FILE ',POTFIL
      call DUMP
      stop
 1020 continue
      write(2,'(/1x,3a/)')
     $       'ERROR READING THE COORDINATES OF ATOM ',ATNAME(NATM1),'.'
      write(*,'(/1x,3a/)')
     $       'ERROR READING THE COORDINATES OF ATOM ',ATNAME(NATM1),'.'
      call DUMP
      stop
 1030 continue
      write(2,'(/1x,3a/)')
     $       'ERROR READING THE CHARGE OF ATOM ',ATNAME(NATM1),'.'
      write(*,'(/1x,3a/)')
     $       'ERROR READING THE CHARGE OF ATOM ',ATNAME(NATM1),'.'
      call DUMP
      stop
 1040 continue
      write(2,'(/1x,3a/)')
     $       'ERROR READING THE VAN DER WAALS RADIUS OF ATOM ',
     $       ATNAME(NATM1),'.'
      write(*,'(/1x,3a/)')
     $       'ERROR READING THE VAN DER WAALS RADIUS OF ATOM ',
     $       ATNAME(NATM1),'.'
      call DUMP
      stop
 1050 continue
      write(2,'(/1x,a/)') 'ERROR READING CELL CONSTANTS.'
      write(*,'(/1x,a/)') 'ERROR READING CELL CONSTANTS.'
      call DUMP
      stop
 1100 continue
      write(2,'(a)') 'ERROR OPENING atoms.par'
      write(*,'(a)') 'ERROR OPENING atoms.par'
      stop
      END

      subroutine LINCUT(LINE,FELD)
** Searches for the first and second position in the character variable LINE
** where a space or a comma is followed by a character which is neither a
** space or a comma. The region between both positions is transferred to
** the character variable FELD and afterwards cut from the variable LINE.
*** VERSION 6.3.92
      implicit real (a-h,o-z)
      CHARACTER LINE*132, FELD*12
      INTEGER CUT
************************************************************************
      FELD=' '
      CUT=0
      DO 10 I=1,131
        IF((LINE(I:I).EQ.' '.OR.LINE(I:I).EQ.',').AND.
     $     (LINE(I+1:I+1).NE.' '.AND.LINE(I+1:I+1).NE.',')) THEN
          LINE = LINE(I+1:)
          CUT=1
          GOTO 20
        END IF
   10 CONTINUE
   20 CONTINUE
      IF(CUT.NE.1) LINE = ' '
      FELD = LINE
      DO 30 I=1,131
        IF((LINE(I:I).EQ.' '.OR.LINE(I:I).EQ.',').AND.
     $     (LINE(I+1:I+1).NE.' '.AND.LINE(I+1:I+1).NE.',')) THEN
          FELD = LINE(:I)
          RETURN
        END IF
   30 CONTINUE
      END
      
      function LOHI(STRING)
** converts small letters to capital letters
      character*8 STRING,LOHI
      integer IC
      IC = ichar('a')-ichar('A')
      do 10 I=1,8
        if(STRING(I:I).ge.'a'.and.STRING(I:I).le.'z') then
          LOHI(I:I) = char(ichar(STRING(I:I))-IC)
        else
          LOHI(I:I) = STRING(I:I)
        end if
   10 continue
      end
      
      function ATNO(NAME)
** Bestimmt die zu einem Atomnamen gehoerende Ordnungszahl.
** Version 22.02.96
      implicit real (a-h,o-z)
      CHARACTER NAME*8,LOHI*8
      CHARACTER PERIOD(100)*2, TEST*2
      INTEGER ATNO
      COMMON /PERIOD/ PERIOD
      TEST = LOHI(NAME)
      ATNO = 0
      if(ichar(TEST(2:2)).lt.ichar('A').or.
     $   ichar(TEST(2:2)).gt.ichar('Z')) TEST(2:2)=' '
      do 10 J=1,92
        if(TEST.eq.PERIOD(J)) ATNO=J
   10 continue
      end
      
      subroutine SPGR(FELD,S,R,T,NR,NS,ICENT,BLTP)
** looks for space group name/number and reads R and T.
** Version 16.11.95
** variables:
** BLTP:      c  Bravais lattice type
** FOUND:     l  .false.: given space group not found in space group table
** ICENT:     i  centricity code (ICENT=1: centrosymmetric structure)
** FELD:      c  space group name or space group number to look for
** NAME:      c  space group name found in space group table
** NR:        i  space group number found in space group table
** NS:        i  number of symmetry operations
** R(I,J,K):  i  rotational part of symmetry operation no. I to give
**               Jth component of position
** S          c  unique axis to look for
** UNAX:      c  unique axis (a, b, c) found in space group table
** T(I,J):    r  translational part of symmetry operation no. I to give
**               Jth component of position
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUSYM=24)
      character FELD*8,NAME*8,UNAX*1,S*1,BLTP*1,LOHI*8
      real T(NUSYM,3)
      integer NR, NS, ICENT, I1(3),I2(3), R(NUSYM,3,3)
      logical FOUND
************************************************************************
      FOUND = .false.
      open(unit=3,file='space.dat',status='old',err=999)
** name or number?
      if(FELD(1:1).ge.'0'.and.FELD(1:1).le.'9') then
        read(FELD,'(bn,i12)',err=100) LOOKNR
        goto 150
      end if
** look for space group name
   10 continue
      read(3,'(i4,2x,i2,3x,i1,3x,a8,a1)',end=100) NR,NS,ICENT,NAME,UNAX
      if(LOHI(NAME).eq.LOHI(FELD).and.
     $  (LOHI(UNAX//'       ').eq.LOHI(S//'       ').or.' '.eq.S.or.
     $                                              UNAX.eq.' ')) then
        FOUND=.true.
        FELD = LOHI(NAME)
        BLTP = NAME(1:1)
        if(NS.gt.NUSYM) then
          write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        do 20 J=1,NS
          read(3,'(3(2i3,3i3))') (I1(K),I2(K),(R(J,K,L),L=1,3),K=1,3)
          do 30 K=1,3
            if(I2(K).ne.0) then
              T(J,K) = real(I1(K))/I2(K)
            else
              T(J,K) = 0.0
            end if
   30     continue
   20   continue
        S = LOHI(UNAX)
        call SYMMCL(BLTP,ICENT)
      else
        do 140 J=1,NS
          read(3,*,end=100)
  140   continue
        goto 10
      end if
      goto 100
** look for space group number
  150 continue
      read(3,'(i4,2x,i2,3x,i1,3x,a8,a1)',end=100) NR,NS,ICENT,NAME,UNAX
      if(NR.eq.LOOKNR.and.
     $  (LOHI(UNAX//'       ').eq.LOHI(S//'       ').or.' '.eq.S
     $                                           .or.UNAX.eq.' ')) then
        FELD = LOHI(NAME)
        BLTP = NAME(1:1)
        FOUND=.true.
        do 160 J=1,NS
          read(3,'(3(2i3,3i3))') (I1(K),I2(K),(R(J,K,L),L=1,3),K=1,3)
          do 170 K=1,3
            if(I2(K).ne.0) then
              T(J,K) = real(I1(K))/I2(K)
            else
              T(J,K) = 0.0
            end if
  170     continue
  160   continue
        call SYMMCL(BLTP,ICENT)
      else
        do 180 J=1,NS
          read(3,*,end=100)
  180   continue
        goto 150
      end if
  100 continue
      if(.not.FOUND) then
        write(2,'(/1x,4a/)') 'WARNING - SPACE GROUP ',FELD,S,
     $                       ' NOT FOUND. SPGR P1 ASSUMED.'
        write(*,'(/1x,4a/)') 'WARNING - SPACE GROUP ',FELD,S,
     $                       ' NOT FOUND. SPGR P1 ASSUMED.'
        FELD='P1'
      end if
  999 continue
      close(3)
      end
**
      subroutine SYMMCL(BLTP,ICNT)
** INCLUDES TRANSLATIONS AND CENTER OF SYMMETRY
** WRITES SYMMLS
** CREATES LIST OF DIFFERENT ROTATIONS
** Version 20.02.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      integer ICNT
      character BLTP*1,SC(-1:1,3)*2
      logical EQUAL1,EQUAL2
      data ((SC(I,J),I=-1,1),J=1,3) /'-X',' ','+X','-Y',' ','+Y',
     $                               '-Z',' ','+Z'/

** face-centered of body-centered
      if(BLTP.eq.'A'.or.BLTP.eq.'B'.or.BLTP.eq.'C'.or.BLTP.eq.'I')then
        if(2*NS.gt.NUSYM) then
          write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        do 510 J=1,NS
          do 510 K=1,3
            T(J+NS,K) = T(J,K)
            if(BLTP.eq.'I') T(J+NS,K)=T(J,K)+0.5
            if(K.eq.1.and.(BLTP.eq.'B'.or.BLTP.eq.'C'))
     $                                       T(J+NS,K)=T(J,K)+0.5
            if(K.eq.2.and.(BLTP.eq.'A'.or.BLTP.eq.'C'))
     $                                       T(J+NS,K)=T(J,K)+0.5
            if(K.eq.3.and.(BLTP.eq.'A'.or.BLTP.eq.'B'))
     $                                       T(J+NS,K)=T(J,K)+0.5
            do 510 L=1,3
              R(J+NS,K,L) = R(J,K,L)
  510   continue
        NS = NS*2
      end if
      if(BLTP.eq.'F') then
        if(4*NS.gt.NUSYM) then
          write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        do 520 J=1,NS
          do 520 K=1,3
            do 520 M=1,3
            T(J+M*NS,K) = T(J,K)+0.5
            if(K.eq.M) T(J+M*NS,K)=T(J,K)
            do 520 L=1,3
              R(J+M*NS,K,L) = R(J,K,L)
  520   continue
        NS = NS*4
      end if
** rhombohedral
      if(BLTP.eq.'R'.and.UNAX.ne.'R') then
        if(3*NS.gt.NUSYM) then
          write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        do 530 J=1,NS
          do 530 K=1,3
            do 530 M=1,2
              if(K.eq.1) then
                if(M.eq.1) T(J+M*NS,K) = T(J,K)+1.0/3
                if(M.ne.1) T(J+M*NS,K) = T(J,K)+2.0/3
              else
                if(M.eq.1) T(J+M*NS,K) = T(J,K)+2.0/3
                if(M.ne.1) T(J+M*NS,K) = T(J,K)+1.0/3
              end if
              do 530 L=1,3
                R(J+M*NS,K,L) = R(J,K,L)
  530   continue
        NS = NS*3
      end if
** centrosymmetric
      if(ICNT.eq.1) then
        if(2*NS.gt.NUSYM) then
          write(2,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/)') 
     $         'ERROR - TOO MANY SYMMETRY OPERATIONS (MORE THAN',NUSYM,
     $         '). PROGRAM ABORTED.'
          call DUMP
          stop
        end if
        do 540 J=1,NS
          do 540 K=1,3
            T(J+NS,K) = 1.0-T(J,K)
              do 540 L=1,3
                R(J+NS,K,L) = -R(J,K,L)
  540   continue
        NS = NS*2
      end if
      do 700 I=1,NS
        SYMMLS(I)=' '
        SYMMLS(I)(11:11)=','
        SYMMLS(I)(22:22)=','
        do 590 J=1,3
          if(abs(1./6-abs(T(I,J)) ).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/6'
          if(abs(1./4-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/4'
          if(abs(1./3-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/3'
          if(abs(1./2-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='1/2'
          if(abs(2./3-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='2/3'
          if(abs(3./4-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='3/4'
          if(abs(5./6-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='5/6'
          if(abs(7./6-abs(T(I,J))).lt.1e-4) 
     $                               SYMMLS(I)(J*11-9:J*11-7)='7/6'
          if(T(I,J).lt.0.0) SYMMLS(I)(J*11-10:J*11-10)='-'
          do 580 K=1,3
            SYMMLS(I)(J*11+K*2-8:J*11+K*2-7)=SC(R(I,J,K),K)
  580     continue
  590   continue
** Delete spaces
        do 610 K=1,9
          do 600 J=1,32
            if(SYMMLS(I)(J:J).eq.' ') then
              SYMMLS(I)=SYMMLS(I)(1:J-1)//SYMMLS(I)(J+1:33)//' '
            end if
  600     continue
  610   continue
** Delete leading '+' characters
        if(SYMMLS(I)(1:1).eq.'+') SYMMLS(I)=SYMMLS(I)(2:33)//' '
        do 620 K=1,2
          KI=index(SYMMLS(I),',+')
          if(KI.ne.0) SYMMLS(I)=SYMMLS(I)(1:KI)//SYMMLS(I)(KI+2:33)//' '
  620   continue
  700 continue
** create list of different orientations
      NSYM=0
      EQUAL1=.false.
      EQUAL2=.false.
      do 750 M=1,NS
        do 740 N=1,M-1
          EQUAL1=.true.
          EQUAL2=.true.
          do 730 J=1,3
            do 720 K=1,3
              if(R(M,J,K).ne.R(N,J,K)) then
                EQUAL1=.false.
              end if
              if(R(M,J,K).ne.-R(N,J,K)) then
                EQUAL2=.false.
              end if
  720       continue
  730     continue
          if(EQUAL1) then
            ISYM(M)=ISYM(N)
            goto 750
          else if(EQUAL2) then
            ISYM(M)=-ISYM(N)
            goto 750
          end if
  740   continue
        if(.not.EQUAL1.and..not.EQUAL2) then
          NSYM=NSYM+1
          ISYM(M)=NSYM
        end if
        if(NSYM.gt.NUSYM/4) then
          write(2,'(/1x,a,i3,a/a/)') 
     $         'ERROR - TOO MANY DIFFERENT ORIENTATIONS (MORE THAN',
     $          NUSYM/4,')',' FOR THIS SPACE GROUP. PROGRAM ABORTED.'
          write(*,'(/1x,a,i3,a/a/)') 
     $         'ERROR - TOO MANY DIFFERENT ORIENTATIONS (MORE THAN',
     $          NUSYM/4,')',' FOR THIS SPACE GROUP. PROGRAM ABORTED.'
          call DUMP
          stop
        end if
  750 continue
      end

      subroutine SYMTRN(XYZ,R,T,I)
**** Dieses Unterprogramm interpretiert Symmetrieoperationen in 
**** algebraischer Schreibweise
      implicit real (a-h,o-z)
      parameter(NUSYM=24)
      character XYZ(3)*8
      real T(NUSYM,3)
      integer R(NUSYM,3,3)
************************************************************************
      print *,XYZ
      do 10 J=1,3
        if(index(XYZ(J),'1').ne.0) T(I,J)=1
        if(index(XYZ(J),'2/').ne.0) T(I,J)=2
        if(index(XYZ(J),'3/').ne.0) T(I,J)=3
        if(index(XYZ(J),'4/').ne.0) T(I,J)=4
        if(index(XYZ(J),'5/').ne.0) T(I,J)=5
        if(index(XYZ(J),'6/').ne.0) T(I,J)=6
        if(index(XYZ(J),'7/').ne.0) T(I,J)=7
        if(index(XYZ(J),'8/').ne.0) T(I,J)=8
        if(index(XYZ(J),'9/').ne.0) T(I,J)=9
   10 continue

      do 20 J=1,3
        if(index(XYZ(J),'/2').ne.0) T(I,J)=T(I,J)/2
        if(index(XYZ(J),'/3').ne.0) T(I,J)=T(I,J)/3
        if(index(XYZ(J),'/4').ne.0) T(I,J)=T(I,J)/4
        if(index(XYZ(J),'/6').ne.0) T(I,J)=T(I,J)/6
   20 continue

      do 30 J=1,3
        if(index(XYZ(J),'-1').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-2').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-3').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-4').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-5').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-6').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-7').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-8').ne.0) T(I,J)=-T(I,J)
        if(index(XYZ(J),'-9').ne.0) T(I,J)=-T(I,J)
   30 continue

      do 50 J=1,3
        if(index(XYZ(J),'-X').ne.0) then
          R(I,J,1)=-1
        else if(index(XYZ(J),'X').ne.0) then
          R(I,J,1)=+1
        end if
        if(index(XYZ(J),'-Y').ne.0) then
          R(I,J,2)=-1
        else if(index(XYZ(J),'Y').ne.0) then
          R(I,J,2)=+1
        end if
        if(index(XYZ(J),'-Z').ne.0) then
          R(I,J,3)=-1
        else if(index(XYZ(J),'Z').ne.0) then
          R(I,J,3)=+1
        end if
   50 continue

      end
**      
      subroutine SROT
** Look for atoms taking part in a subrotation and calculate direction
** of rotation axis
** Version 24.5.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter (PI=3.141592653589793d0)
      logical FRAGM(NUMATM),FOUND
      double precision V(3),X(3),ALPHA1,ALPHA2
      integer K1,K2
      integer IBO(0:8,NUMATM)
      common /BOND/ IBO
** K1, K2        i number of the first and the second subrotation defining
**                 atoms
** FRAGM(I)      l .true.: atom no. I is part of the actual subrotation
************************************************************************
** Loop over all subrotating groups
      do 60 N=1,NSUB
        do 10 I=1,NATM1
          FRAGM(I) = .false.
   10   continue
        K1 = ISUB(1,N)
        K2 = ISUB(2,N)
** Are atoms K1 and K2 connected to each other? If yes, FOUND.eq..true.
        FOUND=.false.
        do 20 I=1,IBO(0,K1)
          if(IBO(I,K1).eq.K2) FOUND=.true.
   20   continue
        if(.not.FOUND) then
          write(2,'(/1x,3a/1x,a/)') 
     $      'WARNING - SUBROTATION DEFINING ATOMS ',
     $      ATNAME(K1),ATNAME(K2),' ARE NOT BONDED TO EACH OTHER.'
          write(*,'(/1x,3a/1x,a/)') 
     $      'WARNING - SUBROTATION DEFINING ATOMS ',
     $      ATNAME(K1),ATNAME(K2),' ARE NOT BONDED TO EACH OTHER.'
        end if
** Is there more than one atom connected to the first or to the second atom?
        if(IBO(0,K1).le.1) then
          write(2,'(/1x,a,i2,3a/)') 
     $      'WARNING - ONLY',IBO(0,K1),
     $      ' ATOM(S) BONDED TO SUBROTATION DEFINING ATOM ',
     $      ATNAME(K1),'.'
          write(*,'(/1x,a,i2,3a/)') 
     $      'WARNING - ONLY',IBO(0,K1),
     $      ' ATOM(S) BONDED TO SUBROTATION DEFINING ATOM ',
     $      ATNAME(K1),'.'
        end if
        if(IBO(0,K2).le.1) then
          write(2,'(/1x,a,i2,3a/)') 
     $      'WARNING - ONLY',IBO(0,K2),
     $      ' ATOM(S) BONDED TO SUBROTATION DEFINING ATOM ',
     $      ATNAME(K2),'.'
          write(*,'(/1x,a,i2,3a/)') 
     $      'WARNING - ONLY',IBO(0,K2),
     $      ' ATOM(S) BONDED TO SUBROTATION DEFINING ATOM ',
     $      ATNAME(K2),'.'
        end if
** give negative numbers to the rotation defining atoms K1 and K2
        if(LSUB(K1).lt.0) then
          LSUB(K1)=-128*N
        else if(LSUB(K1).eq.0) then
          LSUB(K1)=-N
        end if
        if(LSUB(K2).lt.0) then
          LSUB(K2)=-128*N
          LSUB(K1)=0
        else if(LSUB(K2).eq.0) then
          LSUB(K2)=-N
        else
          write(2,'(/1x,2a/1x,a/)') 
     $      'WARNING - SUBROTATION DEFINING ATOM ',
     $      ATNAME(K2),' ALREADY BELONGS TO 2 OTHER SUBROTATING GROUPS.'
          write(*,'(/1x,2a/1x,a/)') 
     $      'WARNING - SUBROTATION DEFINING ATOM ',
     $      ATNAME(K2),' ALREADY BELONGS TO 2 OTHER SUBROTATING GROUPS.'
        end if
** look for all atoms taking part in subrotation no. N
        FRAGM(K1) = .true.
        FRAGM(K2) = .true.
        L = 2
        do 50 M=1,NATM1-1
        do 40 I=1,NATM1
          do 30 J=1,8
            if(IBO(J,I).ne.K1.and.IBO(J,I).ne.0) then
              if(.not.FRAGM(I).and.FRAGM(IBO(J,I)))then
                L = L + 1
                ISUB(L,N) = I
                if(LSUB(I).eq.0) then
                  LSUB(I)=N
                else if (LSUB(I).lt.0) then
                  LSUB(I)=LSUB(I)-128*N
                else
                  LSUB(I)=LSUB(I)+128*N
                end if
                FRAGM(I) = .true.
              end if
            end if
   30     continue
   40   continue
   50   continue
** a) directional vector defining rotation axis (first bond atom in origin)
        V(1) = XYZC(ISUB(2,N),1) - XYZC(ISUB(1,N),1)
        V(2) = XYZC(ISUB(2,N),2) - XYZC(ISUB(1,N),2)
        V(3) = XYZC(ISUB(2,N),3) - XYZC(ISUB(1,N),3)
** b) rotation of rotation axis onto x-axis
** 1. rotation around y-axis onto x-y-plane by angle ALPHA1
        if(abs(V(3)).lt.1e-10) then
          ALPHA1 = 0.0
        else if(abs(V(1)).lt.1e-10) then
          ALPHA1 = PI/2.
        else
          ALPHA1 = atan(V(3)/V(1))
        end if
        SUBDIR(N,1)=sin(ALPHA1)
        SUBDIR(N,3)=cos(ALPHA1)
        X(1) = V(1)*SUBDIR(N,3) + V(3)*SUBDIR(N,1)
        V(1) = X(1)
** 2. rotation around z-axis onto x-axis by angle ALPHA2
        if(abs(V(2)).lt.1e-10) then
          ALPHA2 = 0.0
        else if(abs(V(1)).lt.1e-10) then
          ALPHA2 = PI/2.
        else
          ALPHA2=-atan(V(2)/V(1))
        end if
        SUBDIR(N,2)=sin(ALPHA2)
        SUBDIR(N,4)=cos(ALPHA2)
        X(1) = V(1)*SUBDIR(N,4) - V(2)*SUBDIR(N,2)
        V(1) = X(1)
        if(V(1).lt.0.0) then
          SUBDIR(N,2) = -SUBDIR(N,2)
          SUBDIR(N,4) = -SUBDIR(N,4)
        end if
   60 continue
      end

      subroutine ANASYM(ISP)
** Analyse the symmetry
** Version 07.05.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** additional Variables:
************************************************************************
** SGMAT(M)  i describes the type of rotation or inversion of matrix
**             R(M,I,J)
**              1: trace=3, identity
**             -1: trace=-3, inversion
**              2: trace=-1, determinant=1, 2-fold axis
**             -2: trace=1, determinant=-1, mirror plane
**              3: 3-fold axis along the space diagonal
** IDIR(N)   i indicates if there is a symmetry element in the direction N 
**             0: no, 1: yes
**             N=1, 2, 3: a, b, c-direction
**             N=4, 5, 6, 7: space diagonal, abc, -abc, a-bc, ab-c-direction
** ISP       i crystal system
**             1: triclinic, 2: monoclinic, 3: orthorhombic, 4: tetragonal
**             5: trigonal, 6: hexagonal, 7: cubic
** ITRAC     i trace of matrix
**
      integer SGMAT(NUSYM),IDIR(10),IDET(NUSYM)
      ICENT(1)=0
      ICENT(2)=0
      ICENT(3)=0
      do 5 I=1,10
        IDIR(I)=0
    5 continue
      do 10 M=1,NS
        IDET(M)=R(M,1,1)*R(M,2,2)*R(M,3,3)+R(M,1,2)*R(M,2,3)*R(M,3,1)+
     $          R(M,1,3)*R(M,2,1)*R(M,3,2)-R(M,1,1)*R(M,2,3)*R(M,3,2)-
     $          R(M,1,2)*R(M,2,1)*R(M,3,3)-R(M,1,3)*R(M,2,2)*R(M,3,1)
        ITRAC=R(M,1,1)+R(M,2,2)+R(M,3,3)
        if(ITRAC.eq.3) SGMAT(M)=1
        if(ITRAC.eq.-3) SGMAT(M)=-1
        if(ITRAC.eq.-1.and.IDET(M).eq.1) SGMAT(M)=2
        if(ITRAC.eq.1.and.IDET(M).eq.1) SGMAT(M)=4
        if(ITRAC.eq.-1.and.IDET(M).eq.-1) SGMAT(M)=-4
        if(ITRAC.eq.1.and.IDET(M).eq.-1) SGMAT(M)=-2
        if(ITRAC.eq.0) SGMAT(M)=IDET(M)*3
        if(ITRAC.eq.2) SGMAT(M)=IDET(M)*6
   10 continue
      NR2=0
      NR3=0
      NR4=0
      NR6=0
      I4=0
      do 20 M=1,NS
        ITRAC=R(M,1,1)+R(M,2,2)+R(M,3,3)
** Twofold rotation or screw axis along or mirror or glide plane 
** perpendicular to a cell edge
        if(abs(SGMAT(M)).eq.2) then
          NR2=NR2+1
          if(ITRAC*R(M,1,1).eq.-1.and.
     $               R(M,1,2)+R(M,1,3)+R(M,2,1)+R(M,3,1).eq.0) IDIR(1)=1
          if(ITRAC*R(M,2,2).eq.-1.and.
     $               R(M,1,2)+R(M,3,2)+R(M,2,1)+R(M,2,3).eq.0) IDIR(2)=1
          if(ITRAC*R(M,3,3).eq.-1.and.
     $               R(M,1,3)+R(M,2,3)+R(M,3,1)+R(M,3,2).eq.0) IDIR(3)=1
        end if                                                  
** Threefold rotation or screw axis parallel to a cell edge
        if(abs(SGMAT(M)).eq.3) then
          NR3=NR3+1
          if(R(M,1,1)*IDET(M).eq.1) IDIR(1)=1
          if(R(M,2,2)*IDET(M).eq.1) IDIR(2)=1
          if(R(M,3,3)*IDET(M).eq.1) IDIR(3)=1
        end if
** Threefold rotation or screw axis parallel to a space diagonal
        if(abs(SGMAT(M)).eq.3) then
          if(R(M,1,1).eq.0.and.R(M,2,2).eq.0.and.R(M,3,3).eq.0) then
            if(R(M,1,3).ne.0) then
              I1=R(M,2,1)*IDET(M)
              I2=R(M,3,2)*IDET(M)
            else
              I1=R(M,1,2)*IDET(M)
              I2=R(M,2,3)*IDET(M)
            end if
            if(I1.eq.1.and.I2.eq.1) IDIR(4)=1
            if(I1.eq.-1.and.I2.eq.1) IDIR(5)=1
            if(I1.eq.-1.and.I2.eq.-1) IDIR(6)=1
            if(I1.eq.1.and.I2.eq.-1) IDIR(7)=1
          end if
        end if
** Fourfold rotation or screw axis
        if(abs(SGMAT(M)).eq.4) then
          NR4=NR4+1
          if(R(M,1,1)*IDET(M).eq.1) then
            IDIR(1)=1
            I4=1
          else if(R(M,2,2)*IDET(M).eq.1) then
            IDIR(2)=1
            I4=2
          else if(R(M,3,3)*IDET(M).eq.1) then
            IDIR(3)=1
            I4=3
          end if
        end if
** Sixfold rotation or screw axis parallel to a cell edge
        if(abs(SGMAT(M)).eq.6) then
          NR6=NR6+1
          ISP=6
          if(R(M,1,1)*IDET(M).eq.1.and.R(M,1,2)+R(M,1,3).eq.0) IDIR(1)=1
          if(R(M,2,2)*IDET(M).eq.1.and.R(M,2,1)+R(M,2,3).eq.0) IDIR(2)=1
          if(R(M,3,3)*IDET(M).eq.1.and.R(M,3,1)+R(M,3,2).eq.0) IDIR(3)=1
        end if
        ID=IDIR(1)+IDIR(2)+IDIR(3)
** triclinic
        if(ID.eq.0.and.IDIR(4)+IDIR(5)+IDIR(6)+IDIR(7).eq.0) then
          ISP=1
          UNAX='A'
** monoclinic
        else if(NR3.eq.0.and.NR4.eq.0.and.NR6.eq.0.and.ID.eq.1) then
          ISP=2
          if(IDIR(1).eq.1) UNAX='A'
          if(IDIR(2).eq.1) UNAX='B'
          if(IDIR(3).eq.1) UNAX='C'
** orthorhombic
        else if(NR3.eq.0.and.NR4.eq.0.and.NR6.eq.0.and.ID.eq.3) then
          ISP=3
          UNAX='A'
** tetragonal
        else if(NR4.gt.0.and.NR3.eq.0) then
          ISP=4
          if(I4.eq.1) UNAX='A'
          if(I4.eq.2) UNAX='B'
          if(I4.eq.3) UNAX='C'
** trigonal (hexagonal setting)
        else if(NR2.eq.0.and.NR3.gt.0.and.NR4.eq.0.and.NR6.eq.0.and.
     $                                               IDIR(4).eq.0) then
          ISP=5
          if(IDIR(1).eq.1) UNAX='A'
          if(IDIR(2).eq.1) UNAX='B'
          if(IDIR(3).eq.1) UNAX='C'
** trigonal (rhombohedral setting)
        else if(NR2.eq.0.and.NR3.gt.0.and.NR4.eq.0.and.NR6.eq.0.and.
     $                                               IDIR(4).eq.1) then
          ISP=5
          UNAX='R'
** hexagonal
        else if(NR6.gt.0) then
          ISP=6
          if(IDIR(1).eq.1) UNAX='A'
          if(IDIR(2).eq.1) UNAX='B'
          if(IDIR(3).eq.1) UNAX='C'
** cubic
        else if(NR3.gt.0.and.NR2.gt.0.and.
     $                                IDIR(5)+IDIR(6)+IDIR(7).ne.0) then
          ISP=7
          UNAX='A'
        end if
** centricity
        do 30 J=1,3
          J1=J+1
          J2=J+2
          if(J1.gt.3) J1=J1-3
          if(J2.gt.3) J2=J2-3
**       inversion (overwrites all)
          if(SGMAT(M).eq.-1.and.mod(T(M,J),1.0).eq.0.) then
            ICENT(J)=1
**       2-fold axis or screw axis
          else if(SGMAT(M).eq.2.and.R(M,J,J).eq.1) then
            ICENT(J1)=1
            ICENT(J2)=1
**       mirror plane or glide plane
          else if(SGMAT(M).eq.-2.and.R(M,J,J).eq.-1) then
            ICENT(J)=1
          end if
   30   continue
   20 continue
      END
        
      SUBROUTINE FIXCEL(ISUM,SUMR,T,NS,IVAR,IPAR)
** Fixes cell constants depending on summation and on translational elements
** Version 13.05.98
      parameter(NUSYM=24,NUCLUS=16,NV=36,NUSUB=8)
      integer ISUM(3),NS
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV)
      real T(NUSYM,3)
** fix cell edges?  
** yes, if there are no neighbour cells and no translation components of
** any symmetry operation in the corresponding direction
      DO 780 J=1,3
          DO 765 M=1,NS
            IF(T(M,J).NE.0.0) GOTO 780
  765     CONTINUE
          IF(ISUM(J).EQ.0.AND.IVAR(J).NE.0.AND.SUMR.EQ.0.0) THEN
            DO 770 K=IVAR(J),NV-1
              IPAR(K)=IPAR(K+1)
              IF(IPAR(K).GT.0) IVAR(IPAR(K))=K
  770       CONTINUE
            IVAR(J)=0
            IPAR(NV)=0
          END IF
  780 CONTINUE
** fix cell angles?
** yes, if there are no neighbour cells or only one neighbour cell
** in the corresponding two directions
** and if there are is no symmetry operation with both translational
** components in the corresponding two directions equal to zero.
      DO 800 J=1,3
          J1=J+1
          IF(J1.GT.3) J1=J1-3
          J2=J+2
          IF(J2.GT.3) J2=J2-3
          DO 785 M=1,NS
            IF(T(M,J1).NE.0.0) THEN
              DO 784 N=1,NS
                IF(T(N,J2).NE.0.0) GOTO 800
  784         CONTINUE
            END IF
  785     CONTINUE
          IF(ISUM(J1)*ISUM(J2).EQ.0.AND.IVAR(J+3).NE.0.AND.
     $                                                 SUMR.EQ.0.0) THEN
            DO 790 K=IVAR(J+3),NV-1
              IPAR(K)=IPAR(K+1)
              IF(IPAR(K).GT.0) IVAR(IPAR(K))=K
  790       CONTINUE
            IVAR(J+3)=0
            IPAR(NV)=0
          END IF
  800 CONTINUE
** fix orientation of the first molecule?
** yes, if there is no symmetry operation with translational components
** and if there are no neighbour cells
      DO 815 M=1,NS
          IF(T(M,1).NE.0.0.OR.T(M,2).NE.0.0.OR.T(M,3).NE.0.0) RETURN
  815 CONTINUE
      DO 810 J=1,3
          IF(ISUM(J).NE.0.OR.SUMR.NE.0.0) RETURN
  810 CONTINUE
      DO 820 J=1,3
          IF(IVAR(J+9).NE.0) THEN
            DO 805 K=IVAR(J+9),NV-1
              IPAR(K)=IPAR(K+1)
              IF(IPAR(K).GT.0) IVAR(IPAR(K))=K
  805       CONTINUE
            IVAR(J+9)=0
            IPAR(NV)=0
          END IF
  820 CONTINUE
      END
      subroutine OUTPT1(FN,VOL,ATVOL,SMASS,SQ,IDR,CONT,ILOOP,
     $                  ILOOP1,ILOOP2,ISP,TIME)
** THIS SUBROUTINE WRITES TABLES OF INPUT PARAMETERS AND RELATED ITEMS
** Version 07.05.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.14159265)
      real AMAT(3,3), AMATI(3,3)
      common /TEST/ AMAT,AMATI
      real SMASS(NUCLUS),SQ(NUCLUS),ATVOL,DIP(3),DP,XYZ(3),XC(3)
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      integer IBO(0:8,NUMATM)
      common /BOND/ IBO
      character LINE*80, CFIX(6)*10, PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      character CLASS(7)*12,TIME*24
      integer FN
      real QSUM
      logical CONT,OLD
      common /PARNAM/ PNAME,RNAME
      data CLASS /'triclinic','monoclinic','orthorhombic','tetragonal',
     $            'trigonal','hexagonal','cubic'/
      OLD=.true.
      write(FN,'(/1x,72a)') ('*',J=1,72)
      write(FN,'(1x,A)') TITLE
      if(TIME.ne.' ') write(FN,'(1x,a)') TIME
      write(FN,'(1x,a,i3,a,i3,a,i3,a)') 'Loop no.',ILOOP,'(',ILOOP1,'-',
     $                                                       ILOOP2,')'
      write(FN,'(1x,72a/)') ('*',J=1,72)
      write(FN,'(/33x,14a)') ('*',J=1,14)
      write(FN,'(1x,32a,a,32a)') ('*',J=1,32),' Crystal Data ',
     $                           ('*',J=1,32)
      write(FN,'(33x,14a)') ('*',J=1,14)
      write(FN,'(/1x,80a)') ('-',J=1,78)
      write(FN,'(10x,a)') 'Cell Constants'
      write(FN,'(1x,80a)') ('-',J=1,78)
      do 10 J=1,6
	if(IVAR(J).ne.0) then
	  if(IPAR(IVAR(J)).ne.J) CFIX(J) = 'constrnd.'
	  if(IPAR(IVAR(J)).eq.J) CFIX(J) = ' '
	else
	  CFIX(J) = 'fixed'
	end if
   10 continue
      write(FN,'(1x,a,f10.4,a,5x,a,f10.4,a)') 'a=',CELL(1),' Angstrom',
     $                            'alpha=',CELL(4)/PI*180,' Degrees'
      write(FN,'(3x,a10,17x,a10)') CFIX(1),CFIX(4)
      write(FN,'(1x,a,f10.4,14x,a,f10.4,a)')  'b=',CELL(2),
     $                            ' beta=',CELL(5)/PI*180
      write(FN,'(3x,a10,17x,a10)') CFIX(2),CFIX(5)
      write(FN,'(1x,a,f10.4,14x,a,f10.4,a)')  'c=',CELL(3),
     $                            'gamma=',CELL(6)/PI*180
      write(FN,'(3x,a10,17x,a10)') CFIX(3),CFIX(6)
      write(FN,'(1x,78a)') ('-',J=1,78)
** calculate cell volume and orthogonalisation matrix
      call FRACRT(XYZ,XC,CELL,VOL,1,UNAX,OLD,IERR)
      if(IERR.ne.0) then
	write(FN,'(/a)') 'cannot compute cartesian coordinates'
	if(IERR.eq.1) write(FN,'(a)') 
     $                              'cell angles too small or too large'
	if(IERR.eq.2) write(FN,'(a)') 'cell edges too small'
	if(IERR.eq.4) write(FN,'(a)') 
     $                        'sum of cell angles greater than 180 deg.'
	goto 30
      end if
      OLD=.true.
   30 continue
      write(FN,'(/1x,a7,f12.4,a)') 'V=',VOL,' Cubic-Angstrom'
      ATVOL=0.0
      do 40 L=1,NCLUS
	ATVOL=ATVOL+VDWVOL(L)*real(NS-ISPC(L))/NS
   40 continue
      ATVOL=ATVOL*NS
      if(.not.CONT) write(FN,'(1x,a7,f12.4,2a)') 
     $                            'Vvdw=',ATVOL,' Cubic-Angstrom ',
     $                            '(sum of volumes of VdW-spheres)'
      if(abs(VOL).gt.1e-30) 
     $        write(FN,'(1x,a7,f12.4,a)')    'Vvdw/V=',ATVOL/VOL,
     $       ' (must be between 0.65 and 0.77 in close packed crystals)'

      S = 0.0
      do 50 L=1,NCLUS
	S = S + SMASS(L)*real(NS-ISPC(L))/NS
   50 continue
      if(abs(VOL).gt.1e-30) 
     $    write(FN,'(/1x,a,f10.4,a)') 'rho=',(NS*S*1.6605)/VOL,' Mg/m^3'

      if(.not.CONT) then
	write(FN,'(/29x,22a)') ('*',J=1,22)
        write(FN,'(1x,28a,a,28a)')('*',J=1,28),' Space Group Symmetry ',
     $                            ('*',J=1,28)
	write(FN,'(29x,22a)') ('*',J=1,22)
	if(SPG.ne.' ') write(FN,'(2(1x,a)/)') 'Space Group:',SPG
	write(FN,'(2(1x,a)/)') 'Unique Axis:',UNAX
	write(FN,'(1x,a3,a26,a30,a16/)') 
     $         'Nr.','  Symmetry Operation(s)',' Matrix',' Translation'
	write(FN,'(1x,i2,3x,a24,3x,9i3,1x,3f5.2)') (J,SYMMLS(J)(1:24),
     $             ((R(J,I,K),K=1,3),I=1,3),(T(J,I),I=1,3),J=1,NS)
	write(FN,'(1x,3a)') 'The structure is ',CLASS(ISP),'.'
	if(IDR.eq.4) then
	  write(FN,'(/1x,a/)') 'Cartesian Symmetry Matrix(es)'
	  do 60 J=1,NS
	    N=ISYM(J)
	    if(N.gt.0) then
	      write(FN,'(1x,i2,3x,9f8.5)') J,((RN(N,I,K),K=1,3),I=1,3)
	    else
	      write(FN,'(1x,i2,3x,9f8.5)') J,((-RN(-N,I,K),K=1,3),I=1,3)
	    end if
   60     continue
	  write(FN,'(/27x,26a)') ('*',J=1,26)
	  write(FN,'(1x,26a,a,26a)') ('*',J=1,26),
     $                          ' Orthogonalization Matrix ',
     $                          ('*',J=1,26)
	  write(FN,'(27x,26a)') ('*',J=1,26)
	  write(FN,'(1x,a,3f10.5,a)') 
     $                            '(XO)   (',(AMAT(1,J),J=1,3),')   (X)'
	  write(FN,'(1x,a,3f10.5,a)') 
     $                            '(YO) = (',(AMAT(2,J),J=1,3),') * (Y)'
	  write(FN,'(1x,a,3f10.5,a)') 
     $                            '(ZO)   (',(AMAT(3,J),J=1,3),')   (Z)'
	  write(FN,'(/23x,34a)') ('*',J=1,34)
	  write(FN,'(1x,22a,a,22a)') ('*',J=1,22),
     $                          ' Inverse Orthogonalization Matrix ',
     $                          ('*',J=1,22)
	  write(FN,'(23x,34a)') ('*',J=1,34)
	  write(FN,'(1x,a,3f10.5,a)') 
     $                           '(X)   (',(AMATI(1,J),J=1,3),')   (XO)'
	  write(FN,'(1x,a,3f10.5,a)') 
     $                           '(Y) = (',(AMATI(2,J),J=1,3),') * (YO)'
	  write(FN,'(1x,a,3f10.5,a)') 
     $                           '(Z)   (',(AMATI(3,J),J=1,3),')   (ZO)'
	end if
      end if
      write(FN,'(/1x,a)') 'The fractional coordinates of the center of '
     $                  //'mass of the first molecule/ion are:'
      write(FN,'(1x,f4.2,a,f4.2)') -0.5+ICENT(1)*0.25,' < x < ',
     $                              0.5-ICENT(1)*0.25
      write(FN,'(1x,f4.2,a,f4.2)') -0.5+ICENT(2)*0.25,' < y < ',
     $                              0.5-ICENT(2)*0.25
      write(FN,'(1x,f4.2,a,f4.2)') -0.5+ICENT(3)*0.25,' < z < ',
     $                              0.5-ICENT(3)*0.25
      write(FN,'(/32x,16a)') ('*',J=1,16)
      write(FN,'(1x,31a,a,31a)') ('*',J=1,31),' Molecules/Ions ',
     $                          ('*',J=1,31)
      write(FN,'(32x,16a)') ('*',J=1,16)
      if(.not.CONT) write(FN,'(/1x,i2,1x,a)') 
     $                                 NCLUS, 'Molecule(s)/Ion(s) found'
      write(FN,'(/1x,a,6a11/)') 'mol.no. ','TA(L)','TB(L)','TC(L)',     
     $                          'THETA(L)','CHI(L)','PHI(L)'
      do 110 L=1,NCLUS
        write(FN,'(7x,i2,3f11.7,3f11.5)') L,(XYZS(L,J),J=1,3),
     $                       (mod(ROT(L,J),6.2831853)/PI*180,J=1,3)
  110 continue
      if(NSUB.gt.0) write(FN,'(/1x,a,a11/)') 'N ','PSI(N)'
      do 120 N=1,NSUB
        write(FN,'(1x,i2,f11.5)') N,mod(SUBROT(N),6.2831853)/PI*180
  120 continue
      QSUM=0.0
      if(IDR.eq.2.or.IDR.eq.4) then
	write(FN,'(/1x,12x,a)') 'center(s) of molecule(s)/ion(s)'
        write(FN,'(1x,a7,3a8,2a7,a9,a10)') 'mol.no.',
     $          'x','y','z','mnrad','mxrad','mass',' V-vdW(A^3)'
	do 150 L=1,NCLUS
** calculate cartesian coordinates of centers of gravity
	  do 90 J=1,3
	    XYZ(J)=XYZS(L,J)
   90     continue
	  call FRACRT(XYZ,XC,CELL,VOL,1,UNAX,OLD,IERR)
	  if(IERR.ne.0) then
	    write(FN,'(/a)') 'cannot compute cartesian coordinates'
	    if(IERR.eq.1) write(FN,'(a)') 
     $                              'cell angles too small or too large'
	    if(IERR.eq.2) write(FN,'(a)') 'cell edges too small'
	    if(IERR.eq.4) write(FN,'(a)') 
     $                        'sum of cell angles greater than 180 deg.'
	    goto 150
	  end if
	  OLD=.true.
	  do 100 J=1,3
	    XYZSC(J,L,1)=XC(J)
  100     continue
          write(FN,'(5x,i3,3f8.4,2f7.3,f9.4,f9.3)') L,
     $                              (XYZSC(J,L,1),J=1,3),
     $                               RMIN(L),MXR(L),SMASS(L),VDWVOL(L)
          QSUM = QSUM + SQ(L)*real(NS-ISPC(L))/NS
  150   continue
        write(FN,'(/1x,a)')
     $       'Charges and dipole moments of molecule(s)/ion(s)'
        write(FN,'(1x,a7,a7,a8)') 'mol.no. ','chg','dip (D)'
        do 140 L=1,NCLUS
	  DIP(1)=0.0
	  DIP(2)=0.0
	  DIP(3)=0.0
	  do 160 I=1,NATM1
	    if(ICLUS(I).eq.L) then
	      do 165 J=1,3
		DIP(J)=DIP(J)+Q(I)*XYZC(I,J)
  165         continue
	    end if
  160     continue
	  DP=sqrt(DIP(1)**2+DIP(2)**2+DIP(3)**2)*1.602e-29/3.336e-30
          write(FN,'(5x,i3,f7.3,f8.4)') L,SQ(L),DP
  140   continue
	if(.not.CONT) then
	  write(FN,'(/1x,a)') 'Atom(s) in molecule(s)/ion(s):'
	  do 185 L=1,NCLUS
	    write(FN,'(1x,a,i3)') 'mol.no.',L
	    LINE=' '
	    K=0
	    do 170 I=1,NATM1
	      if(ICLUS(I).eq.L) then
		K=K+8
		write(LINE(K-7:K),'(a)') ATNAME(I)
		if(K.ge.80) then
		  write(FN,'(1x,a)') LINE
		  K=0
		  LINE=' '
		end if
	      end if
  170       continue
	    if(K.gt.0.and.K.lt.80) write(FN,'(1x,a)') LINE
  185     continue
	end if
	if(SPEC) then
	  write(FN,'(/1x,a)') 'Molecule(s)/ion(s) on special positions:'
	  J=0
	  do 300 L=1,NCLUS
	    if(ISPC(L).gt.0) then
	      write(FN,'(1x,i2,12(a6))') L,(SPC(M,L),M=1,ISPC(L))
	      J=1
	    end if
  300     continue
	  if(J.eq.0) write(FN,'(1x,a)') 'none'
	end if
      end if
      if(abs(QSUM).gt.1e-2) then
	write(FN,'(/1x,a,f8.2)') 
     $          'WARNING! Nonzero charge in asymmetric unit:',QSUM
	write(*,'(/1x,a,f8.2)') 
     $          'WARNING! Nonzero charge in asymmetric unit:',QSUM
      end if
      if(NSUB.eq.0) then
	write(FN,'(/1x,a/)') 'no subrotation'
      else
        write(FN,'(/33x,14a)') ('*',J=1,14)
        write(FN,'(1x,32a,a,32a)') ('*',J=1,32),' Subrotations ',
     $                            ('*',J=1,32)
        write(FN,'(33x,14a)') ('*',J=1,14)
	write(FN,'(/1x,i2,1x,a)') NSUB, 'Subrotation(s) found.'
      end if
      do 200 N=1,NSUB
	write(FN,'(/1x,a,i2,a)') 'Rotation axis no.',N,':'
	write(FN,'(1x,3a,f8.4,a)') (ATNAME(ISUB(J,N)),J=1,2),
     $                       ' distance:', DIS(ISUB(1,N),ISUB(2,N)),' A'
        write(FN,'(1x,a)') 'Rotating atom(s):'
	LINE = ' '
	K = 0
	LS2 = 0
	do 190 J=3,NATM1
	  if(ISUB(J,N).ne.0) then
	    LS2 = nint(LSUB(ISUB(J,N))/128.0)
	    K=K+8
	    write(LINE(K-7:K),'(a)') ATNAME(ISUB(J,N))
	    if(K.ge.80) then
	      write(FN,'(1x,a)') LINE
	      K=0
	      LINE=' '
	    end if
	  end if
  190   continue
	if(K.gt.0.and.K.lt.80) write(FN,'(1x,a)') LINE
	if(LS2.ne.0.and.LS2.ne.N) then
	  write(FN,'(1x,a,i3)') 
     $     'This subrotation group is part of subrotation group no.',LS2
	end if
        write(FN,'(1x,a)') 'Torsional angles:'
	do 195 J1=1,IBO(0,ISUB(1,N))
	  if(IBO(J1,ISUB(1,N)).eq.ISUB(2,N)) goto 195
	  do 194 J2=1,IBO(0,ISUB(2,N))
	    if(IBO(J2,ISUB(2,N)).eq.ISUB(1,N)) goto 194
            write(FN,'(1x,4(a8,1x),f8.3)') ATNAME(IBO(J1,ISUB(1,N))),
     $                                    ATNAME(ISUB(1,N)),
     $                                    ATNAME(ISUB(2,N)),
     $                                    ATNAME(IBO(J2,ISUB(2,N))),
     $      TOR(IBO(J1,ISUB(1,N)),ISUB(1,N),ISUB(2,N),IBO(J2,ISUB(2,N)))
     $      + SUBROT(N)/PI*180
  194     continue
  195   continue
  200 continue
      if(.not.CONT) write(FN,'(/1x,i3,1x,a)') NATM1, 'atom(s) found.'
      if(IDR.ne.3.and..not.CONT) then
	write(FN,'(1x,2a)') 'Atomic parameters (cartesian coordinates,',
     $                      ' molecule system)'
	write(FN,'(1x,78a)') ('-',I=1,78)
	write(FN,'(1x,a7,a6,3a8,a6,a6,a5,a6,a5)') 'atom','pot',
     $                'x','y','z','q','mass','vwrd','inrt','imol'
	write(FN,'(1x,78a)') ('-',I=1,78)
	do 370 I=1,NATM1
	  L2 = nint(LSUB(I)/128.0)
	  L1 = LSUB(I)-L2*128
	  write(FN,'(1x,a,1x,a4,3f8.3,f6.2,f6.2,f5.2,2i3,i5)')
     $      ATNAME(I),
     $      PNAM(PTYP(I)),
     $      (XYZC(I,J),J=1,3),
     $      Q(I),RM(I),VWR(I),L1,L2,ICLUS(I)
  370   continue
      end if
** List variables
      if(IDR.ne.3) then
	write(FN,'(/1x,78a)') ('-',I=1,78)
        write(FN,'(1x,a)') 'Variable(s):'
	write(FN,'(1x,78a)') ('-',I=1,78)
        NVAR=0
        do 390 I=1,NV,6
	  LINE=' '
	  do 380 J=1,6
	   if(I+J-1.gt.NV) goto 380
	    if(IPAR(I+J-1).gt.(NUCLUS+1)*6) then
	      LINE(J*10-9:J*10)=RNAME(IPAR(I+J-1)-(NUCLUS+1)*6)
              NVAR=NVAR+1
	    else if(IPAR(I+J-1).gt.0) then
	      LINE(J*10-9:J*10)=PNAME(IPAR(I+J-1))
              NVAR=NVAR+1
	    end if
  380     continue
	  if(LINE.ne.' ') write(FN,'(1x,a)') LINE(1:78)
  390   continue
        if(NVAR.eq.0) write(FN,'(1x,a)') 'No variables'
      end if
** List constraints
      if(IDR.ne.3) then
	NR=0
	do 395 J=1,NCLUS*6+6
	  if(IVAR(J).ne.0) then
	    if(IVAR(J).gt.0) then
	      if(IPAR(IVAR(J)).eq.J) goto 395
	    end if
	    NR=NR+1
	    if(NR.eq.1) then
	      write(FN,'(/1x,a)') 'Constraint(s):'
	      write(FN,'(1x,78a)') ('-',I=1,78)
	    end if
	    if(IVAR(J).gt.0) then
	      write(FN,'(1x,3A)') PNAME(J),' = ',PNAME(IPAR(IVAR(J)))
	    else 
	      write(FN,'(1x,3a)') PNAME(J),' = -',PNAME(IPAR(-IVAR(J)))
	    end if
	  end if
  395   continue
	do 398 J=NUCLUS*6+6+1,NUCLUS*6+6+NSUB
	  if(IVAR(J).ne.0) then
	    if(IVAR(J).gt.0) then
	      if(IPAR(IVAR(J)).eq.J) goto 398
	    end if
	    NR=NR+1
	    if(NR.eq.1) then
              write(FN,'(/1x,a)') 'Constraint(s):'
	      write(FN,'(1x,78a)') ('-',I=1,78)
	    end if
            J1 = NUCLUS*6+6
	    if(IVAR(J).gt.0) then
	      WRITE(FN,'(1x,3A)') 
     $                         RNAME(J-J1),' = ',RNAME(IPAR(IVAR(J))-J1)
	    else
	      WRITE(FN,'(1x,3A)') 
     $                       RNAME(J-J1),' = -',RNAME(IPAR(-IVAR(J))-J1)
	    end if
	  end if
  398   continue
      end if      

      if(.not.CONT.and.IDR.ne.1.and.IDR.ne.3) then
	write(FN,'(/1x,78a)') ('-',I=1,78)
	write(FN,'(1x,a)') 'Bond length(s)'
	write(FN,'(1x,78a)') ('-',I=1,78)
	J = 0
	do 400 I=1,NATM1
	  if(IBO(0,I).gt.1.or.(IBO(0,I).eq.1.and.IBO(1,I).gt.I)) then
	    write(FN,'(1x,a,6(f6.3,1x,a))')
     $        ATNAME(I),(DIS(I,IBO(J,I)),ATNAME(IBO(J,I)),J=1,IBO(0,I))
	    J = 1
	  else if(IBO(0,I).eq.0) then
	    write(FN,'(1x,2a)') ATNAME(I),' no bond'
	  end if
  400   continue
	if(J.eq.0) write(FN,'(1x,a/)') 'no bonds'
      end if
      if(IDR.eq.4) write(FN,'(/1x,28a,a,28a)') ('*',J=1,28),
     $                          ' Potential parameters ',
     $                          ('*',J=1,28)
      write(FN,'(/1x,2a)') 'Name of potential: ',PTNAME
      if(PTNAME.eq.'SQUARE'.or.PTNAME.eq.'SOFT'.or.IDR.ne.4) goto 440
      write(FN,'(1x,a)') 'V(Rij)=Aij*exp(-Bij*Rij)/Rij**Dij-Cij/Rij**6'
      do 430 I=1,NPOT,6
	write(FN,'(11x,8(a10,:))') (PNAM(M),M=I,min(I+5,NPOT))
	do 420 K=1,4
	  write(FN,'(1x,a)') char(ichar('A')+K-1)//'ij'
	  do 410 M1=1,NPOT
	    write(FN,'(1x,a8,6(1pe11.4,:))') 
     $                        PNAM(M1),(POT(M1,M2,K),M2=I,min(I+5,NPOT))
  410     continue
	  write(FN,*)
  420   continue
  430 continue
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0) then
	write(FN,'(/1x,28a,a,28a)') ('*',J=1,20),
     $           ' Surface potential parameters ',('*',J=1,20)
        if(SPOT(1,3).eq.0.0) then
          write(FN,'(1x,a)') 'V(di) = Ai/di^9 - Ci/di^3'
          write(FN,'(10x,2a11)') 'Ai','Ci'
        else
          write(FN,'(1x,a)')
     $                'V(di) = Ai*(di*Bi+2)/Bi^3*exp(-Bi*di) - Ci/di^3'
          write(FN,'(10x,3a11)') 'Ai','Bi','Ci'
        end if
	do 435 M1=1,NPOT
          write(FN,'(1x,a8,1x,3(1pe11.4))') PNAM(M1),
     $                         SPOT(M1+1,1),SPOT(M1+1,2),SPOT(M1+1,3)
  435   continue
      end if
  440 continue
      write(FN,'(/1x,a,1pe11.4,a)') 'Pressure:',PRESS,' Pa'
      write(FN,'(/1x,a,f11.3,a)') 'Minimum cell thickness:',HMIN,' A'
      write(FN,'(/1x,a)') 'Summation:'
      if(SUMR.gt.0.0) then
	WRITE(FN,'(1x,a,1x,f8.4,a)') 'radius =',SUMR,' A'
      else
	WRITE(FN,'(1x,3(i3,a))') ISUM(1)*2+1,' x',ISUM(2)*2+1,' x',
     $                           ISUM(3)*2+1,' cells'
      end if
      end

      subroutine OUTPT2(FN,METHOD,STEP,ISTP,ILOOP,F,ROTC,IDUM)
****** THIS SUBROUTINE WRITES AN ARCHIVES FILE
** Version 21.04.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************

      parameter(PI=3.14159265)
      integer FN,METHOD,ILOOP,IDUM,ISTP(12)
      real STEP(12),ROTC(NUCLUS,3)
      CHARACTER LINE*80, PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      COMMON /PARNAM/ PNAME,RNAME
      real X0(NV),X(NV), RPA(25)
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL

      IS=72
      DO 10 I=72,1,-1
	IF(TITLE(I:I).NE.' ') THEN
	  IS=MIN(I+1,72)
	  GOTO 15
	END IF
   10 CONTINUE
   15 CONTINUE
      WRITE(FN,'(2A)') 'TITLE ', TITLE(1:IS)
      WRITE(FN,'(A,1pe12.4,A)') 'REM E=', F,' kJ/mol'
      WRITE(FN,'(A,2I4)') 'LOOP ',ILOOP,ILOOP
      WRITE(FN,'(A,6F8.2)') 'INCELL ',1.,1.,1.,90.,90.,90.
      WRITE(FN,'(A,6F10.5)') 'CELL ',(CELL(J),J=1,3),
     $                               (CELL(J)*180/PI,J=4,6)
      IF(CELLOK) WRITE(FN,'(A)') 'CELLOK'
      IF(NSUB.ne.0) then
	do 70 N=1,NSUB
	  write(FN,'(3(A,1X))') 'INROT',
     $                      ATNAME(ISUB(1,N)),ATNAME(ISUB(2,N))
   70   continue
      end if
      IF(SPG.NE.' ') WRITE(FN,'(A,A,1X,A)') 'SPGR ',SPG, UNAX
      IF(SPG.NE.' ') WRITE(FN,'(A,A)') ('REM SYMM ',SYMMLS(J),J=1,NS) 
      IF(SPG.EQ.' ') WRITE(FN,'(A,A)') ('SYMM ',SYMMLS(J),J=1,NS) 
      DO 80 I=1,NATM1
	IF(I.gt.1.and.ICLUS(I).ne.ICLUS(I-1)) WRITE(FN,'(A)') 'MOLE'
        IF(I.gt.1.and.ICLUS(I).ne.ICLUS(I-1))
     $     WRITE(FN,'(A,I3,1X,F6.3)') 'RMIN',ICLUS(I-1),RMIN(ICLUS(I-1))
	WRITE(FN,'(a4,1x,a8,1x,a4,1x,3(f10.5,1x),2f6.3)') 'ATOM',
     $              ATNAME(I),PNAM(PTYP(I)),
     $              (XYZC(I,J),J=1,3),Q(I),VWR(I)
   80 CONTINUE
      WRITE(FN,'(A,I3,1X,F6.3)') 'RMIN',NCLUS,RMIN(NCLUS)
** Parameters
      DO 90 L=1,NCLUS
	WRITE(FN,'(A,I3,A)') 'REM ',L,':'
	IF(ROTC(L,1).GT.-999..AND.
     $     ROTC(L,2).GT.-999..AND.ROTC(L,3).GT.-999.) THEN
	  WRITE(FN,'(A5,i3,3(1pe12.4))') 'ROTC ',L,0.,0.,0.
	END IF
	IF(SHIFT) THEN
	  WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',
     $               (mod(XYZS(L,J),1.0),J=1,3),
     $               (mod(ROT(L,J),6.2831853)*180./3.14159265,J=1,3)
	ELSE
	  if(abs(XYZS(L,1)).gt.0.5.or.abs(XYZS(L,2)).gt.0.5.or.
     $       abs(XYZS(L,3)).gt.0.5) WRITE(FN,'(A)')
     $           'REM WARNING - UNUSUALLY LARGE TRANSLATIONAL PARAMETER'
	  WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',(XYZS(L,J),J=1,3),
     $               (mod(ROT(L,J),6.2831853)*180./3.14159265,J=1,3)
	END IF
   90 CONTINUE
      if(NSUB.gt.0) WRITE(FN,'(A)') 'REM INROT:'
      if(NSUB.gt.0) WRITE(FN,'(A5,6(1pe12.4))') 'PARM ',
     $               (mod(SUBROT(J),6.2831853)*180./3.14159265,J=1,NSUB)
      
      if(SUMR.gt.0.0) WRITE(FN,'(a,1x,f8.4)') 'SUMR',SUMR
      if(SUMR.eq.0.0) WRITE(FN,'(a,1x,3i3)') 'SUMR',ISUM
      
** Variables
      LINE=' '
      NVAR=0
      DO 110 I=1,NV
	IF(IPAR(I).GT.0) THEN
	  NVAR=NVAR+1
	  if(IPAR(I).gt.(NUCLUS+1)*6) then
	    LINE(mod(NVAR-1,6)*10+1:mod(NVAR-1,6)*10+10)=
     $                                       RNAME(IPAR(I)-(NUCLUS+1)*6)
	  else
	    LINE(mod(NVAR-1,6)*10+1:mod(NVAR-1,6)*10+10)=PNAME(IPAR(I))
	  end if
	  if(mod(NVAR-1,6).eq.5) then
	    WRITE(FN,'(2a)') 'VARY ',LINE(1:72)
	    LINE=' '
	  end if
	END IF
  110 CONTINUE
      if(mod(NVAR-1,6).ne.5) WRITE(FN,'(2a)') 'VARY ',LINE(1:72)

      do 120 J=1,NCLUS*6+6
	if(IVAR(J).ne.0) then
	  if(IVAR(J).gt.0) then
	    if(IPAR(IVAR(J)).eq.J) goto 120
	  end if
	  if(IVAR(J).gt.0) then
	    write(FN,'(4A)') 'CNST ',PNAME(J),' = ',PNAME(IPAR(IVAR(J)))
	  else 
            write(FN,'(4a)') 'CNST ',PNAME(J),' = - ',
     $                                             PNAME(IPAR(-IVAR(J)))
	  end if
	end if
  120 continue
      do 150 J=NUCLUS*6+6+1,NUCLUS*6+6+NSUB
	if(IVAR(J).ne.0) then
	  if(IVAR(J).gt.0) then
	    if(IPAR(IVAR(J)).eq.J) goto 150
	  end if
	  J1 = NUCLUS*6-6
	  if(IVAR(J).gt.0) then
	    WRITE(FN,'(4A)') 'CNST ',
     $                         RNAME(J-J1),' = ',RNAME(IPAR(IVAR(J))-J1)
	  else
	    WRITE(FN,'(4A)') 'CNST ',
     $                       RNAME(J-J1),' = -',RNAME(IPAR(-IVAR(J))-J1)
	  end if
	end if
  150 continue
      
      if(SPEC) WRITE(FN,'(a)') 'SPEC'
      
      if(IPA(3).eq.1) WRITE(FN,'(a)') 'OUTP FEW'
      if(IPA(3).eq.2) WRITE(FN,'(a)') 'OUTP MUCH'
      if(IPA(3).eq.3) WRITE(FN,'(a)') 'OUTP NO'
      if(IPA(3).eq.4) WRITE(FN,'(a)') 'OUTP ALL'

      WRITE(FN,'(2a)') 'PTYP ',PTNAME
      DO 200 I=1,NPOT
	DO 190 J=1,I
	  WRITE(FN,'(a,2(a,1x),4(1pe12.4))') 'POT ',PNAM(I),PNAM(J),
     $                                      (POT(I,J,K),K=1,4)
  190   CONTINUE
  200 CONTINUE
      WRITE(FN,'(a,3(1pe12.4))') 'SURF ',SPOT(1,1),SPOT(1,2),SPOT(1,3)
      
      WRITE(FN,'(a,1pe12.4)') 'PRES ',PRESS
      WRITE(FN,'(a,1f11.3)') 'HMIN ',HMIN

      WRITE(FN,'(a,i9)') 'RNSD ',IDUM

      if(METHOD.eq.1) WRITE(FN,'(a,i8,1pe12.4)') 'ROBR',IPA(2),RPA(4)
      if(METHOD.eq.2) WRITE(FN,'(a,i8)') 'POWL',IPA(2)
      if(METHOD.eq.3) WRITE(FN,'(a,2i8,3f10.4)') 'GRDL',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.4) WRITE(FN,'(a,2i8,3f10.4)') 'THAC',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.5) WRITE(FN,'(a,2i8,3f10.4)') 'SMAN',IPA(2),IPA(1),
     $                                         RPA(1),RPA(2),RPA(4)
      if(METHOD.eq.6) WRITE(FN,'(a,i8)') 'MELT',IPA(2)
      if(METHOD.eq.7) WRITE(FN,'(a,12(f7.2,i3:))') 'GRID',
     $                                         (STEP(I),ISTP(I),I=1,12)
      if(METHOD.eq.8) WRITE(FN,'(a,i8,3(1pe12.4))') 'STDS',IPA(1),
     $                                         RPA(4),RPA(2),RPA(1)
      if(METHOD.eq.9) WRITE(FN,'(a,i8,3(1pe12.4))') 'NEWT',IPA(1),
     $                                         RPA(4),RPA(2),RPA(1)
      if(METHOD.eq.12) WRITE(FN,'(a,i8,f10.5)') 'SIMP',IPA(2),RPA(2)
      if(METHOD.eq.13) WRITE(FN,'(a,i8,f10.5)') 'GENE',IPA(2)

      WRITE(FN,'(a)') 'END'

      CLOSE(UNIT=FN)
      END
      
      subroutine OUTPT3(FN,F,FC,FD,FR,G1,SMASS,IDR,METHOD,IANALY,ILOOP)
****** THIS SUBROUTINE WRITES A TABLE OF SHORT INTERMOLECULAR CONTACTS
****** AND A TABLE OF OPTIMIZED PARAMETERS
****** Version 23.03.98
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real NA
      parameter(PI=3.14159265,NA=6.022045e23)
      real AMAT(3,3), AMATI(3,3)
      common /TEST/ AMAT,AMATI
      parameter(COUL=1389.4)
      real DX,DY,DZ,DX0,DY0,DZ0, REDCEL(6),SMASS(NUCLUS)
      real R12,RIJ,R2,R2C,XYZ(3),XC(3)
      real F,FC,FD,FR
      real RXYZ(3,NUMATM,NUSYM),YR(NUCLUS,3),MROT(3,3),MROT2(3,3)
      real TNIG(3)
      double precision G1(NV)
      logical OLD,SAMASY
      character MARK*2
      integer FN,TRAN(3,3),ITRAN(3,3),RNIG(3,3)
      common /RXYZ/ RXYZ
** Variables:
** D:      r Distance between two atoms or two clusters (Angstrom)
** MARK:   c MARK='c' marks very close contacts between two atoms
**           MARK='<' marks distances less than sum of van der Waals radii
**           MARK='>>' marks distance less than half of sum of vdW radii
** R12:    r sum of VdW radii of 2 clusters
** RIJ:    r sum of VdW radii of 2 atoms
************************************************************************
      character SC(-3:3,3)*2
      CHARACTER LINE*80, PNAME(NUCLUS*6+6)*8, RNAME(NUSUB)*8
      COMMON /PARNAM/ PNAME,RNAME
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      integer IBO(0:8,NUMATM)
      common /BOND/ IBO
      data ((SC(I,J),I=-3,3),J=1,3)
     $     /'-3X','-2X','-X',' ','+X','+2X','+3X',
     $      '-3Y','-2Y','-Y',' ','+Y','+2Y','+3Y',
     $      '-3Z','-2Z','-Z',' ','+Z','+2Z','+3Z'/

      OLD = .false.
** apply symmetry operations to centers of gravity and molecules
      do 100 M=1,NS
	N=ISYM(M)
** calculate cartesian coordinates of centers of gravity
	do 30 L=1,NCLUS
	  do 10 J=1,3
	    if(SHIFT) XYZ(J)=mod(R(M,J,1)*XYZS(L,1)+R(M,J,2)*XYZS(L,2)+
     $                 R(M,J,3)*XYZS(L,3)+T(M,J),1.0)
	    if(.not.SHIFT) XYZ(J)=R(M,J,1)*XYZS(L,1)+R(M,J,2)*XYZS(L,2)+
     $                 R(M,J,3)*XYZS(L,3)+T(M,J)
	    if(SHIFT.and.(XYZ(J).gt.0.5)) XYZ(J)=XYZ(J)-1.0
	    if(SHIFT.and.(XYZ(J).lt.-0.5)) XYZ(J)=XYZ(J)+1.0
   10     continue
	  call FRACRT(XYZ,XC,CELL,VOL,1,UNAX,OLD,IERR)
	  if(IERR.ne.0) then
	    write(FN,'(/a)') 'cannot compute cartesian coordinates'
	    if(IERR.eq.1) write(FN,'(a)') 
     $                              'cell angles too small or too large'
	    if(IERR.eq.2) write(FN,'(a)') 'cell edges too small'
	    if(IERR.eq.4) write(FN,'(a)') 
     $                        'sum of cell angles greater than 180 deg.'
	    goto 9999
	  end if
	  OLD=.true.
	  do 20 J=1,3
	    XYZSC(J,L,M)=XC(J)
   20     continue
   30   continue
** apply symmetry operations to molecules (only rotational part)
	do 60 I=1,NATM1
	  do 60 J=1,3
	    if(M.ne.1.and.N.gt.0) RXYZ(J,I,M) = RN(N,J,1)*RXYZ(1,I,1) +
     $                                          RN(N,J,2)*RXYZ(2,I,1) +
     $                                          RN(N,J,3)*RXYZ(3,I,1)
	    if(M.ne.1.and.N.lt.0) RXYZ(J,I,M) =-RN(-N,J,1)*RXYZ(1,I,1) -
     $                                          RN(-N,J,2)*RXYZ(2,I,1) -
     $                                          RN(-N,J,3)*RXYZ(3,I,1)
   60   continue
  100 continue
      write(FN,'(/1x,72a)') ('*',J=1,72)
      write(FN,'(1x,A)') TITLE
      write(FN,'(1x,A,i3)') 'Loop no.',ILOOP
      write(FN,'(1x,72a/)') ('*',J=1,72)
      if(IDR.ne.2.and.IDR.ne.4) goto 255
      write(FN,'(/1x,2a/1x,80a)') 
     $   'Short intermolecular contacts',
     $   ' (very close contacts are marked by: ''<'' or ''c'')',
     $                         ('-',I=1,80)
      if(IDR.eq.4) then
	write(FN,'(1x,a/)')'atom I   atom J   dist. s.vdw '
     $                    //'mol.I symm.op.J    EC/ES '//
     $                      '    ED        ER'
      else
	write(FN,'(1x,a/)')'mol. I   mol. J   dist.  s.rad  symm.op.J'
      end if
      if(SUMR.eq.0.0) then
	IC1A=min(ISUM(1),1)
	IC2A=min(ISUM(2),1)
	IC3A=min(ISUM(3),1)
      else
	IC1A=1
	IC2A=1
	IC3A=1
      end if
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0)
     $                                                            IC3A=0
      do 250 IC1=-IC1A,IC1A
      do 240 IC2=-IC2A,IC2A
      do 230 IC3=-IC3A,IC3A
	do 210 M2=1,NS
	  SAMASY=(M2.eq.1.and.IC1.eq.0.and.IC2.eq.0.and.IC3.eq.0)
	  do 200 L1=1,NCLUS
	    do 190 L2=1,NCLUS
	      if(SAMASY.and.L1.gt.L2) goto 190
	      do 185 MM=1,ISPC(L2)
		read(SPC(MM,L2),'(i2)') MM2
		if(MM2.eq.M2) goto 190
  185         continue
	      R12 = 1.1*(MXR(L1)+MXR(L2))
	      DX0 = XYZSC(1,L1,1) - XYZSC(1,L2,M2) - 
     $              (AMAT(1,1)*IC1 + AMAT(1,2)*IC2 + AMAT(1,3)*IC3)
	      DY0 = XYZSC(2,L1,1) - XYZSC(2,L2,M2) -
     $              (AMAT(2,1)*IC1 + AMAT(2,2)*IC2 + AMAT(2,3)*IC3)
	      DZ0 = XYZSC(3,L1,1) - XYZSC(3,L2,M2) -
     $              (AMAT(3,1)*IC1 + AMAT(3,2)*IC2 + AMAT(3,3)*IC3)
	      D = sqrt(DX0**2 + DY0**2 + DZ0**2)
**      no contact between cluster L1 and cluster L2
	      if(D.ge.R12) goto 190
	      if(D.lt.MXR(L1)+MXR(L2)) then
		MARK = '<'
	      else
		MARK = ' '
	      end if
	      if(IDR.eq.2) then
		if(.not.SAMASY.or.L1.ne.L2) then
		  write(FN,'(1x,i8,1x,i6,3x,f6.3,a,f5.2,
     $                     1x,''['',i2,3i1,'']'')')
     $                      L1,L2,D,MARK,MXR(L1)+MXR(L2),
     $                      M2,5+IC1,5+IC2,5+IC3
		end if
		goto 190
	      end if
	      do 120 I=1,NATM1
		if(ICLUS(I).ne.L1) goto 120
		LS2 = nint(LSUB(I)/128.0)
		LS1 = LSUB(I) - LS2*128
		do 110 J=1,NATM1
		  if(ICLUS(J).ne.L2) goto 110
		  LS4 = nint(LSUB(J)/128.0)
		  LS3 = LSUB(J) - LS4*128
**               do not compare molecule/ion L1 with itself, except in the
**               case of subrotations
		  if(SAMASY.and.L1.eq.L2) then
		    if(LS1.eq.LS3) goto 110
                    if((LS1.lt.0..or.LS2.lt.0..or.
     $                  LS3.lt.0..or.LS4.lt.0.).and.
     $                (abs(LS1).eq.abs(LS3).or.abs(LS2).eq.abs(LS4).or.
     $                 abs(LS1).eq.abs(LS4).or.abs(LS2).eq.abs(LS3)))
     $                                                          goto 110
                    if(abs(LS1).gt.abs(LS3)) goto 110
		  end if
		  RIJ= VWR(I) + VWR(J)
		  R2C= 1.01*RIJ
		  R2 = 1.1*RIJ
		  DX = RXYZ(1,I,1) - RXYZ(1,J,M2) + DX0
		  if(abs(DX).ge.R2) goto 110
		  DY = RXYZ(2,I,1) - RXYZ(2,J,M2) + DY0
		  if(abs(DY).ge.R2) goto 110
		  DZ = RXYZ(3,I,1) - RXYZ(3,J,M2) + DZ0
		  if(abs(DZ).ge.R2) goto 110
		  D = sqrt(DX**2 + DY**2 + DZ**2)
		  if(D.ge.R2) goto 110
		  if(SPEC.and.D.lt.1e-4) goto 110
		  if(D.le.RIJ) then
		    MARK = ' <'
		  else if(D.le.R2C) then
		    MARK = ' c'
		  else
		    MARK = '  '
		  end if
		  if(D.le.RIJ*0.75) MARK = '<<'
		  if(D.gt.1e-5) EC=COUL*Q(I)*Q(J)/D
		  if(PTNAME.ne.'SQUARE'.and.PTNAME.ne.'SOFT'.and.
     $                                                  D.gt.1e-5) then
		    ED=-POT(PTYP(I),PTYP(J),3)/D**6
		    ER=POT(PTYP(I),PTYP(J),1)*exp(-POT(PTYP(I),PTYP(J),
     $                 2)*D)*D**(-POT(PTYP(I),PTYP(J),4))
		  else if(PTNAME.eq.'SOFT') then
		    ED=0.0
		    ER=0.0
		    EC=0.0
		    if(D.le.RIJ.and.D.gt.1.0) ER=(D-RIJ)**2
		    if(D.le.1.0) ER=1e10
		  else
		    if(D.ge.RIJ) then
		      ED=-1
		      ER=0.0
		    else if(D.lt.RIJ) then
		      ED=0.0
		      ER=1e10
		    end if
		  end if
		  write(FN,'(1x,a,1x,a,1x,f5.3,a,f4.2,
     $                       1x,''['',i3,'']'',
     $                       1x,''['',i2,3i1,''.'',i2,'']'',
     $                       3(1pg10.2))')
     $                      ATNAME(I),ATNAME(J),D,MARK,VWR(I)+VWR(J),
     $                      L1,M2,5+IC1,5+IC2,5+IC3,L2,EC,ED,ER
  110           continue
  120         continue
  190       continue
  200     continue
  210   continue
  230 continue
  240 continue
  250 continue
  255 continue
** surface contacts
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0) then
** calculate distance between the planes z=0 and z=-1/2
        DZ2 = AMAT(3,3)/2.0
        do 750 L1=1,NCLUS
          if(IDR.eq.2) then
            write(FN,'(1x,a,1x,i6,3x,f6.3,a,f5.2,
     $                 1x,''['',i2,3i1,'']'')')
     $              'SURFACE ',L1,DZ2+XYZSC(3,L1,1),'  ',MXR(L1),1,5,5,5
            goto 750
          end if
          do 740 I=1,NATM1
            if(ICLUS(I).ne.L1) goto 740
            DZ = DZ2 + RXYZ(3,I,1) + XYZSC(3,L1,1)
            RIJ= 2.0+VWR(I)
            R2C= 2.0+1.01*RIJ
            R2 = 2.0+1.1*RIJ
            if(abs(DZ).ge.R2) goto 740
            if(DZ.le.RIJ) then
              MARK = ' <'
            else if(DZ.le.R2C) then
              MARK = ' c'
            else
              MARK = '  '
            end if
            if(DZ.le.RIJ*0.75) MARK = '<<'
            D2 = DZ
            if(DZ.lt.1.0) D2 = 1.0
            if(SPOT(1,3).eq.0.0) then
              EP = SPOT(PTYP(I)+1,1)/D2**9 -
     $             SPOT(PTYP(I)+1,2)/D2**3
            else
              EP = SPOT(PTYP(I)+1,1)*
     $             (D2*SPOT(PTYP(I)+1,2)+2.0)/
     $             SPOT(PTYP(I)+1,2)**3*
     $             exp(-SPOT(PTYP(I)+1,2)*D2) -
     $             SPOT(PTYP(I)+1,3)/D2**3
            end if
            write(FN,'(1x,a,1x,a,1x,f5.3,a,f4.2,
     $                 1x,''['',i3,'']'',
     $                 1x,''['',i2,3i1,''.'',i2,'']'',1pg10.2)')
     $                    'SURFACE ',ATNAME(I),DZ,MARK,2.0+VWR(I),
     $                    L1,1,5,5,5,0,EP
  740     continue
  750   continue
      end if
      if(PTNAME.eq.'SOFT') write(FN,'(1x,a,f10.4)') 'FRMAX:',
     $                                  real((NSUB+1)*NATM1)**(2.0/3.0)
      if(METHOD.ne.10.and.(METHOD.ne.11.or.IANALY.ne.0)) then
	write(FN,'(/1x,3a12)') 'Energies:','[kJ/mol]','[kcal/mol]'
	write(FN,'(/1x,a12,1p,2e12.4)') 'total:',F,F/4.1868
	write(FN,'(1x,a12,1p,2e12.4)') 'Coulomb:',FC,FC/4.1868
	write(FN,'(1x,a12,1p,2e12.4)') 'Dispersion:',FD,FD/4.1868
	write(FN,'(1x,a12,1p,2e12.4)') 'Repulsion:',FR,FR/4.1868
	FPR=1e-33*NA*PRESS*VOL/NS
	if(PRESS.ne.0.0) write(FN,'(1x,a12,1p,2e12.4)') 'Pressure:',
     $                                            FPR,FPR/4.1868
        if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0)
     $                                                              then
	  write(FN,'(1x,a12,1p,2e12.4)') 'Surface:',F-FC-FD-FR-FPR,
     $                                   (F-FC-FD-FR-FPR)/4.1868
	end if

      end if
      LINE=' '
      NVAR=0
** put out gradient
      IF(METHOD.ne.8.and.METHOD.ne.9.and.METHOD.ne.11) goto 265
      IF(METHOD.eq.11.and.IANALY.lt.2) goto 265
      DO 260 I=1,NV
	IF(IPAR(I).GT.0) THEN
	  NVAR=NVAR+1
	  if(NVAR.eq.1) write(FN,'(/1x,2a/)') 
     $                  'Gradient (cell angles and',
     $                  ' rotation angles in radian measure)'
          if(METHOD.eq.11.and.IANALY.eq.99.and.NVAR.eq.1)
     $                     write(FN,'(1x,a)') '(calculated numerically)'
	  if(IPAR(I).gt.(NUCLUS+1)*6) then
	    LINE(mod(NVAR-1,6)*12+1:mod(NVAR-1,6)*12+12)=
     $                                       RNAME(IPAR(I)-(NUCLUS+1)*6)
	  else
	    LINE(mod(NVAR-1,6)*12+1:mod(NVAR-1,6)*12+12)=PNAME(IPAR(I))
	  end if
	  if(mod(NVAR-1,6).eq.5) then
	    WRITE(FN,'(3x,a)') LINE(1:72)
	    write(FN,'(1x,6(1pe12.4))') (G1(J),J=NVAR-5,NVAR)
	    LINE=' '
	  end if
	END IF
  260 CONTINUE
      if(mod(NVAR-1,6).ne.5) WRITE(FN,'(3x,a)') LINE(1:72)
      write(FN,'(1x,6(1pe12.4))') (G1(J),J=6*int(NVAR/6)+1,NVAR)
  265 CONTINUE
      write(FN,'(/1x,a/1x,78a)') 
     $   'Optimized Parameters',('-',I=1,78)
      write(FN,'(3x,6a12/)') 'A','B','C','ALPHA','BETA','GAMMA'
      write(FN,'(3x,3f12.6,3f12.5/)') (CELL(J),J=1,3),
     $                                (CELL(J)/PI*180,J=4,6)
      write(FN,'(3x,a7,f12.2)') 'V =',VOL
      ATVOL=0.0
      do 270 L=1,NCLUS
	ATVOL=ATVOL+VDWVOL(L)*real(NS-ISPC(L))/NS
  270 continue
      ATVOL=ATVOL*NS
      if(abs(VOL).gt.1e-30) 
     $        write(FN,'(3x,a7,f12.4,a)')    'Vvdw/V=',ATVOL/VOL,
     $       ' (must be between 0.65 and 0.77 in close packed crystals)'

      S = 0.0
      do 280 L=1,NCLUS
	S = S + SMASS(L)*real(NS-ISPC(L))/NS
  280 continue
      if(abs(VOL).gt.1e-30) 
     $    write(FN,'(6x,a4,f12.4,a)') 'rho=',(NS*S*1.6605)/VOL,' Mg/m^3'
      write(FN,'(/1x,a,6a11/)') 'L ','TA(L)','TB(L)','TC(L)',     
     $                          'THETA(L)','CHI(L)','PHI(L)'
      do 300 L=1,NCLUS
	write(FN,'(1x,i2,3f11.7,3f11.5)') L,(XYZS(L,J),J=1,3),
     $                       (mod(ROT(L,J),6.2831853)/3.14159*180,J=1,3)
  300 continue
	do 320 L=1,NCLUS
	  do 310 J=1,3
	    YR(L,J)=mod(ROT(L,J),6.2831853)
  310     continue
	  call ROTEUL(L,YR,MROT,.false.)
	  if(IDR.eq.4) then
	    write(FN,'(/1x,a/)') 'Rotation matri(x/ces)'
	    write(FN,'(1x,i3,3f11.5)') L,(MROT(1,J),J=1,3)
	    write(FN,'(4x,3f11.5/4x,3f11.5)') ((MROT(I,J),J=1,3),I=2,3)
	  end if
  320 continue
      if(NSUB.gt.0) write(FN,'(/1x,a,a11/)') 'N ','PSI(N)'
      do 350 N=1,NSUB
	write(FN,'(1x,i2,f11.5)') N,mod(SUBROT(N),6.2831853)/3.14159*180
        write(FN,'(14x,a)') 'Torsional angles:'
	do 195 J1=1,IBO(0,ISUB(1,N))
	  if(IBO(J1,ISUB(1,N)).eq.ISUB(2,N)) goto 195
	  do 194 J2=1,IBO(0,ISUB(2,N))
	    if(IBO(J2,ISUB(2,N)).eq.ISUB(1,N)) goto 194
            write(FN,'(14x,4(a8,1x),f8.3)') ATNAME(IBO(J1,ISUB(1,N))),
     $                                    ATNAME(ISUB(1,N)),
     $                                    ATNAME(ISUB(2,N)),
     $                                    ATNAME(IBO(J2,ISUB(2,N))),
     $      TOR(IBO(J1,ISUB(1,N)),ISUB(1,N),ISUB(2,N),IBO(J2,ISUB(2,N)))
     $      + SUBROT(N)/PI*180
  194     continue
  195   continue
  350 continue
      call NIGGLI(CELL,REDCEL,TRAN)
      write(FN,'(/3x,a)') 'Reduced Cell:'
      write(FN,'(3x,6a12/)') 'A''','B''','C''',
     $                       'ALPHA''','BETA''','GAMMA'''
      write(FN,'(3x,3f12.7,3f12.5/)') (REDCEL(J),J=1,3),
     $                                (REDCEL(J)/PI*180,J=4,6)
      write(FN,'(3x,a/)') 'Transformation:'
      write(FN,'(3x,a,3(3x,a))') '->',' ->  ',' ->  ',' ->  '
      write(FN,'(3x,a,3(i3,a))') 'A''=',TRAN(1,1),'*A + ',
     $                  TRAN(1,2),'*B + ',TRAN(1,3),'*C'
      write(FN,'(3x,a,3(3x,a))') '->',' ->  ',' ->  ',' ->  '
      write(FN,'(3x,a,3(i3,a))') 'B''=',TRAN(2,1),'*A + ',
     $                  TRAN(2,2),'*B + ',TRAN(2,3),'*C'
      write(FN,'(3x,a,3(3x,a))') '->',' ->  ',' ->  ',' ->  '
      write(FN,'(3x,a,3(i3,a))') 'C''=',TRAN(3,1),'*A + ',
     $                  TRAN(3,2),'*B + ',TRAN(3,3),'*C'
** calculate the inverse matrix of the transposed matrix TRAN
      do 400 I=1,3
	I1=I+1
	I2=I+2
	if(I1.gt.3) I1=I1-3
	if(I2.gt.3) I2=I2-3
	ITRAN(I,1)=TRAN(2,I1)*TRAN(3,I2)-TRAN(2,I2)*TRAN(3,I1)
	ITRAN(I,2)=TRAN(3,I1)*TRAN(1,I2)-TRAN(3,I2)*TRAN(1,I1)
	ITRAN(I,3)=TRAN(1,I1)*TRAN(2,I2)-TRAN(1,I2)*TRAN(2,I1)
  400 continue
**      write(FN,'(/1x,a,3a11/)') 'L ','TA(L)''','TB(L)''','TC(L)''' 
**      do 410 L=1,NCLUS
**        write(FN,'(1x,i2,3f11.7)') L,
**     $   ITRAN(1,1)*XYZS(L,1)+ITRAN(1,2)*XYZS(L,2)+ITRAN(1,3)*XYZS(L,3),
**     $   ITRAN(2,1)*XYZS(L,1)+ITRAN(2,2)*XYZS(L,2)+ITRAN(2,3)*XYZS(L,3),
**     $   ITRAN(3,1)*XYZS(L,1)+ITRAN(3,2)*XYZS(L,2)+ITRAN(3,3)*XYZS(L,3)
**  410 continue
      write(FN,'(/1x,a3,a26,a30,a16/)') 'Nr.',
     $         ' New Symmetry Operation(s)',' Matrix',' Translation'
      do 450 M=1,NS
	do 440 I=1,3
	  do 430 K=1,3
	    RNIG(I,K) = ITRAN(I,1)*R(M,1,K) +
     $                  ITRAN(I,2)*R(M,2,K) +
     $                  ITRAN(I,3)*R(M,3,K)
  430     continue
	  TNIG(I) = ITRAN(I,1)*T(M,1) + 
     $              ITRAN(I,2)*T(M,2) + 
     $              ITRAN(I,3)*T(M,3)
  440   continue
	LINE=' '
	LINE(11:11)=','
	LINE(22:22)=','
	do 590 J=1,3
	  if(abs(1./6-abs(TNIG(J)) ).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='1/6'
	  if(abs(1./4-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='1/4'
	  if(abs(1./3-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='1/3'
	  if(abs(1./2-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='1/2'
	  if(abs(2./3-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='2/3'
	  if(abs(3./4-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='3/4'
	  if(abs(5./6-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='5/6'
	  if(abs(7./6-abs(TNIG(J))).lt.1e-4) 
     $                               LINE(J*11-9:J*11-7)='7/6'
          if(T(M,J).lt.0.0) LINE(J*11-10:J*11-10)='-'
	  do 580 K=1,3
            if(abs(RNIG(J,K)).gt.3) then
              LINE='Symm. op. out of range'
              goto 625
            end if
	    LINE(J*11+K*2-8:J*11+K*2-7)=SC(RNIG(J,K),K)
  580     continue
  590   continue
** Delete spaces
	do 610 K=1,9
	  do 600 J=1,32
	    if(LINE(J:J).eq.' ') then
	      LINE=LINE(1:J-1)//LINE(J+1:33)//' '
	    end if
  600     continue
  610   continue
** Delete leading '+' characters
	if(LINE(1:1).eq.'+') LINE=LINE(2:33)//' '
	do 620 K=1,2
	  KI=index(LINE,',+')
	  if(KI.ne.0) LINE=LINE(1:KI)//LINE(KI+2:33)//' '
  620   continue
  625   continue
	write(FN,'(1x,i3,2x,a27,9i3,1x,3f5.2)') M,LINE(1:27),
     $            ((RNIG(I,K),K=1,3),I=1,3),(TNIG(I),I=1,3)
  450 continue
      if(IDR.eq.4) then
**        write(FN,'(/1x,a/)') 'New rotation matri(x/ces)'
	do 700 L=1,NCLUS
	  do 630 J=1,3
	    do 630 K=1,3
	      MROT2(J,K)=AMATI(J,1)*MROT(1,K)+
     $                   AMATI(J,2)*MROT(2,K)+
     $                   AMATI(J,3)*MROT(3,K)
  630     continue
	  do 650 J=1,3
	    do 650 K=1,3
	      MROT(J,K)=ITRAN(J,1)*MROT2(1,K)+
     $                  ITRAN(J,2)*MROT2(2,K)+
     $                  ITRAN(J,3)*MROT2(3,K)
  650     continue
**          write(FN,'(1x,i3,3f11.5)') L,(MROT2(1,J),J=1,3)
**          write(FN,'(4x,3f11.5/4x,3f11.5)') ((MROT2(I,J),J=1,3),I=2,3)
  700   continue
      end if
 9999 continue
      end
      
      subroutine OUTPT4(FN,F)
****** THIS SUBROUTINE WRITES A SCHAKAL FILE
** Version 06.12.95
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.14159265)
      integer FN
      real RXYZ(3,NUMATM,NUSYM)
      real XC(3),XYZ(3)
      common /RXYZ/ RXYZ
      WRITE(FN,'(2A)') 'TITLE ', TITLE(1:65)
      WRITE(FN,'(A,1pe12.4,A)') 'REM E=', F,' kJ/mol'
      WRITE(FN,'(A,6F10.5)') 'CELL ',(CELL(J),J=1,3),
     $                               (CELL(J)/PI*180,J=4,6)
      DO 80 I=1,NATM1
	IF(I.gt.1.and.ICLUS(I).ne.ICLUS(I-1)) WRITE(FN,'(A)') 'MOLE'
	DO 50 J=1,3
	  XC(J)=RXYZ(J,I,1)
   50   CONTINUE
	call FRACRT(XYZ,XC,CELL,VOL,-1,UNAX,.false.,IERR)
	if(SHIFT) WRITE(FN,'(a4,1x,a4,1x,3(f10.6,1x))') 'ATOM',
     $               ATNAME(I),(XYZ(J)+mod(XYZS(ICLUS(I),J),1.0),J=1,3)
	if(.not.SHIFT) WRITE(FN,'(a4,1x,a4,1x,3(f10.6,1x))') 'ATOM',
     $               ATNAME(I),(XYZ(J)+XYZS(ICLUS(I),J),J=1,3)
   80 CONTINUE

      DO 100 M=1,NS
	WRITE(FN,'(A,A)') 'SYMM ',SYMMLS(M)
  100 CONTINUE
      CLOSE(UNIT=FN)
      END
      
      subroutine OUTPT5(FN,F)
****** THIS SUBROUTINE WRITES A POWDER CELL FILE
** Version 15.03.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      parameter(PI=3.14159265)
      integer FN, ATNO
      real RXYZ(3,NUMATM,NUSYM)
      real XC(3),XYZ(3)
      common /RXYZ/ RXYZ

      WRITE(FN,'(A,3(F10.5,1x),3(F10.4,1x))') 'cell ',(CELL(J),J=1,3),
     $                                      (CELL(J)/PI*180,J=4,6)
      WRITE(FN,'(A,I4)') 'natom',NATM1
      DO 80 I=1,NATM1
	DO 50 J=1,3
	  XC(J)=RXYZ(J,I,1)
   50   CONTINUE
	call FRACRT(XYZ,XC,CELL,VOL,-1,UNAX,.false.,IERR)
	IF(SHIFT) WRITE(FN,'(a,1x,i2,1x,3(f10.6,1x),f5.2)')
     $                 ATNAME(I)(1:4),ATNO(ATNAME(I)),
     $                 (XYZ(J)+mod(XYZS(ICLUS(I),J),1.0),J=1,3),1.0
	IF(.not.SHIFT) WRITE(FN,'(a4,1x,i2,1x,3(f10.6,1x),f5.2)')
     $                 ATNAME(I)(1:4),ATNO(ATNAME(I)),
     $                 (XYZ(J)+XYZS(ICLUS(I),J),J=1,3),1.0
   80 CONTINUE
      WRITE(FN,'(A,I4)') 'rgnr',-1
      WRITE(FN,'(A)') TITLE
      WRITE(FN,'(A,1pe12.4,A)') 'E=', F,' kJ/mol'
      CLOSE(UNIT=FN)
      END
      subroutine FOPT(F,FC,FD,FR,X,VOL,IRET)
** Energy of a system of molecules/ions.
** Version 18.11.97
** The position of the atoms is given by XYZC and X (measured in Angstroms).
** V(Rij)=Aij*exp(-Bij*Rij)/Rij**Dij - Cij/Rij**6 + Qi*Qj/Rij
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** IRET        i 0: everything normal
**               1: impossible cell constants
**               2: collision between atoms (Rij<1 or Rij<VWRi+VWRj) or
**                  molecules (RMINi+RMINj>Dij)
**               3: cell height to smaller then HMIN or one projection of
**                  a cell edge onto another cell edge is too large
************************************************************************
** X(I):        Variable no. I
** YS(L,J):     Center of gravity of molecule/ion no. L
** YR(L,J):     Eulerian angles of molecule/ion no. L
** RXYZ(J,I,M): Cartesian coordinates of atom no. I, position M 
**              (before and after rotation, before translation)
** FC:          Coulomb energy
** FR:          Repulsion energy
** FD:          Dispersion energy
** NA:          Avogadro constant
      real NA
      parameter(COUL=1389.4,NA=6.022045e23)
      parameter(PI=3.141592653589793d0, PI2=PI*2)
      real X(NV),YS(NUCLUS,3),YR(NUCLUS,3),XYZ(3),XC(3),XYZAD(3)
      real RXYZ(3,NUMATM,NUSYM),F,FR,FD,FC,FP,VOL
      real YSR,CC(6),MROT(3,3),CSAM,YI(3),YJ(3)
      real R2(64)
      integer IH(64),JOT(64)
      logical OLD,TOUCH,SAMASY,VARCEL
      common /RXYZ/ RXYZ
      real CA(3)
      real A(3,3),AI(3,3)
      common /TEST/ A,AI

** subroutines called by this program unit:
** FRACRT transform fractional coordinates to cartesian and vice versa
** SBROT carry out a subrotation
** ROTEUL rotation by Eulerian angles
** SUMUP sum up to 64 atom-atom potentials
************************************************************************
      OLD=.false.
      IRET=0
      VARCEL=.false.
      FRMAX = real((NSUB+1)*NATM1)**(2.0/3.0)
      XYZ(1) = 0.0
      XYZ(2) = 0.0
      XYZ(3) = 0.0
** update cell constants and put them to CC
      do 10 I6=1,6
	if(IVAR(I6).gt.0) then
	  CC(I6)=X(IVAR(I6))
	  VARCEL=.true.
	else if(IVAR(I6).lt.0) then
	  CC(I6)=-X(-IVAR(I6))
	  VARCEL=.true.
	else
	  CC(I6)=CELL(I6)
	end if
   10 continue
      call FRACRT(XYZ,XC,CC,VOL,1,UNAX,OLD,IERR)
** test the projection of each cell edge on to the other cell edges
      if(SHIFT.and.(abs(CC(1)*cos(CC(5))).gt.CC(3)/1.9).or.
     $             (abs(CC(3)*cos(CC(5))).gt.CC(1)/1.9).or.
     $             (abs(CC(2)*cos(CC(6))).gt.CC(1)/1.9).or.
     $             (abs(CC(1)*cos(CC(6))).gt.CC(2)/1.9).or.
     $             (abs(CC(3)*cos(CC(4))).gt.CC(2)/1.9).or.
     $             (abs(CC(2)*cos(CC(4))).gt.CC(3)/1.9)) then
        if(.not.VARCEL.and..not.CELLOK) then
	  write(2,'(/1x,a,i4,a/)') 'WARNING - UNSUITABLE UNIT CELL.'
	  write(*,'(/1x,a,i4,a/)') 'WARNING - UNSUITABLE UNIT CELL.'
	end if
        if(.not.CELLOK) then
          F = 1e10
          FR = 1e10
          IRET = 3
          goto 999
        end if
      end if

** update XYZS and put it to YS
      XYZAD(1)=0.0
      XYZAD(2)=0.0
      XYZAD(3)=0.0
      do 50 L=1,NCLUS
	L6=L*6
	do 40 J=1,3
	  I6=L6+J
	  if(IVAR(I6).ne.0) then
	    YS(L,J)=sign(1,IVAR(I6))*X(abs(IVAR(I6)))
	    if(SHIFT) YS(L,J)=mod(YS(L,J),1.0)
	  else
	    if(SHIFT) YS(L,J)=mod(XYZS(L,J),1.0)
	    if(.not.SHIFT) YS(L,J)=XYZS(L,J)
	  end if
          if(SHIFT.and.ICENT(J).eq.1.and.L.eq.1) then
            if(YS(L,J).lt.-0.25.and.YS(L,J).gt.-0.75) XYZAD(J)=0.5
            if(YS(L,J).gt.0.25.and.YS(L,J).lt.0.75) XYZAD(J)=-0.5
          end if
   40   continue
   50 continue
** apply symmetry operations to centers of gravity and molecules
      do 120 M=1,NS
** calculate cartesian coordinates of centers of gravity
	do 80 L=1,NCLUS
	  do 60 J=1,3
	    XYZ(J)=R(M,J,1)*YS(L,1)+R(M,J,2)*YS(L,2)+R(M,J,3)*YS(L,3)+
     $             T(M,J)+XYZAD(J)
	    if((XYZ(J).lt.-0.5).and.SHIFT) XYZ(J)=XYZ(J)+1.0
	    if((XYZ(J).gt.0.5).and.SHIFT) XYZ(J)=XYZ(J)-1.0
   60     continue
	  call FRACRT(XYZ,XC,CC,VOL,1,UNAX,OLD,IERR)
** test cell heights
	  if(M.eq.1.and.L.eq.1) then
            if(VOL/(CC(1)*CC(2)*sin(CC(6))).lt.HMIN) then
	      F = 1e10
	      FR = 1e10
	      IRET = 3
	      goto 999
            else if(VOL/(CC(1)*CC(3)*sin(CC(5))).lt.HMIN) then
	      F = 1e10
	      FR = 1e10
	      IRET = 3
	      goto 999
            else if(VOL/(CC(2)*CC(3)*sin(CC(4))).lt.HMIN) then
	      F = 1e10
	      FR = 1e10
	      IRET = 3
	      goto 999
	    end if
	  end if
	  OLD=.true.
	  if(IERR.ne.0) then
	    F=1e10
	    IRET = 1
	    goto 999
	  end if
	  do 70 J=1,3
	    XYZSC(J,L,M)=XC(J)
   70     continue
   80   continue
        if(M.eq.1) then
** perform subrotations and put the result to RXYZ
** copy XYZC to RXYZ
          do 85 I=1,NATM1
            do 84 J=1,3
              RXYZ(J,I,1)=XYZC(I,J)
   84       continue
   85     continue
          do 82 L=1,NSUB
            L6=(NUCLUS+1)*6+L
            if(IVAR(L6).ne.0) then
              YSR=mod(sign(1,IVAR(L6))*X(abs(IVAR(L6))),PI2)
            else
              YSR=mod(SUBROT(L),PI2)
            end if
            call SBROT(L,YSR)
   82     continue
** rotate molecules and put the result to RXYZ
          do 100 L=1,NCLUS
            L6=L*6
            do 90 J=4,6
              I6=L6+J
              if(abs(IVAR(I6)).gt.0) then
                YR(L,J-3)=mod(sign(1,IVAR(I6))*X(abs(IVAR(I6))),PI2)
              else
                YR(L,J-3)=mod(ROT(L,J-3),PI2)
              end if
   90       continue 
            call ROTEUL(L,YR,MROT,.true.)
  100     continue
** apply symmetry operations to molecules (only rotational part)
        else
	  N=ISYM(M)
	  N1=abs(N)
	  do 110 I=1,NATM1
	    do 110 J=1,3
	      RXYZ(J,I,M) = sign(1,N)*(RN(N1,J,1)*RXYZ(1,I,1) +
     $                                 RN(N1,J,2)*RXYZ(2,I,1) +
     $                                 RN(N1,J,3)*RXYZ(3,I,1))
  110     continue
	end if
  120 continue
** calculate distance between the planes z=0 and z=-1/2
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0) then
	DZ2 = A(3,3)/2.0
      end if
      F = 0.0
      FC = 0.0
      FD = 0.0
      FR = 0.0
      FP = 0.0
      if(SUMR.gt.0.0) then
	SA=sin(CELL(4))
	SB=sin(CELL(5))
	SC=sin(CELL(6))
	HA=VOL/(CELL(2)*CELL(3)*SA)
	HB=VOL/(CELL(1)*CELL(3)*SB)
	HC=VOL/(CELL(1)*CELL(2)*SC)
	if(SUMR.lt.HA/2.0) then
	  ISUM(1)=1
	else
	  ISUM(1)=int((SUMR-HA/2.0)/HA+1.0)
	end if
	if(SUMR.lt.HB/2.0) then
	  ISUM(2)=1
	else
	  ISUM(2)=int((SUMR-HB/2.0)/HB+1.0)
	end if
	if(SUMR.lt.HC/2.0) then
	  ISUM(3)=1
	else
	  ISUM(3)=int((SUMR-HC/2.0)/HC+1.0)
	end if
      end if
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0)
     $                                                   ISUM(3)=0

** start summation loop
      do 500 IC1=-ISUM(1),ISUM(1)
      do 490 IC2=-ISUM(2),ISUM(2)
      do 480 IC3=-ISUM(3),ISUM(3)
	M1=1
** calculate lattice translation vector
	do 200 J=1,3
	  CA(J)=A(J,1)*IC1+A(J,2)*IC2+A(J,3)*IC3
  200   continue
** vary symmetry operation of second molecule/ion
	do 190 M2=1,NS
** SAMASY=.true.: both atoms in same asymmetric unit of the same cell
          SAMASY=(M2.eq.1.and.IC1.eq.0.and.IC2.eq.0.and.IC3.eq.0)
          if(SAMASY) then
            CSAM=1.0
** for M2=1 only half of the neighbour cells have to be included into summation
          else if(M2.eq.1) then
            CSAM=1.0
            if(IC1.ge.1.or.(IC1.eq.0.and.IC2.ge.1).or.
     $        (IC1.eq.0.and.IC2.eq.0.and.IC3.ge.1)) goto 190
          else
            CSAM=0.5
	  end if
	  do 180 L1=1,NCLUS
	    do 170 L2=1,NCLUS
              if(SAMASY.and.L1.gt.L2) goto 170                        
	      
** second molecule on special position?
	      if(SPEC.and.ISPC(L2).gt.0) then
		do 165 MM=1,ISPC(L2)
		  READ(SPC(MM,L2),'(i2)') MM2
		  if(MM2.eq.M2) goto 170
  165           continue
	      end if
              RC=sqrt((XYZSC(1,L1,M1)-XYZSC(1,L2,M2)-CA(1))**2+
     $                (XYZSC(2,L1,M1)-XYZSC(2,L2,M2)-CA(2))**2+
     $                (XYZSC(3,L1,M1)-XYZSC(3,L2,M2)-CA(3))**2)
** collision between molecules?
              IF(RC.LT.RMIN(L1)+RMIN(L2).and.(L1.ne.L2.or..not.SAMASY))
     $                                                              THEN
                F = 1e10
                FR = 1e10
                IRET = 2
                goto 999
              END IF
	      if(PTNAME.eq.'SQUARE'.or.PTNAME.eq.'SOFT'.or.SPEC) then
		TOUCH=.false.
** TOUCH=.true.: collision between molecules/ions possible
                if(RC.lt.MXR(L1)+MXR(L2).and.(L1.ne.L2.or..not.SAMASY))
     $                                                      TOUCH=.true.
	      end if
	      NR2 = 0
	      do 160 I=1,NATM1
		if(ICLUS(I).ne.L1) goto 160
		LS2 = nint(LSUB(I)/128.0)
		LS1 = LSUB(I)-LS2*128
		if(PTNAME.eq.'SQUARE'.and..not.TOUCH
     $                               .and.abs(Q(I)).lt.1e-3) goto 160
		if(PTNAME.eq.'SOFT'.and..not.TOUCH) goto 160
		do 390 II=1,3
		  YI(II) = RXYZ(II,I,M1) + XYZSC(II,ICLUS(I),M1)
  390           continue
**           surface potential
                if((SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.
     $              SPOT(1,3).ne.0.0).and.
     $              IC1.eq.0.and.IC2.eq.0.and.L2.eq.1.and.M2.eq.1) then
		  D2 = DZ2 + YI(3)
                  if(D2.lt.1.0) then
                    D2 = 1.0
		    IRET = 2
		  end if
                  if(SPOT(1,3).eq.0.0) then
                    FP = FP + SPOT(PTYP(I)+1,1)/D2**9 - 
     $                        SPOT(PTYP(I)+1,2)/D2**3
                  else
                    FP = FP + SPOT(PTYP(I)+1,1)*
     $                        (D2*SPOT(PTYP(I)+1,2)+2.0)/
     $                        SPOT(PTYP(I)+1,2)**3*
     $                        exp(-SPOT(PTYP(I)+1,2)*D2) -
     $                        SPOT(PTYP(I)+1,3)/D2**3
                  end if
		end if
		do 430 J=1,NATM1
		  if(ICLUS(J).ne.L2) goto 430
		  LS4 = nint(LSUB(J)/128.0)
		  LS3 = LSUB(J)-LS4*128
**               do not compare molecule/ion L1 with itself, except in the
**               case of subrotations
		  if(SAMASY.and.L1.eq.L2) then
		    if(LS1.eq.LS3) goto 430
                    if((LS1.lt.0..or.LS2.lt.0..or.
     $                  LS3.lt.0..or.LS4.lt.0.).and.
     $                (abs(LS1).eq.abs(LS3).or.abs(LS2).eq.abs(LS4).or.
     $                 abs(LS1).eq.abs(LS4).or.abs(LS2).eq.abs(LS3)))
     $                                                          goto 430
                    if(abs(LS1).gt.abs(LS3)) goto 430
		  end if
		  if(PTNAME.eq.'SQUARE'.and..not.TOUCH
     $                                 .and.abs(Q(J)).lt.1e-3) goto 430
		  do 400 JJ=1,3
		    YJ(JJ) = RXYZ(JJ,J,M2)+XYZSC(JJ,ICLUS(J),M2)+CA(JJ)
  400             continue
		  NR2 = NR2 + 1
		  R2(NR2)=sqrt(
     $               (YI(1)-YJ(1))**2+(YI(2)-YJ(2))**2+(YI(3)-YJ(3))**2)
		  JOT(NR2) = J
		  IH(NR2) = I
		  if(R2(NR2).lt.1e-4.and.SPEC) then
		    NR2 = NR2 - 1
		    goto 430
		  end if
		  if(PTNAME.ne.'SQUARE'.and.PTNAME.ne.'SOFT') then
		    if(R2(NR2).lt.1.) then
		      R2(NR2) = 1.0
		      IRET = 2
		    end if
		    if(R2(NR2).gt.SUMR.and.SUMR.gt.0.0) then
		      NR2 = NR2 - 1
		      goto 430
		    end if
		  else if(PTNAME.eq.'SQUARE') then
		    VW = VWR(I) + VWR(J)
		    if(R2(NR2).lt.VW) then
		      F=1e10
		      FR=1e10
		      IRET = 2
		      goto 999
		    else if(R2(NR2).ge.VW.and.R2(NR2).lt.VW*1.1) then
		      FD = FD - CSAM
		    end if
		  else if(PTNAME.eq.'SOFT') then
		    VW = VWR(I) + VWR(J)
		    if(R2(NR2).lt.VW) then
		      FR = FR + CSAM*(R2(NR2)-VW)**2
		      F = FR
		      if(F.gt.FRMAX.or.R2(NR2).lt.1.0) then
			F=1e10
			FR=1e10
			IRET = 2
			goto 999
		      end if
		    end if
		  end if
		  if(NR2.eq.64) then
		    call SUMUP(R2,IH,JOT,NR2,COUL,CSAM,F,FR,FD,FC)
		    NR2=0
		  end if

  430           continue
  160         continue
	      if(NR2.ne.0) then
		call SUMUP(R2,IH,JOT,NR2,COUL,CSAM,F,FR,FD,FC)
		NR2=0
	      end if
  170       continue
  180     continue
  190   continue
  480 continue
  490 continue
  500 continue
** end summation loop

      F = F + 1e-33*NA*PRESS*VOL/NS + FP
      FC = COUL*FC
  999 continue
      end
      
      subroutine SUMUP(R2,IH,JOT,NR2,COUL,CSAM,F,FR,FD,FC)
** Version 19.12.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      integer I,J,IPT,JPT
      character CHCK*4
      common /CHECK/ CHCK
************************************************************************
      real R2(64)
      integer IH(64),JOT(64)
      if(PTNAME.ne.'SQUARE'.and.PTNAME.ne.'SOFT') then
        if(CHCK(1:1).eq.'1') then
          do 400 K=1,min(NR2,64)
            I = IH(K)                    
            J = JOT(K)
            FC = FC + CSAM*Q(I)*Q(J)/R2(K)
  400     continue
        end if
        if(CHCK(2:2).eq.'1'.and.CHCK(4:4).eq.'0') then
          do 410 K=1,min(NR2,64)
            IPT = PTYP(IH(K))
            JPT = PTYP(JOT(K))
            FR = FR + CSAM*POT(IPT,JPT,1)*
     $                exp(-POT(IPT,JPT,2)*R2(K))
  410     continue
        end if
        if(CHCK(2:2).eq.'0'.and.CHCK(4:4).eq.'1') then
          do 420 K=1,min(NR2,64)
            IPT = PTYP(IH(K))
            JPT = PTYP(JOT(K))
            FR = FR + CSAM*POT(IPT,JPT,1)*
     $                (R2(K)**(-POT(IPT,JPT,4)))
  420     continue
        end if
        if(CHCK(2:2).eq.'1'.and.CHCK(4:4).eq.'1') then
          do 430 K=1,min(NR2,64)
            IPT = PTYP(IH(K))
            JPT = PTYP(JOT(K))
            FR = FR + CSAM*POT(IPT,JPT,1)*
     $                exp(-POT(IPT,JPT,2)*R2(K))*
     $                (R2(K)**(-POT(IPT,JPT,4)))
  430     continue
        end if
        if(CHCK(3:3).eq.'1') then
          do 440 K=1,min(NR2,64)
            I = IH(K)                    
            J = JOT(K)
            FD = FD - CSAM*POT(PTYP(I),PTYP(J),3)*R2(K)**(-6)
  440     continue
        end if

	F = FR + FD + COUL*FC
      else if(PTNAME.eq.'SQUARE'.and.CHCK(1:1).eq.'1') then
        do 450 K=1,NR2
	  I = IH(K)                    
	  J = JOT(K)
	  FC = FC + CSAM*Q(I)*Q(J)/R2(K)
  450   continue
	F = FD + COUL*FC
      end if
      end
      
      subroutine GOPT(G,X,IRET)
** Gradient of the energy of a system of molecules/ions.
** Version 27.11.97
** The position of the atoms is given by XYZC and X (measured in Angstroms).

** V = 1/2 * SUM  [V(rij)]
**          i<>j
** V(rij) = Aij*exp(-Bij*rij)/rij**Dij - Cij/rij**6 + Qi*Qj/rij

** Derivative of the potential with respect to the atom-atom distance:
**
** dV(rij)/drij = -Aij*exp(-Bij*rij)*(Bij/rij**Dij + Dij/rij**(Dij+1)) 
**                -6*Cij/rij**7 - Q/rij**2               [1 component]

** Derivative of the potential with respect to the cell constants:

** dV(rij)/da = (dV(rij)/drij)*(drij/da)                 [6 components]

** Derivative of the potential with respect to the components of the
** translational parameter of one molecule/ion:

** dV(rij)/dt = (dV(rij)/drij)*(drij/dt)                 [3 components]

** Derivative of the potential with respect to the Eulerian angles:

** dV(rij)/dang = (dV(rij)/drij)*(drij/dang)             [3 components]

** Atom-atom distance:

** ->
** rij = Ti + GTi + Ri*(rsi + ROTi*ri) - rsj - ROTj*rj

** rij = sqrt((Ti + GTi + Ri*(rsi + ROTi*ri) - rsj + ROTj*rj)^2)

** drij/da = (d(rij^2)/da)/rij          
**         = rij*(dri/da - drj/da)/|rij|                 [6 components]
** drij/dt = (d(rij^2)/dt)/rij
**         = rij*(dri/dt - drj/dt)/|rij|                 [3 components]
** drij/dang = (d(rij^2)/dang)/rij
**           = rij*(dri/dang - drj/dang)/|rij|           [3 components]

** dT/da  = dO/da*T(fract)  [3x6 components]
** dGT/da = dO/da*GT(fract) [3x6 components]
** drs/da = dO/da*rs(fract) [3x6 components]
** drs/dt = O*drs/dt        [3x3 components]

** dV(di)/ddi = -9*Ai/di^10 + 3*Bi/di^4

** di = CELL(3)/2 + rsi + ROTi*zi               [only z-component]

** ddi/da = 0
** ddi/dt = 0                                   [for x- and y-component of t]
**        = CELL(3)                             [for z-component of t]
** ddi/dang = ((dROT/dang)*ri)z                 [only z-component]

** ri1: Ortskoordinate des Atoms i im Kristall (kart. Koordinaten)
** di:  Abstand von der Oberflaeche (kart. Koordinaten)
** T:   Translationsteil der Symmetrieoperation (kart.), abhaengig von den 
**      Zellkonst.
** R:   rotational part of the symmetry operation, constant
** GT:  lattice translation (cart.), depends on cell constants
** rs:  Translation des Molekuels (kart. Koordinaten), abh. von den Zellkonst.
**      und den Translationsparametern
** ROT: rotation matrix of the molecule, depending on rotational parameters
** ri:  Ortskoordinate des Atoms i im Molekuelsystem (kart. Koordinaten),
**      konstant
** rij: vector between atom i and atom j
** a:   cell constant
** t:   translational parameter
** ang: rotation angle
** O:   orthogonalisation matrix
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** G(I):        gradient of the energy
** GA(J,K,L):   gradient of orthogonalisation matrix A(J,K)
** GT(M,J,I):   gradient of translational part of the symmetry operation M
** GGT(J,I):    gradient of the lattice translation
** GSB(J,I,K):  gradient of subrotation no. K of atom no. J
** GYS(L,J,K):  gradient of center of molecule no. L (for cell constants)
** GXYZC(I,J,K):gradient of cartesian coordinate of atom no. I (for rotation)
** GC(J,K,L):   derivatives of the centers of gravity with respect to cell
**              constant K
** MROT(I,J):   rotation matrix (Eulerian angles)
** NA:          Avogadro constant
** RO(I,J):     product of rotation matrix and orthogonalization matrix
** RXYZ(M,I,J): Cartesian coordinates of atom no. I, position M 
**              (after rotation, before translation)
** X(I):        Variable no. I
** YI(K),YJ(K): coordinates of a pair of atoms for which a potential has
**              to be calculated. YI is always in the 1st asymmetric unit.
** DYI(L,J):    derivative no. L of YI
** DYJ(L,J):    derivative no. L of YJ
** DRIJ(L,J):   derivative no. L of distance between 2 atoms
** YS(L,J):     Center of gravity of molecule/ion no. L
** YR(L,J):     Eulerian angles of molecule/ion no. L
      real NA
      parameter(COUL=1389.4,NA=6.022045e23)
      parameter(PI=3.141592653589793d0, PI2=PI*2)
      real X(NV),YS(NUCLUS,3),GYS(NUCLUS,3,6),YR(NUCLUS,3)
      real XYZ(3),XC(3),YI(3),YJ(3),XYZAD(3)
      real DYI((NUCLUS+1)*6+NUSUB,3),DYJ((NUCLUS+1)*6+NUSUB,3)
      real G(NV),RXYZ(3,NUMATM,NUSYM),GROT(3,3,3),CC(6),CSAM
      real GA(3,3,6),GT(NUSYM,3,6),GGT(3,6),RO(3,3),GXYZC(NUMATM,3,3)
      real R2(64),DYIJ(3),DRIJ(64,(NUCLUS+1)*6+NUSUB)
      integer IH(64),JOT(64), L1,L2,N,NR2
      logical VARCEL,OLD,SAMASY
      common /RXYZ/ RXYZ
      real CA(3)
      real A(3,3),AI(3,3),GSB(NUMATM,3,2),MROT(3,3),MROT2(3,3),GC(3,6,2)
      common /TEST/ A,AI
** subroutines called by this program unit:
** DORTH  calculates the gradient of the orthogonalisation matrix.
** FRACRT transform fractional coordinates to cartesian and vice versa
** SBROT  carry out a subrotation
** DSBROT calculate derivative of subrotation matrix.
** ROTEUL rotation by Eulerian angles
** GRTEUL calculate gradient of rotation by Eulerian angles
** SUMUP2 sum up to 64 gradients of atom-atom potentials
      VARCEL=.false.
      OLD=.false.
      IRET = 0
** update cell constants and put them to CC
      do 10 I6=1,6
	if(abs(IVAR(I6)).gt.0) then
	  if(IVAR(I6).gt.0) CC(I6)=X(IVAR(I6))
	  if(IVAR(I6).lt.0) CC(I6)=-X(-IVAR(I6))
	  VARCEL=.true.
	else
	  CC(I6)=CELL(I6)
	end if
   10 continue
** calculate gradient GA of orthogonalisation matrix
      if(VARCEL) call DORTH(CC,GA,UNAX,.false.,IERR)
** calculate gradient GT of translational part of symmetry operation
      if(VARCEL) then
	do 15 M=1,NS
	  do 20 K=1,6
	    do 25 L=1,3
	      GT(M,L,K) = 0.0
	      do 30 J=1,3
		GT(M,L,K) = GT(M,L,K) + GA(L,J,K)*T(M,J)
   30         continue
   25       continue
   20     continue
   15   continue
      end if
** initialize DYI and DYJ
      do 35 IP=1,(NUCLUS+1)*6+NUSUB
        do 35 L=1,3
          DYI(IP,L)=0.0
          DYJ(IP,L)=0.0
   35 continue
** update XYZS and put it to YS
      XYZAD(1)=0.0
      XYZAD(2)=0.0
      XYZAD(3)=0.0
      do 60 L=1,NCLUS
	L6=L*6
	do 40 J=1,3
	  I6=L6+J
	  if(IVAR(I6).ne.0) then
	    YS(L,J)=sign(1,IVAR(I6))*X(abs(IVAR(I6)))
	    if(SHIFT) YS(L,J)=mod(YS(L,J),1.0)
	  else
	    if(SHIFT) YS(L,J)=mod(XYZS(L,J),1.0)
	    if(.not.SHIFT) YS(L,J)=XYZS(L,J)
	  end if
          if(SHIFT.and.ICENT(J).eq.1.and.L.eq.1) then
            if(YS(L,J).lt.-0.25.and.YS(L,J).gt.-0.75) XYZAD(J)=0.5
            if(YS(L,J).gt.0.25.and.YS(L,J).lt.0.75) XYZAD(J)=-0.5
          end if
          if((YS(L,J)+XYZAD(J).lt.-0.5).and.SHIFT) YS(L,J)=YS(L,J)+1.0
          if((YS(L,J)+XYZAD(J).gt.0.5).and.SHIFT) YS(L,J)=YS(L,J)-1.0
   40   continue
** calculate gradient of center of molecule
	if(VARCEL) then
	  do 55 K=1,6
	    do 50 N=1,3
	      GYS(L,N,K) = 0.0
	      do 45 J=1,3
		GYS(L,N,K) = GYS(L,N,K) + GA(N,J,K)*YS(L,J)
   45         continue
   50       continue
   55     continue
	end if
   60 continue
** apply symmetry operations to centers of gravity and molecules
      do 180 M=1,NS
** calculate cartesian coordinates of centers of gravity
	do 90 L=1,NCLUS
	  do 70 J=1,3
	    XYZ(J)=R(M,J,1)*YS(L,1)+R(M,J,2)*YS(L,2)+R(M,J,3)*YS(L,3)+
     $             T(M,J)
   70     continue
	  call FRACRT(XYZ,XC,CC,VOL,1,UNAX,OLD,IERR)
	  if(IERR.ne.0) then
	    IRET = 1
	    goto 999
	  end if
** test cell heights
	  if(M.eq.1.and.L.eq.1) then
            if(VOL/(CC(1)*CC(2)*sin(CC(6))).lt.HMIN) then
	      IRET = 3
	      goto 999
            else if(VOL/(CC(1)*CC(3)*sin(CC(5))).lt.HMIN) then
	      IRET = 3
	      goto 999
            else if(VOL/(CC(2)*CC(3)*sin(CC(4))).lt.HMIN) then
	      IRET = 3
	      goto 999
	    end if
	  end if
	  OLD=.true.
	  do 80 J=1,3
	    XYZSC(J,L,M)=XC(J)
   80     continue
   90   continue
        if(M.eq.1) then
** copy XYZC to RXYZ, initialize GSB
          do 110 I=1,NATM1
            do 100 J=1,3
              RXYZ(J,I,1)=XYZC(I,J)
              GSB(I,J,1)=0.0
              GSB(I,J,2)=0.0
  100       continue
  110     continue
          do 120 L=1,NSUB
            L6=(NUCLUS+1)*6+L
            if(abs(IVAR(L6)).gt.0) then
              YSR=mod(sign(1,IVAR(L6))*X(abs(IVAR(L6))),PI2)
            else
              YSR=mod(SUBROT(L),PI2)
            end if
** calculate derivative of subrotation L and put the result to GSB
            call DSBROT(L,YSR,GSB)
** perform subrotation L and put the result to RXYZ
            call SBROT(L,YSR)
  120     continue
          do 160 L=1,NCLUS
            do 130 J=4,6
              I6=L*6+J
              if(abs(IVAR(I6)).gt.0) then
                YR(L,J-3)=mod(sign(1,IVAR(I6))*X(abs(IVAR(I6))),PI2)
              else
                YR(L,J-3)=mod(ROT(L,J-3),PI2)
              end if
  130       continue
** calculate gradient of rotation matrix GROT of molecule L
            call GRTEUL(L,GROT,YR)
** calculate gradient of cartesian coordinate of atom no. I (for rotation)
            do 150 I=1,NATM1
              if(ICLUS(I).eq.L) then
                do 140 K=1,3
                  do 140 J=1,3
                    GXYZC(I,J,K)=GROT(J,1,K)*RXYZ(1,I,1)+
     $                           GROT(J,2,K)*RXYZ(2,I,1)+
     $                           GROT(J,3,K)*RXYZ(3,I,1)
  140           continue
              end if
  150       continue
** rotate molecule/ion L and put the result to RXYZ
            call ROTEUL(L,YR,MROT,.true.)
  160     continue
        else
	  N=ISYM(M)
	  N1=abs(N)
	  do 170 I=1,NATM1
	    do 170 J=1,3
	      RXYZ(J,I,M) = sign(1,N)*(RN(N1,J,1)*RXYZ(1,I,1) +
     $                                 RN(N1,J,2)*RXYZ(2,I,1) +
     $                                 RN(N1,J,3)*RXYZ(3,I,1))
  170     continue
	end if
  180 continue
** initialize gradient
      do 190 IV=1,NV
	G(IV)=0.0
  190 continue
** calculate distance between the planes z=0 and z=-1/2
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0) then
	DZ2 = A(3,3)/2.0
      end if
      if(SUMR.gt.0.0) then
	SA=sin(CELL(4))
	SB=sin(CELL(5))
	SC=sin(CELL(6))
	HA=VOL/(CELL(2)*CELL(3)*SA)
	HB=VOL/(CELL(1)*CELL(3)*SB)
	HC=VOL/(CELL(1)*CELL(2)*SC)
	if(SUMR.lt.HA/2.0) then
	  ISUM(1)=1
	else
	  ISUM(1)=int((SUMR-HA/2.0)/HA+1.0)
	end if
	if(SUMR.lt.HB/2.0) then
	  ISUM(2)=1
	else
	  ISUM(2)=int((SUMR-HB/2.0)/HB+1.0)
	end if
	if(SUMR.lt.HC/2.0) then
	  ISUM(3)=1
	else
	  ISUM(3)=int((SUMR-HC/2.0)/HC+1.0)
	end if
      end if
      if(SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.SPOT(1,3).ne.0.0)
     $                                                   ISUM(3)=0

** start summation loop **
      do 800 IC1=-ISUM(1),ISUM(1)
      do 790 IC2=-ISUM(2),ISUM(2)
      do 780 IC3=-ISUM(3),ISUM(3)
** calculate gradient of lattice translation
	if(VARCEL) then
          do 320 K=1,6
	    do 320 L=1,3
	      GGT(L,K) = GA(L,1,K)*IC1 + GA(L,2,K)*IC2 + GA(L,3,K)*IC3
  320     continue
	else
	  do 325 K=1,6
	    do 325 L=1,3
	      GGT(L,K) = 0.0
  325     continue
	end if
** calculate lattice translation vector
	do 191 J=1,3
	  CA(J)=A(J,1)*IC1+A(J,2)*IC2+A(J,3)*IC3
  191   continue
	M1=1
        do 770 M2=1,NS
** calculate product of rotation matrix and orthogonalization matrix
	  N=ISYM(M2)
	  do 200 K=1,3
	    do 196 L=1,3
	      RO(K,L)=0.0
	      do 193 J=1,3
		N1=abs(N)
		RO(K,L) = RO(K,L) + sign(1,N)*RN(N1,K,J)*A(J,L)
  193         continue
  196       continue
  200     continue

	  SAMASY=(M2.eq.1.and.IC1.eq.0.and.IC2.eq.0.and.IC3.eq.0)
	  if(SAMASY) then
            CSAM=1.0
** for M2=1 only half of the neighbour cells have to be included into summation
          else if(M2.eq.1) then
            CSAM=1.0
            if(IC1.ge.1.or.(IC1.eq.0.and.IC2.ge.1).or.
     $        (IC1.eq.0.and.IC2.eq.0.and.IC3.ge.1)) goto 770
	  else
	    CSAM=0.5
	  end if
          do 760 L1=1,NCLUS
	    if(NSUB.gt.0) call ROTEUL(L1,YR,MROT,.false.)
** derivatives of the centers of the molecules with respect to the trans-
** lational parameters (first molecule)
            do 300 IP=L1*6+1,L1*6+3
              IV = IVAR(IP)
              LP = (IP-1)/6
              K = IP-L1*6
              do 300 L=1,3
                DYI(IP,L)=sign(1,IV)*A(L,K)
  300       continue
            do 740 L2=1,NCLUS
              if(SAMASY.and.L1.gt.L2) goto 740
	      
	      if(SPEC.and.ISPC(L2).gt.0) then
		do 455 MM=1,ISPC(L2)
		  READ(SPC(MM,L2),'(i2)') MM2
                  if(MM2.eq.M2) goto 740
  455           continue
	      end if

	      if(NSUB.gt.0) call ROTEUL(L2,YR,MROT2,.false.)
** derivatives of the centers of molecules/ions with respect to cell constants
	      if(VARCEL) then
		do 350 K=1,6
		  do 340 L=1,3
		    GC(L,K,1) = GYS(L1,L,K) + GT(M1,L,K)
		    N1=abs(N)
		    GC(L,K,2) = GGT(L,K)  + GT(M2,L,K) + sign(1,N)*
     $                         (RN(N1,L,1)*GYS(L2,1,K) +
     $                          RN(N1,L,2)*GYS(L2,2,K) +
     $                          RN(N1,L,3)*GYS(L2,3,K))
		    if(IVAR(K).ne.0) then
		      DYI(K,L)=GC(L,K,1)
		      DYJ(K,L)=GC(L,K,2)
		    end if
  340             continue
  350           continue
	      end if

** derivatives of the centers of the molecules with respect to the trans-
** lational parameters (second molecule)
              do 600 IP=L2*6+1,L2*6+3
                IV = IVAR(IP)
                LP = (IP-1)/6
                K = IP-L2*6
                do 600 L=1,3
                  DYJ(IP,L)=sign(1,IV)*RO(L,K)
  600         continue
	      NR2 = 0
              do 720 I=1,NATM1
                if(ICLUS(I).ne.L1) goto 720
		LS2 = nint(LSUB(I)/128.0)
                LS1 = LSUB(I) - LS2*128
                YI(1) = RXYZ(1,I,M1) + XYZSC(1,ICLUS(I),M1)
                YI(2) = RXYZ(2,I,M1) + XYZSC(2,ICLUS(I),M1)
                YI(3) = RXYZ(3,I,M1) + XYZSC(3,ICLUS(I),M1)
** derivatives of the atom positions with respect to the rotational
** parameters (first molecule)
                do 610 IP=L1*6+4,L1*6+6
                  IV = IVAR(IP)
                  K = IP-L1*6-3
                  do 610 L=1,3
                    DYI(IP,L) = sign(1,IV)*GXYZC(I,L,K)
  610           continue
                if((SPOT(1,1).ne.0.0.or.SPOT(1,2).ne.0.0.or.
     $              SPOT(1,3).ne.0.0).and.
     $              IC1.eq.0.and.IC2.eq.0.and.L2.eq.1.and.M2.eq.1) then
		  D2 = DZ2 + YI(3)
                  if(D2.lt.1.0) then
                    D2 = 1.0
		    IRET = 2
		  end if
** derivative of V with respect to D2 (surface potential)
                  if(SPOT(1,3).eq.0.0) then
                    DFP = - 9*SPOT(PTYP(I)+1,1)/D2**10 + 
     $                      3*SPOT(PTYP(I)+1,2)/D2**4
                  else
                    DFP = - SPOT(PTYP(I)+1,1)*
     $                     (SPOT(PTYP(I)+1,2)*(SPOT(PTYP(I)+1,2)**2*
     $                      (1.0-D2)+2*SPOT(PTYP(I)+1,2)-3*D2) - 6.0)/
     $                      SPOT(PTYP(I)+1,2)**4 *
     $                      exp(-SPOT(PTYP(I)+1,2)*D2) +
     $                      3*SPOT(PTYP(I)+1,3)/D2**4
                  end if
** derivative of DI with respect to the variables (surface potential)
                  do 620 IP=7,(NUCLUS+1)*6+NSUB
		    IV = IVAR(IP)
                    if(IV.eq.0) goto 620
** translations (surface potential)
		    if(mod(IP,6).gt.0.and.mod(IP,6).le.3.and.
     $                        IP.le.(NUCLUS+1)*6) then
		      LP = (IP-1)/6
		      if(mod(IP,6).eq.1.or.mod(IP,6).eq.2) then
			DX = 0.0
		      else if(LP.eq.L1) then
			DX = sign(1,IV)*CELL(3)
		      end if
** rotations (surface potential)
		    else if((mod(IP,6).eq.0.or.mod(IP,6).gt.3).and.
     $                       IP.le.(NUCLUS+1)*6) then
		      LP = (IP-1)/6
		      K=mod(IP,6)-3
		      if(K.lt.0) K=3
		      DX = 0.0
		      if(LP.eq.L1) then
			DX = sign(1,IV)*GXYZC(I,3,K)
		      end if
** subrotations (surface potential)
		    else
		      IPS = IP - (NUCLUS+1)*6
                      if(abs(LS1).eq.IPS.and.LS2.eq.0) I1=2
                      if(abs(LS1).eq.IPS.and.LS2.ne.0) I1=1
                      if(abs(LS2).eq.IPS.and.LS1.eq.0) I1=2
                      if(abs(LS2).eq.IPS.and.LS1.ne.0) I1=2
                      if((abs(LS1).eq.IPS.or.abs(LS2).eq.IPS).and.
     $                                                     IV.gt.0) then
			DX = MROT(3,1)*GSB(I,1,I1) +
     $                       MROT(3,2)*GSB(I,2,I1) +
     $                       MROT(3,3)*GSB(I,3,I1)
                      else if((abs(LS1).eq.IPS.or.abs(LS2).eq.IPS).and.
     $                                                     IV.lt.0) then
			DX =-MROT(3,1)*GSB(I,1,I1) -
     $                       MROT(3,2)*GSB(I,2,I1) -
     $                       MROT(3,3)*GSB(I,3,I1)
		      else
			DX = 0.0
		      end if
		    end if
**
		    G(abs(IV)) = G(abs(IV)) + DFP*DX
  620             continue
		end if

                do 700 J=1,NATM1
                  if(ICLUS(J).ne.L2) goto 700
		  LS4 = nint(LSUB(J)/128.0)
		  LS3 = LSUB(J)-LS4*128
**               do not compare molecule/ion L1 with itself, except in the
**               case of subrotations
		  if(SAMASY.and.L1.eq.L2) then
                    if(LS1.eq.LS3) goto 700
                    if((LS1.lt.0..or.LS2.lt.0..or.
     $                  LS3.lt.0..or.LS4.lt.0.).and.
     $                (abs(LS1).eq.abs(LS3).or.abs(LS2).eq.abs(LS4).or.
     $                 abs(LS1).eq.abs(LS4).or.abs(LS2).eq.abs(LS3)))
     $                                                          goto 700
                    if(abs(LS1).gt.abs(LS3)) goto 700
		  end if
                  do 630 JJ=1,3
		    YJ(JJ) = RXYZ(JJ,J,M2)+XYZSC(JJ,ICLUS(J),M2)+CA(JJ)
  630             continue
		  NR2 = NR2 + 1
                  DYIJ(1) = YI(1)-YJ(1)
                  DYIJ(2) = YI(2)-YJ(2)
                  DYIJ(3) = YI(3)-YJ(3)
                  R2(NR2) = sqrt(DYIJ(1)**2+DYIJ(2)**2+DYIJ(3)**2)
		  IH(NR2) = I
		  JOT(NR2) = J
                  if(R2(NR2).lt.1e-4.and.SPEC) goto 700
		  if(R2(NR2).lt.1.) then
		    R2(NR2)=1.0
		    IRET = 2
		  end if
		  if(R2(NR2).gt.SUMR.and.SUMR.gt.0.0) then
		    NR2 = NR2 -1
                    goto 700
		  end if
                  N1 = abs(N)
** derivatives of the atom positions with respect to the rotational
** parameters (second molecule)
                  do 640 IP=L2*6+4,L2*6+6
                    IV = IVAR(IP)
                    K = IP-L2*6-3
                    do 640 L=1,3
                      DYJ(IP,L) = sign(1,IV)*sign(1,N)*
     $                            (RN(N1,L,1)*GXYZC(J,1,K) +
     $                             RN(N1,L,2)*GXYZC(J,2,K) +
     $                             RN(N1,L,3)*GXYZC(J,3,K))
  640             continue
** derivatives of the atom positions with respect to the subrotations
                  LS2 = nint(LSUB(I)/128.0)
                  LS1 = LSUB(I) - LS2*128
                  LS4 = nint(LSUB(J)/128.0)
                  LS3 = LSUB(J) - LS4*128
                  do 670 IP=(NUCLUS+1)*6+1,(NUCLUS+1)*6+NSUB
                    IV = IVAR(IP)
                    if(IV.eq.0) goto 670
** IPS: subrotation number
                    IPS = IP - (NUCLUS+1)*6
                    do 660 L=1,3
                      if(abs(LS1).eq.IPS.or.abs(LS2).eq.IPS) then
                        if(abs(LS1).eq.IPS.and.LS2.eq.0) I1=2
                        if(abs(LS1).eq.IPS.and.LS2.ne.0) I1=1
                        if(abs(LS2).eq.IPS.and.LS1.eq.0) I1=2
                        if(abs(LS2).eq.IPS.and.LS1.ne.0) I1=2
                        DYI(IP,L) = sign(1,IV)*(MROT(L,1)*GSB(I,1,I1) +
     $                                          MROT(L,2)*GSB(I,2,I1) +
     $                                          MROT(L,3)*GSB(I,3,I1))
                      else
                        DYI(IP,L) = 0.0
                      end if
                      if(abs(LS3).eq.IPS.or.abs(LS4).eq.IPS) then
                        if(abs(LS3).eq.IPS.and.LS4.eq.0) I1=2
                        if(abs(LS3).eq.IPS.and.LS4.ne.0) I1=1
                        if(abs(LS4).eq.IPS.and.LS3.eq.0) I1=2
                        if(abs(LS4).eq.IPS.and.LS3.ne.0) I1=2
                        do 650 K=1,3
                          XYZ(K) = MROT2(K,1)*GSB(J,1,I1) +
     $                             MROT2(K,2)*GSB(J,2,I1) +
     $                             MROT2(K,3)*GSB(J,3,I1)
  650                   continue
                        N1=abs(N)
                        DYJ(IP,L) = sign(1,IV)*sign(1,N)*
     $                              RN(N1,L,1)*XYZ(L) +
     $                              RN(N1,L,2)*XYZ(L) +
     $                              RN(N1,L,3)*XYZ(L)
                      else
                        DYJ(IP,L) = 0.0
                      end if
  660               continue
  670             continue
                  do 680 IP=1,(NCLUS+1)*6
                    if(IVAR(IP).eq.0) goto 680
                    DRIJ(NR2,IP) = (DYIJ(1)*(DYI(IP,1)-DYJ(IP,1)) +
     $                              DYIJ(2)*(DYI(IP,2)-DYJ(IP,2)) + 
     $                            DYIJ(3)*(DYI(IP,3)-DYJ(IP,3)))/R2(NR2)
  680             continue
                  do 685 IP=(NUCLUS+1)*6+1,(NUCLUS+1)*6+NSUB
                    if(IVAR(IP).eq.0) goto 685
                    DRIJ(NR2,IP) = (DYIJ(1)*(DYI(IP,1)-DYJ(IP,1)) +
     $                              DYIJ(2)*(DYI(IP,2)-DYJ(IP,2)) + 
     $                            DYIJ(3)*(DYI(IP,3)-DYJ(IP,3)))/R2(NR2)
  685             continue
		  if(NR2.eq.64) then
                    call SUMUP2(R2,IH,JOT,NR2,COUL,CSAM,DRIJ,G)
		    NR2=0
		  end if
** reset rotational derivatives of second molecule atom
                  do 690 IP=L2*6+4,L2*6+6
                    do 690 L=1,3
                      DYJ(IP,L) = 0.0
  690             continue
  700           continue

** reset rotational derivatives of first molecule atom
                do 710 IP=L1*6+4,L1*6+6
                  do 710 L=1,3
                    DYI(IP,L) = 0.0
  710           continue
  720         continue

	      if(NR2.ne.0) then
                call SUMUP2(R2,IH,JOT,NR2,COUL,CSAM,DRIJ,G)
		NR2=0
	      end if
** reset translational derivatives of second molecule
              do 730 IP=L2*6+1,L2*6+3
                do 730 L=1,3
                  DYJ(IP,L) = 0.0
  730         continue
  740       continue

** reset translational derivatives of first molecule
            do 750 IP=L1*6+1,L1*6+3
              do 750 L=1,3
                DYI(IP,L) = 0.0
  750       continue
  760     continue

  770   continue
  780 continue
  790 continue
  800 continue
** end summation loop

** add pressure term (depends on cell volume)
      do 900 IP=1,6
	IV = IVAR(IP)
        if(IV.eq.0) goto 900
	if(UNAX.ne.'R'.and.UNAX.ne.'r') then
	  G(IP) = G(IP) + 1e-33*NA*PRESS/NS*(GA(1,1,IP)*A(2,2)*A(3,3) +
     $                                       A(1,1)*GA(2,2,IP)*A(3,3) +
     $                                       A(1,1)*A(2,2)*GA(3,3,IP))
	else
	  G(IP) = G(IP) + 1e-33*NA*PRESS/NS*(GA(1,2,IP)*A(2,3)*A(3,1) +
     $                                       A(1,2)*GA(2,3,IP)*A(3,1) +
     $                                       A(1,2)*A(2,3)*GA(3,1,IP) +
     $                                       GA(1,3,IP)*A(2,1)*A(3,2) +
     $                                       A(1,3)*GA(2,1,IP)*A(3,2) +
     $                                       A(1,3)*A(2,1)*GA(3,2,IP) -
     $                                       GA(3,1,IP)*A(2,2)*A(1,3) -
     $                                       A(3,1)*GA(2,2,IP)*A(1,3) -
     $                                       A(3,1)*A(2,2)*GA(1,3,IP) -
     $                                       GA(2,1,IP)*A(1,2)*A(3,3) -
     $                                       A(2,1)*GA(1,2,IP)*A(3,3) -
     $                                       A(2,1)*A(1,2)*GA(3,3,IP))
	end if
  900 continue
  999 continue
      end

      subroutine SUMUP2(R2,IH,JOT,NR2,COUL,CSAM,DRIJ,G)
** Version 14.07.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** DRIJ(L,J):   derivative no. L of distance between 2 atoms
      real G(NV),CSAM
      real R2(64),DRIJ(64,(NUCLUS+1)*6+NUSUB)
      real COUL
      integer IH(64),JOT(64), NR2, PTI,PTJ
** I/J: number of the first/second atom
      do 100 KR=1,min(NR2,64)
	I=IH(KR)
	J=JOT(KR)
** Derivative of V with respect to R2
	if(PTNAME.ne.'SOFT') then
          PTI=PTYP(I)
          PTJ=PTYP(J)
          DV = - POT(PTI,PTJ,1)*exp(-POT(PTI,PTJ,2)*R2(KR))*
     $          (POT(PTI,PTJ,2)*R2(KR)**(-POT(PTI,PTJ,4)) +
     $           POT(PTI,PTJ,4)*R2(KR)**(-1.0-POT(PTI,PTJ,4))
     $          )
     $         + 6*POT(PTI,PTJ,3)*R2(KR)**(-7)
     $         - COUL*Q(I)*Q(J)/R2(KR)**2
	else
	  VW = VWR(I) + VWR(J)
	  if(R2(KR).ge.VW) then
	    DV = 0.0
	  else if(R2(KR).lt.1.0) then
	    DV = 2*(1.0-VW)
	  else
	    if(R2(KR).lt.VW) DV = 2*(R2(KR)-VW)
	  end if
	end if
	DV = DV*CSAM
        do 500 IP=1,(NUCLUS+1)*6+NSUB
          IV = IVAR(IP)
          if(IV.ne.0) G(abs(IV)) = G(abs(IV)) + DV*DRIJ(KR,IP)
  500   continue
  100 continue
      end

      subroutine ROTEUL(L,YR,MROT,LROT)
** rotation by Eulerian angles
** Version 01.02.96
** unrotated cartesian coordinates are in RXYZ
** rotated cartesian coordinates are in RXYZ
** If LROT is .false., the molecule will not be rotated, only the
** rotation matrix will be calculated
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** RXYZ(J,I,M): Cartesian coordinates of atom no. I, position M 
**              (before/after rotation, before translation)
** YR(L,J):     Eulerian angles of molecule/ion no. L
** MROT(I,J):   rotation matrix, I: line number, J: column number
** LROT:        .true.: calculate rotation matrix, do rotation
**              .false.: calculate rotation matrix, do not do rotation
      real RXYZ(3,NUMATM,NUSYM),XYZ(3)
      real YR(NUCLUS,3), MROT(3,3)
      logical LROT
      common /RXYZ/ RXYZ
      SA=sin(YR(L,1))
      CA=cos(YR(L,1))
      SB=sin(YR(L,2))
      CB=cos(YR(L,2))
      SC=sin(YR(L,3))
      CC=cos(YR(L,3))
      MROT(1,1)=CA*CC-SA*CB*SC
      MROT(1,2)=SA*CC+CA*CB*SC
      MROT(1,3)=SB*SC
      MROT(2,1)=-SA*CB*CC-CA*SC
      MROT(2,2)=-SA*SC+CA*CB*CC
      MROT(2,3)=SB*CC
      MROT(3,1)=SA*SB
      MROT(3,2)=-CA*SB
      MROT(3,3)=CB
      if(.not.LROT) goto 999
      do 50 I=1,NATM1
	if(ICLUS(I).eq.L) then
	  do 30 J=1,3
	    XYZ(J) = 0.0
	    do 20 K=1,3
	      XYZ(J) = XYZ(J) + MROT(J,K)*RXYZ(K,I,1)
   20       continue
   30     continue
	  do 40 J=1,3
	    RXYZ(J,I,1) = XYZ(J)
   40     continue
	end if
   50 continue
  999 continue
      end
      
      subroutine GRTEUL(L,GROT,YR)
** calculate gradient of rotation by Eulerian angles
** Version 06.06.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real YR(NUCLUS,3), GROT(3,3,3)
** YR(L,J):       Eulerian angles of molecule/ion no. L
** GROT(I,J,K):   gradient of rotation matrix, I: line number, J: column number
      SA=sin(YR(L,1))
      CA=cos(YR(L,1))
      SB=sin(YR(L,2))
      CB=cos(YR(L,2))
      SC=sin(YR(L,3))
      CC=cos(YR(L,3))
** Ableitung nach Theta
      GROT(1,1,1)=-SA*CC-CA*CB*SC
      GROT(1,2,1)= CA*CC-SA*CB*SC
      GROT(1,3,1)= 0.0
      GROT(2,1,1)=-CA*CB*CC+SA*SC
      GROT(2,2,1)=-CA*SC-SA*CB*CC
      GROT(2,3,1)= 0.0
      GROT(3,1,1)= CA*SB
      GROT(3,2,1)= SA*SB
      GROT(3,3,1)= 0.0
** Ableitung nach Chi
      GROT(1,1,2)= SA*SB*SC
      GROT(1,2,2)=-CA*SB*SC
      GROT(1,3,2)= CB*SC
      GROT(2,1,2)= SA*SB*CC
      GROT(2,2,2)=-CA*SB*CC
      GROT(2,3,2)= CB*CC
      GROT(3,1,2)= SA*CB
      GROT(3,2,2)=-CA*CB
      GROT(3,3,2)=-SB
** Ableitung nach Phi
      GROT(1,1,3)=-CA*SC-SA*CB*CC
      GROT(1,2,3)=-SA*SC+CA*CB*CC
      GROT(1,3,3)= SB*CC
      GROT(2,1,3)= SA*CB*SC-CA*CC
      GROT(2,2,3)=-SA*CC-CA*CB*SC
      GROT(2,3,3)=-SB*SC
      GROT(3,1,3)= 0.0
      GROT(3,2,3)= 0.0
      GROT(3,3,3)= 0.0
      end
*
      subroutine DORTH(CELL,GA,UNAX,OLD,IERR)
** This subroutine calculates the gradient of the orthogonalisation matrix.
** Version 17.8.95
** CELL:     d cell constants, angles in degrees
** A(I,J,K): d gradient of the transformation matrix fractional -> cartesian
** UNAX:     c unique axis (a, b, c)
** OLD:      l .true.: use old transformation matrix
**             .false.: calculate new transformation matrix
** IERR:     i 0: no error    1: one angle is less than or equal to 1
**             2: one cell edge is less than or equal to 1
************************************************************************
** definition of cartesian axes 
** unique axis=a:
** x-axis parallel to a-axis
** y-axis in a-b-plane, on the same side as b-axis
** z-axis perpendicular to x- and y-axis (right-hand system)
** unique axis=b:
** x-axis perpendicular to y- and z-axis (right-hand system)
** y-axis parallel to b-axis
** z-axis in b-c-plane, on the same side as c-axis
** unique axis=c:
** x-axis in c-a-plane, on the same side as a-axis
** y-axis perpendicular to z- and x-axis (right-hand system)
** z-axis parallel to c-axis
** unique axis=r:
** x-axis
** y-axis perpendicular to z- and x-axis (right-hand system)
** z-axis
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUSYM=24,NUCLUS=16)
      parameter(PI=3.141592653589793d0)
      real CELL(6)
      real C1,C2,C3,S1,S2,S3
      integer IERR
      character UNAX*1
      logical OLD
      real GA(3,3,6)
************************************************************************
      IERR = 0
      if(OLD) goto 100
      if(CELL(4).le.PI/20.or.CELL(5).le.PI/20.or.CELL(6).le.PI/20) then
	IERR = 1
	return
      end if
      C1 = COS(CELL(4))
      C2 = COS(CELL(5))
      C3 = COS(CELL(6))
      S1 = SIN(CELL(4))
      S2 = SIN(CELL(5))
      S3 = SIN(CELL(6))
      if(CELL(1).lt.1.0.or.CELL(2).lt.1.0.or.CELL(3).lt.1.0) then
	IERR = 2
	return
      end if
      do 50 I=1,3
	do 50 J=1,3
	  do 50 K=1,6
	    GA(I,J,K)=0.0
   50 continue
      if(UNAX.eq.' '.or.UNAX.eq.'a'.or.UNAX.eq.'A') then
	A2 = ((C1-C2*C3)/S3)**2+C2**2
	if(A2.gt.1.0) then
	  IERR = 4
	  return
	end if
** Ableitung nach a
	GA(1,1,1) = 1.0
** Ableitung nach b
	GA(1,2,2) = C3
	GA(2,2,2) = S3
** Ableitung nach c
	GA(1,3,3) = C2
	GA(2,3,3) = (C1-C2*C3)/S3
	if(A2.gt.1.0) then
	  IERR = 4
	  return
	end if
	GA(3,3,3) = SQRT(1. - A2)
** Ableitung nach alpha
	GA(2,3,4) = -CELL(3)*S1/S3
	GA(3,3,4) = CELL(3)/SQRT(1. - A2)*(C1-C2*C3)/S3*(S1/S3)
** Ableitung nach beta
	GA(1,3,5) = -CELL(3)*S2
	GA(2,3,5) = CELL(3)*S2*C3/S3
	GA(3,3,5) = CELL(3)/SQRT(1. - A2)*
     $              (C2*S2 - (C1-C2*C3)/S3*(S2*C3/S3))
** Ableitung nach gamma
	GA(1,2,6) = -CELL(2)*S3
	GA(2,2,6) = CELL(2)*C3
	GA(2,3,6) = CELL(3)*(C2-C3*C1)/S3**2
	GA(3,3,6) = -CELL(3)/SQRT(1. - A2)*(C1-C2*C3)/S3*
     $                                     (C2-C3*C1)/S3**2
      
      else if(UNAX.eq.'b'.or.UNAX.eq.'B') then
	A2 = ((C2-C3*C1)/S1)**2+C3**2
	if(A2.gt.1.0) then
	  IERR = 4
	  return
	end if
** Ableitung nach a
	GA(1,1,1) = SQRT(1. - A2)
	GA(2,1,1) = C3
	GA(3,1,1) = (C2-C3*C1)/S1
** Ableitung nach b
	GA(2,2,2) = 1.0
** Ableitung nach c
	GA(2,3,3) = C1
	GA(3,3,3) = S1
** Ableitung nach alpha
	GA(1,1,4) = -CELL(1)/SQRT(1. - A2)*(C2-C3*C1)/S1*
     $                                     (C3-C1*C2)/S1**2
	GA(2,3,4) = -CELL(3)*S1
	GA(3,1,4) = CELL(1)*(C3-C1*C2)/S1**2
	GA(3,3,4) = CELL(3)*C1
** Ableitung nach beta
	GA(1,1,5) = CELL(1)/SQRT(1. - A2)*(C2-C3*C1)/S1*(S2/S1)
	GA(3,1,5) = -CELL(1)*S2/S1
** Ableitung nach gamma
	GA(1,1,6) = CELL(1)/SQRT(1. - A2)*
     $              (C3*S3 - (C2-C3*C1)/S1*(S3*C1/S1))
	GA(2,1,6) = -CELL(1)*S3
	GA(3,1,6) = CELL(1)*S3*C1/S1
      
      else if(UNAX.eq.'c'.or.UNAX.eq.'C') then
	A2 = ((C3-C1*C2)/S2)**2+C1**2
	if(A2.gt.1.0) then
	  IERR = 4
	  return
	end if
** Ableitung nach a
	GA(1,1,1) = S2
	GA(3,1,1) = C2
** Ableitung nach b
	GA(1,2,2) = (C3-C1*C2)/S2
	GA(2,2,2) = SQRT(1. - A2)
	GA(3,2,2) = C1
** Ableitung nach c
	GA(3,3,3) = 1.0
** Ableitung nach alpha
	GA(1,2,4) = CELL(2)*S1*C2/S2
	GA(2,2,4) = CELL(2)/SQRT(1. - A2)*
     $              (C1*S1 + (C3-C1*C2)/S2*(S1*C2/S2))
	GA(3,2,4) = -CELL(2)*S1
** Ableitung nach beta
	GA(1,1,5) = CELL(1)*C2
	GA(1,2,5) = CELL(2)*(C1/S2**2-C3*C2/S2**2)
	GA(2,2,5) = CELL(2)/SQRT(1. - A2)*(C3-C1*C2)/S2*
     $              (C3*C2-C1)/S2**2
	GA(3,1,5) = -CELL(1)*S2
** Ableitung nach gamma
	GA(1,2,6) = -CELL(2)*S3/S2
	GA(2,2,6) = CELL(2)/SQRT(1. - A2)*(C3-C1*C2)/S2*(S3/S2)
      else if(UNAX.eq.'r'.or.UNAX.eq.'R') then
** Ableitung nach a (die Ableitungen nach b und c sind gleich den Ableitungen
**                   nach a)
	GA(1,2,1) = sqrt(0.5)*sqrt(1.0-C1)
	GA(1,3,1) = -GA(1,2,1)
	GA(2,1,1) = -2.0*GA(1,2,1)/sqrt(3.0)
	GA(2,2,1) = -GA(2,1,1)/2.0
	GA(2,3,1) = GA(2,2,1)
	GA(3,1,1) = sqrt((C1-5.0)/3.0)
	GA(3,2,1) = GA(3,1,1)
	GA(3,3,1) = GA(3,1,1)
** Ableitung nach alpha (die Ableitungen nach beta und gamma sind gleich den
**                       Ableitungen nach alpha)
	GA(1,2,4) = CELL(1)*S1/sqrt(2.0-2.0*C1)
	GA(1,3,4) = -GA(1,2,4)
	GA(2,1,4) = -2.0*GA(1,2,4)/sqrt(3.0)
	GA(2,2,4) = -GA(2,1,4)/2.0
	GA(2,3,4) = GA(2,2,4)
	GA(3,1,4) = -CELL(1)*S1/sqrt(12.0*(C1-5.0))
	GA(3,2,4) = GA(3,1,4)
	GA(3,3,4) = GA(3,1,4)
      end if
  100 continue
      return
      end
**
      subroutine SBROT(N,PHI)
** carry out a subrotation (one part of the molecule is kept unchanged, the
** other part is rotated). N is the number of the subrotation.
** Rotation of the points RXYZ(ISUB(I,N),1), I=1,..,NATM1, around the axis,
** which is given by the directional vector
** RXYZ(ISUB(2,N),1)-RXYZ(ISUB(1,N),1). Rotation angle is PHI
** (radian measure), all coordinates are cartesian coordinates.
** The result is in RXYZ
** Version 23.02.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real RXYZ(3,NUMATM,NUSYM)
      common /RXYZ/ RXYZ
      parameter(PI=3.141592653589793d0)
      real PHI
      double precision X(3)
************************************************************************
      if(PHI.eq.0.0) goto 9999
      SPHI = sin(PHI)
      CPHI = cos(PHI)
      SA1=SUBDIR(N,1)
      SA2=SUBDIR(N,2)
      CA1=SUBDIR(N,3)
      CA2=SUBDIR(N,4)
      do 500 I=3,NATM1
** IS, not I is the actual number of the atom which is rotated!
	IS = ISUB(I,N)
	if(IS.eq.0) goto 500
	do 10 J=1,3
	  RXYZ(J,IS,1) = RXYZ(J,IS,1) - RXYZ(J,ISUB(1,N),1)
   10   continue
** b) rotation of rotation axis (together with RXYZ) onto x-axis
** 1. rotation around y-axis onto x-y-plane by angle A1
** and 2. around z-axis onto x-axis by angle A2
	X(1) = RXYZ(1,IS,1)*CA1*CA2 -
     $         RXYZ(2,IS,1)*SA2     + RXYZ(3,IS,1)*SA1*CA2
	X(2) = RXYZ(1,IS,1)*CA1*SA2 + 
     $         RXYZ(2,IS,1)*CA2     + RXYZ(3,IS,1)*SA1*SA2
	X(3) =-RXYZ(1,IS,1)*SA1     + RXYZ(3,IS,1)*CA1
	do 30 J=1,3
	  RXYZ(J,IS,1)=X(J)
   30   continue
** c) rotation around x-axis by angle PHI
	X(1) = RXYZ(1,IS,1)
	X(2) =            RXYZ(2,IS,1)*CPHI - RXYZ(3,IS,1)*SPHI
	X(3) =            RXYZ(2,IS,1)*SPHI + RXYZ(3,IS,1)*CPHI
	do 80 J=1,3
	  RXYZ(J,IS,1)=X(J)
   80   continue
** d) return rotation axis (together with RXYZ) to original direction
	X(1) = RXYZ(1,IS,1)*CA1*CA2 +
     $         RXYZ(2,IS,1)*CA1*SA2 - RXYZ(3,IS,1)*SA1
	X(2) =-RXYZ(1,IS,1)*SA2 + RXYZ(2,IS,1)*CA2
	X(3) = RXYZ(1,IS,1)*SA1*CA2 + 
     $         RXYZ(2,IS,1)*SA1*SA2 + RXYZ(3,IS,1)*CA1
	do 100 J=1,3
	  RXYZ(J,IS,1) = X(J)
  100   continue
** e) Shift back RXYZ (s. a))
	do 110 J=1,3
	  RXYZ(J,IS,1) = RXYZ(J,IS,1) + RXYZ(J,ISUB(1,N),1)
  110   continue
  500 continue
 9999 continue
      end
**
      subroutine DSBROT(N,PHI,GSB)
** calculate derivative of subrotation matrix.
** N is the number of the subrotation.
** Rotation of the points RXYZ(ISUB(I,N),1), I=1,..,NATM1, around the axis,
** which is given by the directional vector
** RXYZ(ISUB(2,N),1)-RXYZ(ISUB(1,N),1). Rotation angle is PHI
** (radian measure), all coordinates are cartesian coordinates.
** The result is in GSB
** GSB(J,I,K):  gradient of subrotation no. K of atom no. J
** Version 27.11.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real RXYZ(3,NUMATM,NUSYM)
      common /RXYZ/ RXYZ
      parameter(PI=3.141592653589793d0)
      real PHI,GSB(NUMATM,3,2)
      double precision X(3)
************************************************************************
      SPHI = sin(PHI)
      CPHI = cos(PHI)
      SA1=SUBDIR(N,1)
      SA2=SUBDIR(N,2)
      CA1=SUBDIR(N,3)
      CA2=SUBDIR(N,4)
      do 500 I=3,NATM1
** IS, not I is the actual number of the atom which is rotated!
	IS = ISUB(I,N)
	if(IS.eq.0) goto 500
        LS2 = nint(LSUB(IS)/128.0)
        LS1 = LSUB(IS) - LS2*128
        if(abs(LS1).eq.N.and.LS2.eq.0) I1=2
        if(abs(LS1).eq.N.and.LS2.ne.0) I1=1
        if(abs(LS2).eq.N.and.LS1.eq.0) I1=2
        if(abs(LS2).eq.N.and.LS1.ne.0) I1=2
	do 10 J=1,3
          GSB(IS,J,I1) = RXYZ(J,IS,1) - RXYZ(J,ISUB(1,N),1)
   10   continue
** b) rotation of rotation axis (together with RXYZ/GSB) onto x-axis
** 1. rotation around y-axis onto x-y-plane by angle ALPHA1
** and 2. around z-axis onto x-axis by angle ALPHA2
        X(2) = GSB(IS,1,I1)*CA1*SA2 + 
     $         GSB(IS,2,I1)*CA2     + GSB(IS,3,I1)*SA1*SA2
        X(3) =-GSB(IS,1,I1)*SA1     + GSB(IS,3,I1)*CA1
	do 30 J=2,3
          GSB(IS,J,I1)=X(J)
   30   continue
** c) derivative of rotation around x-axis by angle PHI
	X(1) = 0.0
        X(2) =           -GSB(IS,2,I1)*SPHI - GSB(IS,3,I1)*CPHI
        X(3) =            GSB(IS,2,I1)*CPHI - GSB(IS,3,I1)*SPHI
	do 80 J=2,3
          GSB(IS,J,I1)=X(J)
   80   continue
** d) return rotation axis (together with XYZC/GSB) to original direction
        X(1) = GSB(IS,2,I1)*CA1*SA2 - GSB(IS,3,I1)*SA1
        X(2) = GSB(IS,2,I1)*CA2
        X(3) = GSB(IS,2,I1)*SA1*SA2 + GSB(IS,3,I1)*CA1
	do 90 J=1,3
          GSB(IS,J,I1) = X(J)
   90   continue
  500 continue
 9999 continue
      end

      function VDWVOL(K)
** THIS SUBROUTINE CALCULATES THE VOLUME OF MOLECULE/ION NO. K,
** I.E., THE SUM OF THE VOLUMES OF THE VAN DER WAALS SPHERES.
** SEE: Kitaigorodski, Molekuelkristalle, Berlin 1979, p. 21/22
** Version 21.11.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      integer IBO(0:8,NUMATM)
      common /BOND/ IBO
      parameter(PI=3.14159265)
      VDWVOL=0.0
      do 10 I=1,NATM1
	if(ICLUS(I).ne.K) goto 10
	VOL=4.0/3*PI*VWR(I)**3
** Calculation of the overlap with all binding partners
	do 20 J=1,IBO(0,I)
** A: distance to binding partner
** B: VdW radius of atom I
** C: VdW radius of binding partner
	  A=DIS(I,IBO(J,I))
	  B=VWR(I)
	  C=VWR(IBO(J,I))
	  if(A.lt.0.01) then
	    goto 20
	  end if
** complete overlap by binding partner
	  if(C.gt.A+B) then
	    VOL=0.0
** partial or no overlap with binding partner
	  else if(C.le.A+B.and.B.le.A+C) then
	    H=B-(B**2+A**2-C**2)/(2*A)
	    if(H.gt.0.0) VOL=VOL-PI*H**2.0*(3*B-H)/3.0
	  end if
   20   continue
	VDWVOL=VDWVOL+VOL
   10 continue
      return
      end

      subroutine DUMP
** THIS SUBROUTINE WRITES THE VALUES OF ALL VARIABLES OF THE COMMON BLOCK
** AND THE COMMON /PARA/ BLOCK TO THE FILE DUMP.OUT
** Version 22.09.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real X0(NV),X(NV), RPA(25),ATVOL
      integer NVAR, IPA(25)
      common /OPTI/ NVAR,X0,X,IPA,RPA,ATVOL
************************************************************************
      open(unit=11,file='dump.out',err=9999,status='unknown')
      print*,'writing to dump.out...'
      write(11,'(6(1x,a,i10))',err=9999) 'NUMATM=',NUMATM,
     $ 'NUSYM=',NUSYM,'NUCLUS=',NUCLUS,'NPOTL=',NPOTL,'NV=',NV,'NUSUB=',
     $ NUSUB
      write(11,'(1x,a,l1)') 'SPEC=',SPEC
      write(11,'(4(1x,a,i10))',err=9999) 'NCH=',NCH,
     $                            'NATM1=',NATM1,'NCLUS=',NCLUS,'NS=',NS
      write(11,'(a/15(i4))',err=9999) 'ICLUS=',ICLUS
      write(11,'(a/15(i4))',err=9999) 'LSUB=',LSUB
      write(11,'(a/15(i4))',err=9999) 'ISPC=',ISPC
      write(11,'(2(1x,a,i4))',err=9999) 'NSUB=',NSUB,'NPOT=',NPOT
      write(11,'(1x,a,3i3)') 'ICENT=',ICENT
      I1=1
      do 70 I=NUMATM,1,-1
        do 70 J=1,NUSUB
          if(ISUB(I,J).ne.0) then
            I1=I
            goto 75
          end if
   70 continue
   75 continue
      write(11,'(a/8(i4,:))',err=9999) 'ISUB=',
     $                                ((ISUB(I,J),J=1,NUSUB),I=1,I1)
      if(I1.ne.0) write(11,'(a)') 'all other elements are zero'
      write(11,'(a/18(i4))',err=9999) 'IVAR=',IVAR
      write(11,'(a/18(i4))',err=9999) 'IPAR=',IPAR
      I1=NUMATM
      do 90 I=NUMATM,1,-1
	if(PTYP(I).ne.0) then
	  I1=I
	  goto 95
	end if
   90 continue
   95 continue
      write(11,'(a/15(i4))',err=9999) 'PTYP=',(PTYP(I),I=1,I1)
      if(I1.ne.NUMATM) write(11,'(a)') 'all other elements are zero'
      I1=NUMATM
      do 100 I=NUMATM,1,-1
	if(VWR(I).ne.0.0) then
	  I1=I
	  goto 105
	end if
  100 continue
  105 continue
      write(11,'(a/5(1pe14.6))',err=9999) 'VWR=',(VWR(I),I=1,I1)
      if(I1.ne.NUMATM) write(11,'(a)') 'all other elements are zero'
      I1=NUCLUS
      do 110 I=NUCLUS,1,-1
	if(MXR(I).ne.0.0) then
	  I1=I
	  goto 115
	end if
  110 continue
  115 continue
      write(11,'(a/5(1pe14.6))',err=9999) 'MXR=',(MXR(I),I=1,I1)
      if(I1.ne.NUCLUS) write(11,'(a)') 'all other elements are zero'
      write(11,'(a/1pe14.6)',err=9999) 'HMIN=',HMIN
      I1=1
      do 120 I=NUMATM,1,-1
	if(Q(I).ne.0.0) then
	  I1=I
	  goto 125
	end if
  120 continue
  125 continue
      write(11,'(a/5(1pe14.6))',err=9999) 'Q=',(Q(I),I=1,I1)
      if(I1.ne.NUMATM) write(11,'(a)') 'all other elements are zero'
      K1=4
      do 130 K=4,1,-1
	do 130 J=1,NPOTL
	  do 130 I=1,NPOTL
	    if(POT(I,J,K).ne.0.0) then
	      K1=K
	      goto 135
	    end if
  130 continue
  135 continue
      do 140 K=1,K1
	write(11,'(a,i1,a/5(1pe14.6))',err=9999) 'POT(I,J,',K,')=',
     $                           ((POT(I,J,K),J=1,NPOTL),I=1,NPOTL)
  140 continue
      if(K1.ne.4) write(11,'(a)') 'all other elements are zero'
      write(11,'(a/3(1pe14.6))',err=9999) 'SPOT=',SPOT
      write(11,'(a,1pe14.6)',err=9999) 'PRESS=',PRESS
      write(11,'(a,3(1pe14.6)/3(1pe14.6))',err=9999) 'CELL=',CELL
      M1=1
      do 340 M=NUSYM,1,-1
        do 340 J=1,3
          if(T(M,J).ne.0.0) then
            M1=M
            goto 345
          end if
  340 continue
  345 continue
      write(11,'(a/3(1pe14.6))',err=9999) 'T=',
     $                                   ((T(I,J),J=1,3),I=1,M1)
      if(M1.ne.NUSYM) write(11,'(a)') 'all other elements are zero'
      M1=1
      do 350 M=NUSYM,1,-1
        do 350 J=1,3
          do 350 K=1,3
            if(R(M,J,K).ne.0.0) then
              M1=M
              goto 355
            end if
  350 continue
  355 continue
      do 30 I=1,M1
        write(11,'(a,i2,a/9(i4))',err=9999) 
     $                             'R(',I,')=',((R(I,J,K),J=1,3),K=1,3)
   30 continue
      if(M1.ne.NUSYM) write(11,'(a)') 'all other elements are zero'
      write(11,'(a/18(i4))') 'ISYM=',ISYM
      I1=1
      do 420 L=NUCLUS,1,-1
        do 420 M=1,NUSYM
          if(SPC(M,L).ne.' ') then
            I1=L
            goto 425
          end if
  420 continue
  425 continue
      do 40 L=1,I1
        write(11,'(a,i2,a/12(a6))') 'SPC(M,',L,')=',(SPC(M,L),M=1,NUSYM)
   40 continue
      if(I1.ne.NUCLUS) write(11,'(a)') 'all other elements are empty'
      I1=NUMATM
      do 430 I=NUMATM,1,-1
        do 430 J=1,3
          if(XYZC(I,J).ne.-999.0) then
            I1=I
            goto 435
          end if
  430 continue
  435 continue
      write(11,'(a/3(1pe14.6))',err=9999) 'XYZC=',
     $                                 ((XYZC(I,J),J=1,3),I=1,I1)
      if(I1.ne.NUMATM) write(11,'(a)') 'all other elements are empty'
      write(11,'(a/3(1pe14.6))',err=9999) 'XYZS=',
     $                                 ((XYZS(L,J),J=1,3),L=1,NUCLUS)
      write(11,'(a/3(1pe14.6))',err=9999) 'ROT=',
     $                                 ((ROT(L,J),J=1,3),L=1,NUCLUS)
      write(11,'(a/5(1pe14.6))',err=9999) 'SUBROT=',SUBROT
      M1=NUSYM
      do 380 M=NUSYM,1,-1
	do 370 L=1,NUCLUS
	  do 360 J=1,3
            if(XYZSC(J,L,M).ne.0.0) then
	      M1=M
	      goto 385
	    end if
  360     continue
  370   continue
  380 continue
  385 continue
      do 390 M=1,M1
	write(11,'(a,i2,a/3(1pe14.6))',err=9999) 'XYZSC(',M,')=',
     $                                ((XYZSC(J,L,M),J=1,3),L=1,NUCLUS)
  390 continue
      if(M1.ne.NUSYM) write(11,'(a)') 'all other elements are empty'
      I1=NUMATM
      do 400 I=NUMATM,1,-1
	if(ATNAME(I).ne.' ') then
	  I1=I
	  goto 405
	end if
  400 continue
  405 continue
      write(11,'(a/8(a,1x))') 'ATNAME=',(ATNAME(I),I=1,I1)
      write(11,'(a)') 'all other elements are empty'
      write(11,'(2a)') 'PTNAME= ',PTNAME
      write(11,'(a/18(a,1x))') 'PNAM=',PNAM
      write(11,'(4a)') 'SPG= ',SPG,' UNAX= ',UNAX
      I1=NUSYM
      do 410 I=NUSYM,1,-1
        if(SYMMLS(I).ne.' ') then
	  I1=I
          goto 415
	end if
  410 continue
  415 continue
      write(11,'(a)') 'SYMMLS= ',(SYMMLS(I),I=1,I1)
      write(11,'(a)') 'all other elements are empty'
      write(11,'(2a)') 'TITLE= ',TITLE
      write(11,'(a,1pe14.6,1x,a,3i4)') 'SUMR= ',SUMR,'ISUM= ',ISUM
      write(11,'(a/5(1pe14.6))',err=9999) 'X0=',X0
      write(11,'(a/5(1pe14.6))',err=9999) 'X=',X
      write(11,'(a/5(1pe14.6))',err=9999) 'RPA=',RPA
      write(11,'(a/5(i8))',err=9999) 'IPA=',IPA
      write(11,'(a,i8,3x,a,1pe14.6)') 'NVAR=',NVAR,'ATVOL=',ATVOL
 9999 continue
      close(unit=11)
      end

      subroutine CONTCT(NCONTC,VOL)
**** THIS FUNCTION CALCULATES THE MAXIMUM NUMBER OF INTERMOLECULAR CONTACTS 
**** USED BY ENERGY CALCULATION
**** Version 24.08.97
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      integer NCONTC, IC1,IC2,IC3,M2
      logical SAMASY
      NCONTC=0
      IF(SUMR.gt.0.0) then
	SA=sin(CELL(4))
	SB=sin(CELL(5))
	SC=sin(CELL(6))
	HA=VOL/(CELL(2)*CELL(3)*SA)
	HB=VOL/(CELL(1)*CELL(3)*SB)
	HC=VOL/(CELL(1)*CELL(2)*SC)
	ISUM(1)=int((SUMR-HA/2.0)/HA+1.0)
	ISUM(2)=int((SUMR-HB/2.0)/HB+1.0)
	ISUM(3)=int((SUMR-HC/2.0)/HC+1.0)
      end if
      do 250 IC1=-ISUM(1),ISUM(1)
      do 240 IC2=-ISUM(2),ISUM(2)
      do 230 IC3=-ISUM(3),ISUM(3)
	do 210 M2=1,NS
	  SAMASY=(M2.eq.1.and.IC1.eq.0.and.IC2.eq.0.and.IC3.eq.0)
	  do 200 L1=1,NCLUS
	    do 190 L2=1,NCLUS
	      if(SAMASY.and.L1.gt.L2) goto 190
	      do 185 MM=1,ISPC(L2)
		read(SPC(MM,L2),'(i2)') MM2
		if(MM2.eq.M2) goto 190
  185         continue
	      do 120 I=1,NATM1
		if(ICLUS(I).ne.L1) goto 120
		LS2 = nint(LSUB(I)/128.0)
		LS1 = LSUB(I)-LS2*128
		do 110 J=1,NATM1
		  if(ICLUS(J).ne.L2) goto 110
		  LS4 = nint(LSUB(J)/128.0)
		  LS3 = LSUB(J)-LS4*128
**               do not compare molecule/ion L1 with itself, except in the
**               case of subrotations
		  if(SAMASY.and.L1.eq.L2) then
		    if(LS1.eq.LS3) goto 110
                    if((LS1.lt.0..or.LS2.lt.0..or.
     $                  LS3.lt.0..or.LS4.lt.0.).and.
     $                (abs(LS1).eq.abs(LS3).or.abs(LS2).eq.abs(LS4).or.
     $                 abs(LS1).eq.abs(LS4).or.abs(LS2).eq.abs(LS3)))
     $                                                          goto 110
                    if(abs(LS1).gt.abs(LS3)) goto 110
		  end if
		  NCONTC=NCONTC+1
  110           continue
  120         continue
  190       continue
  200     continue
  210   continue
  230 continue
  240 continue
  250 continue
 9999 continue
      end
*
      subroutine BONDMA
** CALCULATES BOND MATRIX
** Version 22.02.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      real DIS
** IBO(0,I) contains the number of atoms bonded to atom no. I
** IBO(J,I) contains the number of the atom bonded to atom no. I
      INTEGER IBO(0:8,NUMATM),ATNO, I1,J1
      COMMON /BOND/ IBO  
      REAL BDRD(100),R1,R2
C * COVALENT BOND RADII 
C * (VCH Verlagsgesellschaft mbH, Periodensystem der Elemente)
      DATA (BDRD(L),L=1,100) /
     $ 0.40, 0.00, 1.23, 0.89, 0.81, 0.77, 0.70, 0.66, 0.64, 0.00,
     $ 1.57, 1.36, 1.25, 1.17, 1.10, 1.04, 0.99, 0.00, 2.03, 1.74,
     $ 1.44, 1.32, 1.22, 1.18, 1.18, 1.16, 1.16, 1.15, 1.17, 1.25,
     $ 1.25, 1.22, 1.21, 1.17, 1.14, 0.00, 2.16, 1.91, 1.62, 1.45,
     $ 1.34, 1.30, 1.27, 1.25, 1.25, 1.28, 1.34, 1.41, 1.50, 1.40,
     $ 1.41, 1.37, 1.33, 0.00, 2.53, 1.98, 1.69, 1.65, 1.65, 1.64,
     $ 1.63, 1.62, 1.85, 1.61, 1.59, 1.59, 1.58, 1.57, 1.56, 1.74,
     $ 1.56, 1.44, 1.34, 1.30, 1.28, 1.26, 1.27, 1.30, 1.34, 1.44,
     $ 1.55, 1.54, 1.46, 1.46, 1.45, 0.00, 0.00, 0.00, 0.00, 1.65,
     $ 0.00, 1.42, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00/
C             
C  *******************
      DO 210 I=1,NATM1
	IBO(0,I)=0
	DO 200 J=1,NATM1
	  IF(I.EQ.J.OR.ICLUS(I).NE.ICLUS(J)) GO TO 200 
C     IF BONDING CONDITION FOUND: 
C     STORE J IN IBO ARRAY 
	  I1=ATNO(ATNAME(I))
	  J1=ATNO(ATNAME(J))
	  if(I1.ne.0) R1=BDRD(I1)
	  if(J1.ne.0) R2=BDRD(J1)
	  if(I1.eq.0) R1=0.0
	  if(J1.eq.0) R2=0.0
	  if(DIS(I,J).lt.1.1*(R1+R2)) then
	    IF(IBO(0,I).GE.8) THEN
	      PRINT *,'MORE THAN 8 BONDS FOR ATOM ',ATNAME(I)
	      GO TO 210
	    END IF
	    IBO(0,I)=IBO(0,I)+1
	    IBO(IBO(0,I),I)=J
	  end if
  200   continue 
  210 continue
      end

      subroutine BONDL(LABEL1,LABEL2,BL)
** Change bond distance between the atoms LABEL1 and LABEL2
** Version 02.03.96
************************************************************************
** VARIABLES IN THE COMMON BLOCK:
** ATNAME(I)    c name of atom no. I
** ICENT(J)     i centricity code (1,1,1: inversion center, 1,1,0: 2-fold
**                axis, 1,0,0: mirror plane)
** ICLUS(I)     i number of the molecule/ion of atom no. I
** IPAR(K)      i parameter number of variable no. K
**                Sometimes one variable corresponds to more than one 
**                parameter. In this case IPAR(K) is only one of those 
**                parameters.
** ISPC(L)      i number of symmetry operations which can reproduce 
**                position of molecule/ion no. L
** ISUB(L,N)    i number of Lth atom taking part in Nth subrotation
** ISYM(K)      i number of symmetry dependent orientation of symmetry
**                operation no. K. ISYM(K)<0: molecules must be inverted
** IVAR(I)      i negativ: parameter no. I is negative variable no. -IVAR(I)
**                positiv: parameter no. I is variable no. IVAR(I)
**                zero: parameter no. I is fixed
**                -9999: parameter no. I does not exist
**                Parameters from I=1 to I=6 are cell constants.
**                Parameters from (NUCLUS+1)*6+1 to (NUCLUS+1)*6+NUSUB are
**                subrotations
** LSUB(I)      i no. of the subrotation including atom no. I
**                The atom can be part of 2 subrotations. Therefore LSUB
**                consists of 2 contributions: N1+128*N2. N2 is always the
**                higher subrotating group.
**                0: atom no. I does not take part in any subrotation
**                N1/N2 negativ: atom no. I is one of the two subrotation 
**                defining atoms. These atoms connect group -N1 with group -N2.
** HMIN         r minimum height of the unit cell
** MXR(L)       r maximum radius of molecule/ion no. L (+ van der Waals radius)
** NATM1        i number of atoms in asymmetric unit
** NCH          i number of charges in unit cell
** NCLUS        i number of molecules/ions in asymmetric unit (different 
**                from the constant NUCLUS!)
** NPOT         i number of atom types
** NS           i number of equivalent positions (number of symmetries)
** NSUB         i number of subrotations
** PNAM(M)      c name of atom type no. M
** POT(I,J,K)   r potential parameters for atom type pair I,J, K=1..4
** PRESS        r pressure on the crystal measured in Pa
** PTNAME       c name of potential (12-6, 9-6 ...)
** PTYP(I)      i atom type of atom no. I
** Q(I)         r charge of atom no. I measured in e
** R(K,J,L)     i rotational part of symmetry operation no. K (crystal
**                coordinate system)
** RM(I)        r relative mass of atom no. I
** RN(N,J,L)    r rotational part of symmetry operation (cartesian
**                coordinate system, N=ISYM(K), K=number of symmetry
**                operation)
** SPC(M,L)     c symmetry operation no. M to reproduce position of
**                molecule/ion no. L (special position), e.g. '4556'
** SPEC         l .true.: some atoms are on special positions
** SPG          c space group name
** SPOT(I,K)    r parameters for surface potential
** T(K,J)       r translational part of symmetry operation no. K (crystal
**                coordinate system)
** TITLE        c title of the problem
** UNAX:        c unique axis (a, b, c, r)
** VWR(I)       r VdW radius of atom no. I
** XYZC(I,J)    r coordinates of atom no. I (cartesian, origin in center 
**                of the molecule/ion)
** XYZSC(J,L,M) r coordinates of center of molecule/ion no. L (cartesian)
**                M: number of symmetry operation
************************************************************************
** CONSTANTS:
** NUMATM i max. number of atoms in asymmetric unit
** NUSYM  i max. number of symmetry operations
** NUCLUS i max. number of molecules/ions in asymmetric unit
** NPOTL  i max. number of different atom types
** NV     i max. number of variables
** NUSUB  I max. number of subrotations
************************************************************************
      implicit real (a-h,o-z)
      parameter(NUMATM=200,NUSYM=24,NUCLUS=16,NPOTL=16,NV=36,NUSUB=8)
      integer ICENT(3), ISYM(NUSYM), NCH, NPOT
      integer ICLUS(NUMATM),ISUB(NUMATM,NUSUB),LSUB(NUMATM)
      integer NATM1,NCLUS,NS, NSUB, ISPC(NUCLUS), R(NUSYM,3,3)
      integer IVAR((NUCLUS+1)*6+NUSUB),IPAR(NV),PTYP(NUMATM)
      real RM(NUMATM),MXR(NUCLUS),HMIN, VWR(NUMATM)
      real POT(NPOTL,NPOTL,4), SPOT(NPOTL,3), Q(NUMATM)
      real PRESS, RN(NUSYM/4,3,3), T(NUSYM,3)
      real XYZC(NUMATM,3), XYZSC(3,NUCLUS,NUSYM)
      character ATNAME(NUMATM)*8, PTNAME*8,PNAM(NPOTL)*4
      character SPG*8, SYMMLS(NUSYM)*33, UNAX*1
      character SPC(NUSYM,NUCLUS)*5, TITLE*72
      logical CELLOK, SPEC
      common NATM1,NCLUS,ICENT,
     $       XYZC, HMIN, MXR,Q, NCH, POT, PRESS, SPOT,
     $       ICLUS,LSUB,XYZSC, IVAR,IPAR, ISUB, ISYM, ISPC,
     $       NPOT, NSUB, NS, T, R, RM, RN, VWR, PTYP, PNAM, SPEC,
     $       CELLOK, ATNAME,SPG,UNAX,SPC,PTNAME,SYMMLS,TITLE

** VARIABLES IN THE COMMON /PARA/ BLOCK:
** CELL(J)       r cell constants to be used for packing (angles in rad. meas.)
** ISUM(J)       i number of neigbouring cells to be used for energy 
**                 calculation
** ROT(L,K)      r rotation angles for cluster no. L (radian measure)
** RMIN(L)       r minimum radius of molecule/ion no. L (Angstroms)
** SHIFT         l allows the subroutines FOPT and GOPT to shift all
**                 molecules into the central unit cell (SHIFT=.true.)
** SUBDIR(K,J)   r direction of rotation axis for subrotation no. K
**                 J=1,..4: sin(A1), sin(A2), cos(A1), cos(A2)
**                 A1: angle to rotate rotation axis onto x-y-plane by y-axis
**                 A2: angle to rotate rotation axis onto x-axis by z-axis
** SUBROT(K)     r subrotation angle no. K (radian measure)
** SUMR          r summation radius for energy calculation
** XYZS(L,J)     r coordinates of center of molecule/ion no. L (fractional)
      real CELL(6), ROT(NUCLUS,3), SUBROT(NUSUB), XYZS(NUCLUS,3)
      real RMIN(NUCLUS), SUBDIR(NUSUB,4), SUMR
      integer ISUM(3)
      logical SHIFT
      common /PARA/ CELL, XYZS, ROT, RMIN, SUBROT, SUBDIR, SUMR, ISUM,
     $              SHIFT
************************************************************************
      character LABEL1*8,LABEL2*8
      I1=0
      I2=0
      do 10 I=1,NATM1
	if(LABEL1.eq.ATNAME(I)) I1=I
	if(LABEL2.eq.ATNAME(I)) I2=I
   10 continue
      if(I1.eq.I2) then
	write(2,'(/1x,2a/)') 'WARNING - CANNOT CHANGE BOND LENGTH OF',
     $                       ' 2 IDENTICAL ATOMS.'
	write(*,'(/1x,2a/)') 'WARNING - CANNOT CHANGE BOND LENGTH OF',
     $                       ' 2 IDENTICAL ATOMS.'
	goto 999
      end if
      if(I1.eq.0.or.I2.eq.0) then
	write(2,'(/1x,2a,1x,2a/)') 'WARNING - BOND ',
     $                        LABEL1,LABEL2,' NOT FOUND.'
	write(*,'(/1x,2a,1x,2a/)') 'WARNING - BOND ',
     $                        LABEL1,LABEL2,' NOT FOUND.'
	goto 999
      end if
      D=DIS(I1,I2)
      if(D.gt.1.5*(VWR(I1)+VWR(I2))) then
	write(2,'(/1x,2a,1x,a,f10.5/)')
     $                'WARNING - EXTREMELY LONG BOND: ',LABEL1,LABEL2,D
	write(*,'(/1x,2a,1x,a,f10.5/)')
     $                'WARNING - EXTREMELY LONG BOND: ',LABEL1,LABEL2,D
      end if
      do 20 J=1,3
	XYZC(I2,J)=XYZC(I1,J)+BL/D*(XYZC(I2,J)-XYZC(I1,J))
   20 continue
  999 continue
      end
      subroutine GRDSRC(F,FC,FD,FR,IPAR,STEP,ISTP,ILOOP,ILOOP2)
** Optimization according to the Grid Search Method.
** The maximum number of parameters is 12.
** Version 05.10.97
**
** Variablen:
** X(I)    real   Parameter (vorgegeben)
** Y(I)    real   Parameter (optimiert)
** F       real   Zielfunktionswert
** F2      real   aktueller Zielfunktionswert
** FMIN    real   bisher minimaler Zielfunktionswert
** NV      int    Zahl der Variablen
** IFZMAX  int    maximale Zahl von Zielfunktionswerten
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1,2,4: Eingabewert und Endergebnis
**                2 (def.): wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
**                4: wie 2, jedoch noch zusaetzliche Groessen
** IOUT    int    Ausgabeeinheit (def.: 2)
** IRET    int    -1: Funktionswert nicht definiert
**                1,2: Abbruch der Optimierung durch FOPT
**                11: Abbruch durch ITMAX
**                12: Abbruch durch IFZMAX
** IFZ     int    Zahl der bisherigen Zielfunktionsauswertungen
** STEP(I) real   step width of variable no I
** ISTP(I) int    number of steps of variable no I
**
** Unterprogramme:
** FOPT: Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NUCLUS=16,PI=3.1415926,NV=36,NUSUB=8)
      real X(NV),Y(NV),RPA(25)
      integer IPA(25)
      real FM(16,4),PARM(16,NV),STEP(12),FAKT(12)
      integer ISTP(12)
      integer IPAR(NV)
      character PNAME(NUCLUS*6+6)*8,RNAME(NUSUB)*8,PN*8
      common /OPTI/ NVAR,X,Y,IPA,RPA,ATVOL
      common /PARNAM/ PNAME,RNAME
      IPR=IPA(3)
      IOUT=IPA(4)
      F=1.11111e-11
      IRET=0
** Funktionsaufruf F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      FMIN=F
      IFZ=0
** copy parameter set X to Y
      do 80 I=1,NVAR
        Y(I)=X(I)
   80 continue
      IFZMAX=1
      do 90 I=1,12
        I6=mod(IPAR(I),6)
        FAKT(I)=1.0
        if(IPAR(I).gt.6.and.IPAR(I).le.(NUCLUS+1)*6.and.
     $                            (I6.eq.4.or.I6.eq.5.or.I6.eq.0)) then
          STEP(I)=STEP(I)/180.*PI
          FAKT(I)=180/PI
        end if
        if(IPAR(I).gt.(NUCLUS+1)*6) then
          STEP(I)=STEP(I)/180.*PI
          FAKT(I)=180/PI
        end if
        if(ISTP(I).gt.0) then
          IFZMAX=IFZMAX*ISTP(I)
        else
          ISTP(I)=1
        end if
   90 continue
      write(*,'(1x,a,i8,a,i3,a,i3)') 
     $       'Grid Search, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
      if(IPR.ne.3) then
        write(IOUT,71) 'NV','IFZMAX','IPR',NVAR,IFZMAX,IPA(3)
   71   format(/' ** Grid Search Optimization **'//3a10/3i10/)
        write(IOUT,'(a8,a12,a4,2a12)') ' Var. ',' Stepwidth ','Istp',
     $                                 '  Varmin  ','  Varmax  '
        do 100 I=1,12
          if(IPAR(I).eq.0) goto 100
          if(IPAR(I).le.(NUCLUS+1)*6) then
            PN=PNAME(IPAR(I))
          else
            PN=RNAME(IPAR(I)-(NUCLUS+1)*6)
          end if
          if(abs(STEP(I)).gt.0.0) then
            write(IOUT,'(a8,1pe12.5,i4,2(1pe12.5))') PN,FAKT(I)*STEP(I),
     $                 ISTP(I),FAKT(I)*(X(I)+(1-(ISTP(I)+1)/2)*STEP(I)),
     $                   FAKT(I)*(X(I)+(ISTP(I)-(ISTP(I)+1)/2)*STEP(I))
          end if
  100   continue
      end if
      if(IPR.ne.3) write(IOUT,'(/1x,a12,1x,a7,a12)') 'F(X)',
     $                                                'IFZ','X(1)...'
      if(IPR.ne.3) write(IOUT,501) FMIN,IFZ,(X(I),I=1,NVAR)

      IRET=0

  300 continue
      write(IOUT,*)
      NM=0
      FMAX=FMIN
      if(IPAR(1).le.(NUCLUS+1)*6) PN=PNAME(IPAR(1))
      if(IPAR(1).gt.(NUCLUS+1)*6) PN=RNAME(IPAR(1)-(NUCLUS+1)*6)
      do 430 I1=1,ISTP(1)
       Y(1)=X(1)+(I1-(ISTP(1)+1)/2)*STEP(1)
       write(*,'(1x,a,2(a,1pg13.5),a,i2)') PN,'=',FAKT(1)*Y(1),
     $                             ' FMIN=',FMIN,' before Step no.',I1
       do 420 I2=1,ISTP(2)
        Y(2)=X(2)+(I2-(ISTP(2)+1)/2)*STEP(2)
        do 410 I3=1,ISTP(3)
         Y(3)=X(3)+(I3-(ISTP(3)+1)/2)*STEP(3)
         do 400 I4=1,ISTP(4)
          Y(4)=X(4)+(I4-(ISTP(4)+1)/2)*STEP(4)
          do 390 I5=1,ISTP(5)
           Y(5)=X(5)+(I5-(ISTP(5)+1)/2)*STEP(5)
           do 380 I6=1,ISTP(6)
            Y(6)=X(6)+(I6-(ISTP(6)+1)/2)*STEP(6)
            do 370 I7=1,ISTP(7)
             Y(7)=X(7)+(I7-(ISTP(7)+1)/2)*STEP(7)
             do 360 I8=1,ISTP(8)
              Y(8)=X(8)+(I8-(ISTP(8)+1)/2)*STEP(8)
              do 350 I9=1,ISTP(9)
               Y(9)=X(9)+(I9-(ISTP(9)+1)/2)*STEP(9)
               do 340 I10=1,ISTP(10)
                Y(10)=X(10)+(I10-(ISTP(10)+1)/2)*STEP(10)
                do 330 I11=1,ISTP(11)
                 Y(11)=X(11)+(I11-(ISTP(11)+1)/2)*STEP(11)
                 do 320 I12=1,ISTP(12)
                  Y(12)=X(12)+(I12-(ISTP(12)+1)/2)*STEP(12)
** Funktionsaufruf F2(Y)
                  call FOPT(F2,FC,FD,FR,Y,VOL,IRET)
                  IFZ=IFZ+1
                  if(NM.lt.16) then
                    NM=NM+1
                    FM(NM,1)=F2
                    FM(NM,2)=FC
                    FM(NM,3)=FD
                    FM(NM,4)=FR
** copy parameter set to PARM
                    do 305 I=1,NVAR
                      PARM(NM,I)=Y(I)
  305               continue
                    call SORT(NM,FM,IMIN,IMAX,FMIN,FMAX)
                  else if(F2.lt.FMAX) then
                    FM(IMAX,1)=F2
                    FM(IMAX,2)=FC
                    FM(IMAX,3)=FD
                    FM(IMAX,4)=FR
** copy parameter set to PARM
                    do 310 I=1,NVAR
                      PARM(IMAX,I)=Y(I)
  310               continue
                    if((IPR.eq.2.or.IPR.eq.4).and.F2.lt.FMIN) 
     $                            write(IOUT,501) F2,IFZ,(Y(I),I=1,NVAR)
                    call SORT(NM,FM,IMIN,IMAX,FMIN,FMAX)
                  end if
  320            continue
  330           continue
  340          continue
  350         continue
  360        continue
  370       continue
  380      continue
  390     continue
  400    continue
  410   continue
  420  continue
  430 continue
      if(IRET.gt.0) then
        IRET=2
        goto 500
      end if
  500 continue
      do 510 I=1,NVAR
        Y(I)=PARM(IMIN,I)
  510 continue
      F=FM(IMIN,1)
      FC=FM(IMIN,2)
      FD=FM(IMIN,3)
      FR=FM(IMIN,4)
      if(IPR.ne.3) then
        write(IOUT,'(/1x,a)') 'Lowest energies:'
        write(IOUT,'(5x,a)') 'F(X)        X(1)...'
        do 530 I=1,NM
          do 525 K=NM-1,I,-1
            if(FM(K,1).gt.FM(K+1,1)) then
              do 520 L=1,NVAR
                DUM=PARM(K,L)
                PARM(K,L)=PARM(K+1,L)
                PARM(K+1,L)=DUM
  520         continue
              do 515 L=1,4
                DUM=FM(K,L)
                FM(K,L)=FM(K+1,L)
                FM(K+1,L)=DUM
  515         continue
            end if
  525     continue
          write(IOUT,503) I,FM(I,1),(FAKT(J)*PARM(I,J),J=1,NVAR)
  530   continue
  501   format(1x,1pe12.5,1x,i7,4(1pe12.5,:)/(21x,4(1pe12.5,:)))
  503   format(1x,i3,1x,1pe12.5,5(1pe12.5,:)/(17x,5(1pe12.5,:)))
      end if
      IPA(14)=IRET
      IPA(15)=IFZ
      return
      end

      subroutine SORT(NM,FM,IMIN,IMAX,FMIN,FMAX)
** Look for the lowest and largest F value in FM(I,1)
      implicit real(a-h,o-z)
      real FM(16,4),FMIN,FMAX
      FMIN=1e30
      FMAX=-1e30
      do 10 I=1,NM
        if(FM(I,1).gt.FMAX) then
          FMAX=FM(I,1)
          IMAX=I
        end if
        if(FM(I,1).lt.FMIN) then
          FMIN=FM(I,1)
          IMIN=I
        end if
   10 continue
      end

      subroutine MAP(IPAR,STEP,ISTP,FNAME)
** This program prints the energy in dependence of 1 or 2 parameters.
** The maximum number of parameters is 2.
** Version 26.09.97
**
** Variablen:
** X(I)    real   Parameter (vorgegeben)
** Y(I)    real   Parameter (Kopie)
** F       real   Zielfunktionswert
** FMIN    real   bisher minimaler Zielfunktionswert
** FMAX    real   bisher maximaler Zielfunktionswert
** NV      int    Zahl der Variablen
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Datei
**                2,4: wie 1, zusaetzlich Ausgabe einer Map bzw. Kurve
**                3: nur Datei
** IOUT    int    Ausgabeeinheit (def.: 2)
** IRET    int    -1: Funktionswert nicht definiert
**                1,2: Abbruch der Optimierung durch FOPT
**                11: Abbruch durch ITMAX
** IFZ     int    Zahl der bisherigen Zielfunktionsauswertungen
** STEP(I) real   Schrittweite
** ISTP(I) int    Zahl der Schritte pro Variabler
**
** Unterprogramme:
** FOPT: Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NUCLUS=16,PI=3.1415926,NV=36,NUSUB=8)
      real X(NV),Y(NV),RPA(25),FAKT(2)
      real FMAP(64,64),STEP(12)
      integer IPA(25),ISTP(12),IPAR(NV),IPR,IOUT,IRET
      character MARK(64)*1,CODE*18,LINE*80,NUM*10
      character PNAME(NUCLUS*6+6)*8,RNAME(NUSUB)*8,PN(2)*8
      character FNAME*40, SPACE*40
      common /OPTI/ NVAR,X,Y,IPA,RPA,ATVOL
      common /PARNAM/ PNAME,RNAME
      IPR=IPA(3)
      IOUT=IPA(4)
      CODE='.0123456789ABCDEF*'
      SPACE='                                       '
      LINE=SPACE//SPACE
      IRET=0
** copy variable set X to Y
      do 80 I=1,NVAR
        Y(I)=X(I)
   80 continue
      do 90 I=1,2
        I6=mod(IPAR(I),6)
        FAKT(I)=1.0
        if(IPAR(I).gt.6.and.IPAR(I).le.(NUCLUS+1)*6.and.
     $                            (I6.eq.4.or.I6.eq.5.or.I6.eq.0)) then
          STEP(I)=STEP(I)/180.*PI
          FAKT(I)=180.0/PI
        end if
        if(IPAR(I).gt.(NUCLUS+1)*6) then
          STEP(I)=STEP(I)/180.*PI
          FAKT(I)=180.0/PI
        end if
        if(ISTP(I).le.0) then
          ISTP(I)=1
        end if
   90 continue
      IFN=index(FNAME,' ')
      open(unit=4,file=FNAME(:IFN-1)//'.map',status='unknown',
     $     form='unformatted',err=465)
      close(unit=4)
      if(NVAR.gt.2) then
        write(IOUT,'(/1x,a/)') 'WARNING - MORE THAN 2 VARIABLES IN'// 
     $                         ' MAP.'
        write(*,'(/1x,a/)') 'WARNING - MORE THAN 2 VARIABLES IN'// 
     $                         ' MAP.'
      end if
      NVAR=min(NVAR,2)
      if(IPR.ne.3) write(IOUT,71) NVAR
   71 format(/' ** Energy map, dependence of',i2,' parameter(s) ** ')
      if(IPR.ne.3) write(IOUT,'(/a8,a12,a4,2a13)') ' Var. ',
     $          ' Stepwidth ','Istp','   Varmin  ','   Varmax  '
      do 100 I=1,min(NVAR,2)
        if(IPAR(I).le.(NUCLUS+1)*6) then
          PN(I)=PNAME(IPAR(I))
        else
          PN(I)=RNAME(IPAR(I)-(NUCLUS+1)*6)
        end if
        if(IPR.ne.3) write(IOUT,'(a8,1pe12.4,i4,2(1pe13.5))') 
     $                       PN(I),FAKT(I)*STEP(I),ISTP(I),
     $                       FAKT(I)*(X(I)+(1-(ISTP(I)+1)/2)*STEP(I)),
     $                 FAKT(I)*(X(I)+(ISTP(I)-(ISTP(I)+1)/2)*STEP(I))

  100 continue
      if(NVAR.gt.1) then
        if(IPR.ne.3) write(IOUT,'(/20x,a)') PN(2)//' ->'
        if(IPR.ne.3) write(IOUT,'(a10)') PN(1)
        do 290 L=1,10
          do 280 J=1,ISTP(2)
            X(2)=Y(2)+(J-(ISTP(2)+1)/2)*STEP(2)
            write(NUM,'(1pe10.3)') FAKT(2)*X(2)
            write(LINE(J:J),'(a1)') NUM(L:L)
  280     continue
          if(IPR.ne.3) write(IOUT,'(11x,a)') LINE(1:64)
  290   continue
      end if

      IRET=0
      FMIN=1e30
      FMAX=-1e30
      IMIN1=1
      IMIN2=1
      IMAX1=1
      IMAX2=1

  300 continue
      if(IPR.ne.3) write(IOUT,*)
      do 430 I1=1,ISTP(1)
        FM=1e30
        X(1)=Y(1)+(I1-(ISTP(1)+1)/2)*STEP(1)
        do 420 I2=1,ISTP(2)
          X(2)=Y(2)+(I2-(ISTP(2)+1)/2)*STEP(2)
** Funktionsaufruf F(X)
          call FOPT(F,FC,FD,FR,X,VOL,IRET)
          FMAP(I1,I2)=F
          if(IRET.eq.0) then
            if(F.lt.FMIN) then
              FMIN=F
              IMIN1=I1
              IMIN2=I2
            end if
            FM=min(FM,F)
            if(F.gt.FMAX) then
              FMAX=F
              IMAX1=I1
              IMAX2=I2
            end if
          end if
  420   continue
        write(*,'(1x,a,2(a,1pg13.5))') 
     $                              PN(1),'=',FAKT(1)*X(1),' FMIN=',FM
  430 continue
      FMIN=min(FMIN,FMAX)
      FMAX=max(FMIN,FMAX)
      open(unit=4,file=FNAME(:IFN-1)//'.map',status='unknown',
     $     form='unformatted',err=435)
      write(4,err=435) (FAKT(J)*(Y(J)+(1-(ISTP(J)+1)/2)*STEP(J)),
     $            FAKT(J)*(Y(J)+(ISTP(J)-(ISTP(J)+1)/2)*STEP(J)),
     $            FAKT(J)*STEP(J),J=1,2)
  435 continue
      DF=(sqrt(FMAX-FMIN))/18.0
      do 460 I1=1,ISTP(1)
        X(1) = Y(1)+(I1-(ISTP(1)+1)/2)*STEP(1)
        do 450 I2=1,ISTP(2)
          MARK(I2)=' '
          if(FMAP(I1,I2).le.FMIN) then
            MARK(I2)=CODE(1:1)
            goto 450
          end if
          do 440 J=0,17
            if(sqrt(FMAP(I1,I2)-FMIN).ge.DF*J.and.
     $        sqrt(FMAP(I1,I2)-FMIN).lt.DF*(J+1)) MARK(I2)=CODE(J+1:J+1)
  440     continue
          if(sqrt(FMAP(I1,I2)-FMIN).ge.DF*18) MARK(I2)=CODE(18:18)
  450   continue
        if(NVAR.gt.1.and.IPR.ne.3) write(IOUT,'(1pe10.3,1x,64a)') 
     $                FAKT(1)*X(1),(MARK(I2),I2=1,ISTP(2))
        write(4,err=465) (FMAP(I1,I2),I2=1,ISTP(2))
  460 continue
      goto 470
  465 continue
      write(IOUT,'(/1x,a/)') 'WARNING - COULD NOT OPEN'//
     $                       FNAME(:IFN-1)//'.map'
      write(*,'(/1x,a/)') 'WARNING - COULD NOT OPEN'//
     $                     FNAME(:IFN-1)//'.map'
  470 continue
      close(4)
** two-dimensional map
      if(NVAR.gt.1.and.IPR.ne.3) then
        write(IOUT,'(/a11,6a)') PN(1),
     $                            ('0123456789',J=1,min(ISTP(2)/10+1,6))
        write(IOUT,'(11x,6a)')    ('+    .    ',J=1,min(ISTP(2)/10+1,6))
        write(IOUT,'(22x,a)') PN(2)//' ->'
        write(IOUT,'(/1x,a/5x,a)') 'Explanation of Symbols','E (kJ/mol)'
        do 500 I=1,18
          write(IOUT,'(1x,a,3x,1pg12.5,a,1pg12.5)') 
     $                 CODE(I:I),FMIN+(DF*(I-1))**2,'-',FMIN+(DF*I)**2
  500   continue
        write(IOUT,'(/1x,2a,1pg12.4,2(1x,a,1pg12.4))') 'Minimum: ',
     $        PN(1)//'=',FAKT(1)*(Y(1)+(IMIN1-(ISTP(1)+1)/2)
     $                                    *STEP(1)),PN(2)//'=',
     $        FAKT(2)*(Y(2)+(IMIN2-(ISTP(2)+1)/2)*STEP(2)),
     $        'Fmin = ',FMIN
        write(IOUT,'(/1x,2a,1pg12.4,2(1x,a,1pg12.4))') 'Maximum: ',
     $        PN(1)//'=',FAKT(1)*(Y(1)+(IMAX1-(ISTP(1)+1)/2)
     $                                    *STEP(1)),PN(2)//'=',
     $        FAKT(2)*(Y(2)+(IMAX2-(ISTP(2)+1)/2)*STEP(2)),
     $        'Fmax = ',FMAX
      end if
** one-dimensional map
      if(NVAR.eq.1.and.IPR.ne.3) then
        do 530 I1=1,ISTP(1)
          X(1)=Y(1)+(I1-(ISTP(1)+1)/2)*STEP(1)
          if(FMAP(I1,1).le.FMAX) then
            write(IOUT,'(1x,2a,1pe10.3,a,1pe13.5,a)') PN(1),'=',
     $                      FAKT(1)*X(1),' F=',FMAP(I1,1),
     $            SPACE(:int(1+39*(FMAP(I1,1)-FMIN)/(FMAX-FMIN)))//'*'
          else
            write(IOUT,'(1x,2a,1pe10.3,a,1pe13.5,a)') PN(1),'=',
     $                   FAKT(1)*X(1),' F=',FMAP(I1,1),SPACE(:40)//'*'
          end if
  530   continue
        write(IOUT,'(/1x,2a,1pe12.4)') 'Minimum: ',
     $        PN(1)//'=',FAKT(1)*(Y(1)+(IMIN1-(ISTP(1)+1)/2)*STEP(1))
        write(IOUT,'(/1x,2a,1pe12.4)') 'Maximum: ',
     $        PN(1)//'=',FAKT(1)*(Y(1)+(IMAX1-(ISTP(1)+1)/2)*STEP(1))
      end if
** copy Y to parameter set X (restore old values of X)
      do 600 I=1,NVAR
        X(I)=Y(I)
  600 continue
      IPA(14)=IRET
      do 610 I=1,2
          STEP(I)=STEP(I)*FAKT(I)
  610 continue
      return
      end
*      
      subroutine STPDSC(F,FC,FD,FR,G1,ILOOP,ILOOP2,CSTOP)
** Steepest Descent Optimization
** Version 07.06.97
** Variables:
** KK      int    Feldgroesse
** X(I)    real   Parameter (Startpunkt, vorgegeben)
** Y(I)    real   Parameter (optimiert)
** F       real   Funktionswert
** ITMAX   int    maximum number of iterations (def.: 20)
** IFZ     int    Zahl der Zielfunktionsaufrufe
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 500)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2: wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
**                4: wie 2, jedoch noch zusaetzliche Groessen
** IOUT    int    Ausgabeeinheit (def.: 2)
** EPSX    real   Test fuer max. X-Wert-Aenderung (def.: 1e-4)
** EPSF    real   Test fuer max. Funktionswertaenderung (def.: 1e-6)
** SWA     real   not used
** EPSGRD  real   Test fuer max. Gradient (def.: 1e-6)
**
** Unterprogramme:
** FOPT   Zielfunktion
** GRAD   Gradient der Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),Y(NV),RPA(25)
      integer IPA(25),IPR,ILOOP,ILOOP2,IOUT,NL,IRET,IFZ
      real G1(NV),F,FC,FR,FD
      real MXGRD,ATVOL,EPSX,EPSF,EPSGRD
      character CSTOP*6
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      ITMAX=IPA(1)
      IPR=IPA(3)
      IOUT=IPA(4)
      EPSX=RPA(1)
      EPSF=RPA(2)
      EPSGRD=RPA(4)
      IRET=0
      NL=0
      if(IPR.ne.3) then
        write(IOUT,2) 'ITMAX','IPR','EPSX','EPSF','EPSGRD',
     $                 IPA(1),IPA(3),RPA(1),RPA(2),RPA(4)
    2   format(/' ** Nonlinear Steepest Descent Optimization **'//
     $  5a10/2i10,3(1pe10.3))
      end if
      ITER=0
** Funktionsaufruf F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      FMIN=F
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      IFZ=1
** copy parameter set to Y
      do 10 I=1,KK
        Y(I)=X(I)
   10 continue
      if(IRET.ne.0) goto 142
      if(IPR.ne.3) write(IOUT,'(/a12,2a10,a5,a6,a12)') 
     $         'F','MX-GRAD.','DX','ITER','IFZ','X(1)...'
      if(IPR.ne.3) write(IOUT,114) 
     $          F0,0.0,0.0,ITER,IFZ,(X(I),I=1,KK)
      IRET=0
** Start and end point for linear minimum search
      IBEG=3
      if(EPSX.gt.1e-10) then
        IEND=int(-1.442695*log(EPSX))+1
      else
        IEND=12
      end if

** main loop
      do 100 ITER=1,ITMAX
** calculate gradient G1
        call GOPT(G1,Y,IRET)
**        call GRAD(KK,Y,G1,1d-4,IRET)
        if(IPR.eq.4) then
          write(IOUT,'(1x,a)') 'Gradient'
          write(IOUT,'(1x,8f9.2)') 
     $                        ((G1(J),J=I*8-7,min(I*8,KK)),I=1,KK/8+1)
        end if
        IFZ=IFZ+1
        GRD=0.0
        MXGRD=0.0
        do 20 I=1,KK
          GRD=GRD+G1(I)**2
          if(abs(G1(I)).gt.abs(MXGRD)) MXGRD=G1(I)
   20   continue
        GRD=sqrt(GRD)
        IPTMIN=-1
** determine optimum step width G1/(GRD*2**IPOT), beginning with largest
** step width
        call MLIN(G1,GRD,ALPHA,IBEG,IEND,IPTMIN,FMIN,FCMIN,FDMIN,FRMIN,
     $                                                      VOL,IFZ,IRE)
** Minimum reached? (EPSX-Kriterium)
        if(IPTMIN.eq.-1) then
          IRET=9
          goto 110
        end if
** Minimum reached? (EPSF-Kriterium)
        if(abs(FMIN-F0)/(abs(FMIN)+1e-20).le.EPSF) then
          IRET=-1
          goto 110
        else
          F0=FMIN
        end if
** Minimum reached? (EPSGRD-Kriterium)
        if(GRD.le.EPSGRD) then
          IRET=8
          goto 110
        end if
        if(IPR.eq.2.or.IPR.eq.4) write(IOUT,114) 
     $                       F0,MXGRD,GRD/ALPHA,ITER,IFZ,(Y(I),I=1,KK)
  114   format(1pe12.5,2(1pe10.1),i5,i6,3(1pe12.5,:)/(43x,3(1pe12.5,:)))
        if(mod(NL,16).eq.0.and.IPR.ne.3)
     $                  write(*,'(1x,2(a,i5),a,1pg13.5,a,i3,a,i3)')
     $                  'Steepest Descent, ITER=',ITER,'/',ITMAX,
     $                  ', F=',F0,', loop no.',ILOOP,'/',ILOOP2
        NL=NL+1
        if(IPR.eq.2.or.IPR.eq.4) 
     $     write(*,'(1x,a,i7,a,i6,2(a,1pe10.3),a,1pg13.5,a,0pf4.2)') 
     $   'IFZ=',IFZ,' ITER=',ITER,' GRAD=',GRD,' DX=',GRD/ALPHA,
     $   ' F=',F0,' PC=',ATVOL/VOL
  100 continue
      IRET=11
  110 continue
** Funktionsaufruf F(Y)
      call FOPT(F,FC,FD,FR,Y,VOL,IR)
      IFZ=IFZ+1
      if(IPR.ne.3) write(IOUT,114) 
     $                        F,MXGRD,GRD/ALPHA,ITER,IFZ,(Y(I),I=1,KK)
  142 continue
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      IPA(14)=IRET
      IPA(15)=IFZ
      if(IRET.eq.-1) CSTOP='EPSF'
      if(IRET.eq.1.or.IRET.eq.2) CSTOP='FOPT'
      if(IRET.eq.8) CSTOP='EPSGRD'
      if(IRET.eq.9) CSTOP='EPSX'
      if(IRET.eq.11) CSTOP='ITMAX'
      return
      end
*
      subroutine NEWTON(F,FC,FD,FR,G1,ILOOP,ILOOP2,CSTOP)
** Damped Quasi Newton Optimization
** Version 29.03.98
** Variables:
** KK      int    Feldgroesse
** X(I)    real   Parameter (Startpunkt, vorgegeben)
** Y(I)    real   Parameter (optimiert)
** F       real   Funktionswert
** ITMAX   int    maximale Zahl von Iterationen (def.: 20)
** IFZ     int    Zahl der Zielfunktionsaufrufe
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 500)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2 (def.): wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
**                4: wie 2, jedoch noch zusaetzliche Groessen
** IOUT    int    Ausgabeeinheit (def.: 2)
** ISTART  int    >=0: Matrizen werden im Programm selbst festgelegt (def.: 2)
** EPSX    real   Test fuer max. X-Wert-Aenderung (def.: 1e-4)
** EPSF    real   Test fuer max. Funktionswertaenderung (def.: 1e-6)
** SWA     real   not used
** EPSGRD  real   Test fuer max. Gradient (def.: 1e-6)
**
** Unterprogramme:
** FOPT   Zielfunktion
** GRAD   Gradient der Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),XOLD(NV),Y(NV),RPA(25)
      integer IPA(25)
      double precision G2(NV,NV+1),XK(NV)
**      double precision HTEST(10,10+1)
      real F,FMIN,F0,FC,FD,FR,FCMIN,FDMIN,FRMIN
      real G1(NV),XK2(NV)
      real MXGRD,EPSX,EPSF,EPSGRD
      character CSTOP*6
      logical FIRST
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      common /HESSN/ G2
**      common /HTEST/ HTEST

      ITMAX=IPA(1)
      IPR=IPA(3)
      IOUT=IPA(4)
      EPSX=RPA(1)
      EPSF=RPA(2)
      EPSGRD=RPA(4)
      IRET=0
      NL=0
      ALPHA=1.0
      if(IPR.ne.3) then
        write(IOUT,2) 'ITMAX','IPR','EPSX','EPSF','EPSGRD',
     $                 IPA(1),IPA(3),(RPA(I),I=1,2),RPA(4)
    2   format(/' ** Nonlinear Damped Newton Optimization **'//
     $  5a10/2i10,3(1pe10.3))
      end if
      ITER=0
      SX=0
      MXGRD=0
** Funktionsaufruf F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      IFZ=1
** copy parameter set to Y and XOLD
      do 100 I=1,KK
        Y(I)=X(I)
        XOLD(I)=X(I)
  100 continue
      if(IRET.ne.0) goto 400
      if(IPR.ne.3) write(IOUT,'(/a12,2a10,a5,a6,a12)') 
     $         'F','MX-GRAD.','DX','ITER','IFZ','X(1)...'
      if(IPR.ne.3) write(IOUT,290) 
     $                       F0,MXGRD,SX/ALPHA,ITER,IFZ,(X(I),I=1,KK)

      IRET=0
** calculate gradient
      call GOPT(G1,Y,IRET)
**        call GRAD(KK,Y,G1,1d-4,IRET)
      IFZ=IFZ+1
      FIRST=.true.
** Iteration Loop
      do 300 ITER=1,ITMAX
        GRD=0.0
        MXGRD=0.0
        do 200 I=1,KK
          GRD=GRD+G1(I)**2
          if(abs(G1(I)).gt.abs(MXGRD)) MXGRD=G1(I)
  200   continue
        GRD=sqrt(GRD)
** calculate original Hesse matrix
**        call HESSE(KK,Y)
** calculate Hesse matrix
        call HESSE2(KK,G1,XOLD,Y,FIRST)
        IFZ=IFZ+1
        if(IPR.eq.4) then
          write(IOUT,'(1x,a)') 'Gradient'
          write(IOUT,'(1x,8f8.2)') 
     $                        ((G1(J),J=I*8-7,min(I*8,KK)),I=1,KK/8+1)
          do 220 K=0,KK,8
            write(IOUT,'(1x,a,i2,a,i2,a)') 'Hesse Matrix (col.',K+1,'-',
     $                                     min(KK,K+8),')'
            do 210 I=1,KK
              write(IOUT,'(1x,8f8.2)') (G2(I,J),J=K+1,min(KK,K+8))
  210       continue
  220     continue
        end if
        do 230 I=1,KK
          G2(I,KK+1)=G1(I)
  230   continue
** calculate new parameter values
        call GJ(KK,XK,IERR)
        if(IERR.eq.1) goto 390
        INEG=0
        SX=0.0
** calculate gradient norm and test diagonal elements of Hesse matrix
        do 240 I=1,KK
          DX=XK(I)
          SX=SX+DX**2
          if(G2(I,I).le.0.0) INEG=1
  240   continue
        SX=sqrt(SX)
        FMIN=F
        IPTMIN=-1
** determine optimum step width 1/(GRD*2**IPOT)
        IBEG=1
        if(EPSX.gt.1e-10) then
          IEND=int(-1.442695*log(EPSX))+1
        else
          IEND=12
        end if
        do 280 I=1,KK
          XOLD(I)=Y(I)
          XK2(I)=XK(I)
  280   continue
** determine optimum step width, beginning with largest
** step width
        call MLIN(XK2,1.0,ALPHA,IBEG,IEND,IPTMIN,FMIN,FCMIN,FDMIN,FRMIN,
     $                                                      VOL,IFZ,IRE)
        if(IPTMIN.lt.0) then
          IRET=9
          goto 390
        end if
** Funktionsaufruf F(Y)
        call FOPT(F,FC,FD,FR,Y,VOL,IRET)
        IFZ=IFZ+1
** Minimum erreicht? (EPSF-Kriterium)
        if(abs(F-F0)/(abs(F)+1e-20).le.EPSF) then
          IRET=-1
          goto 390
        else
          F0=F
          FCMIN=FC
          FDMIN=FD
          FRMIN=FR
        end if
** Minimum erreicht? (EPSGRD-Kriterium)
        if(abs(MXGRD).le.EPSGRD) then
          IRET=8
          goto 390
        end if
        if(IPR.ne.3) write(IOUT,290) 
     $                          F,MXGRD,SX/ALPHA,ITER,IFZ,(Y(I),I=1,KK)
  290   format(1pe12.5,2(1pe10.1),i5,i6,3(1pe12.5,:)/(43x,3(1pe12.5,:)))
        if(mod(NL,16).eq.0) write(*,'(1x,a,i5,a,i3,a,i3)') 
     $       'Damped Newton, ITMAX=',ITMAX,', loop no.',ILOOP,'/',ILOOP2
        NL=NL+1
        if(IPR.eq.2.or.IPR.eq.4) 
     $         write(*,'(1x,a,i6,a,i3,2(a,1pg10.3),a,1pg13.5,a,0pf4.2)')
     $         'IFZ=',IFZ,' ITER=',ITER,' MX-GRAD=',MXGRD,
     $         ' DAMP=',ALPHA,' F=',F,' PC=',ATVOL/VOL
  300 continue

      IRET=11
  390 continue
      if(IPR.ne.3) write(IOUT,290) 
     $                         F,MXGRD,SX/ALPHA,ITER,IFZ,(Y(I),I=1,KK)
  400 continue
      IPA(14)=IRET
      IPA(15)=IFZ
      F=F0
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      if(IERR.eq.1) write(IOUT,*) 'singular Hesse matrix'
      if(IERR.eq.1) write(*,*) 'singular Hesse matrix'
      if(IRET.eq.-1) CSTOP='EPSF'
      if(IRET.eq.1.or.IRET.eq.2) CSTOP='FOPT'
      if(IRET.eq.8) CSTOP='EPSGRD'
      if(IRET.eq.9) CSTOP='EPSX'
      if(IRET.eq.11) CSTOP='ITMAX'
      return
      end
*      
      subroutine GRAD(KK,Y,G1,H,IRET)
      implicit real(a-h,o-z)
      parameter(NV=36)
      real Y(NV)
      real C
      double precision G1(NV),FI(5),H
      do 20 I=1,KK
        C=Y(I)
        Y(I)=Y(I)-3*H
        do 10 K=1,5
          Y(I)=Y(I)+H
          if(K.ne.1.and.K.ne.5) goto 10
** Funktionsaufruf F(Y)
          call FOPT(F,FC,FD,FR,Y,VOL,IRET)
          if(IRET.ne.0) goto 999
          FI(K)=F
   10   continue
** Calculation of the derivative (3 point formula)
        G1(I)=(FI(5)-FI(1))/(4*H)
        Y(I)=C
   20 continue
  999 continue
      return
      end
*      
      subroutine HESSE(KK,Y)
      implicit real(a-h,o-z)
      parameter(NV=36)
      real Y(NV),G1(NV)
**      double precision G2(NV,NV+1)
      double precision G2(10,10+1)
      double precision GI(NV,2),H
**      common /HESSN/ G2
      common /HTEST/ G2
      H=1d-3
** calculate gradient G1(Y)
      call GOPT(G1,Y,IRET)
      do 30 J=1,KK
        GI(J,1)=G1(J)
   30 continue
      do 20 I=1,KK
        C=Y(I)
        Y(I)=C+H
** calculate gradient G1(Y)
        call GOPT(G1,Y,IRET)
        do 40 J=1,KK
          GI(J,2)=G1(J)
   40   continue
** calculate Hesse matrix G2(Y)
        do 50 J=1,KK
          G2(I,J)=(-GI(J,1)+GI(J,2))/H
   50   continue
        Y(I)=C
   20 continue
** averaging of symmetrical matrix elements G2(I,J)<->G2(J,I)
      do 70 J=1,KK
        do 60 I=J+1,KK
          G2(J,I)=(G2(J,I)+G2(I,J))/2
          G2(I,J)=G2(J,I)
   60   continue
   70 continue
      return
      end
*
      subroutine HESSE2(KK,GOLD,XOLD,XNEW,FIRST)
** Version 29.03.1998
** See: Robert B. Schnabel, "Unconstrained Optimization in 1981" in
** "Nonlinear Optimization 1981", NATO Conference Series, Series II: System
** Science, ed. M.J.D. Powell
      implicit real(a-h,o-z)
      parameter(NV=36)
      real XOLD(NV),XNEW(NV),GOLD(NV),GNEW(NV),SH(NV)
      double precision HOLD(NV,NV+1)
      double precision DG(NV),DX(NV),YS,SHS
      logical FIRST
      common /HESSN/ HOLD

** HOLD(I,J)  double  Old Hesse matrix (at the position XOLD, will be
**                    updated to the new Hesse matrix)
** GOLD(I)    double  Old gradient (at the position XOLD)
** GNEW(I)    double  New gradient
** XOLD(I)    double  Old position
** XNEW(I)    double  New position
** DG(J)      double  difference between new and old gradient
** DX(J)      double  difference between new and old position
** SH(J)      double  product between DX and HOLD
**
**      H+ = HC + (delta(GRAD)*delta(GRAD)T)/(delta(GRAD)T*delta(X) -
**           (HC*delta(X)*delta(X)T*HC)/delta(X)T*HC*delta(X))

** create start values for Hesse matrix
      if(FIRST) then
        do 120 I=1,KK
          do 110 J=1,KK
            if(I.eq.J) HOLD(I,J)=1.0
            if(I.ne.J) HOLD(I,J)=0.0
  110     continue
  120   continue
        FIRST=.false.
        return
      end if
** calculate new gradient G1(Y)
      call GOPT(GNEW,XNEW,IRET)
      do 20 J=1,KK
        DG(J)=GNEW(J)-GOLD(J)
        DX(J)=XNEW(J)-XOLD(J)
        GOLD(J)=GNEW(J)
   20 continue
** scalar product YS=DG*DX
      YS=0.0
      do 30 J=1,KK
        YS=YS+DG(J)*DX(J)
   30 continue
** product SH=DX*HOLD
      do 60 J=1,KK
        SH(J)=0.0
        do 50 K=1,KK
          SH(J)=SH(J)+DX(K)*HOLD(K,J)
   50   continue
   60 continue
** scalar product SHS=SH*DX
      SHS=0.0
      do 80 J=1,KK
        SHS=SHS+SH(J)*DX(J)
   80 continue
      do 100 J=1,KK
        do 90 K=1,KK
          HOLD(J,K) = HOLD(J,K) + DG(J)*DG(K)/YS - SH(J)*SH(K)/SHS
   90   continue
  100 continue
      return
      end
*
      subroutine GJ(N,X,IERR)
***********************************************************************
**     This subroutine solves linear systems of equations 
**     using the gauss-jordan method
**     Version 1.4.98
**
** Input data:
**
** N:          order of the linear system of equations
** CM(N,N):    coefficient matrix
** CM(N,N+1):  constant vector
**
** Output data:
**
** N:          for verification purposes
** CM(N,N+1):              "
** X(N):       solution to the linear system
**
** IERR:       IERR=1: the coefficient matrix is singular
**             (pivot element < 1d-35)
**
**
**
**
      implicit double precision(a-h,o-z)
      parameter(NV=36)
      double precision CM(NV,NV+1),AM(NV,NV+1),X(NV)
      double precision AMAX, ELEMNT, F
      integer I,J,K,L,N,IERR
      integer IP1,NP1,LOC(NV),PIVO(NV)
      common /HESSN/ CM
      NP1=N+1
      IERR=0
      do 10 I=1,N
        PIVO(I)=0
   10 continue
**
**   Main loop. Eliminate one column at a time
************************************************************************
      do 100 I=1,N
        IP1 = I+1
**
**   Find maximum element in Ith column
**
        AMAX = 0.
        do 20 K=1,N
          ELEMNT = abs(CM(K,I))
**
**     Has this row previously been used as a pivot?
**
          if(ELEMNT.gt.AMAX.and.PIVO(K).ne.1) then
            LOC(I) = K
            AMAX = ELEMNT
          end if
   20   continue
**
**    is the coefficient matrix singular?
**
        if(AMAX.le.1d-35) goto 9999
        L = LOC(I)
        PIVO(L) = 1
**
**    copy CM to AM
**
        do 30 J=1,N
          do 30 K=1,N+1
            AM(J,K)=CM(J,K)
   30   continue
**
**    perform elimination; L is pivot row, CM(L,I) is pivot element
**
        do 50 J=1,N
          if(J.ne.L) then
            F = -AM(J,I)/AM(L,I)
            do 40 K=IP1,NP1
              AM(J,K) = AM(J,K)+F*AM(L,K)
   40       continue
          end if
   50   continue
  100 continue
************************************************************************
**     calculate the solution vector, X
**
      DO 200 I=1,N
        L = LOC(I)
        X(I) = AM(L,NP1)/AM(L,I)
  200 continue
      return
 9999 IERR = 1
      end

      subroutine MLIN(G,GRD,ALPHA,IBEG,IEND,IPTM,FMIN,FCMIN,FDMIN,FRMIN,
     $                                                   VOLMIN,IFZ,IRE)
** version 18.4.98
** Find the minimum of the function along the direction G. The maximum
** step width is G/(GRD*2**IBEG).

** GRD     real  Length of vector G
** IRE=0: No minimum found
**    -1: Minimum found
**    -2: Minimum found at the beginning or at the end of the search

      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),Y(NV),YT(NV),RPA(25)
      integer IPA(25)
      real G(NV),GRD,ALPHA,VOLMIN
      real XX(7), FF(7),FC(7),FD(7),FR(7),FPT,VOL(7)
      integer IPOT,IBEG,IEND,IPTM,IFZ,IRET,IRE
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL

      IPTM=-1
      IMIN=1
      IRE=0
** determine optimum step width G/(GRD*2**IPOT), beginning with step width
** corresponding to IBEG
      FF(1)=-1e10
      FF(3)=0.0
      FF(5)=-1e10
** ALPHA = GRD, 2*GRD, 4*GRD, 8*GRD, ...
** IPOT  =   0,     1,     2,     3, ...
      do 50 IPOT=IBEG,IEND
          ALPHA=GRD*(2.0**IPOT)
** calculate new parameter values
          do 30 I=1,KK
            YT(I)=Y(I)-G(I)/ALPHA
   30     continue
          FF(1)=FF(3)
          FC(1)=FC(3)
          FD(1)=FD(3)
          FR(1)=FR(3)
          FF(3)=FF(5)
          FC(3)=FC(5)
          FD(3)=FD(5)
          FR(3)=FR(5)
** Funktionsaufruf F(5)(YT)
          call FOPT(FF(5),FC(5),FD(5),FR(5),YT,VOL(5),IRET)
          IFZ=IFZ+1
** Minimum found? Then calculate the midpoints between the first and the
** third point and the third and the fifth point and test it.
** 0...........XX(1).XX(2).XX(3).......XX(4).......XX(5)..
**             FF(1) FF(2) FF(3)       FF(4)       FF(5)
          if(abs(IPOT-IBEG).ge.2
     $                      .and.FF(3).lt.FF(1).and.FF(3).lt.FF(5)) then
            IRE=-1
            XX(1)=ALPHA/4.0
            XX(3)=ALPHA/2.0
            XX(2)=(XX(1)+XX(3))/2.0
            XX(5)=ALPHA
            XX(4)=(XX(3)+XX(5))/2.0
            do 35 I=1,KK
              YT(I)=Y(I)-G(I)/XX(2)
   35       continue
** Funktionsaufruf FF(2)(YT)
            call FOPT(FF(2),FC(2),FD(2),FR(2),YT,VOL(2),IRET)
            IFZ=IFZ+1
** Funktionsaufruf FF(4)(YT)
            call FOPT(FF(4),FC(4),FD(4),FR(4),YT,VOL(4),IRET)
            IFZ=IFZ+1
            FPT=FF(1)
            ALPHA=XX(1)
            IMIN=1
            do 55 I=2,5
              if(FF(I).lt.FPT) then
                FPT=FF(I)
                ALPHA=XX(I)
                IMIN=I
              end if
   55       continue
            XX(6)=XX(IMIN)+(XX(1)-XX(4))/12.0
            XX(7)=XX(IMIN)-(XX(1)-XX(4))/12.0
            do 65 J=6,7
              do 75 I=1,KK
                YT(I)=Y(I)-G(I)/XX(J)
   75         continue
** Funktionsaufruf FF(J)(YT)
              call FOPT(FF(J),FC(J),FD(J),FR(J),YT,VOL(J),IRET)
              IFZ=IFZ+1
              if(FF(J).lt.FPT) then
                FPT=FF(J)
                ALPHA=XX(J)
                IMIN=J
              end if
   65       continue
** Ist der beste Punkt ein neues Minimum? Wenn ja, einen Schritt machen
** und Suche beenden.
            if(FPT.le.FMIN) then
              FMIN=FPT
              FCMIN=FC(IMIN)
              FDMIN=FD(IMIN)
              FRMIN=FR(IMIN)
              VOLMIN=VOL(IMIN)
              IPTM=0
              IBEG=max(2,IPOT-2)
              if((IEND-IBEG).lt.5) IBEG=IEND-5
              do 40 I=1,KK
                Y(I)=Y(I)-G(I)/ALPHA
   40         continue
              goto 60
            end if
** Wenn kein Minimum gefunden, dann weitersuchen, evtl. FMIN neuen Wert
** zuweisen.
          else if(FF(5).lt.FMIN) then
            IRE=-2
            FMIN=FF(5)
            VOLMIN=VOL(5)
            IMIN=5
            IPTM=IPOT
            IBEG=max(2,IPOT-2)
            if((IEND-IBEG).lt.5) IBEG=IEND-5
          end if
   50 continue
   60 continue
      if(IPTM.gt.0) then
          ALPHA=GRD*(2.0**IPTM)
          do 70 I=1,KK
            Y(I)=Y(I)-G(I)/ALPHA
   70     continue
          FCMIN=FC(IMIN)
          FDMIN=FD(IMIN)
          FRMIN=FR(IMIN)
          VOLMIN=VOL(IMIN)
      end if
      end

      subroutine INTPOL(X,F,XS,FS,IRET)
** Interpolation and calculation of the minimum for 5 non-equidistant
** points X,F
** The polynom is:
**                B(1) +
**                B(2)*(X-X(1)) +
**                B(3)*(X-X(1))*(X-X(2)) +
**                B(4)*(X-X(1))*(X-X(2))*(X-X(3)) +
**                B(5)*(X-X(1))*(X-X(2))*(X-X(3))*(X-X(4)) +
** The first derivative is:
**                4*B(5)*X**3 +
**                3*(B(4) - B(5)*(X(1)+X(2)+X(3)+X(4)))*X**2 +
**                2*(B(3) - B(4)*(X(1)+X(2)+X(3)) + B(5)*(X(1)*X(2)+X(1)*X(3)+
**                          X(1)*X(4)+X(2)*X(3)+X(2)*X(4)+X(3)*X(4)))*X +
**                1*(B(2) - B(3)*(X(1)+X(2)) +
**                          B(4)*(X(2)*X(3)+X(1)*X(3)+X(1)*X(2)))
**
** The second derivative is:
**                12*B(5)*X**2 +
**                6*(B(4) - B(5)*(X(1)+X(2)+X(3)+X(4)))*X +
**                2*(B(3) - B(4)*(X(1)+X(2)+X(3)) + B(5)*(X(1)*X(2)+X(1)*X(3)+
**                        X(1)*X(4)+X(2)*X(3)+X(2)*X(4)+X(3)*X(4))) +
** IRET=1: The polynom is linear. Therefore no minimum can be calculated.
** IRET=2: Das Argument der Wurzel ist negativ. Therefore no minimum can
**         be calculated.
      real X(5),F(5),D(2:5),E(3:5),XS,FS,XX1,XX2,FF1,FF2
      real B(5),P,Q
      integer IRET

      IRET=0
      FF1=1.0
      FF2=1.0
      XS=0.0
      do 10 I=2,5
        D(I)=(F(I)-F(I-1))/(X(I)-X(I-1))
        if(I.ge.3) E(I)=(D(I)-D(I-1))/(X(I)-X(I-2))
   10 continue
** Polynom-Koeffizienten B(1) bis B(5)
      B(1)=F(1)
      B(2)=D(2)
      B(3)=E(3)
      B(4)=(E(4)-E(3))/(X(4)-X(1))
      B(5)=((E(5)-E(4))/(X(5)-X(2))-B(4))/(X(5)-X(1))
** Nullstellen des Polynoms A1*X**3 + B1*X**2 + C1*X + D1
      A1=4*B(5)
      B1=3*(B(4)-B(5)*(X(1)+X(2)+X(3)+X(4)))
      C1=2*(B(3)-B(4)*(X(1)+X(2)+X(3))+
     $     B(5)*(X(1)*X(2)+X(1)*X(3)+X(1)*X(4)+X(2)*X(3)+
     $           X(2)*X(4)+X(3)*X(4)))
      D1=1*(B(2)-B(3)*(X(1)+X(2))+B(4)*(X(2)*X(3)+X(1)*X(3)+X(1)*X(2)))
** Cardanische Formel
      Q=2*B1**3/(54*A1**3)-B1*C1/(6*A1**2)+D1/(2*A1)
      P=(3*A1*C1-B1**2)/(9*A1**2)
      D23=Q**2+P**3
** eine reelle Loesung
      if(D23.gt.0.0) then
        U=(-Q+sqrt(D23))**(1.0/3.0)
        V=(-Q-sqrt(D23))**(1.0/3.0)
        Y1=U+V
        X1=Y1-(B1/(3*A1))
** ein bis zwei reelle Loesungen
      else if(D23.eq.0.0) then
** drei reelle Loesungen
      else
      end if
      if(abs(B(4)).gt.1e-12) then
** Funktionswerte der 2. Ableitung berechnen
        FF1=(2*XX1+P)*(3*B(4))
        FF2=(2*XX2+P)*(3*B(4))
      else if(abs(B(3)).gt.1e-12) then
        print*,2
        XX1=(B(3)*(X(1)+X(2))+B(4)*(X(1)*X(2)+X(2)*X(3)+X(1)*X(3))-B(2))
     $      /(2*(B(3)-B(4)*(X(1)+X(2)+X(3))))
        XX2=XX1
      else
        print*,3
        IRET=1
      end if
      if(FF1.gt.0.0.and.IRET.eq.0) then
        XS=XX1
        FS=B(1)+B(2)*(XX1-X(1))+B(3)*(XX1-X(1))*(XX1-X(2))+
     $     B(4)*(XX1-X(1))*(XX1-X(2))*(XX1-X(3))
      else if(FF2.gt.0.0.and.IRET.eq.0) then
        XS=XX2
        FS=B(1)+B(2)*(XX2-X(1))+B(3)*(XX2-X(1))*(XX2-X(2))+
     $     B(4)*(XX2-X(1))*(XX2-X(2))*(XX2-X(3))
      end if
      end
      subroutine ROBRO(F,FC,FD,FR,VMAX,ILOOP,ILOOP2,CSTOP)
** Optimization procedure according to Rosenbrock (Rosenbrock & Storey, 
** "Computational Techniques for Chemical Engineers")
** H.H. Rosenbrock (1960). The Computer Journal 3, 175
** Version 04.08.1997
** Constants:
** KK      int    Feldgroesse
** Variables:
** ALPHA(I) real  total progress made since the axes were last rotated
**                2.0: Startvalue
**                1.0: successful step in direction I
**                0.0: no success after successful step in direction I
** D(I)    real   sum of all step widths since the axes were last rotated
** E(I)    real   I=1..KK: step widths
** EPSX    real   Test for max. X-value-change (def.: 1e-4)
** EPSF    real   Test for max. function value change (def.: 1e-6)
** EPSMI   real   Test for max. relat. parameter value change (def.: 1e-6)
** F       real   function value
** ITMAX   int    maximale Zahl von Iterationen (def.: 20)
** IFZ     int    Zahl der Zielfunktionsaufrufe
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 500)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2 (def.): wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
**                4: wie 2, jedoch noch zusaetzliche Groessen
** IOUT    int    Ausgabeeinheit (def.: 2)
** ISTART  int    >=0: Matrizen werden im Programm selbst festgelegt (def.: 2)
** LTE     int    1: unsuccessful step after successful step in all directions
** SWA     real   start value of step widths (def.: -.05)
** VL(I,J) real   set of orthogonal unit vectors (J is the number of the 
**                vector)
** X(I)    real   Parameter (Startpunkt, vorgegeben)
** Y(I)    real   Parameter (optimiert)
**
** subroutines:
** FOPT   Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),Y(NV),RPA(25),VL(NV,NV),D(NV),ALPHA(NV),VMAX(NV),ATVOL
      integer IPA(25)
      real BETA(NV),E(NV)
      character CSTOP*6
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      ITMAX=IPA(1)
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      ISTART=IPA(5)
      EPSX=RPA(1)
      EPSF=RPA(2)
      SWA=RPA(3)
      EPSMI=RPA(4)
      IRE1=0
      F=1.11111e-11
      IRET=0
      NL=0
      if(IPR.ne.3) then
        write(IOUT,2) 'ITMAX','IFZMAX','IPR',ITMAX,IFZMAX,IPR,
     $                'EPSX','EPSF','SWA','EPSMI',
     $                EPSX,EPSF,SWA,EPSMI
    2   format(/' ** Rosenbrock''s Optimization Method **'
     $  //3a10/3i10//4a12/4(1pe12.4))
      end if
      ITER=0
** Function call F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      IFZ=1
      if(IPR.ne.3) write(IOUT,'(a12,2a9,2a5,a12)') 
     $         'F','ALPHA1','GAMMA','ITER','IFZ','X(1)...'
** copy parameter set to Y
      do 8 I=1,KK
        Y(I)=X(I)
    8 continue
      if(IRET.eq.1) goto 360
   10 continue
      if(IPR.ne.3) write(IOUT,400) F,(X(I),I=1,KK)
   15 continue
      if(ISTART.lt.0) goto 30

   18 continue
      IRET=0
** initialize matrix VL and step width E
      do 20 I=1,KK
        do 20 J=1,KK
          VL(I,J) = 0.0
   20 continue
      do 24 I=1,KK
        VL(I,I) = 1.0
        E(I)=VMAX(I)
        if(SWA.ge.0.0) E(I)=abs(SWA*VMAX(I))
   24 continue

** Startpunkt fuer Iterationsschleife
   30 continue
      ITER=ITER+1
      do 32 I=1,KK
        ALPHA(I) = 2.0
        D(I) = 0.0
   32 continue
   40 continue
      II=1
   50 continue
      ABM=.0
      do 54 I=1,KK
        ABA=E(II)*VL(I,II)
        ABR=abs(ABA)/(abs(Y(I))+1e-20)
        if(ABR.gt.ABM) ABM=ABR
        Y(I)=Y(I)+ABA
   54 continue
      if(ABM.le.EPSMI) then
        IRET=8
        goto 320
      end if
** Function call F(Y)
      call FOPT(F1,FC,FD,FR,Y,VOL,IRET)
      IFZ=IFZ+1
      if(IRET.eq.1) goto 370
   60 continue
** the new function is value smaller (that is, better) than the old one
      if(F1.le.F) then
        D(II) = D(II)+E(II)
** step width is multiplied by 3
        E(II) = 3.0*E(II)
        if(abs(E(II)).gt.VMAX(II)) E(II)=sign(1.0,E(II))*VMAX(II)
        F=F1
        if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $        'Rosenbrock, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
        NL = NL + 1
        write(*,'(1x,a,i6,2(a,i5),a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ,
     $               ', ITER=',ITER,'/',ITMAX,', F=',F,', PC=',ATVOL/VOL
        FCMIN=FC
        FDMIN=FD
        FRMIN=FR
        if(ALPHA(II).ge.1.5) ALPHA(II) = 1.0
      else
** no improvement
        do 68 I=1,KK
          Y(I) = Y(I) - E(II)*VL(I,II)
   68   continue
** step width is multiplied by -0.5
        E(II) = -0.5*E(II)
        if(ALPHA(II).le.1.5) ALPHA(II) = 0.0
      end if
** Optimierung beenden? (IFZMAX-Kriterium)
      if(IFZ.ge.IFZMAX) then
        IRET=12
        goto 390
      end if
      LTE=0
      do 78 I=1,KK
        if(ALPHA(I).gt.0.5) LTE=1
   78 continue
      if(LTE.ne.0) then
        if(II.eq.KK) goto 40
        II=II+1
        goto 50
      end if
** calculate new set of unit vectors (rotate axes)
      SUM1 = 0.0
      do 88 I=1,KK
        SUM = 0.0
        do 86 J=1,KK
          SUM = SUM + D(J)*VL(I,J)
   86   continue
        BETA(I) = SUM
        SUM1 = SUM1 + SUM**2
   88 continue
      SUM=sqrt(SUM1)
      ALPHA1=SUM
      do 90 I=1,KK
        VL(I,1) = BETA(I)/SUM
   90 continue
      do 110 IP=2,KK
        IPM = IP - 1
        do 94 I=1,KK
          SUM = 0.0
          do 92 J=IP,KK
            SUM = SUM + D(J)*VL(I,J)
   92     continue
          ALPHA(I) = SUM
   94   continue
        if(IP.eq.2) then
          S1 = 0.0
          do 98 I=1,KK
            S1 = S1 + ALPHA(I)**2
   98     continue
          ALPHA2 = sqrt(S1)
        end if
        SUM1 = 0.0
        do 106 I=1,KK
          SUM2 = 0.0
          do 104 J=1,IPM
            SUM3 = 0.0
            do 102 K=1,KK
              SUM3 = SUM3 + ALPHA(K)*VL(K,J)
  102       continue
            SUM2 = SUM2 + SUM3*VL(I,J)
  104     continue
          BETA(I) = ALPHA(I) - SUM2
          SUM1 = SUM1 + BETA(I)**2
  106   continue
        SUM = sqrt(SUM1)
        do 108 I=1,KK
          VL(I,IP) = BETA(I)/SUM
  108   continue
  110 continue

      GAMMA = ALPHA2/ALPHA1
      if(IPR.eq.2) write(IOUT,290) F,ALPHA1,GAMMA,ITER,IFZ,(Y(I),I=1,KK)
  290 format (1pg12.5,2(1pe9.1),2i5,3(1pe12.5,:)/(40x,3(1pe12.5,:)))
** Finish optimization? (ITMAX-Kriterium)
      if(ITER.ge.ITMAX) then
        IRET=11
        goto 390
      end if
      ABM=.0
      do 300 I=1,KK
        ABW=abs(Y(I)-X(I))/(abs(Y(I))+1e-20)
** Minimum reached? (EPSX-Kriterium)
        if(ABW.le.EPSX) then
          IRET=0
          goto 340
        end if
  300 continue
** Minimum reached? (EPSF-Kriterium)
      if(abs(F-F0)/(abs(F)+1e-20).le.EPSF) then
        IRET=-1
        goto 340
      else
        do 310 I=1,KK
          X(I)=Y(I)
  310   continue
        F0=F
        if(IPR.eq.4) write(IOUT,290)
     $                             F,ALPHA1,GAMMA,ITER,IFZ,(Y(I),I=1,KK)
** Back for another iteration.
        goto 30
      end if
  320 continue
      do 330 I=1,KK
        Y(I) = Y(I) - E(II)*VL(I,II)
  330 continue
  340 continue
      if(abs(ISTART).ne.2.or.IRE1.ne.0) goto 390
      IRE1=1
      if(IPR.ne.3) write(IOUT,350)
  350 format(/' restart')
      goto 18
  360 continue
      IRET=1
      goto 390
  370 continue
      IRET=2
      do 380 I=1,KK
        Y(I) = Y(I) - E(II)*VL(I,II)
  380 continue
  390 continue
      if(IPR.ne.3) write(IOUT,290) F,ALPHA1,GAMMA,ITER,IFZ,(Y(I),I=1,KK)
  400 format(1pg12.5,28x,3(1pe12.5,:)/(40x,3(1pe12.5,:)))
      IPA(14)=IRET
      IPA(15)=IFZ
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      if(IRET.eq.-1) CSTOP='EPSF'
      if(IRET.eq.0)  CSTOP='EPSX'
      if(IRET.eq.1.or.IRET.eq.2) CSTOP='FOPT'
      if(IRET.eq.8) CSTOP='EPSMI'
      if(IRET.eq.11) CSTOP='ITMAX'
      if(IRET.eq.12) CSTOP='IFZMAX'
      return
      end
      
      subroutine POWELL(SWA,F,FC,FD,FR,VMAX,ILOOP,ILOOP2,CSTOP)
** nonlinear optimization by conjugated directions,
** gradient free method by Powell
** J.M.D. Powell (1964). The Computer Journal 7, 155
** See also: W.H. Press, B.P. Flannery, S.A. Teukolsky & W.T. Vetterling
** (1987). "Numerical Recipes", Cambridge University Press, Cambridge, 1987
** Die Methode benutzt KK linear unabhaengige Richtungen, die so gewaehlt
** werden, dass eine quadratische Funktion in endlich vielen Schritten
** exakt minimiert wird und dass die dabei erhaltenen Richtungen 
** zueinander konjugiert sind.
** Version 27.04.1998
** Constants:
** KK      int    Array size
** Variables:
** X(I)    real   Starting point (will not be changed by this routine)
** YT(I)   real   Copy of the best point
** Y(I)    real   Best point (will be renewed after each iteration cycle)
** F       real   Function value
** FRET    real   Best function value
** ITMAX   int    maximum number of iterations (def.: 20)
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 500)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2 (def.): wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
**                4: wie 2, jedoch noch zusaetzliche Groessen
** IOUT    int    Ausgabeeinheit (def.: 2)
** IFAIL   char   ' ': Minimization in this iteration successful
**                '-': Minimization in this iteration failed
** IRI     char   ' ':
**                '*': Minimum moved to the new direction
** IMAX    int    maximale Zahl von Schritten mit max. Schrittweite (def.: 100)
** IP      int    maximale Zahl von Splineinterpolationen (def.:   1)
** SWA     real   >0: start step width
**                <0: for the ith direction the start step width 
**                |SWA|*X(I) will be used.
** EPSX    real   Test fuer max. X-Wert-Aenderung
** EPSF    real   Test fuer max. Funktionswertaenderung
** EPS     real   
** IRET    int    -1: Abbruch durch EPSF
**                0:  Abbruch durch EPSX
**                1,2 Abbruch von FOPT aus
**                6:  SWA=.0
**                8,9 Abbruch von MLINE aus
**                11: Abbruch durch ITMAX
**                12: Abbruch durch IFZMAX
** IRE     int    Reason for stopping of minimum search
**                -2: Minimum liegt auf Stuetzstelle
**                -1: Abbruch durch IP
**                 0: Abbruch durch EPS
**                 1: Abbruch von FOPT aus
**                 2: SANF oder SMAX nicht positiv
**                 3: Abbruch durch IMAX
** IREF(I)  int   speichert Grund des Abbruch der Minimumsuche fuer jeden
**                Iterationszyklus I
** VL(I,J)  real  directions no. I. All direction vectors have the length 1.
** E(I)     real  starting step width for direction no. I
** subroutines:
** FOPT:   Zielfunktion
** MLIN:   sucht das Minimum der Zielfunktion entlang einer Geraden
************************************************************************
      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),Y(NV),YT(NV),YTT(NV),G(NV),RPA(25),VL(NV,NV),VMAX(NV)
      real E(NV),ATVOL
      real EPSX,EPSF,EPS,GQ,FRET
      integer IPA(25),IREF(50),ITMAX,IFZMAX,IPR,IOUT
      integer IP,KK,INR
      character IFAIL*1,IRI*1,CSTOP*6
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      ITMAX=IPA(1)
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      IP=IPA(7)
      EPSX=RPA(1)
      EPSF=RPA(2)
      EPS=RPA(4)
      if(KK.eq.1) then
        NL=0
      end if
      if(IPR.ne.3) then
        write(IOUT,24) 'ITMAX','IFZMAX','IPR',
     $                 'IP',ITMAX,IFZMAX,IPR,IP,
     $                 'SWA','EPSX','EPSF','EPS',
     $                 SWA,EPSX,EPSF,EPS
   24   format(/' ** Powell''s Optimization Method **'//
     $  4a7/4i7//4a10/4(1pe10.2))
        write(IOUT,'(/a)') ' IRE:  reason for stopping minimum search'
        write(IOUT,'(a)') ' IFZ:  number of function calls (total)'
        write(IOUT,'(a/)') ' IFZI: number of function calls'
      end if
      IRET=0
      ITER=0
** FRET: Energy of the starting point X
      call FOPT(FRET,FC,FD,FR,X,VOL,IRET)
      FMIN=FRET
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      IFZ=1
      IFZI=1
      if(IPR.ne.3) then
        write(IOUT,'(/a8,4x,3a5,1x,a3,a6,a10)')
     $       'F  ',' ITER','  IFZ',' IFZI','IRI',' IFAIL','X(1)...'
      end if
      if(IRET.ne.0) then
        IRET=1
        goto 280
      end if
      if(IPR.eq.1) write(IOUT,34) FRET,ITER,(X(I),I=1,KK)
   34 format(1pg12.5,i5,23x,3(1pe12.5,:)/(40x,3(1pe12.5,:)))
      if(IPR.eq.2.or.IPR.eq.4)
     $        write(IOUT,112) FRET,ITER,IFZ,IFZI,IRI,IFAIL,(X(I),I=1,KK)

** initialize matrix VL
      do 40 I=1,KK
        do 40 J=1,KK
          VL(I,J) = 0.0
   40 continue
      do 48 I=1,KK
        VL(I,I) = 1.0
        E(I)=VMAX(I)
        if(SWA.ge.0.0) E(I)=abs(SWA*VMAX(I))
        if(SWA.eq.0.0) then
          IRET=6
          goto 280
        end if
   48 continue
** Save the initial point X as Y and YT
      do 52 I=1,KK
        Y(I)=X(I)
        YT(I)=X(I)
   52 continue

** Start of the iteration loop
   50 continue
      IFAIL=' '
      IFZI=0
      IREFI=0
      ITER=ITER+1
      FP=FRET
      INR=0
      DMAX=0.0
      do 55 I=1,KK
        GQ=0.0
** Copy direction VL(I,*) to G
        do 56 J=1,KK
          G(J)=VL(I,J)*E(J)
          GQ=GQ+G(J)**2
   56   continue
        GQ=sqrt(GQ)
** Minimize F(Y+G/AMIN) along the direction G
** minimum point is Y, minimum function value is FRET
** negative direction:
        call MLIN(G,GQ,AMIN,1,12,IPTM,FRET,FC,FD,FR,VOL,IFZI,IRE)
** Record the maximum change (DMAX) so far of the function
** INR is the number of the direction which makes the maximum change
        if(abs(FP-FRET).gt.DMAX) then
          DMAX=abs(FP-FRET)
          INR=I
        end if
** positive direction:
        call MLIN(G,-GQ,AMIN,1,12,IPTM,FRET,FC,FD,FR,VOL,IFZI,IRE)
** Record the maximum change (DMAX) so far of the function
** INR is the number of the direction which makes the maximum change
        if(abs(FP-FRET).gt.DMAX) then
          DMAX=abs(FP-FRET)
          INR=I
        end if
        if(FRET.lt.FMIN) then
          if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $        'Powell, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i6,2(a,i5),a,1pg13.5,a,0pf4.2)') 'IFZ=',
     $         IFZ+IFZI,', ITER=',ITER,'/',ITMAX,', F=',FMIN,
     $         ', PC=',ATVOL/VOL
          FMIN=FRET
        end if
        IREFI=IREFI+1
        IREF(IREFI)=IRE
** no further minimization neccesary in one-dimensional case
        if(KK.eq.1) then
          IRET=IRE
          IRI=' ' 
          goto 120
        end if
** GQ: Betrag des Vektors G
        if(FRET.lt.FP) then
          E(I)=GQ/abs(AMIN)
        else
          IFAIL='-'
        end if
        FMIN=FRET
   55 continue

** Terminate optimization? (ITMAX-Kriterium)
      if(ITER.ge.ITMAX) then
        IRET=11
        goto 500
      end if
** Minimum reached? (EPSF-Kriterium)
      if(abs(FP-FRET).le.EPSF*abs(FP)) then
        IRET=-1
        goto 500
      end if
** calculation of the function value at an "extrapolated point", 2*Y-YT,
** somewhat further along the proposed new direction
** calculation of new directions G
      DY=0.0
      do 130 I=1,KK
        DY=DY+(Y(I)-YT(I))**2
  130 continue
** Minimum reached? (EPSX-Kriterium)
      if(sqrt(DY).le.EPSX) then
        IRET=0
        goto 500
      end if
      GQ=0.0
      do 76 J=1,KK
        YTT(J)=2.0*Y(J)-YT(J)
        G(J)=Y(J)-YT(J)
        GQ=GQ+G(J)**2
        YT(J)=Y(J)
   76 continue
      GQ=sqrt(GQ)
      call FOPT(FPTT,FC,FD,FR,YTT,VOL,IRET)
      IFZI=IFZI+1
      if(IRET.ne.0) then
        IRET=2
        goto 500
      end if
      T=2.0*(FP-2.0*FRET+FPTT)*(FP-FRET-DMAX)**2-DMAX*(FP-FPTT)**2
** Two reasons not to use new direction
      if(T.ge.0.0.or.FPTT.ge.FP) then
        if(T.ge.0.0) then
          IRI=' '
          IFAIL='-'
        end if
        IFZ=IFZ+IFZI
        if(IPR.eq.2.or.IPR.eq.4) then
          if(IPR.eq.4) write(IOUT,111) (IREF(I),I=1,IREFI)
          write(IOUT,112) FRET,ITER,IFZ,IFZI,IRI,IFAIL,(Y(I),I=1,KK)
        end if
        goto 50
      end if

**  Keep the old set of directions, because the averaged direction YT-X 
**  is all played out, or
**  Keep the old set of directions, because either (i) the decrease along the
**  average direction was not primarily due to any single direction's 
**  decrease, or (ii) there is a substantial second derivative along the
**  average direction and we seem to be near to the bottom of its minimum.
   84 continue
      FRET=FPTT
** Move to the minimum of the new direction, and save the new direction
** negative direction:
        call MLIN(G,GQ,AMIN,1,12,IPTM,FRET,FCMIN,FDMIN,FRMIN,VOL,
     $                                                        IFZI,IRE)
** positive direction:
        call MLIN(G,-GQ,AMIN,1,12,IPTM,FRET,FCMIN,FDMIN,FRMIN,VOL,
     $                                                        IFZI,IRE)
        IREFI=IREFI+1
        IREF(IREFI)=IRE
        if(FRET.ge.FMIN) then
          IRI=' ' 
          IFAIL='-'
          goto 120
        else
          if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $        'Powell, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i6,2(a,i5),a,1pg13.5,a,0pf4.2)') 'IFZ=',
     $             IFZ+IFZI,', ITER=',ITER,'/',ITMAX,', F=',FMIN,
     $             ', PC=',ATVOL/VOL
          FMIN=FRET
        end if
** save the new direction
        do 80 J=1,KK
          VL(INR,J)=G(J)/GQ
   80   continue
        IRI='*'
        FMIN=FRET
        if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $        'Powell, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
        NL=NL+1
        write(*,'(1x,a,i6,2(a,i5),a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ+IFZI,
     $            ', ITER=',ITER,'/',ITMAX,', F=',FMIN,', PC=',ATVOL/VOL
  120 continue
      IFZ=IFZ+IFZI
      if(IPR.eq.2.or.IPR.eq.4) then
        if(IPR.eq.4) write(IOUT,111) (IREF(I),I=1,IREFI)
  111   format(' IRE ',25i4)
        write(IOUT,112) FRET,ITER,IFZ,IFZI,IRI,IFAIL,(Y(I),I=1,KK)
  112   format(1pg12.5,3i5,a3,1x,a5,4x,3(1pe12.5,:)
     $   /(40x,3(1pe12.5,:)))
      end if
      if(KK.eq.1) goto 500
** Terminate optimization? (IFZMAX-Kriterium)
      if(IFZ.ge.IFZMAX) then
        IRET=12
        goto 500
      end if
      do 140 I=1,KK
        Y(I)=YT(I)
  140 continue
** Back for another iteration
      goto 50

  280 continue
      do 290 I=1,KK
        Y(I)=X(I)
  290 continue
  500 continue
      call FOPT(F,FC,FD,FR,Y,VOL,IR)
      if(IR.ne.0) IRET=IR
      if(IPR.ne.3) write(IOUT,162) F,ITER,IFZ,(Y(I),I=1,KK)
  162 format(1pg12.5,i5,i5,18x,3(1pe12.5,:)/(40x,3(1pe12.5,:)))
      if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $        'Powell, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
      NL=NL+1
      write(*,'(1x,a,i6,2(a,i5),a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ,
     $               ', ITER=',ITER,'/',ITMAX,', F=',F,', PC=',ATVOL/VOL
      if(IRET.eq.-1) CSTOP='EPSF'
      if(IRET.eq.0)  CSTOP='EPSX'
      if(IRET.eq.1.or.IRET.eq.2) CSTOP='FOPT'
      if(IRET.eq.6)  CSTOP='SWA'
      if(IRET.eq.8.or.IRET.eq.9) CSTOP='MLIN'
      if(IRET.eq.11) CSTOP='ITMAX'
      if(IRET.eq.12) CSTOP='IFZMAX'
      IPA(14)=IRET
      IPA(15)=IFZ
      return
      end
      
      subroutine SIMPLX(F,FC,FD,FR,VMAX,NN,ILOOP,ILOOP2,CSTOP)
** Optimization according to the Polytype Method (Simplex) 
** Siehe: C. Richter, Optimierungsverfahren und BASIC-Programme
** oder:
** M.J. Box (1965). The Computer Journal 8, 42
** Version 09.01.97
** Constants:
** NV      int    Number of variables
** Variables:
** X(I)    real   Parameter (Startpunkt, vorgegeben)
** Y(I)    real   Parameter (optimiert)
** F       real   Function value
** IFZ     int    Zahl der Zielfunktionsaufrufe
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 500)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2,4: wie 1, zusaetzlich Ergebnisse jeder Iteration
**                3: keine Ausgabe
** IOUT    int    Ausgabeeinheit (def.: 2)
** EPSX    real   Test fuer max. X-Wert-Aenderung (def.: 1e-4)
** EPSF    real   Test fuer max. Funktionswertaenderung (def.: 1e-6)
** SWA     real   Anfangsschrittweite (def.: -.05)
** EPSMI   real   Test fuer max. relat. Parameteraenderung (def.: 1e-6)
** SIMP(I,J) real Eckpunkt Nr. I des Simplex
** FSIMP(I)  real Energie des Eckpunkts Nr. I des Simplex
** SP(J)   real   Schwerpunkt des Simplex
**
** subroutines:
** FOPT   Zielfunktion
************************************************************************

      implicit real(a-h,o-z)
      parameter(NV=36)
      real X(NV),Y(NV),Y2(NV),RPA(25),VMAX(NV),SIMP(NV+1,NV+1),ATVOL
      real FSIMP(NV+1),SP(NV),FMAX,FMIN
      real ALPHA,EPSF,BETA,GAMMA
      integer IPA(25),ISORT(NV+1)
      integer IFZMAX,IPR,IOUT
      double precision RAN2
      character CSTOP*6
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      ALPHA=RPA(1)
      EPSF=RPA(2)
      BETA=RPA(3)
      GAMMA=RPA(4)
** S0 Start-Simplex bilden, Funktionswerte der Eckpunkte und Schwerpunkt 
** berechnen
      FMAX=-1e10
      FMIN=1e10
      ALPHA=1.0
      GAMMA=1.2
      BETA=0.5
      if(IPR.ne.3) then
        write(IOUT,2) 'IFZMAX','IPR',
     $                (IPA(I),I=2,3),'ALPHA','EPSF','BETA','GAMMA',
     $                (RPA(I),I=1,4)
    2   format(/' ** Nonlinear Optimization ',
     $          'According to the Polytope Method (Simplex) **'//
     $           2a10/2i10//4a12/4(1pe12.4))
        write(IOUT,'(/a12,a12,a5,a12)') 
     $         'F','DF','IFZ','X(1)...'
      end if
** Function call F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      IFZ=1
      FSIMP(1)=F
      VOLMIN=VOL
      do 10 J=1,KK
        SP(J)=0.0
   10 continue
      if(IRET.ne.0) then
        I1=1
        goto 30
      else
        I1=2
      end if
      do 20 J=1,KK
        SIMP(1,J)=X(J)
        SP(J) = SIMP(1,J)/(KK+1)
   20 continue
   30 continue
      do 100 I=I1,KK+1
   50   continue
        do 60 J=1,KK
          SIMP(I,J)=X(J)+(RAN2(NN)-0.5)*VMAX(J)
          SP(J)=SP(J)+SIMP(I,J)/(KK+1)
          Y(J)=SIMP(I,J)
   60   continue
   70   continue
** Function call F(Y)
        call FOPT(F,FC,FD,FR,Y,VOL,IRET)
        IFZ=IFZ+1
** Optimierung beenden? (IFZMAX-Kriterium)
        if(IFZ.ge.IFZMAX) then
          IRET=12
          goto 500
        end if
        if(IRET.ne.0.and.I.eq.1) then
          do 80 J=1,KK
            SP(J)=0.0
   80     continue
          goto 50
        else if(IRET.ne.0) then
          do 90 J=1,KK
            SP(J)=SP(J)-SIMP(I,J)/(KK+1)
            SIMP(I,J)=(SIMP(I,J)+SP(J)*(KK+1.0)/(I-1))/2.0
            SP(J)=SP(J)+SIMP(I,J)/(KK+1)
            Y(J)=SIMP(I,J)
   90     continue
          goto 70
        end if
        FSIMP(I)=F
  100 continue
      SUM1=0.0
      NL=0
************************************************************************
** S1 die Eckpunkte sortieren nach steigenden Funktionswerten
      do 190 I=1,KK+1
        ISORT(I)=I
  190 continue
  200 continue
      do 220 I=1,KK+1
        do 210 J=KK,I,-1
          if(FSIMP(ISORT(J)).gt.FSIMP(ISORT(J+1))) then
            IDUM=ISORT(J)
            ISORT(J)=ISORT(J+1)
            ISORT(J+1)=IDUM
          end if
  210   continue
  220 continue
      FMIN=FSIMP(ISORT(1))
      FMAX=FSIMP(ISORT(KK+1))
** S2 den Schwerpunkt aller Eckpunkte ohne den schlechtesten berechnen
      do 230 J=1,KK
        SP(J)=0.0
        do 230 I=1,KK
          SP(J)=SP(J)+SIMP(ISORT(I),J)/KK
  230 continue
************************************************************************
** S3 Eckpunkt mit dem hoechsten Funktionswert am Schwerpunkt der uebrigen 
** Eckpunkte spiegeln
      do 240 J=1,KK
        Y(J)=SP(J)+ALPHA*(SP(J)-SIMP(ISORT(KK+1),J))
  240 continue
** Function call F2(Y)
      call FOPT(F2,FC,FD,FR,Y,VOL,IRET)
      IFZ=IFZ+1
      if(F2.lt.FMIN.and.IRET.eq.0) then
        VOLMIN=VOL
        FMIN=F2
        if(IPR.eq.2.or.IPR.eq.4) write(IOUT,114) FMIN,SUM1,
     $                                 IFZ,(Y(I),I=1,KK)
  114   format (2(1pg12.5),i5,3(1pe12.5,:)/(29x,3(1pe12.5,:)))
        if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $          'Simplex, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
        NL=NL+1
        write(*,'(1x,a,i6,a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ,', F=',FMIN,
     $                                          ', PC=',ATVOL/VOLMIN
** S4 Expansion entlang der Reflexionsrichtung
        do 250 J=1,KK
          Y2(J)=SP(J)+GAMMA*(Y(J)-SP(J))
  250   continue
** Function call F3(Y2)
        call FOPT(F3,FC,FD,FR,Y2,VOL,IRET)
        IFZ=IFZ+1
        if(IRET.eq.0.and.F3.lt.F2) then
          VOLMIN=VOL
          FMIN=F3
          if(IPR.eq.2.or.IPR.eq.4) write(IOUT,114) FMIN,SUM1,
     $                                 IFZ,(Y2(I),I=1,KK)
          if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $          'Simplex, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i6,a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ,
     $                                ', F=',FMIN,', PC=',ATVOL/VOLMIN
          do 260 J=1,KK
            Y(J)=Y2(J)
  260     continue
        end if
        FSIMP(ISORT(KK+1))=FMIN
        goto 400
** S5 Kontraktion entlang der Reflexionsrichtung
      else if(F2.ge.FMAX.or.IRET.ne.0) then
        do 270 J=1,KK
          Y2(J)=SP(J)+BETA*(Y(J)-SP(J))
  270   continue
** Function call F4(Y2)
        call FOPT(F4,FC,FD,FR,Y2,VOL,IRET)
        IFZ=IFZ+1
        if(IRET.eq.0.and.F4.lt.FMIN) then
          FMIN=F4
          if(IPR.eq.2.or.IPR.eq.4) write(IOUT,114) FMIN,SUM1,
     $                                 IFZ,(Y2(I),I=1,KK)
          if(mod(NL,16).eq.0) write(*,'(1x,a,i6,a,i3,a,i3)')
     $          'Simplex, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i6,a,1pg13.5,a,0pf4.2)') 'IFZ=',IFZ,
     $                                ', F=',FMIN,', PC=',ATVOL/VOLMIN
          FSIMP(ISORT(KK+1))=FMIN
          goto 380
        end if
** S6 Reflexion des kontrahierten Punktes am Schwerpunkt
        do 280 J=1,KK
          Y2(J)=SP(J)+ALPHA*(SIMP(ISORT(KK+1),J)-SP(J))
  280   continue
** Function call F4(Y2)
        call FOPT(F4,FC,FD,FR,Y2,VOL,IRET)
        IFZ=IFZ+1
        if(F4.lt.FMAX.and.IRET.eq.0) then
          FSIMP(ISORT(KK+1))=FMIN
          goto 380
        end if
      else
        FSIMP(ISORT(KK+1))=F2
        goto 400
      end if

** S7 Mittelung des Punktes Y2 mit dem bisher besten Punkt SIMP(ISORT(1),J)
      do 290 J=1,KK
        Y2(J)=(Y2(J)+SIMP(ISORT(1),J))/2.0
  290 continue
** Function call F4(Y2)
      call FOPT(F4,FC,FD,FR,Y2,VOL,IRET)
      IFZ=IFZ+1
      if(F4.lt.FMAX.and.IRET.eq.0) goto 380

** S8 Mittelung aller Punkte mit dem bisher besten Punkt SIMP(ISORT(1),J)
  300 continue
      do 370 I=2,KK+1
  350   continue
        do 360 J=1,KK
          SIMP(ISORT(I),J)=(SIMP(ISORT(I),J)+SIMP(ISORT(1),J))/2.0
          Y2(J)=SIMP(ISORT(I),J)
  360   continue
** Function call F(Y2)
        call FOPT(F,FC,FD,FR,Y2,VOL,IRET)
        IFZ=IFZ+1
        if(IRET.ne.0) goto 350
        FSIMP(ISORT(I))=F
  370 continue
      goto 470
** Ersetze Y durch Y2
  380 continue
      do 390 J=1,KK
        Y(J)=Y2(J)
  390 continue
      FSIMP(ISORT(KK+1))=F4
  400 continue
** S9 Ersetze den bisher schlechtesten Wert durch Y
      do 460 J=1,KK
        SIMP(ISORT(KK+1),J)=Y(J)
  460 continue
  470 continue
** S10 Berechne DF
      SUM1=0.0
      do 490 I=1,KK+1
        SUM2=0.0
        do 480 J=1,KK+1
          SUM2=SUM2+FSIMP(J)
  480   continue          
        SUM1=SUM1+(FSIMP(I)-SUM2/(KK+1))**2
  490 continue
      SUM1=sqrt(SUM1/(KK+1))
** Optimierung beenden? (IFZMAX-Kriterium)
      if(IFZ.ge.IFZMAX) then
        IRET=12
        goto 500
      end if
      if(SUM1.ge.EPSF) goto 200
************************************************************************
  500 continue
      call FOPT(F,FC,FD,FR,Y,VOL,IRET)
      FMIN=F
      IFZ=IFZ+1
      if(IPR.ne.3) write(IOUT,114) F,SUM1,IFZ,(Y(I),I=1,KK)
      write(*,'(1x,a,i6,a,i3,a,1pe9.2,a,1pg11.4,a,0pf4.2)') 'IFZ=',IFZ,
     $                            ', IP=',ISORT(KK+1),', ALPHA=',ALPHA,
     $                                    ', F=',FMIN,', PC=',ATVOL/VOL
      if(IRET.eq.0) CSTOP='EPSF'
      if(IRET.eq.1.or.IRET.eq.2) CSTOP='FOPT'
      if(IRET.eq.12) CSTOP='IFZMAX'
      return
      end
      subroutine SIMANN(F,FC,FD,FR,IOPT,VMAX,NN,ILOOP,ILOOP2,CSTOP)
** Simulated annealing optimization
** See: R.J. Gdanitz, Chem. Phys. Lett. 190 (1992), 391-396
** or: N. Metropolis, A.W. Rosenbluth, M.N. Rosenbluth, A.H. Teller &
** E. Teller, J. Chem. Phys. 21 (1953), 1087-1092
** or
** Threshold Accepting optimization
** G. Dueck & T. Scheuer, J. Comput. Phys. 90 (1990), 161-175
** or
** Great Deluge optimization
** Gunter Dueck, J. Comput. Phys. 104 (1993), 86-92,
** Version 28.09.97
**
** Constants:
** KB      real   Boltzmannkonstante (kJ/K)
** NA      real   Avogadro's number (1/mol)
** Variables:
** X(I)    real   Parameters (vorgegeben)
** YT(I)   real   Test Parameters
** YMIN(I) real   bisher optimale Parameters
** Y(I)    real   Parameters (optimiert)
** F       real   Zielfunktionswert
** F1      real   letzter akzeptierter Zielfunktionswert
** F2      real   aktueller Zielfunktionswert
** FMIN    real   bisher minimaler Zielfunktionswert
** ITER    int    bisherige Zahl von aufeinanderfolgenden Erfolgen
** ITMAX   int    maximale Zahl von aufeinanderfolgenden Misserfolgen (d.h.,
**                Versuche ohne Verbesserung des Funktionswerts) (def.: 500)
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 10000)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabeparameter und Endergebnis
**                2: wie 1, zusaetzlich Endergebnisse von jedem
**                   Zyklus (konstantes T)
**                3: keine Ausgabe
**                4: wie 1, zusaetzlich Ergebnisse jeder Iteration bei
**                   der das bisherige Optimum untertroffen wird.
** IOUT    int    Ausgabeeinheit (def.: 2)
** IOPT    int    0: Simulated Annealing
**                1: Threshold Accepting
**                2: Great Deluge
** EPSX    real   Test fuer min. Schrittweite fuer Parameter (def.: 1e-4)
** TSTART  real   Temperature/energy level to start optimization with
** TEND    real   optimization will be stopped if T is lower or equal to TEND
** IRET    int    -1: Function value not defined
**                1,2: Abbruch der Optimierung durch FOPT
**                 9: Abbruch durch EPSX
**                10: Abbruch durch TEND
**                11: Abbruch durch ITMAX
**                12: Abbruch durch IFZMAX
** IFZ     int    Zahl der bisherigen Zielfunktionsauswertungen
** IFZ2    int    Zahl der bisherigen Zielfunktionsauswertungen seit des
**                letzten Erreichens eines neuen Minimums oder der letzten
**                Temperatursenkung
** VL(I)   real   aktuelle max. Schrittweite fuer Parameter Nr. I
**
** Unterprogramme:
** FOPT: Zielfunktion
** RAN2: Random Number Generator
************************************************************************

      implicit real(a-h,o-z)
      real KB,NA
      parameter(KB=1.380662e-26, NA=6.022045e23, NV=36)
      real X(NV),Y(NV),YT(NV),YMIN(NV),VL(NV),VLMIN(NV),VMAX(NV)
      real F,FC,FD,FR,FMIN,FCMIN,FDMIN,FRMIN
      real ATVOL,EPSX,TSTART,TEND,TDEC
      real RPA(25)
      integer IPA(25)
      double precision RAN2
      character CT*4,CSTOP*6
      common/OPTI/ KK,X,Y,IPA,RPA,ATVOL
      ITMAX=IPA(1)
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      IVAR=IPA(5)
      EPSX=RPA(1)
      TSTART=RPA(2)
      TEND=RPA(4)
      if(IOPT.eq.0) then
        TDEC=0.9
        CT='T='
      else if(IOPT.eq.1) then
        TDEC=0.9
        CT='TH='
      else
        TDEC=(TEND-TSTART)/20
        CT='LEV='
      end if
      NL=0
      F=1.11111e-11
      FVAR1 = 2.0**(0.5/KK)
      FVAR2 = 3.0**(0.5/KK)
      IRET=0
      ITER=0
** function call F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      F1=F0
      FMIN=F0
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      VOLMIN=VOL
      IFZ=0
** copy parameter set to Y and YMIN
      do 20 I=1,KK
        Y(I)=X(I)
        YMIN(I)=X(I)
   20 continue
** initialize VL
      VLMAX=0.0
      do 30 I=1,KK
        VL(I)=VMAX(I)
        if(IVAR.ne.0) VL(I)=VL(I)/10.0
        VLMIN(I)=VL(I)
        if(VL(I).gt.VLMAX) VLMAX=VL(I)
   30 continue
      if(IPR.ne.3) then
        if(IOPT.eq.0) then
          write(IOUT,'(/a)') ' ** Simulated Annealing Optimization **'
        else if(IOPT.eq.1) then
          write(IOUT,'(/a)') ' ** Threshold Accepting Optimization **'
        else if(IOPT.eq.2) then
          write(IOUT,'(/a)') ' ** Great Deluge Optimization **'
          write(IOUT,71) 'ITMAX','IFZMAX','IOUT',ITMAX,IFZMAX,IPR,
     $                   'EPSX','LEVEL1','LEVEL2','VLMAX',
     $                   EPSX,TSTART,TEND,VLMAX
        end if
        if(IOPT.eq.0.or.IOPT.eq.1) then
          write(IOUT,71) 'ITMAX','IFZMAX','IOUT',ITMAX,IFZMAX,IPR,
     $                   'EPSX','TSTART','TEND','VLMAX',
     $                   EPSX,TSTART,TEND,VLMAX
        end if
   71   format(//3a10/3i10//4a12/4(1pe12.3))
      end if
      if(IPR.eq.2.or.IPR.eq.4) then
        write(IOUT,'(a)') 'Maximum variation of variables:'
        write(IOUT,'(6(1pe12.3))') (VL(I),I=1,KK)
      end if
**      if(IRET.ne.0) goto 500
      IRET=0
      T=TSTART
      if(IPR.ne.3.and.IOPT.eq.0) write(IOUT,'(/1x,a12,2a9,a5,a12)')
     $                             'F(X)','T[K]','VLMAX','IFZ','X(1)...'
      if(IPR.ne.3.and.IOPT.gt.0) write(IOUT,'(/1x,a12,2a9,a5,a12)')
     $                       'F(X) ','T[kJ/mol]','VLMAX','IFZ','X(1)...'
      if(IPR.ne.3) write(IOUT,491) F0,T,VLMAX,IFZ,(X(I),I=1,KK)

** Start of the iteration loop:
** SIMULATED ANNEALING (IOPT=0):
** The temperature is lowered , i.e. T is multiplied by TDEC if
** a) the number of unsuccessful trials without reducing F, ITER, is greater 
**    than ITMAX, 
** b) the number of trials without finding a new optimum, IFZ2, is greater 
** than ITMAX*3. 
** In the case of b) iteration will be continued using the old optimum
** parameters. 
** During this cooling process the value of the maximum
** displacement VL(I) is multiplied by FVAR2, if the trial function has been
** accepted (in the case of VL(I)=VMAX(I), VL(I) is not changed), otherwise 
** it is divided by FVAR1. If VLMAX<EPSX, the crystal is considered "frozen"
** and the simulation is finished.
** If IVAR<>0 then VL(I) will not be changed.
** THRESHOLD ACCEPTING (IOPT=1):
** The threshold is lowered , i.e. T is multiplied by TDEC if
** a) the number of unsuccessful trials without reducing F, ITER, is greater 
**    than ITMAX, 
** b) the number of trials without finding a new optimum, IFZ2, is greater 
** than ITMAX*3. 
** In the case of b) iteration will be continued using the old optimum
** parameters. During this process the value of the maximum
** displacement VL(I) is multiplied by FVAR2, if the trial function has been
** accepted (in the case of VL(I)=VMAX(I), VL(I) is not changed), otherwise 
** it is divided by FVAR1. If VLMAX<EPSX, the crystal is considered "frozen"
** and the simulation is finished.
** If IVAR<>0 then VL(I) will not be changed.
** GREAT DELUGE (IOPT=2):
** The energy level is lowered , i.e. TDEC is substracted from T if
** a) the number of unsuccessful trials without reducing F, ITER, is greater 
**    than ITMAX, 
** b) the number of trials without finding a new optimum, IFZ2, is greater 
** than ITMAX*3. 
** In the case of b) iteration will be continued using the old optimum
** parameters. During this process the value of the maximum
** displacement VL is multiplied by FVAR2, if the trial function has been
** accepted (in the case of VL=1.0, VL is not changed), otherwise it is
** divided by FVAR1. If VLMAX<EPSX, the simulation is finished.
** If IVAR<>0 then VL(I) will not be changed.
  300 continue
      ITER=0
      IFZ2=0
      write(IOUT,*)

  400 continue
** perturbation of the old conformation
      VARMX=0.0
      do 420 I=1,KK
        VARY=(RAN2(NN)-.5)*VL(I)
        YT(I)=Y(I)+VARY
        if(abs(VARY).gt.VARMX) then
          VARMX=abs(VARY)
        end if
  420 continue
      IFZ=IFZ+1
      IFZ2=IFZ2+1
** function call F(YT)
      call FOPT(F2,FC,FD,FR,YT,VOL,IRET)
      if(IFZ.gt.IFZMAX) then
        IRET=12
        goto 500
      end if
      if(IRET.eq.-1) goto 400
      EXPKB=0.0
      if(IOPT.eq.0.and.abs(F2-F1)/(NA*KB*T).lt.70) then
        EXPKB=exp(-(F2-F1)/(NA*KB*T))
      end if
**   accept trial function because F value is lower than last F value
      if(F2.lt.F1) then
        do 450 I=1,KK
          Y(I)=YT(I)
  450   continue
        F1=F2
        if(F2.lt.FMIN) then
          FMIN=F2
          FCMIN=FC
          FDMIN=FD
          FRMIN=FR
          VOLMIN=VOL
          IFZ2=0
          do 430 I=1,KK
            YMIN(I)=YT(I)
            VLMIN(I)=VL(I)
  430     continue
          if(mod(NL,16).eq.0.and.IOPT.eq.0) write(*,'(1x,a,i7,2(a,i3))')
     $      'Simulated Annealing, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.1) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Threshold Accepting, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.2) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Great Deluge, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i7,a,1pg12.4,a,1pg10.3,a,1pg13.5,a,0pf4.2)') 
     $            'IFZ=',IFZ,', '//CT, T, ', VLMAX=',VLMAX,', F=',FMIN,
     $            ', PC=',ATVOL/VOLMIN
          if(IPR.eq.4) write(IOUT,491) F2,T,VLMAX,IFZ,(Y(I),I=1,KK)
        end if
        do 440 I=1,KK
          if(VL(I).lt.VMAX(I).and.IVAR.eq.0) VL(I)=VL(I)*FVAR2
  440   continue
        ITER=0
        if(IFZ2.gt.ITMAX*3) then
          if(IOPT.le.1) T=T*TDEC
          if(IOPT.eq.2) T=T+TDEC
          if(mod(NL,16).eq.0.and.IOPT.eq.0) write(*,'(1x,a,i7,2(a,i3))')
     $      'Simulated Annealing, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.1) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Threshold Accepting, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.2) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Great Deluge, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i7,a,1pg12.4,a,1pg10.3,a,1pg13.5,a,0pf4.2)')
     $            'IFZ=',IFZ,', '//CT,T, ', VLMAX=',VLMAX,', F=',FMIN,
     $            ', PC=',ATVOL/VOLMIN
          if(IPR.eq.2) write(IOUT,491) F2,T,VLMAX,IFZ,(Y(I),I=1,KK)
          if(T.lt.TEND) then
            IRET=10
            goto 500
          end if
          if(IFZ2.gt.ITMAX*3) then
            do 485 I=1,KK
              Y(I)=YMIN(I)
              VL(I)=VLMIN(I)
  485       continue
            F=FMIN
          end if
          ITER=0
          IFZ2=0
        end if
**   accept trial function despite higher F value (0)
      else if((EXPKB.gt.RAN2(NN).and.IOPT.eq.0).or.
     $       (F2.lt.F1+T.and.IOPT.eq.1).or.(F2.lt.T.and.IOPT.eq.2)) then
        do 460 I=1,KK
          Y(I)=YT(I)
  460   continue
        F1=F2
        ITER=ITER+1
        if(ITER.gt.ITMAX.or.IFZ2.gt.ITMAX*3) then
          if(IOPT.le.1) T=T*TDEC
          if(IOPT.eq.2) T=T+TDEC
          if(mod(NL,16).eq.0.and.IOPT.eq.0) write(*,'(1x,a,i7,2(a,i3))')
     $      'Simulated Annealing, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.1) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Threshold Accepting, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.2) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Great Deluge, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i7,a,1pg12.4,a,1pg10.3,a,1pg13.5,a,0pf4.2)') 
     $            'IFZ=',IFZ,', '//CT,T, ', VLMAX=',VLMAX,', F=',FMIN,
     $            ', PC=',ATVOL/VOLMIN
          if(T.lt.TEND) then
            IRET=10
            goto 500
          end if
          if(IFZ2.gt.ITMAX*3) then
            do 470 I=1,KK
              Y(I)=YMIN(I)
              VL(I)=VLMIN(I)
  470       continue
            F=FMIN
          end if
          if(IPR.eq.2) write(IOUT,491) F,T,VLMAX,IFZ,(Y(I),I=1,KK)
          ITER=0
          IFZ2=0
        end if
      else

**   do not accept trial function      
        ITER=ITER+1
        if(ITER.gt.ITMAX.or.IFZ2.gt.ITMAX*3) then
          if(IOPT.le.1) T=T*TDEC
          if(IOPT.eq.2) T=T+TDEC
          if(mod(NL,16).eq.0.and.IOPT.eq.0) write(*,'(1x,a,i7,2(a,i3))')
     $      'Simulated Annealing, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.1) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Threshold Accepting, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/'
     $      ,ILOOP2
          if(mod(NL,16).eq.0.and.IOPT.eq.2) write(*,'(1x,a,i7,2(a,i3))') 
     $      'Great Deluge, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
          NL=NL+1
          write(*,'(1x,a,i7,a,1pg12.4,a,1pg10.3,a,1pg13.5,a,0pf4.2)') 
     $            'IFZ=',IFZ,', '//CT, T,', VLMAX=',VLMAX,', F=',FMIN,
     $            ', PC=',ATVOL/VOLMIN
          if(T.lt.TEND) then
            IRET=10
            goto 500
          end if
          if(IFZ2.gt.ITMAX*3) then
            do 480 I=1,KK
              Y(I)=YMIN(I)
              VL(I)=VLMIN(I)
  480       continue
            F=FMIN
          end if
          if(IPR.eq.2) write(IOUT,491) F,T,VLMAX,IFZ,(Y(I),I=1,KK)
  491     format(1x,1pg12.4,1pg9.3,1pe10.3,i7,2x,3(1pe12.5,:)/
     $          (41x,3(1pe12.5,:)))
          ITER=0
          IFZ2=0
        end if
        do 490 I=1,KK
          if(IVAR.eq.0) VL(I)=VL(I)/FVAR1
  490   continue
      end if
      VLMAX=0.0
      do 495 I=1,KK
        if(VL(I).gt.VLMAX) VLMAX=VL(I)
  495 continue
      if(VLMAX.gt.EPSX) goto 400

      IRET=9
  500 continue
      do 510 I=1,KK
        Y(I)=YMIN(I)
  510 continue
      F=FMIN
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      if(IPR.ne.3) write(IOUT,491) F,T,VLMAX,IFZ,(Y(I),I=1,KK)
      IPA(14)=IRET
      IPA(15)=IFZ
      if(IRET.eq.-1) write(IOUT,*) 'value of function not defined'
      if(IRET.eq.-1) write(*,*) 'value of function not defined'
      if(IRET.ge.1.and.IRET.le.3) CSTOP='FOPT'
      if(IRET.eq.9) CSTOP='EPSX'
      if(IRET.eq.10) CSTOP='TEND'
      if(IRET.eq.12) CSTOP='IFZMAX'
      return
      end
*
      subroutine MELT(F,FC,FD,FR,VMAX,NN,ILOOP,ILOOP2,CSTOP)
** "Melting" of the structure
** Siehe: R.J. Gdanitz, Chem. Phys. Lett. 190 (1992), 391-396
** oder: N. Metropolis, A.W. Rosenbluth, M.N. Rosenbluth, A.H. Teller &
** E. Teller, J. Chem. Phys. 21 (1953), 1087-1092
** Version 09.01.97
**
** Konstanten:
** KB      real   Boltzmannkonstante (kJ/K)
** NA      real   Avogadro's number (1/mol)
** Variablen:
** X(I)    real   Parameters (vorgegeben)
** YT(I)   real   Test Parameters
** Y(I)    real   Parameters (optimiert)
** DTEMP   real   Temperaturabnahme pro Schritt
** F       real   Zielfunktionswert
** F1      real   letzter akzeptierter Zielfunktionswert
** F2      real   aktueller Zielfunktionswert
** ITER    int    bisherige Zahl von aufeinanderfolgenden Erfolgen
** IFZMAX  int    maximale Zahl von Zielfunktionswerten
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabewert und Endergebnis
**                2: wie 1, zusaetzlich Ergebnisse jeder Iteration
**                   die neues Optimum erzielt
**                3: keine Ausgabe
**                4: wie 1, zusaetzlich Ergebnisse jeder Iteration mit 
**                   kleinerem Zielfunktionswerte als bei vorherigem 
**                   Parametersatz
** IOUT    int    Ausgabeeinheit (def.: 2)
** IRET    int    -1: Funktionswert nicht definiert
**                1,2: Abbruch der Optimierung durch FOPT
**                11: Abbruch durch ITMAX
**                12: Abbruch durch IFZMAX
** IFZ     int    Zahl der bisherigen Zielfunktionsauswertungen
** IFZ2    int    Zahl der bisherigen Zielfunktionsauswertungen seit des
**                letzten Erreichens eines neuen Minimums oder der letzten
**                Temperatursenkung
**
** Unterprogramme:
** FOPT: Zielfunktion
** RAN2: Random Number Generator
************************************************************************

      implicit real(a-h,o-z)
      real KB,NA
      parameter(KB=1.380662e-26, NA=6.022045e23, NV=36)
      real X(NV),Y(NV),YT(NV),RPA(25),VL(NV),VMAX(NV)
      integer IPA(25)
      double precision RAN2
      character CSTOP*6
      common /OPTI/ KK,X,Y,IPA,RPA,ATVOL
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      DTEMP=-.05
      TSTART=1000.
      F=1.11111e-11
      IRET=0
      ITER=0
** initialize VL
      VLMAX=0.0
      do 30 I=1,KK
        VL(I)=VMAX(I)
        if(VL(I).gt.VLMAX) VLMAX=VL(I)
   30 continue
** function call F(X)
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      F1=F0
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      write(*,'(1x,a,i8,a,i3,a,i3)') 
     $          'Melting, IFZMAX=',IFZMAX,', loop no.',ILOOP,'/',ILOOP2
      if(IPR.ne.3) then
        write(IOUT,71) 'IOUT','IFZMAX','DTEMP','TSTART',
     $                 IPR,IFZMAX,DTEMP,TSTART
   71   format(/' ** Melting **'//2a10,2a12/2i10,2(1pg12.3))
      end if
      IFZ=0
** copy parameter set to Y
      do 80 I=1,KK
        Y(I)=X(I)
   80 continue
      if(IRET.lt.0.or.IRET.gt.3) goto 500
      if(IPR.ne.3) write(IOUT,'(/1x,a12,2a9,a5,a12)') 'F(X)','T[K]',
     $                                          'VARMAX','IFZ','X(1)...'
      T=TSTART
      IRET=0
      if(IPR.ne.3) write(IOUT,491) F0,T,VARMX,IFZ,(X(I),I=1,KK)

** Start of Iteration Loop:
** Starting with a temperature of TSTART, K and a maximum allowed displacement
** of VARMX, after each generation of a trial configuration, T is multiplied
** by 1.05 until the crystal is considered "molten", i.e. 10 consecutive
** trials, including the initial conformation, have been accepted.
  200 continue
** perturbation of the old conformation
      VARMX=0.0
      do 420 I=1,KK
        VARY=(RAN2(NN)-.5)*VL(I)
        YT(I)=Y(I)+VARY
        if(abs(VARY).gt.VARMX) then
          VARMX=abs(VARY)
        end if
  420 continue
      IFZ=IFZ+1
** function call F(YT)
      call FOPT(F2,FC,FD,FR,YT,VOL,IRET)
      if(IFZ.gt.IFZMAX) then
        IRET=12
        goto 500
      end if
      if(IRET.ne.0) goto 200
      if(F2.lt.F1) then
        do 260 I=1,KK
          Y(I)=YT(I)
  260   continue
        F1=F2
        FCMIN=FC
        FDMIN=FD
        FRMIN=FR
        if(IPR.eq.2.or.IPR.eq.4) 
     $                    write(IOUT,491) F1,T,VARMX,IFZ,(Y(I),I=1,KK)
        ITER=ITER+1
      else if(exp(-(F2-F1)/(NA*KB*T)).gt.RAN2(NN)) then
        do 280 I=1,KK
          Y(I)=YT(I)
  280   continue
        F1=F2
        FCMIN=FC
        FDMIN=FD
        FRMIN=FR
        if(IPR.eq.4) write(IOUT,491) F1,T,VARMX,IFZ,(Y(I),I=1,KK)
        ITER=ITER+1
      else
        ITER=0
      end if
      T=T*1.05
      if(ITER.lt.10) goto 200
      IRET=11
** End of Iteration loop
  
  500 continue
      F=F1
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      if(IPR.ne.3) write(IOUT,491) F,T,VARMX,IFZ,(Y(I),I=1,KK)
  491   format(1x,1pe12.4,2(1pe9.1),i7,3(1pe12.5,:)/
     $        (38x,3(1pe12.5,:)))
      IPA(14)=IRET
      IPA(15)=IFZ
      if(IRET.eq.-1) write(IOUT,*) 'value of function not defined'
      if(IRET.eq.0) CSTOP='EPSX'
      if(IRET.ge.1.and.IRET.le.3) CSTOP='FOPT'
      if(IRET.eq.11) CSTOP='ITMAX'
      if(IRET.eq.12) CSTOP='IFZMAX'
      if(IRET.eq.-1) write(*,*) 'value of function not defined'
      return
      end

      subroutine GENALG(F,FC,FD,FR,VMAX,NN,ILOOP,ILOOP2,CSTOP)
** Genetic Algorithm optimization
** See: Y. Xiao & D.E. Williams (1993). Chem. Phys. Lett 215, 17-24.
** Version 18.2.97
**
** Constants:
** KB      real   Boltzmannkonstante (kJ/K)
** NA      real   Avogadro's number (1/mol)
** Variables:
** X(I)    real   Parameters (vorgegeben)
** YT(I)   real   Test Parameters
** Y(I)    real   Parameters (optimiert)
** F       real   Zielfunktionswert
** F2      real   aktueller Zielfunktionswert
** FMIN    real   bisher minimaler Zielfunktionswert
** IPMAX   int    maximale Groesse der Population
** IFZMAX  int    maximale Zahl von Zielfunktionswerten (def.: 10000)
** IPR     int    Steuerung der Ausgabe von Ergebnissen
**                1: Eingabeparameter und Endergebnis
**                2: wie 1, zusaetzlich Endergebnisse von jeder Generation
**                3: keine Ausgabe
**                4: wie 1, zusaetzlich Energien von jedem Individuum
** IOUT    int    Ausgabeeinheit (def.: 2)
** IRET    int    -1: Function value not defined
**                1,2: Abbruch der Optimierung durch FOPT
**                 9: Abbruch durch EPSX
**                10: Abbruch durch TEND
**                11: Abbruch durch ITMAX
**                12: Abbruch durch IFZMAX
** IFZ     int    Zahl der bisherigen Zielfunktionsauswertungen
** VL(I)   real   aktuelle max. Schrittweite fuer Parameter Nr. I
**
** Unterprogramme:
** FOPT: Zielfunktion
** RAN2: Random Number Generator
************************************************************************

      implicit real(a-h,o-z)
      real KB,NA
      parameter(KB=1.380662e-26, NA=6.022045e23, NV=36)
      real X(NV),Y(NV),YT(NV),VL(NV),VMAX(NV)
      real GX(100,NV),GF(100)
      real F,FC,FD,FR,FMIN,FCMIN,FDMIN,FRMIN, VARY
      real ATVOL
      real RPA(25)
      integer IPA(25)
      double precision RAN2
      character CSTOP*6
      common/OPTI/ KK,X,Y,IPA,RPA,ATVOL
      IGNMAX=IPA(1)
      IFZMAX=IPA(2)
      IPR=IPA(3)
      IOUT=IPA(4)
      IPMAX=IPA(6)
      RMUTAT=RPA(1)
      NL=0
      NDEATH=0
      NBIRTH=0
      IRET=0
** function call F(X)
      IFZ=1
      call FOPT(F,FC,FD,FR,X,VOL,IRET)
      F0=F
      FMIN=F0
      FCMIN=FC
      FDMIN=FD
      FRMIN=FR
      VOLMIN=VOL
** copy parameter set to Y
      do 20 I=1,KK
        Y(I)=X(I)
   20 continue
** initialize VL
      VLMAX=0.0
      do 30 I=1,KK
        VL(I)=VMAX(I)
        if(VL(I).gt.VLMAX) VLMAX=VL(I)
   30 continue
      if(IPR.ne.3) then
          write(IOUT,'(/a)') ' ** Genetic Algorithm Optimization **'
          write(IOUT,71) 'IPMAX','IFZMAX','IOUT','IGNMAX','MUTAT',
     $                    IPMAX,IFZMAX,IPR,IGNMAX,RMUTAT
   71   format(//5a10/4i10,f10.3//)
      end if
      if(IPR.eq.2.or.IPR.eq.4) then
        write(IOUT,'(a)') 'Maximum variation of variables (mutation):'
        write(IOUT,'(6(1pe12.3))') (VL(I)*RMUTAT,I=1,KK)
      end if
      FMIN=1e30
      FMAX=-1e30
      IRET=0
      IGEN=1
      IFZ=0
      if(IPR.ne.3) write(IOUT,'(/1x,a12,2a4,3a7,a12)')
     $         'F(X)','IG','NP','NDEATH','NBIRTH',' IFZ ','X(1)...'
** create first generation of IPMAX individuals
      do 410 K=1,IPMAX
        IL=0
  415   continue
        do 420 I=1,KK
          VARY=(RAN2(NN)-.5)*VL(I)
          YT(I)=Y(I)+VARY
          GX(K,I)=YT(I)
  420   continue
        IFZ=IFZ+1
** function call F(YT)
        call FOPT(F2,FC,FD,FR,YT,VOL,IRET)
** try up to 10 times to find a valid structure
        if(IRET.ne.0.and.IFZ.le.IFZMAX.and.IL.lt.10) then
          IL=IL+1
          goto 415
        end if
        GF(K)=F2
        if(F2.lt.FMIN) then
          FMIN=F2
          FCMIN=FC
          FDMIN=FD
          FRMIN=FR
          IMIN=K
          VOLMIN=VOL
        end if
        if(F2.gt.FMAX.and.F2.lt.1e30) then
          FMAX=F2
        end if
  410 continue
      NPOP=IPMAX
      if(IPR.ne.3) write(IOUT,491) FMIN,IGEN,NPOP,NDEATH,NBIRTH,IFZ,
     $                             (GX(IMIN,I),I=1,KK)
  491 format(1x,1pg12.4,2i4,3i7,3(1pe12.5,:)/(42x,3(1pe12.5,:)))
      if(IPR.eq.4) write(IOUT,'(6(1pe12.4,:))') (GF(K),K=1,IPMAX)
      write(*,'(1x,a,i7,a,i5,a,i4,a,1pg13.5,a,0pf4.2)') 
     $            'IFZ=',IFZ,', IGEN=', IGEN, ', NPOP=',NPOP,
     $            ', F=',FMIN,', PC=',ATVOL/VOLMIN

** Start of the iteration loop:

  400 continue
      IGEN=IGEN+1
      if(IGEN.gt.IGNMAX) then
        IRET=10
        goto 600
      end if
      if(IFZ.gt.IFZMAX) then
        IRET=12
        goto 600
      end if
      if(IRET.eq.-1) goto 400
**   go through all the population and decide between
**   a) Death: the individual will die or
**   b1) Birth (crossing-over): two individuals will create a child
**   b2) Birth (no crossing-over): one individual will create a child

** a) Death **
      IDEAD=0
      NDEATH=0
      do 450 K=1,IPMAX
        if(GF(K).ge.1e30) then
          IDEAD=K
          goto 450
        end if
        if(GF(K)-FMIN.gt.1000.0) then
          EXPKB=1e-10
        else
          EXPKB=exp(-(GF(K)-FMIN)/(NA*KB*1000))
        end if
        if(RAN2(NN).lt.(1.0-EXPKB)*NPOP/real(IPMAX)) then
          if(GF(K).ge.FMAX) then
            FMAX=-1e30
            do 460 J=1,IPMAX
              if(J.ne.K.and.GF(J).gt.FMAX.and.GF(J).lt.1e30) FMAX=GF(J)
  460       continue
          end if
          GF(K)=1e30
          IDEAD=K
          NPOP=NPOP-1
          NDEATH=NDEATH+1
        end if
  450 continue
** b) Birth (1: crossing-over, 2: no crossing-over)
      NBIRTH=0
      if(NPOP.lt.IPMAX) then
        do 520 I=1,10
          IDEAD=0
          do 500 K=1,IPMAX
            if(GF(K).ge.1e30) then
              IDEAD=K
              goto 500
            end if
  500     continue
          if(IDEAD.eq.0) goto 520
          K1=RAN2(NN)*IPMAX+1
          if(RAN2(NN).lt.0.5) then
            K2=RAN2(NN)*IPMAX+1
          else
            K2=K1
          end if
          if(GF(K1)-FMIN.gt.1000.0) then
            EXPKB1=1e-10
          else
            EXPKB1=exp(-(GF(K1)-FMIN)/(NA*KB*1000))
          end if
          if(GF(K2)-FMIN.gt.1000.0) then
            EXPKB2=1e-10
          else
            EXPKB2=exp(-(GF(K2)-FMIN)/(NA*KB*1000))
          end if
          if(RAN2(NN).gt.(1.0-EXPKB1)*(1.0-EXPKB2)*NPOP/(2.0*IPMAX).and.
     $                                          IDEAD.ne.0) then
            IL=0
  505       continue
            do 510 J=1,KK
              VARY=(RAN2(NN)-.5)*VL(J)*RMUTAT
              RN=RAN2(NN)
              if(RN.lt.0.25) then
                YT(J)=GX(K1,J)+VARY
              else if(RN.lt.0.50) then
                YT(J)=GX(K2,J)+VARY
              else
                YT(J)=(GX(K1,J)+GX(K2,J))/2.0+VARY
              end if
              GX(IDEAD,J)=YT(J)
  510       continue
** function call F(YT)
            IFZ=IFZ+1
            call FOPT(F2,FC,FD,FR,YT,VOL,IRET)
** try up to 10 times to find a valid structure
            if(IRET.ne.0.and.IFZ.le.IFZMAX.and.IL.lt.10) then
              IL=IL+1
              goto 505
            end if
            GF(IDEAD)=F2
            if(F2.lt.FMIN) then
              FMIN=F2
              FCMIN=FC
              FDMIN=FD
              FRMIN=FR
              IMIN=IDEAD
              VOLMIN=VOL
              if(IPR.ne.3) write(IOUT,491) FMIN,IGEN,NPOP,NDEATH,NBIRTH,
     $                                     IFZ,(GX(IMIN,J),J=1,KK)
              if(mod(NL,16).eq.0) write(*,'(1x,a,i7,a,i5,a,i3,a,i3)') 
     $          'Genetic algorithm, IFZMAX=',IFZMAX,' IGNMAX=',IGNMAX,
     $          ', loop no.',ILOOP,'/',ILOOP2
              NL=NL+1
              write(*,'(1x,a,i7,a,i5,a,i4,a,1pg13.5,a,0pf4.2)') 
     $            'IFZ=',IFZ,', IGEN=', IGEN, ', NPOP=',NPOP,
     $            ', F=',FMIN,', PC=',ATVOL/VOLMIN
            end if
            if(F2.gt.FMAX.and.F2.lt.1e30) then
              FMAX=F2
            end if
            if(F2.lt.1e30) then
              NPOP=NPOP+1
              NBIRTH=NBIRTH+1
            end if
            IDEAD=0
          end if
  520   continue
      end if
**
      if(IPR.eq.2.or.IPR.eq.4) write(IOUT,491) FMIN,IGEN,NPOP,NDEATH,
     $                                 NBIRTH,IFZ,(GX(IMIN,I),I=1,KK)
      if(IPR.eq.4) write(IOUT,'(6(1pg12.4,:))') (GF(K),K=1,IPMAX)
      goto 400

  600 continue

      do 610 I=1,KK
        Y(I)=GX(IMIN,I)
  610 continue
      F=FMIN
      FC=FCMIN
      FD=FDMIN
      FR=FRMIN
      if(IPR.ne.3) write(IOUT,491) FMIN,IGEN,NPOP,NDEATH,NBIRTH,IFZ,
     $                             (Y(I),I=1,KK)
      if(IPR.eq.4) write(IOUT,'(6(1pg12.4,:))') (GF(K),K=1,IPMAX)
      IPA(14)=IRET
      IPA(15)=IFZ
      if(IRET.eq.-1) write(IOUT,*) 'value of function not defined'
      if(IRET.eq.-1) write(*,*) 'value of function not defined'
      if(IRET.ge.1.and.IRET.le.3) CSTOP='FOPT'
      if(IRET.eq.10) CSTOP='IGNMAX'
      if(IRET.eq.12) CSTOP='IFZMAX'
      return
      end
